@@ -16,6 +16,10 @@ module.exports = {
         document: false,
         console: false,
         localStorage: false,
+        Blob: false,
+        atob: false,
+        ArrayBuffer: false,
+        Uint8Array: false,
 
         // browser classes
         HTMLElement: false,
