@@ -20,33 +20,32 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/baseframework/view/baselabels',
     'less!io.ox/office/baseframework/view/basestyle'
-], function (ext, Utils, Config, Forms, Scheduler, DriveUtils) {
+], function (ext, Utils, Config, Forms, Scheduler, DriveUtils, Labels) {
 
     'use strict';
 
-    // mix-in class ApplicationWindow==========================================
+    // private global functions ===============================================
 
     /**
      * Creates and initializes an application window for an application with
      * the specified module name.
      *
-     * @param {String} moduleName
-     *  The application module name.
+     * @param {ox.ui.App} app
+     *  The application to create the window for.
      *
-     * @param {Object} [launchOptions]
-     *  Optional parameters controlling the creation of the ox.ui.App base
+     * @param {jQuery} [rootNode]
+     *  The root application node to embed the window into.
      *
      * @returns {ox.ui.Window}
      *  The application window.
      */
-    function createAppWindow(moduleName, launchOptions) {
-
-        // the root node for the window
-        var page = Utils.getOption(launchOptions, 'page', null);
+    function createAppWindow(app, rootNode) {
 
         // create the core application window
-        var appWindow = ox.ui.createWindow({ name: moduleName, search: false, chromeless: true, page: page });
+        var appWindow = ox.ui.createWindow({ name: app.getName(), search: false, chromeless: true, page: rootNode });
+        app.setWindow(appWindow);
 
         // bug 53506: track whether the busy mode is currently active
         var isBusy = false;
@@ -85,6 +84,14 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
                         headerNode.append($('<div class="clear-title">').text(topLabel));
                     }
 
+                    // bug 59041: add a custom quit button (no quit button anymore on top-bar application tabs)
+                    var quitButton = $(Forms.createButtonMarkup(Labels.QUIT_BUTTON_OPTIONS));
+                    quitButton.addClass('quit-button').on('click', function () {
+                        app.trigger('docs:busy:quit'); // 53941 -> quit button calls cancel handler
+                        app.quit();
+                    });
+                    headerNode.append(quitButton);
+
                     // on IE, remove stripes (they are displayed too nervous and flickering)
                     if (_.browser.IE) {
                         blockerNode.find('.progress-striped').removeClass('progress-striped');
@@ -288,8 +295,7 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
             });
 
             // create and initialize the application window
-            var appWindow = createAppWindow(moduleName, launchOptions);
-            app.setWindow(appWindow);
+            var appWindow = createAppWindow(app, Utils.getOption(launchOptions, 'page'));
 
             // special handling for smatphones, make sure the Portal window is closed when a Documents app is launched - bug #57537
             if (_.device('smartphone')) {
