@@ -605,10 +605,21 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 //
                 // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
                 // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
-                if (document.isNonConvertibleContent) {
+                //
+                // bugfix Bug #58768 - "Misleading alert for empty 'document content as email"
+                // Follow up for Bug #58402.
+                //
+                if (document.isNotConvertible) {
+                    var isEmptyDocument = document.isEmpty;
 
-                    var dialogTitle = gt('Non convertible document content');
-                    var dialogMessage = gt('This document contains elements that cannot be sent in an email. Do you want to send this document as email content?');
+                    var dialogTitle = (
+                        (isEmptyDocument && gt('Empty document'))
+                        || gt('Non convertible document content')
+                    );
+                    var dialogMessage = (
+                        (isEmptyDocument && gt('This document is empty. Do you want to send this document as email content?'))
+                        || gt('This document contains elements that cannot be sent in an email. Do you want to send this document as email content?')
+                    );
                     var dialog = new Dialogs.QueryDialog(self, dialogMessage, { title: dialogTitle });
 
                     // show the dialog, open mail compose
