@@ -99,6 +99,8 @@ define('io.ox/office/baseframework/app/basecontroller', [
         this.cancelable = Utils.getBooleanOption(definition, 'cancel', false);
         // whether an asynchronous setter does not block the controller
         this.nonblocking = Utils.getBooleanOption(definition, 'nonblocking', false);
+        // whether the setter does not cuase a controller update
+        this.silent = Utils.getBooleanOption(definition, 'silent', false);
         // behavior for returning browser focus to application
         this.preserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false);
         // custom focus target node or callback handler
@@ -121,6 +123,12 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
     // private methods  -------------------------------------------------------
 
+    ControllerItem.prototype._updateController = function () {
+        if (!this.silent) {
+            this.controller.update();
+        }
+    };
+
     /**
      * Returns the state descriptor of the specified parent item.
      */
@@ -259,7 +267,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // show busy screen if setter is running asynchronously
             // (but not for modal dialogs which have their own blocker overlay)
             pending = !this.nonblocking && (promise.state() === 'pending');
-            if (pending && !Dialogs.isModalDialogOpen()) {
+            if (pending && !Dialogs.isDialogOpen()) {
                 var showCancel = this.cancelable && _.isFunction(promise.abort);
                 docView.enterBusy({ cancelHandler: showCancel ? function () { promise.abort(); } : null });
             }
@@ -285,11 +293,11 @@ define('io.ox/office/baseframework/app/basecontroller', [
         if (pending) {
             this.waitForAny(promise, function () {
                 docView.leaveBusy();
-                controller.update();
+                this._updateController();
                 Utils.logSelenium(this.key, promise.state());
             }, this);
         } else {
-            controller.update();
+            this._updateController();
         }
 
         return promise;
@@ -583,6 +591,9 @@ define('io.ox/office/baseframework/app/basecontroller', [
          *  @param {Boolean} [definition.nonblocking=false]
          *      If set to true, the promise returned by the setter function
          *      will be ignored. The busy blocker screen will NOT be shown.
+         *  @param {Boolean} [definition.silent=false]
+         *      If set to true, executing the item will not cause a controller
+         *      update.
          *  @param {Boolean} [definition.cancel=false]
          *      If set to true, and if the setter function of the item has
          *      returned a pending abortable promise, the busy blocker screen
@@ -764,8 +775,12 @@ define('io.ox/office/baseframework/app/basecontroller', [
          */
         this.update = (function () {
 
+            // whether a full update is required without using cached states (56005)
+            var fullUpdateRequired = false;
+
             // clear the entire cache state on every call of the update() method
-            function invalidateStates() {
+            function invalidateStates(fullUpdate) {
+                if (fullUpdate) { fullUpdateRequired = true; }
                 stateCache.clear();
                 createUpdateDeferred();
                 return this.getUpdatePromise();
@@ -805,11 +820,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
                 // reduce to the properties that differ from previous state
                 var changedStates = stateCache.omit(function (state, key) {
-                    if (key in dirtyKeys) { return false; }
+                    if (fullUpdateRequired || (key in dirtyKeys)) { return false; }
                     var prevState = notifiedStates.get(key, null);
                     return prevState && (prevState.enabled === state.enabled) && _.isEqual(prevState.value, state.value);
                 });
 
+                // return to partial update mode
+                fullUpdateRequired = false;
+
                 // bug 40770: store the values of the current cache for next update() call
                 notifiedStates = stateCache.clone(function (state) {
                     return { enabled: state.enabled, value: state.value };
@@ -980,7 +998,8 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // quit/destroy the application (do not return the promise,
             // otherwise this controller would wait for its own destruction)
             'app/quit': {
-                set: function () { _.defer(function () { app.quit(); }); }
+                set: function () { _.defer(function () { app.quit(); }); },
+                silent: true // bug 58409: no controller update when quitting
             },
 
             // disabled during import, enabled afterwards
@@ -1034,7 +1053,8 @@ define('io.ox/office/baseframework/app/basecontroller', [
             'document/sendmail/inline-html': {
                 parent: 'document/sendmail',
                 enable: function () { return app.canSendMail(); },
-                set: function (config) { return app.sendMail(config); }
+                set: function (config) { return app.sendMail(config); },
+                nonblocking: !!_.browser.Safari
             },
 
             'document/sendmail/pdf-attachment': {
@@ -1089,7 +1109,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            itemMap.forEach(function (item) { item.destroy(); });
+            itemMap.destroyElements();
             self = docModel = docView = null;
             itemMap = stateCache = notifiedStates = null;
             keyShortcuts = charShortcuts = null;
