@@ -14,16 +14,18 @@
 
 define('io.ox/office/baseframework/app/extensionregistry', [
     'io.ox/core/capabilities',
+    'io.ox/core/extensions',
+    'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/config'
-], function (Capabilities, Utils, Config) {
+    'io.ox/office/tk/utils/driveutils'
+], function (Capabilities, Ext, BaseConfig, Utils, DriveUtils) {
 
     'use strict';
 
     // which file formats are editable (maps format identifier to booleans)
     var EDITABLE_FILE_FORMATS = {
         ooxml: true,
-        odf: Config.getFlag('module/odfsupport', true)
+        odf: BaseConfig.getFlag('module/odfsupport', true)
     };
 
     // the extension suffix for files with an internal error
@@ -93,7 +95,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
                 ppt:  { format: 'ooxml', template: 'pot', macros: true, convert: true },
                 pps:  { format: 'ooxml', macros: true, convert: true }, // slide show
                 ppa:  { format: 'ooxml', macros: true, convert: true }, // add-in
-                odp:  { format: 'odf', template: 'otp', macros: true, editable: Config.getFlag('module/odpsupport', true) }
+                odp:  { format: 'odf', template: 'otp', macros: true, editable: BaseConfig.getFlag('module/odpsupport', true) }
             }
         }
     };
@@ -107,9 +109,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     // all configurations, mapped by lower-case extension
     var fileExtensionMap = {};
 
-    // can we edit guard protected documents?
-    var editGuardDocs = Capabilities.has('guard-docs');
-
     // private global functions ===============================================
 
     function registerFileExtension(extension, settings) {
@@ -162,16 +161,13 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  registered for the extension of the passed file name. If omitted, the
      *  edit application module name for the extension will be ignored.
      *
-     *  @param {Boolean} ignoreGuardExt
-     *  Ignore/skip the Guard extension
-     *
      * @returns {Object|Null}
      *  The file extension settings; or null, if the extension is not known.
      */
-    ExtensionRegistry.getExtensionSettings = function (fileName, editModule, ignoreGuardExt) {
+    ExtensionRegistry.getExtensionSettings = function (fileName, editModule) {
 
         // the lower-case extension of the passed file name
-        var extension = Utils.getFileExtension(fileName, ignoreGuardExt);
+        var extension = DriveUtils.getFileExtension(fileName);
         // the extension settings object
         var extensionSettings = (extension in fileExtensionMap) ? fileExtensionMap[extension] : null;
         // the module name of the edit application for the extension
@@ -228,7 +224,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  file extension.
      */
     ExtensionRegistry.getEditModule = function (fileName) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, null, editGuardDocs);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName);
         return Utils.getStringOption(extensionSettings, 'module', null);
     };
 
@@ -249,7 +245,8 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  applications.
      */
     ExtensionRegistry.isEditable = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, editGuardDocs);
+        if (!BaseConfig.GUARD_AVAILABLE && DriveUtils.hasGuardExt(fileName)) { return false; }
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
         return Utils.getBooleanOption(extensionSettings, 'editable', false);
     };
 
@@ -270,8 +267,9 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  Documents edit applications.
      */
     ExtensionRegistry.isNative = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, editGuardDocs);
-        return Utils.getBooleanOption(extensionSettings, 'editable', false) && Utils.getBooleanOption(extensionSettings, 'native', false);
+        if (!ExtensionRegistry.isEditable(fileName, editModule)) { return false; }
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
+        return Utils.getBooleanOption(extensionSettings, 'native', false);
     };
 
     /**
@@ -292,8 +290,9 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  edit applications by conversion to a native file format.
      */
     ExtensionRegistry.isConvertible = function (fileName, editModule) {
+        if (!ExtensionRegistry.isEditable(fileName, editModule)) { return false; }
         var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
-        return Utils.getBooleanOption(extensionSettings, 'editable', false) && !Utils.getBooleanOption(extensionSettings, 'native', false);
+        return !Utils.getBooleanOption(extensionSettings, 'native', false);
     };
 
     /**
@@ -316,7 +315,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  - An empty string for all other file names.
      */
     ExtensionRegistry.getFileFormat = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, true);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
         return Utils.getStringOption(extensionSettings, 'format', '');
     };
 
@@ -351,7 +350,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  template file by itself, its own extension will be returned.
      */
     ExtensionRegistry.getTemplateExtension = function (fileName) {
-        var extension = Utils.getFileExtension(fileName);
+        var extension = DriveUtils.getFileExtension(fileName);
         return TEMPLATE_EXT_MAP[extension] || null;
     };
 
@@ -374,21 +373,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return Utils.getBooleanOption(extensionSettings, 'macros', false);
     };
 
-    /**
-     * Returns whether the file with the passed name contains the 'internal
-     * error' extension suffix.
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @returns {Boolean}
-     *  Whether the file with the passed name contains the 'internal error'
-     *  extension suffix.
-     */
-    ExtensionRegistry.isGuardEncrypted = function (fileName) {
-        return Utils.isGuardEncrypted(fileName);
-    };
-
     /**
      * Returns whether the file with the passed name contains the 'internal
      * error' extension suffix.
@@ -401,7 +385,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  extension suffix.
      */
     ExtensionRegistry.isError = function (fileName) {
-        var extension = Utils.getFileExtension(fileName);
+        var extension = DriveUtils.getFileExtension(fileName);
         return extension.substr(-INTERNAL_ERROR_SUFFIX.length) === INTERNAL_ERROR_SUFFIX;
     };
 
@@ -417,7 +401,9 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  The passed passed file name with the 'internal error' extension suffix.
      */
     ExtensionRegistry.createErrorFileName = function (fileName) {
-        return ExtensionRegistry.isError(fileName) ? fileName : (fileName + INTERNAL_ERROR_SUFFIX);
+        if (ExtensionRegistry.isError(fileName)) { return fileName; }
+        var fileExt = DriveUtils.getFileExtension(fileName);
+        return DriveUtils.replaceFileExtension(fileName, fileExt + INTERNAL_ERROR_SUFFIX);
     };
 
     // static initialization ==================================================
@@ -467,6 +453,15 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         });
     });
 
+    // extension point to call isNative(). Used by OX Viewer when plugging OX Spreadsheet.
+    Ext.point('io.ox/office/extensionregistry').extend({
+        id: 'io.ox/office/extensionregistry',
+        index: 10000,
+        isNative: function (baton) {
+            return ExtensionRegistry.isNative(baton.data.get('filename'));
+        }
+    });
+
     // exports ================================================================
 
     return ExtensionRegistry;
