@@ -24,7 +24,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
     // debug mode: whether to show all tours repeatedly
     var DEBUG_SHOW_TOURS = Config.getDebugUrlFlag('office:show-tours');
 
-    // the RequireJS paths of all registered application tours
+    // configuration of all registered application tours
     var appTourRegistry = {};
 
     // whether a tour is currently running, for fail-safety
@@ -445,13 +445,6 @@ define('io.ox/office/baseframework/app/guidedtour', [
 
     // static methods ---------------------------------------------------------
 
-    /**
-     * Returns the configuration key used to store the 'shown' flag for a tour.
-     */
-    function getShownConfigKey(requirePath) {
-        return requirePath.replace(/^io.ox\/office\//, '') + '/shown';
-    }
-
     /**
      * Returns the CSS selector for the root node of a specific control group.
      *
@@ -488,19 +481,6 @@ define('io.ox/office/baseframework/app/guidedtour', [
         return GuidedTour.getGroupSelector(selector, key) + ' .button[data-value="' + value + '"]';
     };
 
-    /**
-     * Returns whether the specified tour has been shown at least once.
-     *
-     * @param {String} requirePath
-     *  The path to the module that exports the tour class constructor.
-     *
-     * @returns {Boolean}
-     *  Whether the specified tour has been shown at least once.
-     */
-    GuidedTour.isShown = function (requirePath) {
-        return Config.getFlag(getShownConfigKey(requirePath));
-    };
-
     /**
      * Starts the specified tour, and sets a server configuration item that
      * specifies that the tour has been shown.
@@ -510,7 +490,11 @@ define('io.ox/office/baseframework/app/guidedtour', [
      *  options passed to this method will be forwarded to the tour
      *  constructor.
      *
-     * @param {Object} [options]
+     * @param {string} shownConfigKey
+     *  The key of the user configuration item used to save the `shown` flag
+     *  for the guided tour.
+     *
+     * @param {object} [options]
      *  Optional parameters (will also be passed to the tour constructor):
      *  @param {Boolean} [options.once=false]
      *      If set to true, the tour will only be started, if it has not been
@@ -522,17 +506,22 @@ define('io.ox/office/baseframework/app/guidedtour', [
      *  will be rejected, if the tour has not been started (e.g. when using the
      *  option 'once').
      */
-    GuidedTour.run = function (requirePath, options) {
+    GuidedTour.run = function (requirePath, shownConfigKey, options) {
 
         // do not run a tour twice if specified (override the once flag with debug URL hash flag)
-        if (options && options.once && !DEBUG_SHOW_TOURS && GuidedTour.isShown(requirePath)) {
+        if (options && options.once && !DEBUG_SHOW_TOURS && Config.getFlag(shownConfigKey)) {
             return $.Deferred().reject();
         }
 
         // require the tour implementation dynamically
         return require([requirePath]).then(function (TourClass) {
-            Config.set(getShownConfigKey(requirePath), true);
-            return new TourClass(options).start();
+            var tour = new TourClass(options);
+            Config.set(shownConfigKey, true);
+            // Workaround for bug 62755: Write the `shown` flag again after the tour
+            // has finished. Backend server may have written other configuration data
+            // which might have deleted the `shown` flag set initially.
+            tour.on('stop', function () { Config.set(shownConfigKey, true); });
+            return tour.start();
         });
     };
 
@@ -541,52 +530,56 @@ define('io.ox/office/baseframework/app/guidedtour', [
      * entry starting the tour will be added to the global 'Settings' drop-down
      * menu of the AppSuite.
      *
-     * @param {String} appType
-     *  The application type identifier.
+     * @param {string} moduleName
+     *  The full module name of the application.
      *
      * @param {String} requirePath
      *  The path to the module that exports the tour class constructor.
+     *
+     * @param {string} shownConfigKey
+     *  The key of the user configuration item used to save the `shown` flag
+     *  for the application tour.
      */
-    GuidedTour.registerAppTour = function (appType, requirePath) {
-        appTourRegistry[appType] = requirePath;
-        Wizard.registry.add({ id: 'default/' + appType }, function () { GuidedTour.run(requirePath); });
+    GuidedTour.registerAppTour = function (moduleName, requirePath, shownConfigKey) {
+        appTourRegistry[moduleName] = { requirePath: requirePath, shownConfigKey: shownConfigKey };
+        Wizard.registry.add({ id: 'default/' + moduleName }, function () { GuidedTour.runAppTour(moduleName); });
     };
 
     /**
      * Returns whether a welcome tour has been registered for the specified
-     * application type with the method GuidedTour.registerAppTour().
+     * application type with the public function `registerAppTour()`.
      *
-     * @param {String} appType
-     *  The application type identifier.
+     * @param {string} moduleName
+     *  The full module name of the application.
      *
      * @returns {Boolean}
      *  Whether a welcome tour has been registered for the specified
      *  application type.
      */
-    GuidedTour.hasAppTour = function (appType) {
-        return appType in appTourRegistry;
+    GuidedTour.hasAppTour = function (moduleName) {
+        return moduleName in appTourRegistry;
     };
 
     /**
      * Returns whether the welcome tour for the specified application type has
      * been shown at least once.
      *
-     * @param {String} appType
-     *  The application type identifier.
+     * @param {string} moduleName
+     *  The full module name of the application.
      *
      * @returns {Boolean}
      *  Whether the specified welcome tour has been shown at least once.
      */
-    GuidedTour.isAppTourShown = function (appType) {
-        var requirePath = appTourRegistry[appType];
-        return !!requirePath && GuidedTour.isShown(requirePath);
+    GuidedTour.isAppTourShown = function (moduleName) {
+        var tourConfig = appTourRegistry[moduleName];
+        return !!tourConfig && Config.getFlag(tourConfig.shownConfigKey);
     };
 
     /**
      * Starts the welcome tour for the specified application type.
      *
-     * @param {String} appType
-     *  The application type identifier.
+     * @param {string} moduleName
+     *  The full module name of the application.
      *
      * @param {Object} [options]
      *  Optional parameters. See method GuidedTour.run() for details.
@@ -596,9 +589,9 @@ define('io.ox/office/baseframework/app/guidedtour', [
      *  will be rejected, if the tour has not been started (e.g. when using the
      *  option 'once').
      */
-    GuidedTour.runAppTour = function (appType, options) {
-        var requirePath = appTourRegistry[appType];
-        return requirePath ? GuidedTour.run(requirePath, options) : $.Deferred().reject();
+    GuidedTour.runAppTour = function (moduleName, options) {
+        var tourConfig = appTourRegistry[moduleName];
+        return tourConfig ? GuidedTour.run(tourConfig.requirePath, tourConfig.shownConfigKey, options) : $.Deferred().reject();
     };
 
     // exports ================================================================
