@@ -20,21 +20,23 @@ define('io.ox/office/baseframework/utils/errorcontext', function () {
 
     var // the exported ErrorContext class
         ErrorContext = {
-            GENERAL:         '', // no specific context
-            CREATEDOC:       'CREATEDOC',
-            LOAD:            'LOAD',
-            SPREADSHEET:     'SPREADSHEET',
-            SAVE:            'SAVE',
-            SAVEAS:          'SAVEAS',
-            CLOSE:           'CLOSE',
-            RENAME:          'RENAME',
-            DOWNLOAD:        'DOWNLOAD',
-            OFFLINE:         'OFFLINE',
-            CONNECTION:      'CONNECTION',
-            SYNCHRONIZATION: 'SYNCHRONIZATION',
-            FLUSH:           'FLUSH',
-            READONLY:        'READONLY',
-            RESTOREDOC:      'RESTOREDOC'
+            GENERAL:          '', // no specific context
+            CREATEDOC:        'CREATEDOC',
+            LOAD:             'LOAD',
+            TEXT:             'TEXT',
+            PRESENTATION:     'PRESENTATION',
+            SPREADSHEET:      'SPREADSHEET',
+            SAVE:             'SAVE',
+            SAVEAS:           'SAVEAS',
+            CLOSE:            'CLOSE',
+            RENAME:           'RENAME',
+            DOWNLOAD:         'DOWNLOAD',
+            OFFLINE:          'OFFLINE',
+            CONNECTION:       'CONNECTION',
+            SYNCHRONIZATION:  'SYNCHRONIZATION',
+            FLUSH:            'FLUSH',
+            READONLY:         'READONLY',
+            RESTOREDOC:       'RESTOREDOC'
         };
 
     // exports ================================================================
