@@ -129,6 +129,7 @@ define('io.ox/office/baseframework/utils/errormessages', [
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_ERROR: gt('The document could not be loaded, because it contains an unsupported feature.'),
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_FRAME_ATTACHED_TO_FRAME_ERROR: gt('The document could not be loaded, because it contains grouped text frames.'),
             LOADDOCUMENT_NO_FILTER_FOR_DOCUMENT_ERROR: gt('The document could not be loaded, because the document format is unknown'),
+            LOADODCUMENT_MEDIATYPE_NOT_SUPPORTED_ERROR: gt('The document could not be loaded. The file format is not supported.'),
             'GENERAL_PERMISSION_READ_MISSING_ERROR.LOAD': gt('The document could not be read, because you do not have read permissions.'),
             'GENERAL_FILE_NOT_FOUND_ERROR.LOAD': gt('The document cannot be found. Please check, if the document has been removed.'),
             'GENERAL_MEMORY_TOO_LOW_ERROR.LOAD': gt('The document could not be loaded. The server is currently too busy. Please try again later.'),
@@ -206,7 +207,7 @@ define('io.ox/office/baseframework/utils/errormessages', [
             errorClass = _.isObject(errorCode) ? errorCode.getErrorClass() : ErrorCode.ERRORCLASS_ERROR,
             // error context data
             errorContextData = _.isObject(errorCode) ? errorCode.getContextData() : {},
-            // error value
+            // optional error value to be used for extended error messages
             errorValue = _.isObject(errorCode) ? errorCode.getErrorValue() : null,
             // a flexible key to map error code/context to error message
             keyToMap = null,
@@ -221,7 +222,9 @@ define('io.ox/office/baseframework/utils/errormessages', [
             // whether the application initiating the error was launched by the OX Viewer.
             isViewerMode = Utils.getBooleanOption(options, 'viewerMode', false),
             // whether this client is editor or not
-            isEditor = Utils.getBooleanOption(options, 'isEditor', false);
+            isEditor = Utils.getBooleanOption(options, 'isEditor', false),
+            // error value used for error message
+            hasErrorValueForMessageUsed = false;
 
         // set a defined message type dependent on the error class
         messageData.type = (errorClass === ErrorCode.ERRORCLASS_WARNING) ? 'warning' : 'error';
@@ -298,6 +301,7 @@ define('io.ox/office/baseframework/utils/errormessages', [
                 case 'RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR':
                     // use the optional error value to provide the illegal character to the user
                     if (_.isString(errorValue) && (errorValue.length > 0)) {
+                        hasErrorValueForMessageUsed = true;
                         messageData.message = messageData.message.concat(': "').concat(errorValue).concat('"');
                     } else {
                         messageData.message = messageData.message.concat('.');
@@ -308,6 +312,7 @@ define('io.ox/office/baseframework/utils/errormessages', [
                     // #. %1$s is the name of the editor of the document
                     // #. c-format
                     if (_.isString(errorValue) && (errorValue.length > 0)) {
+                        hasErrorValueForMessageUsed = true;
                         messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by "%1$s". Please contact "%1$s" or try again later.', gt.noI18n(errorValue));
                     } else {
                         messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by someone. Please try again later.');
@@ -414,7 +419,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
                 case 'LOADDOCUMENT_FEATURE_NOT_SUPPORTED_FRAME_ATTACHED_TO_FRAME_ERROR':
                 case 'GENERAL_FILE_CORRUPT_ERROR':
                 case 'GENERAL_FILE_NOT_FOUND_ERROR':
-                case 'LOADDOCUMENT_NO_FILTER_FOR_DOCUMENT_ERROR': delete messageData.action; break;
+                case 'LOADDOCUMENT_NO_FILTER_FOR_DOCUMENT_ERROR':
+                case 'LOADODCUMENT_MEDIATYPE_NOT_SUPPORTED_ERROR': delete messageData.action; break;
                 case 'LOADDOCUMENT_FAILED_ERROR':
                     if (errorContext === ErrorContext.CLOSE) {
                         // special behavior for close - don't provide reload in this case
@@ -435,7 +441,14 @@ define('io.ox/office/baseframework/utils/errormessages', [
                     if (originalFileId.length > 30) {
                         originalFileId = '...' + originalFileId.substring(originalFileId.length - 27, originalFileId.length);
                     }
-                    messageData.extendedMessage += ' File\xa0id:\xa0' + originalFileId;
+                    messageData.extendedMessage += ' File\xa0id:\xa0' + originalFileId + '. ';
+                }
+                if (_.isString(errorValue) && (errorValue.length > 0) && !hasErrorValueForMessageUsed) {
+                    // include possible error value for extended message if not been used yet
+                    if (errorValue.length > 30) {
+                        errorValue = '...' + errorValue.substring(errorValue.length - 27, errorValue.length);
+                    }
+                    messageData.extendedMessage += ' Error\xa0value:\xa0' + errorValue;
                 }
             }
         }
