@@ -772,6 +772,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     if (self.isVisible()) { restoreTabIndexes(); }
                     self.stopListeningTo(blockerNode, 'keydown', keyDownHandler);
                     self.stopListeningTo(appWindow, 'idle', unregisterListeners);
+                    self.stopListeningTo(app, 'docs:busy:quit');
                 }
 
                 // bug 38770: grab focus to prevent modifications of document
@@ -811,6 +812,9 @@ define('io.ox/office/baseframework/view/baseview', [
                     cancelButton = $.button({ label: gt('Cancel') })
                         .addClass('btn-warning')
                         .on('click', function () { cancelHandler.call(self); });
+
+                    // immediately run cancel handler when the quit button of the busy screen has been clicked (53941)
+                    self.listenTo(app, 'docs:busy:quit', function () { cancelHandler.call(self); });
                 }
 
                 // create a warning alert box if specified, insert cancel button into the alert box
