@@ -587,7 +587,8 @@ define('io.ox/office/baseframework/view/component', [
 
                 // bug 37236: update enabled state of all new groups, e.g. when initializing
                 // a view component lazily (e.g. directly before showing a pop-up menu)
-                this.waitForImportSuccess(updateAllGroupsDebounced);
+                // -> this update is required in case of import success, but also for failures (57970)
+                this.waitForImport(updateAllGroupsDebounced);
             }
 
             // bind group visibility to controller item
