@@ -41,24 +41,24 @@ define('io.ox/office/baseframework/view/control/userpicture', [
      *  @param {Boolean} [immediatedelete=false]
      *      Whether an existing background image shall be deleted synchronously.
      */
-    function UserPicture(userData, initOptions) {
+    function UserPicture(docView, userData, initOptions) {
 
-        var // the size of the image container
-            nodeSize = Utils.getIntegerOption(initOptions, 'size', 48),
+        // the size of the image container
+        var nodeSize = Utils.getIntegerOption(initOptions, 'size', 48);
 
-            // size of the photo bitmap (double on retina displays)
-            bitmapSize = nodeSize * (Utils.RETINA ? 2 : 1),
+        // size of the photo bitmap (double on retina displays)
+        var bitmapSize = nodeSize * (Utils.RETINA ? 2 : 1);
 
-            // whether an existing background image shall be deleted synchronously (this is important
-            // for the change track user picture, because there is only one change trage badge).
-            immediateDelete = Utils.getBooleanOption(initOptions, 'immediatedelete', false),
+        // whether an existing background image shall be deleted synchronously (this is important
+        // for the change track user picture, because there is only one change trage badge).
+        var immediateDelete = Utils.getBooleanOption(initOptions, 'immediatedelete', false);
 
-            // the element containing the photo (as CSS background)
-            pictureNode = $('<div class="photo-container" style="min-width:' + nodeSize + 'px;height:' + nodeSize + 'px;background-size:' + nodeSize + 'px;">');
+        // the element containing the photo (as CSS background)
+        var pictureNode = $('<div class="photo-container" style="min-width:' + nodeSize + 'px;height:' + nodeSize + 'px;background-size:' + nodeSize + 'px;">');
 
         // base constructors --------------------------------------------------
 
-        Group.call(this, initOptions);
+        Group.call(this, docView, initOptions);
 
         // private methods ----------------------------------------------------
 
@@ -68,15 +68,16 @@ define('io.ox/office/baseframework/view/control/userpicture', [
          */
         function updateHandler(currentData) {
 
-            var // unique identifier of the user
-                userId = Utils.getIntegerOption(currentData, 'userId'),
-                // display name of the user
-                userName = _.noI18n(Utils.getStringOption(currentData, 'userName', ''));
+            // unique identifier of the user
+            var userId = Utils.getIntegerOption(currentData, 'userId');
+            // display name of the user
+            var userName = _.noI18n(Utils.getStringOption(currentData, 'userName', ''));
 
-            if (immediateDelete) { pictureNode.css('background-image', ''); } // avoid flickering by deferred exchange of old picture in CT badge
+            // avoid flickering by deferred exchange of old picture in CT badge
+            if (immediateDelete) { pictureNode.css('background-image', ''); }
 
             ContactsAPI.pictureHalo(pictureNode, _.isNumber(userId) ? { internal_userid: userId } : {}, { width: bitmapSize, height: bitmapSize, scaleType: 'cover' });
-            Forms.setToolTip(pictureNode, { tooltip: userName });
+            Forms.setToolTip(pictureNode, userName);
         }
 
         // initialization -----------------------------------------------------
@@ -94,7 +95,7 @@ define('io.ox/office/baseframework/view/control/userpicture', [
 
         // destroy class members
         this.registerDestructor(function () {
-            userData = initOptions = pictureNode = null;
+            docView = userData = initOptions = pictureNode = null;
         });
 
     } // class UserPicture
