@@ -88,6 +88,11 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         aspectLocked: { def: false },
 
+        /**
+         * The minimal height of text frames (ODF only).
+         */
+        minFrameHeight: { def: 0 },
+
         /**
          * Left border of the rectangle used to set the position of embedded
          * child objects.
@@ -116,7 +121,17 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          * Replacement image for unsupported drawing objects. The string
          * contains either BASE64 encoded bitmap data, or SVG mark-up.
          */
-        replacementData: { def: '', scope: 'element' }
+        replacementData: { def: '', scope: 'element' },
+
+        /**
+         * Disables selection of the drawing
+         */
+        noSelect: { def: false },
+
+        /**
+         * Drawing id, used to identify drawing objects (needed for connector objects).
+         */
+        id: { def: '0' }
     };
 
     // definitions for drawing fill attributes --------------------------------
@@ -172,6 +187,10 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
     // definitions for drawing outline attributes -----------------------------
 
+    var MARKERFILL_ATTRIBUTE_DEFINITIONS = _.extend({}, FILL_ATTRIBUTE_DEFINITIONS, {
+        onlyMarker: { def: false }
+    });
+
     // supports ALL fill attributes
     var LINE_ATTRIBUTE_DEFINITIONS = _.extend({}, FILL_ATTRIBUTE_DEFINITIONS, {
 
@@ -375,7 +394,8 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          * disables autoResizeHeight & autoResizeText
          */
         noAutoResize:   { def: false },
-       /**
+
+        /**
         * Specifies the text orientation
         */
         vert: { def: 'horz' }
@@ -388,17 +408,24 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         /**
          * Geometry attributes defines the geometry that should be drawn by providing
          * a pathList whose points are determined by a combination of constant,
-         * guide and absolute values
+         * guide and absolute values (using null instead of empty array and objects
+         * because of task 57331)
          */
         presetShape: { def: '' },
 
-        avList: { def: {} },
+        avList: { def: null },
 
-        gdList: { def: [] },
+        ahList: { def: null },
 
-        pathList: { def: [] },
+        gdList: { def: null },
 
-        textRect: { def: {} },
+        cxnList: { def: null },
+
+        pathList: { def: null },
+
+        textRect: { def: null },
+
+        textPath: { def: '' },
 
         hostData: { def: '' }
     };
@@ -430,7 +457,8 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         stacking: { def: 'standard', scope: 'element' },
 
         /**
-         * if true line charts are smooth spline charts
+         * if true line charts are smooth spline charts.
+         * Only for ods, ooxml curved is on the series_attributes
          */
         curved: { def: false, scope: 'element' },
 
@@ -444,7 +472,17 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         /**
          * defines if the points of the first series are same color or not
          */
-        varyColors: { def: false, scope: 'element' }
+        varyColors: { def: false, scope: 'element' },
+
+        /**
+         * Rotation of a 3D Chart.
+         */
+        rotationX: { def: 0, scope: 'element' },
+        rotationY: { def: 0, scope: 'element' },
+        /**
+         * if true the chart contains a errorbar
+         */
+        eb: { dev: false, scope: 'element' }
     };
 
     // definitions for chart data series attributes ---------------------------
@@ -500,7 +538,19 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
         axisXIndex: { def: 0 },
 
-        axisYIndex: { def: 0 }
+        axisYIndex: { def: 0 },
+
+        axisZIndex: { def: 0 },
+
+        chart3d: { def: false },
+
+        bubble3d: { def: false },
+
+        noFill: { def: false },
+
+        noLine: { def: false },
+        // curved line only for ooxml, ods curved is on the chart_attributes
+        curved: { def: false }
     };
 
     // definitions for chart axis attributes ----------------------------------
@@ -513,7 +563,9 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
         max: { def: 'auto' },
 
-        label: { def: false }
+        label: { def: false },
+
+        format: { def: '' }
     };
 
     // definitions for chart legend attributes --------------------------------
@@ -551,7 +603,7 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         StyleCollection.call(this, docModel, 'drawing', (function () {
             var families = Utils.getStringOption(initOptions, 'families', '');
             if (families) { families += ' '; }
-            families += 'line fill image shape geometry connector paragraph character';
+            families += 'line fill markerFill markerBorder image shape geometry connector paragraph character';
             return Utils.extendOptions(initOptions, { families: families });
         }()));
 
@@ -559,7 +611,9 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
         docModel.registerAttributes('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
         docModel.registerAttributes('fill', FILL_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('markerFill', MARKERFILL_ATTRIBUTE_DEFINITIONS);
         docModel.registerAttributes('line', LINE_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('markerBorder', LINE_ATTRIBUTE_DEFINITIONS);
         docModel.registerAttributes('text', TEXT_ATTRIBUTE_DEFINITIONS);
         docModel.registerAttributes('image', IMAGE_ATTRIBUTE_DEFINITIONS);
         docModel.registerAttributes('connector', CONNECTOR_ATTRIBUTE_DEFINITIONS);
