@@ -24,6 +24,8 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
 
     'use strict';
 
+    var MARKER_LIST = ['triangle', 'cross'];
+
     // class ChartTypePicker ==================================================
 
     /**
@@ -38,21 +40,20 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
      */
     function ChartTypePicker(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the document model and app
-            docModel = docView.getDocModel(),
-            app = docView.getApp(),
+        // the document model and app
+        var docModel = docView.getDocModel();
 
-            // data-model for CanvasJS to drop all changed value before drawing
-            data = {},
+        // data-model for CanvasJS to drop all changed value before drawing
+        var data = {};
 
-            scatterPoints = [2.5, 4, 1.5, 3.5, 2, 2.5];
+        var scatterPoints = [2.5, 4, 1.5, 3.5, 2, 2.5];
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             width: 150,
             icon: 'fa-bar-chart-o',
             tooltip: gt('Chart type'),
@@ -77,12 +78,12 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
          * creates CanvasJS structure
          * and draws deferred all types in the chain to images
          */
-        var updatePreviewCharts = this.createDebouncedMethod($.noop, function () {
+        var updatePreviewCharts = this.createDebouncedMethod('ChartTypePicker.updatePreviewCharts', null, function () {
 
             var // unique identifier used by CanvasJS
                 id = _.uniqueId('io-ox-office-chart-dummy-'),
                 // container node for the CanvasJS chart
-                containerNode = $('<div id="' + id + '" style="position:fixed;visibility:hidden;left:-100px;top:-100px;width:100px;height:100px;">').appendTo('body'),
+                containerNode = $('<div id="' + id + '" style="position:fixed;visibility:hidden;left:-100px;top:-100px;width:100px;height:90px;">').appendTo('body'),
                 // the CanvasJS renderer
                 chart = new CanvasJS.Chart(id, data),
                 // the <canvas> node from the renderer
@@ -93,17 +94,29 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
                 return;
             }
 
-            self.iterateArraySliced(self.getOptionButtons(), function (buttonNode) {
+            var promise = self.iterateArraySliced(self.getOptionButtons(), function (buttonNode) {
 
-                var id = Forms.getButtonValue(buttonNode),
-                    options = $(buttonNode).data('options'),
-                    cjs = options.data.cjs,
-                    single = /^(pie|doughnut)$/.test(cjs);
+                var id = Forms.getButtonValue(buttonNode);
+                var options = $(buttonNode).data('options');
+
+                var cjs = options.data.series.cjs;
+                var single = /^(pie|doughnut)/.test(cjs);
+                var markersOnly = options.data.series.markersOnly;
 
                 _.each(data.data, function (dataSeries, index) {
                     dataSeries.type = cjs;
                     var cl = { type: 'scheme', value: 'accent' + (index + 1) };
-                    dataSeries.color = docModel.getCssColor(cl, 'fill');
+                    if (markersOnly) {
+                        dataSeries.markerColor = docModel.getCssColor(cl, 'fill');
+                        dataSeries.color = 'transparent';
+                        dataSeries.markerType = MARKER_LIST[(index % MARKER_LIST.length)];
+                        dataSeries.markerSize = 10;
+                    } else {
+                        dataSeries.color = docModel.getCssColor(cl, 'fill');
+                        dataSeries.markerColor = dataSeries.color;
+                        dataSeries.markerType = 'circle';
+                        dataSeries.markerSize = 1;
+                    }
                 });
 
                 _.each(data.data[0].dataPoints, function (dataPoint, index) {
@@ -130,12 +143,13 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
                     src: canvasNode[0].toDataURL(),
                     alt: Utils.getStringOption(options, 'label')
                 });
+            }, 'ChartTypePicker.updatePreviewCharts');
 
-            }, { infoString: 'ChartTypePicker: updatePreviewCharts 2', app: app }).done(function () {
+            promise.done(function () {
                 containerNode.remove();
             });
 
-        }, { delay: 50, infoString: 'ChartTypePicker: updatePreviewCharts 1', app: app });
+        }, { delay: 50 });
 
         // initialization -----------------------------------------------------
 
@@ -152,7 +166,7 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
 
             _.each(pointList, function (points, series) {
                 var dataPoints = [];
-                data.data[series] = { markerSize: 2, indexLabelFontColor: 'transparent', indexLabelLineColor: 'transparent', showInLegend: false, dataPoints: dataPoints, sourcePoints: {} };
+                data.data[series] = { indexLabelFontColor: 'transparent', indexLabelLineColor: 'transparent', showInLegend: false, dataPoints: dataPoints, sourcePoints: {} };
                 _.each(points, function (point, index) {
                     dataPoints.push({ label: 'bla ' + (index + 1), y: point, z: Math.floor(2 + Math.random() * 100) });
                 });
@@ -180,7 +194,7 @@ define('io.ox/office/drawinglayer/view/control/charttypepicker', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = initOptions = docModel = docView = data = app = null;
+            self = initOptions = docModel = docView = data = null;
         });
 
     } // class ChartTypePicker
