@@ -15,9 +15,9 @@
 define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
-    'io.ox/office/baseframework/view/popup/layermenu',
+    'io.ox/office/baseframework/view/popup/floatingmenu',
     'io.ox/office/drawinglayer/view/drawingframe'
-], function (Utils, KeyCodes, LayerMenu, DrawingFrame) {
+], function (Utils, KeyCodes, FloatingMenu, DrawingFrame) {
 
     'use strict';
 
@@ -28,7 +28,7 @@ define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
      *
      * @constructor
      *
-     * @extends LayerMenu
+     * @extends FloatingMenu
      *
      * @param {EditView} docView
      *  The document view that contains this instance.
@@ -37,7 +37,7 @@ define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
      *  The types of drawing objects supported by this menu, as space-separated
      *  list.
      */
-    function DrawingFrameMenu(docView, drawingType, titleLabel, initOptions) {
+    var DrawingFrameMenu = FloatingMenu.extend({ constructor: function (docView, drawingType, titleLabel, initOptions) {
 
         // self reference
         var self = this;
@@ -48,9 +48,11 @@ define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
         // convert space-separated list of drawing object types to flag set
         var drawingTypeSet = Utils.makeSet(drawingType.split(/\s+/));
 
+        var enterBusyVisibleState = false;
+
         // base constructor ---------------------------------------------------
 
-        LayerMenu.call(this, docView, titleLabel, Utils.extendOptions({
+        FloatingMenu.call(this, docView, titleLabel, Utils.extendOptions({
             anchorBorder: 'right left'
         }, initOptions, {
             anchor: function () { return drawingFrame; },
@@ -90,11 +92,28 @@ define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
         // initialization -----------------------------------------------------
 
         // hide the menu automatically in read-only mode
-        this.listenTo(docView.getApp(), 'docs:editmode:leave', function () { self.hide(); });
+        this.listenTo(docView.getApp(), 'docs:editmode:leave docs:beforequit', function () {
+            self.hide();
+            enterBusyVisibleState = false;
+        });
 
         // adjust position and visibility of the menu according to the current selection
         this.listenTo(docView, 'render:drawingselection', renderDrawingSelectionHandler);
 
+        // listen to busy mode enter and hide the menu because it's above the busy screen
+        this.listenTo(docView, 'busy:enter', function () {
+            enterBusyVisibleState = self.isVisible();
+            // self.hide();
+        });
+
+        // show the menu after busy mode leave if it was visible on busy:enter
+        this.listenTo(docView, 'busy:leave', function () {
+            if (enterBusyVisibleState) {
+                // self.show();
+                enterBusyVisibleState = false;
+            }
+        });
+
         self.on('popup:hide', function () {
             docView.getApp().getController().update();
             drawingFrame = null;
@@ -105,11 +124,10 @@ define('io.ox/office/drawinglayer/view/popup/drawingframemenu', [
             self = initOptions = docView = null;
         });
 
-    } // class DrawingFrameMenu
+    } }); // class DrawingFrameMenu
 
     // exports ================================================================
 
-    // derive this class from class LayerMenu
-    return LayerMenu.extend({ constructor: DrawingFrameMenu });
+    return DrawingFrameMenu;
 
 });
