@@ -15,9 +15,8 @@
 define('io.ox/office/editframework/app/editcontroller', [
     'io.ox/office/tk/utils',
     'io.ox/office/baseframework/app/basecontroller',
-    'io.ox/office/editframework/utils/editconfig',
-    'io.ox/core/capabilities'
-], function (Utils, BaseController, Config, Capabilities) {
+    'io.ox/office/editframework/utils/editconfig'
+], function (Utils, BaseController, Config) {
 
     'use strict';
 
@@ -198,7 +197,10 @@ define('io.ox/office/editframework/app/editcontroller', [
             'view/toolbars/show': {
                 // always enabled (also in read-only mode, and in application error state)
                 get: function () { return docView.getToolPane().isVisible(); },
-                set: function (state) { docView.getToolPane().toggle(state); }
+                set: function (state) {
+                    app.setUserSettingsValue('showToolbars', state);
+                    docView.getToolPane().toggle(state);
+                }
             },
 
             // the identifier of the active tool bar
@@ -318,7 +320,7 @@ define('io.ox/office/editframework/app/editcontroller', [
 
             'document/saveasencrypted/dialog': {
                 parent: 'app/valid',
-                enable: function () { return Capabilities.has('guard-docs'); },
+                enable: function () { return !app.isExternalStorage() && Config.GUARD_AVAILABLE; },
                 set: function (type) { return docView.showSaveAsDialog(type); }
             },
 
@@ -337,8 +339,8 @@ define('io.ox/office/editframework/app/editcontroller', [
             'document/users': {
                 parent: 'app/valid',
                 enable: function () { return app.getActiveClients().length > 1; },
-                get: function () { return docView.getCollaboratorPopup().isVisible(); },
-                set: function (state) { docView.toggleCollaboratorPopup(state); }
+                get: function () { return docView.getCollaboratorMenu().isVisible(); },
+                set: function (state) { docView.getCollaboratorMenu().toggle(state); }
             },
 
             // base item for search/replace
