@@ -204,10 +204,16 @@ define('io.ox/office/editframework/app/fileactions', [
                     //DriveUtils does this already, but in this situation we dont have the id of the folder yet
                     return e.baton.app.folder.getData().then(function (data) {
                         if (_.isObject(data) && _.isString(data.id)) {
-                            return DriveUtils.getCreateState(data.id).then(function (create) {
-                                if (create) {
-                                    return DriveUtils.getTrashState(data.id).then(function (state) {
-                                        return !state;
+                            return DriveUtils.getCreateState(data.id).then(function (createState) {
+                                if (createState) {
+                                    return DriveUtils.getWriteState(data.id).then(function (writeState) {
+                                        if (writeState) {
+                                            return DriveUtils.getTrashState(data.id).then(function (trashState) {
+                                                return !trashState;
+                                            });
+                                        } else {
+                                            return false;
+                                        }
                                     });
                                 } else {
                                     return false;
