@@ -530,8 +530,11 @@ define('io.ox/office/editframework/app/rtconnection', [
             }
 
             // check error code to decide, if we can try to re-join
-            if (hasError && response.error.code === 1007) {
-                // try to re-join in case of code 1007 (STATE_MISSING)
+            if (hasError && (response.error.code === 1007 || response.error.code === 1009)) {
+                // Try to re-join in case of code 1007 (STATE_MISSING) or 1009 (RESULT_MISSING)
+                // ATTENTION: This code is behaviour driven and can brake at any time changes
+                // are done in real-time core code.
+                rejoinPossible = true;
                 handleRejoin(def, response, retryHandler);
             } else {
                 joining = false;
