@@ -100,8 +100,10 @@ define('io.ox/office/editframework/model/attributedmodel', [
      *      explicit attribute set, but the old explicit attribute will be
      *      removed from the explicit attribute set, when using the method
      *      AttributedModel.setAttributes(). This option has no effect, if this
-     *      model instance uses style sheets (see option 'styleFamily'), or
-     *      refers to a parent model object (see option 'parentModel').
+     *      model instance uses style sheets (see option 'styleFamily'). If
+     *      this model refers to a parent attribute model (see option
+     *      'parentModel'), its attributes will be used for comparison, instead
+     *      of the default values defined in the attribute definitions.
      */
     function AttributedModel(docModel, initAttributes, initOptions) {
 
@@ -115,7 +117,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
         var parentModel = Utils.getObjectOption(initOptions, 'parentModel', null);
 
         // whether to remove explicit attributes equal to the attribute defaults
-        var autoClear = !styleFamily && !parentModel && Utils.getBooleanOption(initOptions, 'autoClear', false);
+        var autoClear = !styleFamily && Utils.getBooleanOption(initOptions, 'autoClear', false);
 
         // the collection of style sheets for the style family
         var styleCollection = styleFamily ? docModel.getStyleCollection(styleFamily) : null;
@@ -301,7 +303,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
          *  explicit attributes of this instance.
          *
          * @returns {Object}
-         *  A dep copy of the passed attribute set that will only contain the
+         *  A deep copy of the passed attribute set that will only contain the
          *  attribute values that are not equal to the explicit attibute values
          *  of this model instance (incluging missing explicit attributes); or
          *  null values that will delete an existing explicit attribute.
@@ -328,7 +330,8 @@ define('io.ox/office/editframework/model/attributedmodel', [
                             AttributeUtils.insertAttribute(reducedAttributeSet, family, name, null);
                         }
                     } else {
-                        if (!oldExplicitAttrs || !(name in oldExplicitAttrs) || !_.isEqual(value, oldAttrValues[name])) {
+                        var hasAttrs = oldExplicitAttrs && (name in oldExplicitAttrs);
+                        if ((!autoClear && !hasAttrs) || !_.isEqual(value, oldAttrValues[name])) {
                             AttributeUtils.insertAttribute(reducedAttributeSet, family, name, value);
                         }
                     }
@@ -522,7 +525,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
                 // update the attribute map with the new attribute values
                 definitionMap.forEachSupported(attributeSet[family], function (value, name, definition) {
-                    if (AttributeUtils.updateAttribute(explicitAttributes, name, value, autoClear ? definition : null)) {
+                    if (AttributeUtils.updateAttribute(explicitAttributes, name, value, (autoClear && !parentModel) ? definition : null)) {
                         changed = true;
                     }
                 }, options);
