@@ -338,6 +338,26 @@ define('io.ox/office/editframework/model/editmodel', [
             self.trigger(success ? 'operations:success' : 'operations:error', operations, external);
         }
 
+        /**
+         * Returns the implementation callback function for the document
+         * operation wrapped in the passed operation context.
+         *
+         * @param {OperationContext} context
+         *  The operation wrapper.
+         *
+         * @returns {Funtion}
+         *  The implementation callback function for the operation.
+         *
+         * @throws {OperationError}
+         *  If the operation does not exist.
+         */
+        function getOperationHandler(context) {
+            var name = context.getStr('name');
+            var handler = operationHandlerMap.get(name, null);
+            context.ensure(handler, 'unknown operation %s', name);
+            return handler;
+        }
+
         /**
          * Executes the handler function for the passed operation.
          *
@@ -380,10 +400,7 @@ define('io.ox/office/editframework/model/editmodel', [
                 // the context passed to the operation handler
                 var context = new ContextClass(self, operation, external, importing);
                 // the callback handler for the operation
-                var handler = operationHandlerMap.get(context.getStr('name'), null);
-
-                // check existence of operation handler (always, also if operation will be filtered below)
-                context.ensure(handler, 'unknown operation');
+                var handler = getOperationHandler(context);
 
                 // Check the correct operation state number of an external operation. The OSN must be
                 // identical on every client. The OSN is sent from server, when the document is loaded.
@@ -986,32 +1003,24 @@ define('io.ox/office/editframework/model/editmodel', [
          *  The JSON operation object of the document operation to be applied
          *  locally and silently.
          *
-         * @returns {Boolean}
-         *  Whether the passed operation has been applied successfully.
+         * @returns {EditModel}
+         *  A reference to this instance.
+         *
+         * @throws {OperationError}
+         *  If the passed operation is invalid (wrong/missing name etc.), or
+         *  the exception thrown by the operation handler implementation.
          */
         this.invokeOperationHandler = function (operation) {
 
-            // callback handler throws exceptions to indicate operation errors
-            try {
+            // the operation context passed to the callback
+            var context = new ContextClass(this, operation, false);
+            // the callback handler for the operation
+            var handler = getOperationHandler(context);
 
-                // the operation context passed to the callback
-                var context = new ContextClass(this, operation, false);
+            // suppress implicit undo operations generated e.g. in text framework
+            undoManager.disableUndoSync(handler.bind(this, context));
 
-                // the callback handler for the operation
-                var handler = operationHandlerMap.get(context.getStr('name'), null);
-                context.ensure(handler, 'unknown operation');
-
-                // suppress implicit undo operations generated e.g. in text framework
-                undoManager.disableUndo(function () {
-                    handler.call(this, context);
-                }, this);
-
-                return true;
-
-            } catch (ex) {
-                Utils.exception(ex);
-                return false;
-            }
+            return this;
         };
 
         /**
@@ -1102,7 +1111,7 @@ define('io.ox/office/editframework/model/editmodel', [
             var storeSelection = Utils.getBooleanOption(options, 'storeSelection', false);
             var storeSelectionHandler = storeSelection ? _.noop : Utils.getFunctionOption(options, 'storeSelection', null);
 
-            // whether the generator applies all generated operations immediately
+            // whether the generator already has immediately applied all generated operations
             var immediateMode = generator.isImmediateApplyMode();
 
             // simulate actions processing mode for deferred callbacks
@@ -1110,30 +1119,16 @@ define('io.ox/office/editframework/model/editmodel', [
 
                 // get the current selection state of the document
                 var oldSelectionState = storeSelectionHandler ? self.getSelectionState() : null;
-                // invoke the callback function
-                var result = callback.call(self, generator);
-                // start with a promise
-                var promise = self.convertToPromise(result);
 
-                // clean-up if the callback function fails
-                promise = promise.catch(function (result) {
+                // invoke the callback function (may throw immediately)
+                var promise = null;
+                try {
+                    promise = self.convertToPromise(callback.call(self, generator));
+                } catch (err) {
+                    promise = self.createRejectedPromise(err);
+                }
 
-                    // no thing to do, if application is already in internal error state, or if the
-                    // operations have not been applied directly while generating them
-                    if (app.isInternalError() || !immediateMode) { throw result; }
-
-                    // revert all operations that have been applied directly in the callback function
-                    var promise2 = self.iterateArraySliced(generator.getOperations({ undo: true }), function (operation) {
-                        if (!self.invokeOperationHandler(operation)) {
-                            return $.Deferred().reject({ cause: 'operation' });
-                        }
-                    }, 'EditModel.createAndApplyOperations');
-
-                    // restore the rejected state of the outer promise (unless reverting the operations fails too)
-                    return promise2.then(function () { throw result; });
-                });
-
-                // apply and send the operations after the callback has finished, and return the original result of the generator callback function
+                // apply and send the operations after the callback has finished
                 promise = promise.then(function (result) {
 
                     // only send the generated operations in immediate mode
