@@ -17,8 +17,9 @@ define('io.ox/office/editframework/model/fontcollection', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/container/valuemap',
+    'io.ox/office/tk/render/font',
     'io.ox/office/baseframework/model/modelobject'
-], function (Config, Utils, Scheduler, ValueMap, ModelObject) {
+], function (Config, Utils, Scheduler, ValueMap, Font, ModelObject) {
 
     'use strict';
 
@@ -79,52 +80,10 @@ define('io.ox/office/editframework/model/fontcollection', [
 
     // private global functions ===============================================
 
-    // Calculates and returns the container width for the given font.
-    // When this font is not available, it uses the fallback font and
-    // therefore returns the container width for the fallback font.
-    function calcFontMetric(font) {
-
-        // container for calculation, with the font and the fallback font attached, it's moved offscreen
-        var hiddenCalcContainer = $('<div style="position:absolute; width:auto; font-size: 100px; left:-9000px; font-family:' + font + ';">');
-        // the span with a string for measurements
-        var textToMeasure = $('<span>abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234</span>');
-
-        $('body').append(hiddenCalcContainer.append(textToMeasure));
-        var fontWidth = hiddenCalcContainer.outerWidth();
-        hiddenCalcContainer.remove();
-        return fontWidth;
-    }
-
-    /**
-     * Check if the the given font is available in the browser. It's available
-     * when it is installed at the client or when it is already in the DOM as a web font.
-     * It was created to work with Calibri', 'Carlito', 'Cambria' and 'Caladea', so in other
-     * cases see the restriction below.
-     *
-     * Important restriction: This does only work 100% reliable for the fonts 'Calibri', 'Carlito',
-     * 'Cambria' and 'Caladea' at the moment. That said, it should work for all fonts that have a
-     * different metric to 'monospace'. So just check if the detection for the font that should
-     * be checked works when installed and when not installed.
-     *
-     * But to be reliable for every font without checking it before, this function needs to be enhanced
-     * with at least a second check in addition to the monospace font.
-     */
-    function isFontAvailableInBrowser(font) {
-
-        // width from the container with the test font
-        var testFontWidth = calcFontMetric(font + ',monospace');
-        // width from the container with the fallback font
-        var monoFontWidth = calcFontMetric('monospace');
-
-        // When the testFontWidth is equal to the fallbackFontWidth it means that the testFont was not used by the browser.
-        // Therefore the font is available when both width values are different.
-        return testFontWidth !== monoFontWidth;
-    }
-
-    // When used with 'office:testautomation=true', the importReplacementFonts is tested with a own, unique font (see 'debugFontName') that doesn't exists on Windows and Linux.
+    // When used with 'office:testautomation=true', the importReplacementFonts is tested with a own, unique font (see 'DEBUG_FONT_NAME') that doesn't exists on Windows and Linux.
     // Since Calibri and Cambria are system fonts in Windows, it would not work otherwise. In Linux 'Fontconfig' may generate Calibri replacement fonts on OS level that are not possible to detect.
-    function debugReplacementFonts() {
-        return !Config.AUTOTEST || isFontAvailableInBrowser(DEBUG_FONT_NAME);
+    function isTestFontInstalled() {
+        return !Config.AUTOTEST || Font.isInstalled(DEBUG_FONT_NAME, 'AB');
     }
 
     // class FontCollection ===================================================
@@ -315,6 +274,8 @@ define('io.ox/office/editframework/model/fontcollection', [
          */
         this.getCssFontFamily = function (fontName) {
 
+            if (!fontName) { return ''; } // increasing resilience
+
             // fonts are keyed by capitalized names
             fontName = Utils.capitalizeWords(fontName);
 
@@ -367,19 +328,31 @@ define('io.ox/office/editframework/model/fontcollection', [
          * fonts on OS level that are not possible to detect (for more information see our wiki).
          *
          * @returns {jQuery.Promise}
-         *  A promise that will be resolved when the font is available in the browser,
-         *  or rejected when an error has occurred.
+         *  A promise that will be resolved when the font is available in the browser. It's also resolved
+         *  when font loading didn't work, because everything works like before the
+         *  replacement fonts existed. There is no error handling possible in a fail handler.
          */
         this.importReplacementFonts = function () {
 
-            var
-                loadDeferred = Scheduler.createDeferred(docModel, 'FontCollection.importReplacementFonts'),
-                // whether 'Calibri' or the metric compatible replacement 'Carlito' is available at the device
-                calibriOrReplacementAvailible = isFontAvailableInBrowser('Calibri') || isFontAvailableInBrowser('Carlito'),
-                // whether 'Cambria' or the metric compatible replacement 'Caladea' is available at the device
-                cambriaOrReplacementAvailible = isFontAvailableInBrowser('Cambria') || isFontAvailableInBrowser('Caladea'),
-                // whether a possible font download should be allowed
-                blockDownloadToken = false;
+            // whether 'Calibri' or the metric compatible replacement 'Carlito' is available at the device
+            var calibriOrReplacementAvailible = Font.isInstalled('Calibri') || Font.isInstalled('Carlito');
+            // whether 'Cambria' or the metric compatible replacement 'Caladea' is available at the device
+            var cambriaOrReplacementAvailible = Font.isInstalled('Cambria') || Font.isInstalled('Caladea');
+
+            // only for debug, but very helpful to detect failures
+            Utils.withLogging(function () {
+                Utils.log('ImportReplacementFonts - Calibri:', Font.isInstalled('Calibri'), ' - Carlito:', Font.isInstalled('Carlito'), ' | Cambria:', Font.isInstalled('Cambria'), ' - Caladea:', Font.isInstalled('Caladea'), '| FontDebugMode:', Config.AUTOTEST, '- ' + DEBUG_FONT_NAME + ':', isTestFontInstalled());
+            });
+
+            // check if font or replacement is installed locally, or already available in the browser
+            if (calibriOrReplacementAvailible && cambriaOrReplacementAvailible && isTestFontInstalled()) {
+                Utils.log('ImportReplacementFonts - Needed fonts are installed or a replacement fonts is already available for rendering in the browser');
+                debugStateImportReplacementFonts.installedOrReplacementAvailable = true;
+                return this.createResolvedPromise();
+            }
+
+            // the deferred object representing the font import
+            var loadDeferred = Scheduler.createDeferred(this, 'FontCollection.importReplacementFonts');
 
             // Attach the CSS content which contains the web font to DOM
             function addFontToDOM(cssFontData) {
@@ -394,123 +367,107 @@ define('io.ox/office/editframework/model/fontcollection', [
                     // trigger a reflow in the browser, at least Chrome needs this to make
                     // the font really available for rendering in the browser
                     Utils.findHiddenNodes('.font-preloading-helper').outerWidth();
-
-                    // Check and resolve the Promise if the font is available in the browser. This must
-                    // be checked async, because when the code runs synchronous e.g. Chrome is not able to make
-                    // the font available for rendering in the browser. This check should normally resolve with
-                    // true in the first round, but browser can behave differently here. So better be save and
-                    // check until the font is finally available or the interval is timed out.
-                    var pollingStartTime = Date.now();
-                    var isFontLoadedInBrowserPolling = window.setInterval(function () {
-
-                        // exit condition: break when the font is still not ready in the browser after 2000ms
-                        if (2000 < (Date.now() - pollingStartTime)) {
-                            //console.log(Date.now() - pollingStartTime);
-                            window.clearInterval(isFontLoadedInBrowserPolling);
-                            loadDeferred.resolve();
-
-                            Utils.warn('ImportReplacementFonts - Timeout while checking font availability for rendering in the Browser after appending font data to DOM');
-
-                        // check if the font is available now
-                        } else if (isFontAvailableInBrowser('Carlito') && isFontAvailableInBrowser('Caladea') && debugReplacementFonts()) {
-
-                            window.clearInterval(isFontLoadedInBrowserPolling);
-                            loadDeferred.resolve();
-                            Utils.log('ImportReplacementFonts - Font is finally available for rendering in the browser after appending font data to DOM');
-                            // set debug state
-                            debugStateImportReplacementFonts.fontReadyInDOM = true;
-
-                        }
-                    }, 100);
                 }
+
+                // Check and resolve the Promise if the font is available in the browser. This must
+                // be checked async, because when the code runs synchronous e.g. Chrome is not able to make
+                // the font available for rendering in the browser. This check should normally resolve with
+                // true in the first round, but browser can behave differently here. So better be save and
+                // check until the font is finally available or the interval is timed out.
+                var pollingStartTime = Date.now();
+                var isFontLoadedInBrowserPolling = window.setInterval(function () {
+
+                    // exit condition: break when the font is still not ready in the browser after 2000ms
+                    if (2000 < (Date.now() - pollingStartTime)) {
+                        //console.log(Date.now() - pollingStartTime);
+                        window.clearInterval(isFontLoadedInBrowserPolling);
+                        loadDeferred.resolve();
+
+                        Utils.warn('ImportReplacementFonts - Timeout while checking font availability for rendering in the Browser after appending font data to DOM');
+
+                    // check if the font is available now
+                    } else if (Font.isInstalled('Carlito') && Font.isInstalled('Caladea') && isTestFontInstalled()) {
+
+                        window.clearInterval(isFontLoadedInBrowserPolling);
+                        loadDeferred.resolve();
+                        Utils.log('ImportReplacementFonts - Font is finally available for rendering in the browser after appending font data to DOM');
+                        // set debug state
+                        debugStateImportReplacementFonts.fontReadyInDOM = true;
+
+                    }
+                }, 100);
             }
 
-            // only for debug
-            Utils.withLogging(function () {
-                Utils.log('ImportReplacementFonts - Calibri:', isFontAvailableInBrowser('Calibri'), ' - Carlito:', isFontAvailableInBrowser('Carlito'), ' - Cambria:', isFontAvailableInBrowser('Cambria'), ' - Caladea:', isFontAvailableInBrowser('Caladea'), '| FontDebugMode:', Config.AUTOTEST, '- ' + DEBUG_FONT_NAME + ':', isFontAvailableInBrowser(DEBUG_FONT_NAME));
-            });
+            // add font when it's cached in localStorage
+            var storageFontData = localStorage.getItem(LOCAL_STORAGE_FONT_KEY);
+            if (storageFontData) {
 
-            // check if font or replacement is installed locally, or already available in the browser
-            if (calibriOrReplacementAvailible && cambriaOrReplacementAvailible && debugReplacementFonts()) {
-                loadDeferred.resolve();
-                Utils.log('ImportReplacementFonts - Needed fonts are installed or a replacement fonts is already available for rendering in the browser');
+                // add font to DOM to be useable
+                addFontToDOM(storageFontData);
+
+                Utils.log('ImportReplacementFonts - Attaching font data from localStorage to DOM');
                 // set debug state
-                debugStateImportReplacementFonts.installedOrReplacementAvailable = true;
+                debugStateImportReplacementFonts.fontAttachedFromLocalStorage = true;
 
-            // when font is not available in the browser
+            // when not cached, load them from server
             } else {
-                // get the data from local storage
-                var localStorageData = localStorage.getItem(LOCAL_STORAGE_FONT_KEY);
 
-                // add font when it's cached in localStorage
-                if (localStorageData !== null && localStorageData !== undefined) {
+                // whether a possible font download should be allowed
+                var blockDownloadToken = localStorage.getItem(LOCAL_STORAGE_BLOCK_FONT_DOWNLOAD_KEY) === 'true';
 
-                    // add font to DOM to be useable
-                    addFontToDOM(localStorageData);
+                // Check if the localStorage is available and really writable (possible problem with browser incognito mode).
+                // Also do not try to download again when localStorage has no free size left
+                // important: the token and also the whole localStorage, besides the fonts,
+                // should be cleared after a logout. Since the token is also deleted, it will
+                // try to download it again after that.
+                if (window.Storage && Utils.isLocalStorageSupported() && !blockDownloadToken) {
 
-                    Utils.log('ImportReplacementFonts - Attaching font data from localStorage to DOM');
-                    // set debug state
-                    debugStateImportReplacementFonts.fontAttachedFromLocalStorage = true;
+                    // get the css file which contains the base64 encoded fonts
+                    $.ajax({
+                        url: ox.root + '/apps/io.ox/office/tk/render/fonts.css',
+                        dataType: 'text',
+                        timeout: 40000 // with 3G 512 kbit/s the 1.7mb font.css needs about 27s to download, add some safety buffer
+                    }).done(function (data) {
 
-                // when not cached, load them from server
-                } else {
+                        Utils.log('ImportReplacementFonts - Loaded fonts via AJAX-request, attach data to localStorage');
+                        // set debug state
+                        debugStateImportReplacementFonts.fontLoadedWithAjax = true;
 
-                    blockDownloadToken = localStorage.getItem(LOCAL_STORAGE_BLOCK_FONT_DOWNLOAD_KEY) === 'true';
+                        try {
+                            // put to local storage
+                            localStorage.setItem(LOCAL_STORAGE_FONT_KEY, data);
+                            // add font to DOM to be useable
+                            addFontToDOM(data);
 
-                    // Check if the localStorage is available and really writable (possible problem with browser incognito mode).
-                    // Also do not try to download again when localStorage has no free size left
-                    // important: the token and also the whole localStorage, besides the fonts,
-                    // should be cleared after a logout. Since the token is also deleted, it will
-                    // try to download it again after that.
-                    if ((typeof (Storage) !== 'undefined') && Utils.isLocalStorageSupported() && !blockDownloadToken) {
-
-                        // get the css file which contains the base64 encoded fonts
-                        $.ajax({
-                            url: ox.root + '/apps/io.ox/office/tk/render/fonts.css',
-                            dataType: 'text',
-                            timeout: 40000 // with 3G 512 kbit/s the 1.7mb font.css needs about 27s to download, add some safety buffer
-                        }).done(function (data) {
-
-                            Utils.log('ImportReplacementFonts - Loaded fonts via AJAX-request, attach data to localStorage');
-                            // set debug state
-                            debugStateImportReplacementFonts.fontLoadedWithAjax = true;
+                        } catch (ex) {
+                            Utils.warn('ImportReplacementFonts - Failed to store data in localStorage', ex);
 
                             try {
-                                // put to local storage
-                                localStorage.setItem(LOCAL_STORAGE_FONT_KEY, data);
-                                // add font to DOM to be useable
-                                addFontToDOM(data);
-
-                            } catch (ex) {
-                                Utils.warn('ImportReplacementFonts - Failed to store data in localStorage', ex);
-
-                                try {
-                                    // set token
-                                    localStorage.setItem(LOCAL_STORAGE_BLOCK_FONT_DOWNLOAD_KEY, true);
-                                } catch (ex2) {
-                                    Utils.warn('ImportReplacementFonts - Failed to store do-not-download-again token in localStorage', ex2);
-                                }
-
-                                loadDeferred.resolve();
+                                // set token
+                                localStorage.setItem(LOCAL_STORAGE_BLOCK_FONT_DOWNLOAD_KEY, true);
+                            } catch (ex2) {
+                                Utils.warn('ImportReplacementFonts - Failed to store do-not-download-again token in localStorage', ex2);
                             }
 
-                        }).fail(function () {
-
-                            // fail mean that just the replacement is not available, everything works like before the replacement fonts existed
                             loadDeferred.resolve();
+                        }
 
-                            Utils.warn('ImportReplacementFonts - Loading font via AJAX-request failed, probably timed out');
-                        });
+                    }).fail(function () {
 
-                    // do nothing when no localStorage is available, everything works like before the replacement fonts existed
-                    } else {
+                        // fail mean that just the replacement is not available, everything works like before the replacement fonts existed
                         loadDeferred.resolve();
-                        Utils.warn('ImportReplacementFonts - No localStorage supported or "do-not-download-again" token set', blockDownloadToken);
-                    }
+
+                        Utils.warn('ImportReplacementFonts - Loading font via AJAX-request failed, probably timed out');
+                    });
+
+                // do nothing when no localStorage is available, everything works like before the replacement fonts existed
+                } else {
+                    loadDeferred.resolve();
+                    Utils.warn('ImportReplacementFonts - No localStorage supported or "do-not-download-again" token set', blockDownloadToken);
                 }
             }
 
-            return docModel.createAbortablePromise(loadDeferred, function () {
+            return this.createAbortablePromise(loadDeferred, function () {
                 Utils.warn('ImportReplacementFonts -  Promise aborted');
             });
         };
@@ -541,31 +498,6 @@ define('io.ox/office/editframework/model/fontcollection', [
 
     } }); // class FontCollection
 
-    // static methods ---------------------------------------------------------
-
-    /**
-     * Returns the first font name specified in the passed font family string
-     * received from a CSS font-family attribute. The CSS font family may
-     * consist of a comma separated list of font names, where the font names
-     * may be enclosed in quote characters.
-     *
-     * @param {String} cssFontFamily
-     *  The value of a CSS font-family attribute.
-     *
-     * @returns {String}
-     *  The first font name from the passed string, without quote characters.
-     */
-    FontCollection.getFirstFontName = function (cssFontFamily) {
-
-        // extract first font name from comma separated list
-        var fontName = $.trim(cssFontFamily.split(',')[0]);
-
-        // Remove leading and trailing quote characters (be tolerant and allow
-        // mixed quotes such as "Font' or even a missing quote character on one
-        // side of the string). After that, trim again and return.
-        return Utils.capitalizeWords($.trim(fontName.match(/^["']?(.*?)["']?$/)[1]).toLowerCase());
-    };
-
     // exports ================================================================
 
     return FontCollection;
