@@ -780,7 +780,7 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          * @returns {*}
          */
         this.getGradientValue = function (gradient, targets) {
-            return Gradient.parseCssColors(gradient, this, targets);
+            return Gradient.resolveColors(gradient, this, targets);
         };
 
         /**
