@@ -107,9 +107,14 @@ define('io.ox/office/editframework/model/operationgenerator', [
         if (isUndo(options)) { this._undoOperations = operations; } else { this._docOperations = operations; }
     };
 
-    OperationGenerator.prototype._internalError = function (msg) {
-        Utils.error('OperationGenerator.appendOperations(): ' + msg);
+    OperationGenerator.prototype._throw = function (err) {
+        Utils.exception(err);
         this._docModel.getApp().setInternalError(ClientError.ERROR_WHILE_MODIFYING_DOCUMENT, ErrorContext.GENERAL);
+        throw err;
+    };
+
+    OperationGenerator.prototype._ensureNotImmediate = function (options, msg) {
+        if (this._applyImmediately && !isUndo(options)) { this._throw(new Error(msg)); }
     };
 
     // public methods ---------------------------------------------------------
@@ -177,10 +182,9 @@ define('io.ox/office/editframework/model/operationgenerator', [
     OperationGenerator.prototype.reverseOperations = function (options) {
 
         // regular operations must not be reversed when they have been applied immediately
-        if (this._applyImmediately && !isUndo(options)) {
-            this._internalError('cannot reverse operations that have been applied immediately');
-        }
+        this._ensureNotImmediate(options, 'cannot reverse operations that have been applied immediately');
 
+        // reverse the specified operations array
         this._get(options).reverse();
         return this;
     };
@@ -200,10 +204,9 @@ define('io.ox/office/editframework/model/operationgenerator', [
     OperationGenerator.prototype.clearOperations = function (options) {
 
         // regular operations must not be cleared when they have been applied immediately
-        if (this._applyImmediately && !isUndo(options)) {
-            this._internalError('cannot clear operations that have been applied immediately');
-        }
+        this._ensureNotImmediate(options, 'cannot clear operations that have been applied immediately');
 
+        // clear the specified operations array
         this._get(options).splice(0);
         return this;
     };
@@ -243,8 +246,10 @@ define('io.ox/office/editframework/model/operationgenerator', [
         // apply the new operations immediately if specified (but skip other operation generators
         // that are in immediate mode by themselves)
         if (this._applyImmediately && !isUndo(options) && !((operations instanceof OperationGenerator) && operations.isImmediateApplyMode())) {
-            if (!newOperations.every(this._docModel.invokeOperationHandler, this._docModel)) {
-                this._internalError('error while applying generated operations');
+            try {
+                newOperations.forEach(this._docModel.invokeOperationHandler, this._docModel);
+            } catch (err) {
+                this._throw(err);
             }
         }
 
@@ -276,9 +281,7 @@ define('io.ox/office/editframework/model/operationgenerator', [
     OperationGenerator.prototype.prependOperations = function (operations, options) {
 
         // regular operations must not be prepended when they will be applied immediately
-        if (this._applyImmediately && !isUndo(options)) {
-            this._internalError('cannot prepend operations, and apply them immediately');
-        }
+        this._ensureNotImmediate(options, 'cannot prepend operations, and apply them immediately');
 
         // the own operations, and the new operations, as JS arrays
         var ownOperations = this._get(options);
