@@ -318,13 +318,13 @@ define('io.ox/office/editframework/model/undomanager', [
          *  if any callback function returns a rejected promise, or the boolean
          *  value false.
          */
-        function invokeCallbacks(callbacks) {
+        function invokeOperationCallbacks(callbacks) {
             return callbacks.reduce(function (promise, callback) {
                 return promise.then(function () {
                     var result = callback.call(self);
                     return (result === false) ? $.Deferred().reject() : result;
                 });
-            }, $.when());
+            }, self.createResolvedPromise());
         }
 
         /**
@@ -348,7 +348,7 @@ define('io.ox/office/editframework/model/undomanager', [
 
             // invoke the callback functions, or apply the document operations
             // (bug 30954: always create a deep copy of the operations)
-            var promise = _.isFunction(operations[0]) ? invokeCallbacks(operations) :
+            var promise = _.isFunction(operations[0]) ? invokeOperationCallbacks(operations) :
                 docModel.applyOperations(_.copy(operations, true), { async: true });
 
             // restore the selection state, after all operations have been applied
@@ -410,9 +410,9 @@ define('io.ox/office/editframework/model/undomanager', [
          *  events 'undo:before', 'undo:after', 'redo:before', and 'redo:after'
          *  triggered when applying undo/redo operations.
          *
-         * @returns {Any}
-         *  The return value of the callback function. In asynchronous mode,
-         *  this will be the promise returned by the callback function.
+         * @returns {jQuery.Promise}
+         *  A promise that will resolve or reject according to the result of
+         *  the callback function.
          */
         this.enterUndoGroup = function (callback, context, options) {
 
@@ -435,7 +435,12 @@ define('io.ox/office/editframework/model/undomanager', [
             groupLevel += 1;
 
             // invoke the callback function
-            var promise = this.convertToPromise(callback.call(context));
+            var promise = null;
+            try {
+                promise = this.convertToPromise(callback.call(context));
+            } catch (err) {
+                promise = this.createRejectedPromise(err);
+            }
 
             // wait for the result, clean up the undo group
             this.waitForAny(promise, function () {
@@ -468,42 +473,28 @@ define('io.ox/office/editframework/model/undomanager', [
         };
 
         /**
-         * Opens an undo action group and executes the specified callback
-         * function. All undo operations added by the callback function will be
-         * collected in the action group and act like a single undo action.
-         * Nested calls are supported.
+         * Executes the specified callback function synchronously, and drops
+         * all undo operations added by the callback function to this instance.
          *
          * @param {Function} callback
-         *  The callback function that will be executed while the undo action
-         *  group is open. If the function returns a promise, the undo group
-         *  remains opened asynchronously until this object will be resolved or
-         *  rejected by the callback.
+         *  The callback function to be executed.
          *
          * @param {Object} [context]
          *  The context the callback function will be bound to.
          *
-         * @param {Object} [options]
-         *  Additional options that will be stored in the undo action generated
-         *  by this method, and that will be passed to the listeners of the
-         *  events 'undo:before', 'undo:after', 'redo:before', and 'redo:after'
-         *  triggered when applying undo/redo operations.
-         *
          * @returns {Any}
-         *  The return value of the callback function. In asynchronous mode,
-         *  this will be the promise returned by the callback function.
+         *  The return value of the callback function.
+         *
+         * @throws {Error}
+         *  Any exception thrown by the callback function.
          */
-        this.disableUndo = function (callback, context) {
-
-            // open a new disabled group
-            disableLevel += 1;
-
-            // invoke the callback function
-            var promise = this.convertToPromise(callback.call(context));
-
-            // wait for the result, leave the disabled group
-            this.waitForAny(promise, function () { disableLevel -= 1; });
-
-            return promise;
+        this.disableUndoSync = function (callback, context) {
+            try {
+                disableLevel += 1;
+                return callback.call(context);
+            } finally {
+                disableLevel -= 1;
+            }
         };
 
         /**
