@@ -22,37 +22,25 @@ define('io.ox/office/editframework/utils/attributeutils', [
 
     var AttributeUtils = {};
 
-    // public methods ---------------------------------------------------------
+    // constants --------------------------------------------------------------
 
     /**
-     * Returns whether the passed string is the name of a attribute that is
-     * registered in the passed attribute definition map.
+     * The internal identifier of the major scheme font in OOXML documents.
      *
-     * @param {Object} definitions
-     *  The attribute definitions map to be checked for an attribute.
-     *
-     * @param {String} name
-     *  The attribute name to be checked.
-     *
-     * @param {Object} [options]
-     *  Optional parameters:
-     *  @param {Boolean} [options.special=false]
-     *      If set to true, the check will include 'special' attributes too
-     *      (attributes marked with the 'special' flag in the attribute
-     *      definitions denoting an attribute for internal use only, not for
-     *      usage in document operations). Otherwise, special attributes will
-     *      not be recognized by this method.
-     *
-     * @returns {Boolean}
-     *  Whether the attribute is registered in the attribute definitions map.
+     * @constant
+     * @type String
      */
-    AttributeUtils.isRegisteredAttribute = function (definitions, name, options) {
+    AttributeUtils.MAJOR_FONT_KEY = '+mj-lt';
 
-        // whether to include special attributes
-        var special = Utils.getBooleanOption(options, 'special', false);
+    /**
+     * The internal identifier of the minor scheme font in OOXML documents.
+     *
+     * @constant
+     * @type String
+     */
+    AttributeUtils.MINOR_FONT_KEY = '+mn-lt';
 
-        return (name in definitions) && (special || (definitions[name].special !== true));
-    };
+    // public methods ---------------------------------------------------------
 
     /**
      * Returns whether the passed (incomplete) attribute set contains the
@@ -168,7 +156,7 @@ define('io.ox/office/editframework/utils/attributeutils', [
      *  they do not match with the current value of the attribute changed
      *  initially. The array property 'childAttrs' of an attribute definition
      *  has been assembled from the 'parent' attribute descriptors passed to
-     *  the method ModelAttributesMixin.registerAttributeDefinitions().
+     *  the method AttributePool.registerAttributes().
      */
     AttributeUtils.updateAttribute = function (attributes, name, value, autoClearDefinition) {
 
@@ -251,6 +239,20 @@ define('io.ox/office/editframework/utils/attributeutils', [
         return _.isObject(attributes) ? (direct ? attributes : _.copy(attributes, true)) : {};
     };
 
+    /**
+     * Stoes the passed explicit attribute set into the DOM node.
+     *
+     * @param {HTMLElement|jQuery} node
+     *  The DOM element whose explicit attribute set will be changed. If this
+     *  object is a jQuery collection, uses the first node it contains.
+     *
+     * @param {Object} attributeSet
+     *  The explicit attribute set to be stored into the passed DOM node.
+     */
+    AttributeUtils.setExplicitAttributes = function (node, attributeSet) {
+        $(node).data('attributes', attributeSet);
+    };
+
     /**
      * Returns the identifier of the style sheet referred by the passed
      * element.
@@ -290,13 +292,39 @@ define('io.ox/office/editframework/utils/attributeutils', [
         );
     };
 
+    /**
+     * Returns the value of the CSS property 'text-decoration' for the passed
+     * character attributes.
+     *
+     * @param {Object} charAttrs
+     *  A map of character attributes. Uses the attributes 'underline' and
+     *  'strike' to generate the CSS property value.
+     *
+     * @returns {String}
+     *  The resulting value of the CSS property 'text-decoration'.
+     */
+    AttributeUtils.getCssTextDecoration = function (charAttrs) {
+
+        var result = '';
+
+        function addToken(token) {
+            if (result) { result += ' '; }
+            result += token;
+        }
+
+        if (charAttrs.underline === true) { addToken('underline'); }
+        if ((typeof charAttrs.strike === 'string') && (charAttrs.strike !== 'none')) { addToken('line-through'); }
+
+        return result || 'none';
+    };
+
     /**
      * checks if assigned character attribute have theme-relevant parameters
      * -character.fontName is minor or major font
      */
-    AttributeUtils.isCharacterFontThemed = function (character) {
-        if (character) { return character.fontName === '+mj-lt' || character.fontName === '+mn-lt'; }
-        return false;
+    AttributeUtils.isCharacterFontThemed = function (charAttrs) {
+        var fontName = Utils.getStringOption(charAttrs, 'fontName', null);
+        return (fontName === AttributeUtils.MAJOR_FONT_KEY) || (fontName === AttributeUtils.MINOR_FONT_KEY);
     };
 
     /**
