@@ -70,6 +70,11 @@ define('io.ox/office/editframework/utils/border', [
      */
     Border.NONE = { style: 'none' };
 
+    Border.HAIR_WIDTH_HMM = BORDER_WIDTH_HMM_MAP.hair;
+    Border.THIN_WIDTH_HMM = BORDER_WIDTH_HMM_MAP.thin;
+    Border.MEDIUM_WIDTH_HMM = BORDER_WIDTH_HMM_MAP.medium;
+    Border.THICK_WIDTH_HMM = BORDER_WIDTH_HMM_MAP.thick;
+
     // static methods ---------------------------------------------------------
 
     /**
@@ -285,8 +290,7 @@ define('io.ox/office/editframework/utils/border', [
      *  The resulting line width, in 1/100 of millimeters.
      */
     Border.getWidthForPreset = function (preset) {
-        var width = BORDER_WIDTH_HMM_MAP[preset];
-        return _.isNumber(width) ? width : 0;
+        return BORDER_WIDTH_HMM_MAP[preset] || 0;
     };
 
     // exports ================================================================
