@@ -15,11 +15,10 @@
 define('io.ox/office/editframework/utils/gradient', [
 
     'io.ox/office/tk/utils',
+    'io.ox/office/editframework/utils/color',
+    'io.ox/office/editframework/utils/attributeutils'
 
-    'io.ox/office/editframework/utils/attributeutils',
-    'io.ox/office/editframework/utils/color'
-
-], function (Utils, AttributeUtils, Color) {
+], function (Utils, Color, AttributeUtils) {
 
     'use strict';
 
@@ -30,6 +29,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
         Object          = global.Object,
         Array           = global.Array,
+        Number          = global.Number,
 
         NOOP            = global.Function.prototype,
 
@@ -45,8 +45,7 @@ define('io.ox/office/editframework/utils/gradient', [
         isEqualValue    = _.isEqual,
 
         isFunction      = _.isFunction,
-      //isArray         = _.isArray,
-      //isObject        = _.isObject,
+        isNumber        = _.isNumber,
 
         isObjectObject  = function (type) {
             return (!!type && regXObjectObject.test(expose_internal_class_name.call(type)));
@@ -77,6 +76,8 @@ define('io.ox/office/editframework/utils/gradient', [
         math_degree     = function getRadix(angleRadix) {
             return (angleRadix * 180 / MATH_PI);
         },
+        math_sqrt       = Math.sqrt,
+
         math_cos        = Math.cos,
         math_sin        = Math.sin,
         math_tan        = Math.tan,
@@ -109,7 +110,263 @@ define('io.ox/office/editframework/utils/gradient', [
 
     // var gradientList = []; // @NOTIFICATION: for debugging only.
 
-    // private static (locally scoped) class methods ==========================
+    // private static (locally scoped) helper class and class methods =========
+
+    var GradientColor = (function (/*Object, Math*/) {
+        //
+        // var
+        //     expose_internal_class_name  = Object.prototype.toString,
+        //     regXObjectObject            = (/^\[object\s+Object]$/),
+        //
+        //     math_min    = Math.min,
+        //     math_max    = Math.max,
+        //
+        //     math_round  = Math.round;
+        //
+        //     math_sqrt   = Math.sqrt,
+
+        // // var regXHexChannels = (/^#*(?:(?:([0-9a-f])([0-9a-f])([0-9a-f]))|(?:([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})))$/i);
+        // var regXHexString = (/^#*([0-9a-f]{3}|[0-9a-f]{6})$/i);
+        // var regXDecString = (/^rgb[a]*\s*\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})(?:\s*,\s*([0-9.]{1,4}))?\s*\)$/i);
+
+        function alphaChannelSubtraction(minuendValue, subtrahendValue) {
+            return (minuendValue.a - subtrahendValue.a);
+        }
+
+        function colorValueSubtraction(minuendValue, subtrahendValue) {
+            return {
+                r: (minuendValue.r - subtrahendValue.r),
+                g: (minuendValue.g - subtrahendValue.g),
+                b: (minuendValue.b - subtrahendValue.b)
+            };
+        }
+        function colorValueSummation(c1Value, c2Value) {
+            return {
+                r: (c1Value.r + c2Value.r),
+                g: (c1Value.g + c2Value.g),
+                b: (c1Value.b + c2Value.b)
+            };
+        }
+
+        function colorValueChannelShifting(colorValue, percentageValue) {
+            percentageValue = (math_max(0, math_min(100, percentageValue)) / 100);
+            return {
+                r: math_round(colorValue.r * percentageValue),
+                g: math_round(colorValue.g * percentageValue),
+                b: math_round(colorValue.b * percentageValue)
+            };
+        }
+
+        /**
+         *  1) Chosen approach ... also the one that describes all other possible solutions and why not to choose them ...
+         *
+         *     Calculating the Perceived Brightness of a Color
+         *     [http://www.nbdtech.com/Blog/archive/2008/04/27/Calculating-the-Perceived-Brightness-of-a-Color.aspx]
+         *
+         *     - further reads in German:
+         *          * YIQ-Farbmodell    [https://de.wikipedia.org/wiki/YIQ-Farbmodell]  //
+         *          * Chrominanz        [https://de.wikipedia.org/wiki/Chrominanz]      //
+         *          * Luminanz          [https://de.wikipedia.org/wiki/Luminanz]        //
+         *          * Helligkeit        [https://de.wikipedia.org/wiki/Helligkeit]      // BRIGHTNESS
+         *
+         *  2) JS formula ...
+         *
+         *     Calculate brightness value by RGB or HEX color (sitting on a w3 working draft for accessibility)
+         *     [https://gist.github.com/w3core/e3d9b5b6d69a3ba8671cc84714cca8a4]
+         *
+         *  3) notable ...
+         *
+         *     “Light intensity” of an RGB value
+         *     [https://computergraphics.stackexchange.com/questions/5085/light-intensity-of-an-rgb-value]
+         *
+         */
+        function parseBrightnessFromGradientColorValue(colorValue) {
+            return math_round(math_sqrt(
+
+                (colorValue.r * colorValue.r * 0.241) +
+                (colorValue.g * colorValue.g * 0.691) +
+                (colorValue.b * colorValue.b * 0.068)
+
+            ) * colorValue.a);
+        }
+
+        function createGradientColorValueFromDescriptor(descriptorOrValue) {
+            var value = {},
+                alpha = descriptorOrValue.a,
+
+                bytes = descriptorOrValue.bytes;
+
+            alpha = (isNumber(alpha) ? math_max(0, math_min(1, alpha)) : 1);
+            // console.log('createGradientColorValueFromDescriptor :: alpha : ', alpha);
+
+            if (bytes) {
+                value.r = bytes[0];
+                value.g = bytes[1];
+                value.b = bytes[2];
+            } else {
+                value.r = descriptorOrValue.r;
+                value.g = descriptorOrValue.g;
+                value.b = descriptorOrValue.b;
+            }
+            value.a = alpha;
+
+            return value;
+        }
+
+        function GradientColor(descriptor) {
+            var colorValue = createGradientColorValueFromDescriptor(descriptor);
+
+            this.compile = function (compileValue) {
+                compileValue = createGradientColorValueFromDescriptor(compileValue);
+
+                colorValue.r = compileValue.r;
+                colorValue.g = compileValue.g;
+                colorValue.b = compileValue.b;
+                colorValue.a = compileValue.a;
+
+                // object_extend(colorValue, createGradientColorValueFromDescriptor(compileValue));
+
+                return this;
+            };
+
+            this.valueOf = function () {
+                return { r: colorValue.r, g: colorValue.g, b: colorValue.b, a: colorValue.a };
+            };
+            this.toString = function () {
+                return ['{ r: ', colorValue.r, ', g: ', colorValue.g, ', b: ', colorValue.b, ', a: ', colorValue.a, ' }'].join('');
+            };
+
+            this.parseBrightness = function () {
+                return parseBrightnessFromGradientColorValue(colorValue);
+            };
+
+            this.deltaAlpha = function (subtrahendValue) {
+                return alphaChannelSubtraction(colorValue, subtrahendValue.valueOf());
+            };
+
+            this.subtract = function (subtrahendValue) {
+                return this.compile(colorValueSubtraction(colorValue, subtrahendValue.valueOf()));
+            };
+            // this.getDifference = function (subtrahendValue) {
+            //     return (new GradientColor(colorValueSubtraction(colorValue, subtrahendValue.valueOf())));
+            // };
+
+            this.add = function (addValue) {
+                return this.compile(colorValueSummation(colorValue, addValue.valueOf()));
+            };
+            // this.getSum = function (addValue) {
+            //     return (new GradientColor(colorValueSummation(colorValue, addValue.valueOf())));
+            // };
+
+            this.shiftChannels = function (percentageValue) {
+                return this.compile(colorValueChannelShifting(colorValue, percentageValue));
+            };
+
+            return this;
+        }
+        // GradientColor.prototype[ ... ]
+
+        return GradientColor;
+
+    }(/*Object, Math*/));
+
+    // Microsoft specific color-stop list computation =========================
+
+    function isNeedsMicrosoftSpecificGradientCalculation(colorStopList) {
+        return (
+               (colorStopList.length === 2)
+            && ((colorStopList[0].position === 0) && (colorStopList[1].position === 1))
+            && (colorStopList[0].color !== colorStopList[1].color)
+        );
+    }
+
+    function applyMSSpecificColorStopListPatch(colorStopList) {
+        var
+            patchedList = [],
+
+            colorStopStartValue = colorStopList[0],
+            colorStopEndValue   = colorStopList[1],
+
+            gradientStartColor  = (new GradientColor(colorStopStartValue.colorDescriptor)),
+            gradientEndColor    = ((new GradientColor(colorStopEndValue.colorDescriptor))),
+
+            alphaReference      = gradientStartColor.valueOf().a,
+            alphaDelta          = gradientEndColor.deltaAlpha(gradientStartColor);
+
+        // please do not turn this function into a closure ... a plain function declaration donates most to an optimal JIT compiler result.
+        function getShiftedAlpha(reference, delta, shift) {
+            return Number((reference + (delta * shift)).toPrecision(2));
+        }
+
+        /**
+         *  The Microsoft specific gradient for a full-range (0% - 100%),
+         *  2-values colorstop-list seems to always stretch a gradient's
+         *  scale much more in favor of it's colors of higher brightness.
+         *
+         *  The next steps take this into account and temporarily patch
+         *  such a gradients appearance/behavior on the fly.
+         */
+        if (gradientStartColor.parseBrightness() < gradientEndColor.parseBrightness()) {
+
+            // stepwise calculate from 100% to 0% and unshift results into list.
+            patchedList = [{
+
+                position: 0.9,
+                color: getGradientColorString(gradientEndColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.9))
+
+            }, colorStopEndValue];
+
+            // 70% color value of original full color range positioned to 50%.
+            gradientEndColor = (gradientEndColor).subtract(gradientStartColor).shiftChannels(70).add(gradientStartColor);
+            patchedList.unshift({
+                position: 0.5,
+                color: getGradientColorString(gradientEndColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.5))
+            });
+
+            // 30% color value of new color stopped range (50% positioning * 60% channel shifting: .5 * .6 = .3) positioned to 20%.
+            gradientEndColor = (gradientEndColor).subtract(gradientStartColor).shiftChannels(60).add(gradientStartColor);
+            patchedList.unshift({
+                position: 0.25,
+                color: getGradientColorString(gradientEndColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.25))
+            });
+
+            patchedList.unshift(colorStopStartValue);
+
+        } else {
+            // inverted stepwise calculation (from 0% to 100% with switched operands) and push results into list.
+
+            patchedList = [
+                colorStopStartValue, {
+
+                    position: 0.1,
+                    color: getGradientColorString(gradientStartColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.1))
+                }
+            ];
+
+            // 70% color value of original full color range positioned to 50%.
+            gradientStartColor = (gradientStartColor).subtract(gradientEndColor).shiftChannels(70).add(gradientEndColor);
+            patchedList.push({
+                position: 0.5,
+                color: getGradientColorString(gradientStartColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.5))
+            });
+
+            // 30% color value of new color stopped range (50% positioning * 60% channel shifting: .5 * .6 = .3) positioned to 20%.
+            gradientStartColor = (gradientStartColor).subtract(gradientEndColor).shiftChannels(60).add(gradientEndColor);
+            patchedList.push({
+                position: 0.75,
+                color: getGradientColorString(gradientStartColor.valueOf(), getShiftedAlpha(alphaReference, alphaDelta, 0.75))
+            });
+
+            patchedList.push(colorStopEndValue);
+        }
+        return patchedList;
+    }
+
+    function getPatchedColorStopListIfNeeded(colorStopList) {
+        return ((isNeedsMicrosoftSpecificGradientCalculation(colorStopList) && applyMSSpecificColorStopListPatch(colorStopList)) || colorStopList);
+    }
+
+    // canvas helpers =========================================================
 
     function returnCleanSketchSheet(width, height) {
         CANVAS_ELEMENT.width  = width;
@@ -170,6 +427,8 @@ define('io.ox/office/editframework/utils/gradient', [
         return drawingContext.createPattern(sketchCanvas, 'no-repeat');
     }
 
+    // gradient computation functionality =====================================
+
     /**
      *
      * @param context
@@ -638,7 +897,8 @@ define('io.ox/office/editframework/utils/gradient', [
     }
 
     function parseColorStopsForFillPathRectangular(colorStopList) {
-        // halven of all positions and inverse duplicating the before halvened range.
+        // halfen of all positions and inverse duplicating the before halfened range.
+        colorStopList = getPatchedColorStopListIfNeeded(colorStopList);
 
         colorStopList = array_from(colorStopList).map(function (colorStopValue) {
             return {
@@ -755,10 +1015,14 @@ define('io.ox/office/editframework/utils/gradient', [
      * @returns {CanvasGradient}
      */
     function createGradientFillLinear(context, colorStopList, x1, y1, x2, y2) {
+
+        colorStopList = getPatchedColorStopListIfNeeded(colorStopList);
         var
             gradientFill = context.createLinearGradient(x1, y1, x2, y2);
 
         colorStopList.forEach(function (colorStopValue) {
+            // window.console.log('+++ createGradientFillLinear :: addColorStop :: [position, color] : ', colorStopValue.position, colorStopValue.color);
+
             gradientFill.addColorStop(colorStopValue.position, colorStopValue.color);
         });
         return gradientFill;
@@ -808,8 +1072,8 @@ define('io.ox/office/editframework/utils/gradient', [
 
             colorStopList     = parseColorStopsForFillPathRectangular(gradientValue.colorStops);
 
-        // debugging
-        //
+        // // debugging
+        // //
         // document.body.appendChild(sketchCanvas);
         // sketchCanvas.style.position = 'absolute';
 
@@ -855,8 +1119,8 @@ define('io.ox/office/editframework/utils/gradient', [
 
             colorStopList     = parseColorStopsForFillPathRectangular(gradientValue.colorStops);
 
-        // debugging
-        //
+        // // debugging
+        // //
         // document.body.appendChild(sketchCanvas);
         // sketchCanvas.style.position = 'absolute';
 
@@ -899,7 +1163,7 @@ define('io.ox/office/editframework/utils/gradient', [
             cathetus_1b       = math_abs(path_y1 - tileRectMeasures.y1),
             radius_1          = math_round(Utils.radius(cathetus_1a, cathetus_1b)),
 
-            colorStopList     = gradientValue.colorStops,
+            colorStopList     = getPatchedColorStopListIfNeeded(gradientValue.colorStops),
           //rotationValue     = (gradientValue.rotation % 360),
 
             gradientFill      = context.createRadialGradient(path_x1, path_y1, 0, path_x1, path_y1, radius_1);/*
@@ -917,6 +1181,8 @@ define('io.ox/office/editframework/utils/gradient', [
         }*/
 
         colorStopList.forEach(function (colorStopValue) {
+            // window.console.log('+++ getGradientFillRadialUnbound :: addColorStop :: [position, color] : ', colorStopValue.position, colorStopValue.color);
+
             gradientFill.addColorStop(colorStopValue.position, colorStopValue.color);
         });
 
@@ -945,7 +1211,7 @@ define('io.ox/office/editframework/utils/gradient', [
             cathetus_1b       = math_abs(path_y1 - tileRectMeasures.y1),
             radius_1          = math_round(Utils.radius(cathetus_1a, cathetus_1b)),
 
-            colorStopList     = gradientValue.colorStops,
+            colorStopList     = getPatchedColorStopListIfNeeded(gradientValue.colorStops),
           //rotationValue     = (gradientValue.rotation % 360),
 
             gradientFill      = context.createRadialGradient(path_x1, path_y1, 0, path_x1, path_y1, radius_1);/*
@@ -963,6 +1229,8 @@ define('io.ox/office/editframework/utils/gradient', [
          }*/
 
         colorStopList.forEach(function (colorStopValue) {
+            // window.console.log('+++ getGradientFillRadialBound :: addColorStop :: [position, color] : ', colorStopValue.position, colorStopValue.color);
+
             gradientFill.addColorStop(colorStopValue.position, colorStopValue.color);
         });
 
@@ -1063,14 +1331,70 @@ define('io.ox/office/editframework/utils/gradient', [
 
     /**
      *
-     * @param colorStop
-     * @returns {*}
+     * @param descriptorOrValue {Object}
+     * @param alpha {Number} optional
+     * @returns {string}
      */
-    function parseCssColorStop(colorStop, docModel, target) {
+    function getGradientColorString(descriptorOrValue, alpha) {
+        alpha = (isNumber(alpha) ? math_max(0, math_min(1, alpha)) : descriptorOrValue.a);
 
-        colorStop.color = docModel.getCssColor(colorStop.color, 'fill', target);
+        var bytes = descriptorOrValue.bytes;
+        var hex   = descriptorOrValue.hex;
 
-        return colorStop;
+        return (
+               ((alpha === 1) && hex && ['#', hex.toLowerCase()].join(''))
+
+            || (bytes && ['rgba(', [bytes[0], bytes[1], bytes[2], alpha].join(','), ')'].join(''))
+
+            || ['rgba(', [descriptorOrValue.r, descriptorOrValue.g, descriptorOrValue.b, alpha].join(','), ')'].join('')
+        );
+    }
+
+    /**
+     *
+     * @param colorStopValue {Object}
+     * @returns  {Object} colorStopValue
+     *  Returns a mapped variant of a `ColorStop` value with it's `color` attribute being
+     *  the string representation of a canvas gradient color.
+     *  In addition the newly assigned `colorDescriptor` attribute holds all information
+     *  of how to technically describe a color by various color models.
+     */
+    function resolveColorStopValue(colorStopValue, docModel, target) {
+        var
+            colorType   = Color.parseJSON(colorStopValue.color),
+            descriptor  = object_extend({}, docModel.resolveColor(colorType, 'fill', target)); // map [ColorDescriptor] instance to pure [Object] instance.
+        //
+        // [{
+        //     a: 0.82,
+        //     bytes: (4) [0, 0, 0, 209],
+        //     css: "rgba(0,0,0,0.82)",
+        //     dark: true,
+        //     hex: "000000",
+        //     hsl: {a: 0.82, h: 0, s: 0, l: 0},
+        //     rgb: {a: 0.82, r: 0, g: 0, b: 0},
+        //     type: "scheme",
+        //     y: 0,
+        // }, {
+        //     a: 0,
+        //     bytes: (4) [255, 255, 255, 0],
+        //     css: "transparent",
+        //     dark: false,
+        //     hex: "FFFFFF",
+        //     hsl: {a: 0, h: 0, s: 0, l: 1},
+        //     rgb: {a: 0, r: 1, g: 1, b: 1},
+        //     type: "scheme",
+        //     y: 1,
+        // }]
+
+        // overwrite `color` attribute.
+        //
+        // https://developer.mozilla.org/en-US/docs/Web/API/CanvasGradient/addColorStop
+        // https://developer.mozilla.org/en-US/docs/Web/CSS/color_value
+        //
+        colorStopValue.color = getGradientColorString(descriptor);
+        colorStopValue.colorDescriptor = descriptor;
+
+        return colorStopValue;
     }
 
     /**
@@ -1286,7 +1610,7 @@ define('io.ox/office/editframework/utils/gradient', [
         /**
          * Returns whether this gradient equals the passed gradient type.
          *
-         * @param {Gradient} gradient
+         * @param {Gradient} type
          *  The gradient type to be compared with this gradient.
          *
          * @returns {Boolean}
@@ -1529,7 +1853,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
             gradient = (new Gradient(state, colorStopList, traitList));
         }
-        //if (gradient) { gradientList.push(gradient); } // @NOTIFICATION: for debugging only.
+        // if (gradient) { gradientList.push(gradient); } // @NOTIFICATION: for debugging only.
 
         return gradient;
     }
@@ -1713,12 +2037,12 @@ define('io.ox/office/editframework/utils/gradient', [
      * @param target
      * @returns {*}
      */
-    function parseCssColors(gradient, docModel, target) {
+    function resolveColors(gradient, docModel, target) {
         var
             gradientValue = gradient.valueOf();
 
-        gradientValue.colorStops.forEach(function (colorStop) {
-            parseCssColorStop(colorStop, docModel, target);
+        gradientValue.colorStops.map(function (colorStopValue) {
+            return resolveColorStopValue(colorStopValue, docModel, target);
         });
 
         return gradientValue;
@@ -1736,10 +2060,10 @@ define('io.ox/office/editframework/utils/gradient', [
     function parseFillStyle(docModel, gradient, context, target, pathCoords) {
       //// Utils.info('+++ Gradient.parseFillStyle +++ pathCoords : ', pathCoords);
         var                                                                           //  - refactor `CanvasWrapper` making it aware of a parent `Shape` abstraction
-            $drawingNode    = $(context.canvas).closest('.drawing.rotated-drawing'),  //  - ones a canva wrapper type can acces it parent shape type, retrieving
+            $drawingNode    = $(context.canvas).closest('.drawing.rotated-drawing'),  //  - ones a canvas wrapper type can access it's parent shape type, retrieving
             drawingAttrs    = AttributeUtils.getExplicitAttributes($drawingNode),     //    values like e.g. `parentRotation` will be much easier and far cleaner.
 
-            gradientValue   = parseCssColors(gradient, docModel, target),
+            gradientValue   = resolveColors(gradient, docModel, target),
             gradientFill,
 
             parentRotation  = (drawingAttrs && drawingAttrs.drawing && drawingAttrs.drawing.rotation) || 0;
@@ -1803,10 +2127,10 @@ define('io.ox/office/editframework/utils/gradient', [
 
     var Module = {      //  assign locally scoped static method implementations.
 
-      //all:                function () { return array_from(gradientList); },       // @NOTIFICATION: for debugging only.
+        // all:                function () { return array_from(gradientList); },       // @NOTIFICATION: for debugging only.
         create:             createGradient,
 
-        parseCssColors:     parseCssColors,
+        resolveColors:      resolveColors,
         parseFillStyle:     parseFillStyle,
 
         parseImageDataUrl:  parseImageDataUrl,
