@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -29,6 +30,16 @@ define('io.ox/office/editframework/utils/mixedborder', [
         insidev: 'borderInsideVert'
     };
 
+    // the names of all border mode properties in cells, mapped by border properties
+    var CELL_BORDER_MODE_PROPERTIES = {
+        borderLeft: 'left',
+        borderRight: 'right',
+        borderTop: 'top',
+        borderBottom: 'bottom',
+        borderInsideHor: 'insideh',
+        borderInsideVert: 'insidev'
+    };
+
     // the names of all border properties in paragraphs, mapped by border mode properties
     var PARAGRAPH_BORDER_ATTRIBUTES = {
         left: 'borderLeft',
@@ -276,6 +287,17 @@ define('io.ox/office/editframework/utils/mixedborder', [
      *      have vertical inner borders), instead of the two attributes
      *      'borderInsideHor' and 'borderInsideVert'.
      *
+     *  @param {Boolean} [options.clearBorderNoneFromAttributes=false]
+     *      If set to true, and the border is not visible (e.g. the paragraph
+     *      border is removed in text), it will clear the related border
+     *      attribute from the paragraph attributes list by returning 'null'
+     *      for the related operation, instead of returning the styles from
+     *      'Border.NONE'. This is conform with the behavior in Word.
+     *
+     *  @param {Boolean} [options.fullBorderSet=false]
+     *      If set to true, a full set of borders shall be returned. This is
+     *      the case in the presentation app.
+     *
      * @returns {Object}
      *  The table/cell attributes containing all border attributes that are
      *  mentioned in the passed border mode. In case the passed border mode is
@@ -288,8 +310,12 @@ define('io.ox/office/editframework/utils/mixedborder', [
         var attributeNames = getBorderAttributeNames(options);
         // the resulting border attributes
         var borderAttributes = {};
+        // indicates if 'Border.NONE' or 'null' is returned for an invisible border
+        var clearBorderNoneFromAttributes = Utils.getBooleanOption(options, 'clearBorderNoneFromAttributes', false);
+        // whether a full set of borders shall be returned
+        var fullBorderSet = Utils.getBooleanOption(options, 'fullBorderSet', false);
 
-        function addBorderAttribute(visible, propName) {
+        function addBorderAttribute(visible, propName, obj, keepState) {
 
             // ignore invalid properties
             if (!(propName in attributeNames)) { return; }
@@ -304,20 +330,46 @@ define('io.ox/office/editframework/utils/mixedborder', [
             // toggle visibility if specified (but switch from 'mixed' state to visible)
             visible = (visible === null) ? ((origVisible && origBorder.mixed) || !origVisible) : visible;
 
-            // use default border, if any of the original border properties is ambiguous
-            var newBorder = !visible ? Border.NONE : (origVisible && !MixedBorder.hasAmbiguousProperties(origBorder)) ? origBorder : defaultBorder;
+            // no toggling, but keeping the state (only useful in connection with 'fullBorderSet')
+            if (keepState) { visible = origVisible; }
 
-            // build the border attribute value according to visibility and original borders
-            borderAttributes[borderAttrName] = _.copy(newBorder, true);
-            delete borderAttributes[borderAttrName].mixed;
+            // return 'null' when the border is not visible, this removes
+            // the border attribute completely from the paragraph attributes
+            if (clearBorderNoneFromAttributes && !visible) {
+                borderAttributes[borderAttrName] = null;
+
+            // the old, normal behaviour
+            } else {
+                // use default border, if any of the original border properties is ambiguous
+                var newBorder = !visible ? Border.NONE : (origVisible && !MixedBorder.hasAmbiguousProperties(origBorder)) ? origBorder : defaultBorder;
+
+                // build the border attribute value according to visibility and original borders
+                borderAttributes[borderAttrName] = _.copy(newBorder, true);
+                delete borderAttributes[borderAttrName].mixed;
+            }
         }
 
         if (_.isObject(borderMode)) {
             // fill the resulting attribute map
             _.each(borderMode, addBorderAttribute);
+
+            // if full border mode is set, all border attributes must be specified
+            if (fullBorderSet) {
+                _.each(CELL_BORDER_ATTRIBUTES, function (type) {
+                    if (!borderAttributes[type]) { borderAttributes[type] = { style: 'none' }; }
+                });
+            }
+
         } else if (_.isString(borderMode)) {
             // toggle the visibility of a single border
             addBorderAttribute(null, borderMode);
+
+             // if full border mode is set, all border attributes must be specified (keeping the visibility of all other borders)
+            if (fullBorderSet) {
+                _.each(CELL_BORDER_ATTRIBUTES, function (type) {
+                    if (!borderAttributes[type]) { addBorderAttribute(null, CELL_BORDER_MODE_PROPERTIES[type], null, true); }
+                });
+            }
         }
 
         return borderAttributes;
