@@ -18,6 +18,20 @@ define('io.ox/office/editframework/utils/operations', [
 
     'use strict';
 
+    // static class BaseOperations ============================================
+
+    var BaseOperations = {};
+
+    // static methods ---------------------------------------------------------
+
+    BaseOperations.extend = function () {
+        var operations = _.clone(this);
+        _.each(arguments, function (constants) {
+            _.extend(operations, constants);
+        });
+        return operations;
+    };
+
     // static class EditOperations ============================================
 
     /**
@@ -25,7 +39,7 @@ define('io.ox/office/editframework/utils/operations', [
      *
      * @extends DrawingOperations
      */
-    var EditOperations = _.extend(DrawingOperations, {
+    var EditOperations = BaseOperations.extend(DrawingOperations, {
 
         /**
          * Name of the initial operation while importing a document, sets
