@@ -23,13 +23,14 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
 
     // class FontNameValidator ================================================
 
-    var FontNameValidator = ComboField.Validator.extend({ constructor: function (docModel) {
+    var FontNameValidator = ComboField.Validator.extend(function (docModel) {
+        ComboField.Validator.call(this);
+        this._docModel = docModel;
+    });
 
-        this.valueToText = function (value) {
-            return docModel.resolveFontName(value);
-        };
-
-    } });
+    FontNameValidator.prototype.valueToText = function (value) {
+        return this._docModel.resolveFontName(value);
+    };
 
     // class FontFamilyPicker =================================================
 
@@ -65,7 +66,6 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
         }, initOptions, {
             sortItems: true,
             typeAhead: true,
-            itemMatcher: schemeMatcher, // TODO (bug 53416) remove when list items for scheme fonts are available
             validator: new FontNameValidator(docModel)
         }));
 
@@ -73,22 +73,21 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
 
         // private methods ----------------------------------------------------
 
-        function schemeMatcher(value, fontKey) {
-            return docModel.resolveFontName(value) === fontKey;
-        }
-
         /**
          * Creates a list item for the specified font.
          */
-        function createFontEntry(section, fontKey) {
-            var fontName = docModel.resolveFontName(fontKey);
-            self.createListEntry(fontKey, {
+        function createFontEntry(section, fontKey, subLabel, sortIndex) {
+            var fontName = self.valueToText(fontKey);
+            var buttonNode = self.getMenu().createItemNode(fontKey, {
                 section: section,
                 label: _.noI18n(fontName),
                 labelStyle: { fontFamily: docModel.getCssFontFamily(fontName), fontSize: '115%' },
-                tooltip: _.noI18n(fontName),
-                sortIndex: fontName.toLowerCase()
+                tooltip: _.noI18n(fontName + (subLabel ? (' ' + subLabel) : '')),
+                sortIndex: sortIndex || fontName.toLowerCase()
             });
+            if (subLabel) {
+                buttonNode.append($('<span class="sub-label">').text(subLabel));
+            }
         }
 
         /**
@@ -98,12 +97,14 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
 
             self.getMenu().clearContents();
 
-            // TODO (bug 53416) create the menu entries for scheme fonts
-//            if (docView.getApp().isOOXML()) {
-//                self.getMenu().createSectionNode('scheme');
-//                createFontEntry('scheme', AttributeUtils.MAJOR_FONT_KEY);
-//                createFontEntry('scheme', AttributeUtils.MINOR_FONT_KEY);
-//            }
+            // create the menu entries for scheme fonts
+            if (docView.getApp().isOOXML()) {
+                self.getMenu().createSectionNode('scheme');
+                //#. a label suffix for the default font of the document, used for "important text" such as headings (shown in font drop-down font name)
+                createFontEntry('scheme', AttributeUtils.MAJOR_FONT_KEY, gt.pgettext('font', '(Headings)'), 1);
+                //#. a label suffix for the default font of the document, used for "regular text" (shown in font drop-down after font name)
+                createFontEntry('scheme', AttributeUtils.MINOR_FONT_KEY, gt.pgettext('font', '(Body)'), 2);
+            }
 
             // create the menu entries for the regular fonts contained in the document font collection
             self.getMenu().createSectionNode('fonts');
@@ -114,6 +115,8 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
 
         // initialization -----------------------------------------------------
 
+        this.getMenuNode().addClass('font-family-picker');
+
         // add all known fonts after import and changed fonts
         this.waitForImportSuccess(fillList);
         this.listenTo(themeCollection, 'triggered', fillList);
