@@ -67,6 +67,8 @@ define('io.ox/office/editframework/view/control/languagepicker', [
                 definition.supported = _.contains(supportedLocales, definition.lc);
             });
             return localeDefinitions;
+        }, function () {
+            return localeDefinitions; // returning the list of locales also in the error case (59345)
         });
     }());
 
