@@ -42,15 +42,15 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
      * @param {Object} [initOptions]
      *  Optional parameters passed to the RadioList constructor. Supports all
      *  options of the RadioList class, and the following additional options:
-     *  @param {String|String[]} [initOptions.previewFamilies]
+     *  - {String|Array<String>} [initOptions.previewFamilies]
      *      The attribute families used to get the formatting options of the
      *      list items representing the style sheets. If omitted, only
      *      attributes of the family specified by the 'family' parameter will
      *      be used.
-     *  @param {String[]} [initOptions.sections]
+     *  - {Array<String>} [initOptions.sections]
      *      An array specifying the order of all predefined section
      *      identifiers.
-     *  @param {String} [initOptions.i18nModulePath]
+     *  - {String} [initOptions.i18nModulePath]
      *      The module path to the localized JSON object containing the
      *      configuration of translated style sheet names. Each property of the
      *      map must be a string with the English style sheet name as key.
@@ -58,42 +58,51 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
      *      capturing groups (in parentheses). The values of the map are the
      *      translated style sheet names. The placeholders '$1', '$2', etc.
      *      will match the capturing groups defined in the key patterns.
+     *  - {Boolean} [initOptions.addSectionLabel=false]
+     *      Whether to add a label to the sections.
+     *  - {Array<Object>} [initOptions.additionalItems]
+     *      Additional stylesheet items. The array contains objects with the
+     *      style attributes.
      */
     function StyleSheetPicker(docView, family, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the model instance
-            docModel = docView.getDocModel(),
+        // the model instance
+        var docModel = docView.getDocModel();
 
-            // the style collection
-            styleCollection = docModel.getStyleCollection(family),
+        // the theme model that has been used to create the scheme color table
+        var themeModel = docModel.getThemeModel();
 
-            // the path to the translated style sheet names
-            modulePath = Utils.getStringOption(initOptions, 'i18nModulePath', ''),
+        // the style collection
+        var styleCollection = docModel.getStyleCollection(family);
 
-            // the configuration for translated style sheet names
-            translationDatabase = {},
+        // the path to the translated style sheet names
+        var modulePath = Utils.getStringOption(initOptions, 'i18nModulePath', '');
 
-            // the cache with translated style sheet names
-            translationCache = {},
+        // the configuration for translated style sheet names
+        var translationDatabase = {};
 
-            app = docView.getApp(),
-            // targetChain for finding current active theme
-            target = [],
-            // painted TargetChain is set when buttons are repainted
-            paintedTarget = null;
+        // the cache with translated style sheet names
+        var translationCache = {};
+
+        // whether the preview table needs to be refreshed
+        var dirty = true;
+
+        var addSectionLabel = Utils.getBooleanOption(initOptions, 'sectionLabel', false);
+
+        var additionalItems = Utils.getArrayOption(initOptions, 'additionalItems', []);
 
         // base constructors --------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             itemDesign: 'grid',
             sortItems: true,
             updateCaptionMode: 'none'
         }, initOptions));
 
-        AppObjectMixin.call(this, app);
+        AppObjectMixin.call(this, docView.getApp());
 
         // private methods ----------------------------------------------------
 
@@ -114,10 +123,10 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
          */
         function translateStyleName(styleName) {
 
-            var // the lower-case style name, used as database key
-                styleKey = styleName.toLowerCase(),
-                // the translated style name
-                translatedName = null;
+            // the lower-case style name, used as database key
+            var styleKey = styleName.toLowerCase();
+            // the translated style name
+            var translatedName = null;
 
             // first, check the cache of the translation database
             translatedName = translationCache[styleKey];
@@ -138,24 +147,21 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
          */
         function updateHandler(styleId) {
             var styleName = styleId ? styleCollection.getName(styleId) : null;
+            if (!styleName) {
+                _.find(additionalItems, function (style) {
+                    if (style.id === styleId) {
+                        styleName = style.name;
+                        return true;
+                    }
+                });
+            }
             self.setLabel(styleName ? translateStyleName(styleName) : '');
         }
 
-        /**
-         * Creates a new button in the drop-down menu for the specified style
-         * sheet.
-         */
-        function createOptionButton(styleName, styleId) {
+        function createOptionButton(styleName, styleId, category, priority) {
 
-            // nothing to do for hidden styles
-            if (styleCollection.isHidden(styleId)) { return; }
-
-            var // the section identifier for the style sheet
-                category = styleCollection.getUICategory(styleId) || '',
-                // sorting priority
-                priority = Math.floor(styleCollection.getUIPriority(styleId)),
-                // the sort index stored at the button for lexicographical sorting
-                sortIndex = String((priority < 0) ? (priority + 0x7FFFFFFF) : priority);
+            // the sort index stored at the button for lexicographical sorting
+            var sortIndex = String((priority < 0) ? (priority + 0x7FFFFFFF) : priority);
 
             //TODO: hacked code for functions like "create new paragraph stylesheet"
             //we could use the category for
@@ -171,31 +177,65 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
             sortIndex = ((priority < 0) ? '0' : '1') + sortIndex + styleName.toLowerCase();
 
             // create the list item, pass sorting index
-            self.createOptionButton(styleId, { section: category, label: styleName, tooltip: styleName, sortIndex: sortIndex });
+            self.createOptionButton(styleId, { section: category, label: styleName, tooltip: styleName, sortIndex: sortIndex, priority: priority });
+        }
+
+        /**
+         * Creates a new button in the drop-down menu for the specified style
+         * sheet.
+         */
+        function createStyleCollectionButton(styleName, styleId) {
+
+            // nothing to do for hidden styles
+            if (styleCollection.isHidden(styleId)) { return; }
+
+            // the section identifier for the style sheet
+            var category = styleCollection.getUICategory(styleId) || '';
+            // sorting priority
+            var priority = Math.floor(styleCollection.getUIPriority(styleId));
+
+            createOptionButton(styleName, styleId, category, priority);
+        }
+
+        /**
+         * Create a new additional button.
+         * @param {Object} button see@ initOptions.additionalItems
+         */
+        function createAdditionalButton(button) {
+            createOptionButton(button.name, button.id, button.category, button.priority);
         }
 
         /**
          * Fills the drop-down list with all known style names, and adds
          * preview CSS formatting to the list items.
          */
-        function fillListDirect() {
+        function initializeStyleTable() {
+
+            var newThemeModel = docModel.getThemeModel();
+            dirty = dirty || (themeModel !== newThemeModel);
+            themeModel = newThemeModel;
+            if (!dirty) { return; }
+
             // bug 33737, 33747: restore browser focus
             self.getMenu().guardFocusedListItem(function () {
                 self.clearMenu();
                 // configure the sections
                 _.each(Utils.getArrayOption(initOptions, 'sections'), function (sectionId) {
-                    self.createMenuSection(sectionId);
+                    if (addSectionLabel) {
+                        var translatedName = translateStyleName(sectionId);
+                        self.createMenuSection(sectionId, { label: translatedName ? translatedName : sectionId });
+                    } else {
+                        self.createMenuSection(sectionId);
+                    }
                 });
                 // insert the style sheets
-                _.each(styleCollection.getStyleSheetNames({ skipHidden: true }), createOptionButton);
-            });
-        }
+                _.each(styleCollection.getStyleSheetNames({ skipHidden: true }), createStyleCollectionButton);
 
-        /**
-         * Fills the drop-down list with all known style names, and adds
-         * preview CSS formatting to the list items.
-         */
-        var fillList = this.createDebouncedMethod($.noop, fillListDirect, { delay: 1000, infoString: 'StyleSheetPicker: fillList', app: app });
+                _.each(additionalItems, createAdditionalButton);
+            });
+
+            dirty = false;
+        }
 
         /**
          * Handles inserted or modified style sheets in the style collection.
@@ -212,12 +252,8 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
                 var oldCellNode = menuNode.find(btnSelector).parent();
                 var oldIndex = oldCellNode.index();
 
-                //-----------------------------------------------------
-
                 self.deleteOptionButton(styleId);
-                createOptionButton(styleCollection.getName(styleId), styleId);
-
-                //-----------------------------------------------------
+                createStyleCollectionButton(styleCollection.getName(styleId), styleId);
 
                 //compare old with new index an correct if required
                 var newCellNode = menuNode.find(btnSelector).parent();
@@ -234,17 +270,6 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
             });
         }
 
-        function changeActiveThemeTarget(evt, newTarget) {
-            target = newTarget;
-        }
-
-        function checkActiveThemeTarget() {
-            if (!_.isEqual(target, paintedTarget)) {
-                paintedTarget = target;
-                fillListDirect();
-            }
-        }
-
         /**
          * Handles deleted style sheets in the style collection.
          */
@@ -261,36 +286,29 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
         // update translated style name in drop-down button
         this.registerUpdateHandler(updateHandler);
 
-        // add all known style sheets after import
-        this.waitForImportSuccess(function () {
-            this.executeDelayed(fillList, { delay: 1000, infoString: 'EditFramework: StyleSheetPicker', app: docView.getApp() });
-        }, this);
-
         // handle all changes in the style sheet collection
         this.listenTo(styleCollection, 'insert:stylesheet', insertStyleHandler);
         this.listenTo(styleCollection, 'delete:stylesheet', deleteStyleHandler);
         this.listenTo(styleCollection, 'change:stylesheet', insertStyleHandler);
 
-        // also reinitialize the preview if theme settings have been changed
-        this.listenTo(docModel.getThemeCollection(), 'triggered', fillList);
+        // repaint the color table if the theme target chain has changed
+        this.getMenu().on('popup:beforeshow', initializeStyleTable);
 
-        this.getMenu().on('popup:beforeshow', checkActiveThemeTarget);
-        this.listenTo(docModel, 'change:activethemetarget', changeActiveThemeTarget);
+        // reinitialize the preview if theme settings have been changed
+        this.listenTo(docModel.getThemeCollection(), 'triggered', function () { dirty = true; });
 
         // load the translated style names if specified
         if (modulePath.length > 0) {
             this.waitForSuccess(LocaleData.loadResource(modulePath, { merge: true }), function (data) {
                 translationDatabase = data;
                 translationCache = {};
-                if (this.isImportSucceeded()) {
-                    fillList();
-                }
+                if (this.isImportSucceeded()) { dirty = true; }
             }, this);
         }
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = initOptions = docView = docModel = styleCollection = app = null;
+            self = initOptions = docView = docModel = styleCollection = null;
         });
 
     } // class StyleSheetPicker
