@@ -29,11 +29,11 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
 
     'use strict';
 
-    var // width of a single grid cell, in pixels
-        CELL_WIDTH = Utils.TOUCHDEVICE ? 27 : 18,
+    // width of a single grid cell, in pixels
+    var CELL_WIDTH = Utils.TOUCHDEVICE ? 27 : 18;
 
-        // height of a single grid cell, in pixels
-        CELL_HEIGHT = Utils.TOUCHDEVICE ? 24 : 16;
+    // height of a single grid cell, in pixels
+    var CELL_HEIGHT = Utils.TOUCHDEVICE ? 24 : 16;
 
     // class TableSizePicker ==================================================
 
@@ -56,7 +56,7 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
      *  @param {Integer} [initOptions.maxRows=15]
      *      The maximal number of rows to be displayed in the control.
      */
-    function TableSizePicker(initOptions) {
+    function TableSizePicker(docView, initOptions) {
 
         // self reference
         var self = this;
@@ -78,14 +78,14 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
         var menu = null;
 
         // the drop-down button
-        var menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ attributes: { 'aria-haspopup': true } }, initOptions)));
+        var menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ icon: 'docs-table-insert', attributes: { 'aria-haspopup': true } }, initOptions)));
 
         // the button control to be inserted into the drop-down menu
         // since 'aria-label' would override 'aria-describedby' and title is used as native tooltip, so nothing is set
         var gridButtonNode = $(Forms.createButtonMarkup({ attributes: { role: 'menuitem' } }));
 
         // canvas element for rendering the grid lines
-        var canvas = new Canvas();
+        var canvas = new Canvas(docView);
 
         // the tooltip node showing the current grid size
         var sizeToolTip = null;
@@ -101,13 +101,11 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
 
         // base constructors --------------------------------------------------
 
-        Group.call(this, Utils.extendOptions({
-            icon: 'docs-table-insert'
-        }, initOptions));
-        CaptionMixin.call(this, menuButton, initOptions);
+        Group.call(this, docView, initOptions);
+        CaptionMixin.call(this, menuButton, Utils.extendOptions({ smallerVersion: { hideLabel: true } }, initOptions));
         WidthMixin.call(this, menuButton, initOptions);
 
-        menu = new BaseMenu({
+        menu = new BaseMenu(docView, {
             classes: 'table-size-picker',
             anchor: this.getNode(),
             prepareLayoutHandler: prepareLayoutHandler
@@ -311,7 +309,7 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
         menu.appendContentNodes(gridButtonNode);
 
         // create the tooltip that shows the table size currently selected
-        sizeToolTip = new ToolTip({ anchor: menu.getNode(), prepareLayoutHandler: toolTipPrepareLayoutHandler });
+        sizeToolTip = new ToolTip(docView, { anchor: menu.getNode(), prepareLayoutHandler: toolTipPrepareLayoutHandler });
 
         // ARIA additions
         sizeToolTip.getNode().attr({ id: sizeToolTip.getUid(), 'aria-live': 'assertive', 'aria-relevant': 'additions', 'aria-atomic': true, role: 'tooltip' });
@@ -348,7 +346,7 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
             canvas.destroy();
             sizeToolTip.destroy();
             gridButtonNode.remove();
-            self = menu = gridButtonNode = canvas = sizeToolTip = null;
+            self = docView = menu = gridButtonNode = canvas = sizeToolTip = null;
         });
 
     } // class TableSizePicker
