@@ -16,11 +16,12 @@
 define('io.ox/office/editframework/view/control/tablestylepicker', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/forms',
     'io.ox/office/tk/render/canvas',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/view/control/stylesheetpicker',
     'gettext!io.ox/office/editframework/main'
-], function (Config, Utils, Canvas, Border, StyleSheetPicker, gt) {
+], function (Config, Utils, Forms, Canvas, Border, StyleSheetPicker, gt) {
 
     'use strict';
 
@@ -85,27 +86,45 @@ define('io.ox/office/editframework/view/control/tablestylepicker', [
      *
      * @extends StyleSheetPicker
      *
+     * @param {EditView} docView
+     *  The document view instance owning this control.
+     *
+     * @param {Function} styleFlagsResolver
+     *  A callback function that will be invoked everytime before the drop-down
+     *  menu will be painted. Must return an object with the current style
+     *  flags of the selected table element; or null, if no table element is
+     *  selected. All style flags can be omitted, their default values are
+     *  false.
+     *
      * @param {Object} [initOptions]
-     *  Optional parameters. Supports all options that are supported by the
-     *  method TableStyleCollection.resolveCellAttributeSet() used to resolve
-     *  the formatting attributes of the cells depending on their position in
-     *  the table, and the following options:
+     *  Optional parameters:
      *  - {Array<Object>} [initOptions.additionalItems]
      *      Additional stylesheet items. The array contains objects with the
      *      style attributes.
      */
-    function TableStylePicker(docView, initOptions) {
+    function TableStylePicker(docView, styleFlagsResolver, initOptions) {
 
         // self reference
         var self = this;
 
+        // the document model
         var docModel = docView.getDocModel();
 
+        // the collection of table style sheets of the document
         var tableStyles = docModel.getStyleCollection('table');
 
+        // table style flags (visibility of header/footer, first/last column, etc.)
+        var styleFlags = Utils.makeSet(['firstRow', 'lastRow', 'firstCol', 'lastCol', 'bandsHor', 'bandsVert'], false);
+
+        // all tables that have not been formatted yet
+        var pendingButtonNodes = [];
+
         // the canvas element used to render the preview tables
         var canvas = new Canvas(docView);
 
+        // background loop processing all pending tables
+        var formatTimer = null;
+
         // base constructors --------------------------------------------------
 
         StyleSheetPicker.call(this, docView, 'table', {
@@ -318,67 +337,6 @@ define('io.ox/office/editframework/view/control/tablestylepicker', [
             }
         }
 
-        /**
-         * Add the color of the first cell to the Button node for selenium test.
-         * @param {jQuery} node button node
-         * @param {String} styleId table style id
-         *
-         * @param {String|Array<String>|Null} [targets]
-         *  A name or an array of names to specify the target theme. If omitted
-         *  or set to null, the active theme of the document will be used.
-         */
-        function addFirstCellColorForSelenium(node, styleId, targets) {
-            var tableAttrs = tableStyles.getStyleSheetAttributeMap(styleId, true);
-            var cellAttrs = tableStyles.resolveCellAttributeSet(tableAttrs, { start: 0, end: 0 }, { start: 0, end: 0 }, COL_COUNT, ROW_COUNT, initOptions);
-            if (cellAttrs && cellAttrs.cell && cellAttrs.cell.fillColor) {
-                node.css('color', docModel.getCssColor(cellAttrs.cell.fillColor, 'fill', targets));
-            }
-        }
-
-        /**
-         * Renders the specified table into the canvas.
-         *
-         * @param {Canvas} canvas
-         *  the canvas for render the table.
-         *
-         * @param {String} styleId
-         *  the id of the table style.
-         *
-         * @param {String|Array<String>|Null} [targets]
-         *  A name or an array of names to specify the target theme. If omitted
-         *  or set to null, the active theme of the document will be used.
-         */
-        function renderTable(canvas, styleId, targets) {
-            canvas.clear().render(function (context) {
-
-                var tableAttrs = tableStyles.getStyleSheetAttributeMap(styleId, true);
-
-                // paint background color and cache the cell style attributes
-                var attrMatrix = _.times(ROW_COUNT, function (row) {
-                    var rowRange = { start: row, end: row };
-                    return _.times(COL_COUNT, function (col) {
-                        var colRange = { start: col, end: col };
-                        var cellAttrs = tableStyles.resolveCellAttributeSet(tableAttrs, colRange, rowRange, COL_COUNT, ROW_COUNT, initOptions);
-                        renderCellFillColor(context, col, row, cellAttrs, targets);
-                        return cellAttrs;
-                    });
-                });
-
-                // paint the border by using the cached cell styles
-                attrMatrix.forEach(function (attrVector, row) {
-                    var prevVector = (row > 0) ? attrMatrix[row - 1] : null;
-                    var nextVector = (row + 1 < ROW_COUNT) ? attrMatrix[row + 1] : null;
-                    attrVector.forEach(function (cellAttrs, col) {
-                        var tAttrs = prevVector ? prevVector[col] : null;
-                        var bAttrs = nextVector ? nextVector[col] : null;
-                        var lAttrs = (col > 0) ? attrVector[col - 1] : null;
-                        var rAttrs = (col + 1 < COL_COUNT) ? attrVector[col + 1] : null;
-                        renderBordersAndTextPlaceholder(context, cellAttrs, col, row, tAttrs, bAttrs, lAttrs, rAttrs, targets);
-                    });
-                });
-            });
-        }
-
         /**
          * Registers a new table that will be formatted delayed with a specific
          * table style sheet.
@@ -389,67 +347,76 @@ define('io.ox/office/editframework/view/control/tablestylepicker', [
          * @param {String} styleId
          *  The identifier of the table style sheet.
          */
-        var updateTableFormatting = (function () {
+        function updateTableFormatting() {
 
-            // which tables in list items need formatting
-            var pendingTables = [];
-            // background loop processing all pending tables
-            var formatTimer = null;
+            // check if the background loop is already running
+            if (formatTimer) { return; }
 
-            // initialize effective rectangle of the canvas wrapper (size of the DOM canvas node will be initialized too)
-            canvas.initialize({ left: -1, top: -1, width: ICON_WIDTH + 2, height: ICON_HEIGHT + 2 });
+            // create a new background loop that processes all pending tables
+            formatTimer = self.repeatSliced(function () {
 
-            // set the CSS location of the canvas element relative to its parent element
-            canvas.getNode().css({ left: -1, top: -1 });
+                // find a pending table that is still in the drop-down menu (menu may have been cleared
+                // in the meantime), abort the background loop, if no more tables are available
+                var buttonNode = null;
+                while ((buttonNode = pendingButtonNodes.shift()) && !Utils.containsNode(self.getMenuNode(), buttonNode)) {}
+                if (!buttonNode) { return Utils.BREAK; }
 
-            // direct callback: called every time when updateTableFormatting() has been called
-            function registerTable(tableNode, styleId) {
-                pendingTables.push({ tableNode: tableNode, styleId: styleId });
-            }
+                // the identifier of the table style sheet
+                var styleId = Forms.getButtonValue(buttonNode);
+                // the current theme targets
+                var targets = docModel.getThemeTargets();
+                // the attribute set of the table style
+                var tableAttrs = tableStyles.getStyleSheetAttributeMap(styleId, true);
 
-            // deferred callback: called once after the specified timeout
-            function formatTables() {
+                canvas.clear().render(function (context) {
 
-                // check if the background loop is already running
-                if (formatTimer) { return; }
+                    // paint background color and cache the cell style attributes
+                    var attrMatrix = _.times(ROW_COUNT, function (row) {
+                        return _.times(COL_COUNT, function (col) {
+                            var cellAttrs = tableStyles.resolveCellAttributeSet(tableAttrs, col, row, COL_COUNT, ROW_COUNT, styleFlags);
+                            renderCellFillColor(context, col, row, cellAttrs, targets);
+                            return cellAttrs;
+                        });
+                    });
 
-                // create a new background loop that processes all pending tables
-                formatTimer = self.repeatSliced(function () {
+                    // paint the border by using the cached cell styles
+                    attrMatrix.forEach(function (attrVector, row) {
+                        var prevVector = (row > 0) ? attrMatrix[row - 1] : null;
+                        var nextVector = (row + 1 < ROW_COUNT) ? attrMatrix[row + 1] : null;
+                        attrVector.forEach(function (cellAttrs, col) {
+                            var tAttrs = prevVector ? prevVector[col] : null;
+                            var bAttrs = nextVector ? nextVector[col] : null;
+                            var lAttrs = (col > 0) ? attrVector[col - 1] : null;
+                            var rAttrs = (col + 1 < COL_COUNT) ? attrVector[col + 1] : null;
+                            renderBordersAndTextPlaceholder(context, cellAttrs, col, row, tAttrs, bAttrs, lAttrs, rAttrs, targets);
+                        });
+                    });
+                });
 
-                    // table info with table and style identifier of the next table to be formatted
-                    var tableInfo = null;
+                // set the rendered table image
+                $(buttonNode).children('img').attr('src', canvas.getDataURL());
 
-                    // find a pending table that is still in the drop-down menu (menu may have been cleared
-                    // in the meantime), abort the background loop, if no more tables are available
-                    while ((tableInfo = pendingTables.shift()) && !Utils.containsNode(self.getMenuNode(), tableInfo.tableNode)) {}
-                    if (!tableInfo) { return Utils.BREAK; }
+                // only for selenium test
+                if (Config.AUTOTEST) {
+                    var cellAttrs = tableStyles.resolveCellAttributeSet(tableAttrs, 0, 0, COL_COUNT, ROW_COUNT, styleFlags);
+                    var fillColor = cellAttrs.cell ? cellAttrs.cell.fillColor : null;
+                    if (fillColor) { $(buttonNode).css('color', docModel.getCssColor(fillColor, 'fill', targets)); }
+                }
 
-                    var img = $(tableInfo.tableNode).find('>img');
-                    $(tableInfo.tableNode).find('.caption').remove();
+            }, 'TableStylePicker.updateTableFormatting');
 
-                    var targets = docModel.getThemeTargets();
-                    renderTable(canvas, tableInfo.styleId, targets);
-
-                    // Only for selenium test
-                    if (Config.AUTOTEST) {
-                        addFirstCellColorForSelenium($(tableInfo.tableNode), tableInfo.styleId, targets);
-                    }
-
-                    img.attr({ src: canvas.getDataURL() });
-                }, 'TableStylePicker.updateTableFormatting.formatTables', { slice: 100 });
-
-                // forget reference to the timer, when all tables have been formatted
-                formatTimer.always(function () { formatTimer = null; });
-            }
-
-            // create and return the debounced updateTableFormatting() method (with a delay of 10ms per table)
-            return self.createDebouncedMethod('TableStylePicker.updateTableFormatting', registerTable, formatTables, { delay: 10 });
-        }());
+            // forget reference to the timer, when all tables have been formatted
+            formatTimer.always(function () { formatTimer = null; });
+        }
 
         // initialization -----------------------------------------------------
 
+        // initialize effective rectangle of the canvas wrapper (size of the DOM canvas node will be initialized too)
+        canvas.initialize({ left: -1, top: -1, width: ICON_WIDTH + 2, height: ICON_HEIGHT + 2 });
+
         // register a handler that inserts a table element into each list item
-        this.listenTo(this.getMenu(), 'create:item', function (event, buttonNode, styleId) {
+        this.listenTo(this.getMenu(), 'create:item', function (event, buttonNode) {
+
             buttonNode.addClass('mini-caption').css({
                 minWidth: ICON_CONTAINER_WIDTH,
                 maxWidth: ICON_CONTAINER_WIDTH,
@@ -458,13 +425,39 @@ define('io.ox/office/editframework/view/control/tablestylepicker', [
                 lineHeight: 'normal'
             }).append('<img style="margin:0px;">');
 
-            updateTableFormatting(buttonNode, styleId);
+            buttonNode.find('.caption').remove();
+
+            // register the button for rendering, but do not actually render it yet
+            pendingButtonNodes.push(buttonNode[0]);
+        });
+
+        // repaint the preview tables, if the style flags of the selected table are different
+        this.listenTo(this.getMenu(), 'popup:beforeshow', function () {
+
+            // the current style flags for comparison
+            var oldStyleFlags = _.copy(styleFlags);
+            // get the current table style flags
+            var newStyleFlags = styleFlagsResolver.call(self);
+
+            // create the new complete style flags object (newStyleFlags may be incomplete)
+            styleFlags = _.mapObject(styleFlags, function (flag, key) {
+                return Utils.getBooleanOption(newStyleFlags, key, false);
+            });
+
+            // put all buttons into the pending map, if the style flags have changed
+            if (!_.isEqual(oldStyleFlags, styleFlags)) {
+                pendingButtonNodes = self.getOptionButtons().get().slice();
+            }
+
+            // render the pending table elements
+            updateTableFormatting();
         });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             canvas.destroy();
-            self = docView = docModel = tableStyles = canvas = null;
+            self = docView = docModel = tableStyles = null;
+            canvas = pendingButtonNodes = null;
         });
 
     } // class TableStylePicker
