@@ -33,14 +33,14 @@ define('io.ox/office/editframework/view/control/toolbartabgroup', [
      * @param {ToolBarTabCollection} toolBarTabs
      *  The collection with all tool bars registered for the application.
      */
-    function ToolBarTabGroup(toolBarTabs) {
+    function ToolBarTabGroup(docView, toolBarTabs) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        RadioGroup.call(this, { classes: 'tab-group', role: 'tablist' });
+        RadioGroup.call(this, docView, { classes: 'tab-group', role: 'tablist' });
 
         // private methods ----------------------------------------------------
 
@@ -89,7 +89,7 @@ define('io.ox/office/editframework/view/control/toolbartabgroup', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = toolBarTabs = null;
+            self = docView = toolBarTabs = null;
         });
 
     } // class ToolBarTabGroup
