@@ -14,25 +14,25 @@
 
 define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/dialogs',
+    'io.ox/office/tk/dialog/basedialog',
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/view/editlabels',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, Dialogs, HyperlinkUtils, Labels, gt) {
+], function (Utils, BaseDialog, HyperlinkUtils, Labels, gt) {
 
     'use strict';
 
-    var // a unique DOM identifier for the label of the display text input field
-        DISPLAY_LABEL_ID = _.uniqueId('display'),
+    // a unique DOM identifier for the label of the display text input field
+    var DISPLAY_LABEL_ID = _.uniqueId('display');
 
-        // a unique DOM identifier for the display text input field
-        DISPLAY_INPUT_ID = _.uniqueId('display'),
+    // a unique DOM identifier for the display text input field
+    var DISPLAY_INPUT_ID = _.uniqueId('display');
 
-        // a unique DOM identifier for the label of the URL input field
-        URL_LABEL_ID = _.uniqueId('url'),
+    // a unique DOM identifier for the label of the URL input field
+    var URL_LABEL_ID = _.uniqueId('url');
 
-        // a unique DOM identifier for the URL input field
-        URL_INPUT_ID = _.uniqueId('url');
+    // a unique DOM identifier for the URL input field
+    var URL_INPUT_ID = _.uniqueId('url');
 
     // class HyperlinkDialog ==================================================
 
@@ -42,7 +42,7 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
      *
      * @constructor
      *
-     * @extends ModalDialog
+     * @extends BaseDialog
      *
      * @param {EditView} docView
      *  The document view instance that has created this dialog.
@@ -54,19 +54,8 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
      * @param {String} [display]
      *  The initial display string for the URL to be shown in the dialog. If
      *  omitted, the text field for the display string will appear empty.
-     *
-     * @param {Object} [options]
-     *  Additional options for the dialog
-     *  Optional parameters:
-     *  @param {Boolean} [options.showremove=true]
-     *      If set to false, the remove button is not shown, although an initial
-     *      URL is specified for this dialog. This is necessary, if the dialog
-     *      is redrawn after an invalid URL was found (53058).
      */
-    var HyperlinkDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, url, display, options) {
-
-        // self reference
-        var self = this;
+    var HyperlinkDialog = BaseDialog.extend(function (docView, url, display) {
 
         // whether to keep URL and display text in sync
         var syncDisplay = !display || (url === display);
@@ -91,12 +80,9 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             'aria-required': true
         }).addClass('form-control');
 
-        // whether the remove button is visible
-        var removeIsVisible = false;
-
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, docView, {
+        BaseDialog.call(this, docView, {
             width: 400,
             title: url ? Labels.EDIT_HYPERLINK_LABEL : Labels.INSERT_HYPERLINK_LABEL,
             okLabel: gt('Insert')
@@ -116,9 +102,8 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
         }
 
         function updateUrlField() {
-            var currUrl = getUrl(), hasUrl = currUrl.length > 0;
-            self.enableOkButton(hasUrl);
-            urlInputNode.attr('aria-invalid', !hasUrl);
+            var currUrl = getUrl();
+            urlInputNode.attr('aria-invalid', currUrl.length === 0);
             if (syncDisplay) { displayInputNode.val(currUrl); }
         }
 
@@ -126,36 +111,6 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             syncDisplay = false;
         }
 
-        // public methods -----------------------------------------------------
-
-        this.show = _.wrap(this.show, function (show) {
-            return show.call(this).then(function (action) {
-                switch (action) {
-
-                    case 'ok':
-                        var currUrl = getUrl();
-                        var display = displayInputNode.val();
-
-                        // add http: as default if protocol is missing
-                        var newUrl = (currUrl.indexOf(':') < 0) ? ('http://' + currUrl) : currUrl;
-
-                        // show warning and reopen the dialog, if the URL is invalid (not changing the state of the remove button (53058))
-                        if (!HyperlinkUtils.hasSupportedProtocol(newUrl) || !HyperlinkUtils.isValidURL(newUrl)) {
-                            docView.yell({ type: 'warning', message: Labels.INVALID_HYPERLINK_LABEL });
-                            return new HyperlinkDialog(docView, currUrl, display, { showremove: removeIsVisible }).show();
-                        }
-
-                        // return result object for a valid URL
-                        return { url: newUrl, text: display };
-
-                    case 'remove':
-                        return { url: null, text: null };
-                }
-
-                return $.Deferred().reject();
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         // close dialog automatically after losing edit rights
@@ -182,17 +137,17 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             )
         );
 
-        // add a Remove button, if a URL has been passed
-        if (url && Utils.getBooleanOption(options, 'showremove', true)) {
-            this.addAlternativeButton('remove', gt('Remove'));
-            this.getButton('remove').addClass('btn-warning');
-            removeIsVisible = true;
-        }
+        // register a change handler to toggle the insert button
+        this.addOkValidator(function () { return getUrl().length > 0; });
+        this.validateOn(urlInputNode, 'input');
 
-        // register a change handlers to toggle the insert button
+        // update input fields when typing
         urlInputNode.on('input', updateUrlField);
         displayInputNode.on('input', updateDisplayField);
 
+        // set initial focus
+        this.setFocusNode(urlInputNode);
+
         // Bugfix 40844: when the user focus the displayInputNode via tab or mouse click,
         // the text in the displayInputNode should be selected
         displayInputNode.on('focus', function () {
@@ -207,23 +162,34 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             }
         });
 
-        // set initial focus
-        this.on('show', function () {
-            updateUrlField();
+        // handler for the OK button (keep dialog open, if the current URL is invalid)
+        this.setOkHandler(function () {
+            var currUrl = getUrl();
+            var display = displayInputNode.val();
 
-            // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus should not be in an input element
+            // add http: as default if protocol is missing
+            var newUrl = (currUrl.indexOf(':') < 0) ? ('http://' + currUrl) : currUrl;
 
-            // Bug 46886
-            // Also for IPad because since IOS 9, body is not scrolled when code triggers focus on input element
-            if (Utils.SMALL_DEVICE || Utils.IOS) {
-                _.defer(function () { Utils.setFocus(self.getCancelButton()); });
-            } else {
-                Utils.setFocus(urlInputNode).select();
+            // show warning and keep the dialog open, if the URL is invalid
+            if (!HyperlinkUtils.hasSupportedProtocol(newUrl) || !HyperlinkUtils.isValidURL(newUrl)) {
+                docView.yell({ type: 'warning', message: Labels.INVALID_HYPERLINK_LABEL });
+                return new $.Deferred().reject();
             }
-        });
 
-    } }); // class HyperlinkDialog
+            // return result object for a valid URL
+            return { url: newUrl, text: display };
+        }, { keepOpen: 'fail' });
+
+        // add a Remove button, if a URL has been passed
+        if (url) {
+            this.createButton('remove', gt('Remove'), {
+                alignLeft: true,
+                buttonStyle: 'warning',
+                actionHandler: _.constant({ url: null, text: null })
+            });
+        }
+
+    }); // class HyperlinkDialog
 
     // exports ================================================================
 
