@@ -548,7 +548,7 @@ define('io.ox/office/editframework/view/editview', [
 
                     // create a new tool bar for debugging containing debug options
                     self.createToolBar('debug')
-                        .addGroup('debug/slowsave', new Button(self, { icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.get('module/debugslowsavetime', 0) + 's)'), toggle: true }));
+                        .addGroup('debug/slowsave', new Button(self, { icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.getInt('module/debugslowsavetime') + 's)'), toggle: true }));
                     break;
                 default:
             }
@@ -835,16 +835,19 @@ define('io.ox/office/editframework/view/editview', [
         };
 
         /**
-         * Overrides the same method of the base class BaseView, and adds
-         * functionality to react on the event that the user loses the edit
-         * rights for the document.
+         * Overwrites the base class method BaseView.enterBusy() and adds an
+         * event handler for the applicatioon event "docs:editmode:leave"
+         * indicating lost edit rights for the document. The event handler will
+         * call the cancel handler passed to this method automatically.
          *
          * @param {Object} [options]
          *  Optional parameters. Supports all options that are also supported
          *  by the base class method BaseView.enterBusy(), and the following
          *  additional options:
-         *  @param {Function} [options.cancelHandler]
-         *      The cancelHandler itselfs
+         *  - {Boolean} [options.cancelOnReadOnly=true]
+         *      If set to false, the cancel handler passed to this method will
+         *      NOT be called automatically, when the document is losing the
+         *      edit rights.
          *
          * @returns {EditView}
          *  A reference to this instance.
@@ -857,9 +860,8 @@ define('io.ox/office/editframework/view/editview', [
             // calling the base class before registering handler
             enterBusy.call(this, options);
 
+            // invoke cancel handler when leaving edit mode, unregister event handler when leaving busy mode
             if (cancelHandler && Utils.getBooleanOption(options, 'cancelOnReadOnly', true)) {
-
-                // invoke cancel handler when leaving edit mode, unregister event handler when leaving busy mode
                 this.listenTo(app, 'docs:editmode:leave', cancelHandler);
                 this.listenOnceTo(app.getWindow(), 'idle', function () {
                     self.stopListeningTo(app, 'docs:editmode:leave', cancelHandler);
