@@ -17,11 +17,11 @@ define('io.ox/office/editframework/view/operationspane', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/keycodes',
     'io.ox/office/baseframework/view/pane',
+    'io.ox/office/editframework/utils/editconfig',
     'io.ox/office/editframework/utils/operationutils',
-    'io.ox/office/editframework/app/rtconnection',
     'io.ox/office/editframework/view/popup/attributestooltip',
     'less!io.ox/office/editframework/view/operationspane'
-], function (Utils, Forms, KeyCodes, Pane, OperationUtils, RTConnection, AttributesToolTip) {
+], function (Utils, Forms, KeyCodes, Pane, EditConfig, OperationUtils, AttributesToolTip) {
 
     'use strict';
 
@@ -113,12 +113,13 @@ define('io.ox/office/editframework/view/operationspane', [
 
                         var entry = pendingOperations.shift();
 
-                        var name = entry.operation.name || '';
+                        var name = entry.operation.name || entry.operation.n || '';
                         var osn = OperationUtils.getOSN(entry.operation);
                         var opl = OperationUtils.getOPL(entry.operation);
 
                         var properties = _.clone(entry.operation);
                         delete properties.name;
+                        delete properties.n;
                         delete properties.osn;
                         delete properties.opl;
 
@@ -272,7 +273,7 @@ define('io.ox/office/editframework/view/operationspane', [
 
         // create the operations log table, and the debug info table
         opTableNode = $('<table class="debug-table"><tbody><tr><th></th><th title="Operation type">T</th><th title="Operation State Number" style="font-size:70%;">OSN</th><th title="Operation Length" style="font-size:70%;">OPL</th><th>Name</th><th>Properties</th></tr></tbody></table>');
-        infoTableNode = $('<table class="debug-table" style="table-layout:fixed;"><colgroup><col width="50"></col><col></col></colgroup></table>');
+        infoTableNode = $('<table class="debug-table" style="table-layout:fixed;"><colgroup><col width="50"></col><col></col></colgroup><tbody></tbody></table>');
 
         // add the operations table and the info table to the debug pane
         [{ node: opTableNode, cls: 'ops' }, { node: infoTableNode, cls: 'info' }].forEach(function (entry) {
@@ -307,7 +308,9 @@ define('io.ox/office/editframework/view/operationspane', [
         this.listenTo(docModel, 'operations:after', function (event, operations, external) {
             if (!app.isOperationsBlockActive()) {
                 operations.forEach(function (operation) {
-                    pendingOperations.push({ operation: _.copy(operation, true), orig: operation, external: external });
+                    var localOp = _.copy(operation, true);
+                    if (EditConfig.USE_SHORT_OPERATIONS && OperationUtils.isConversionDefined) { OperationUtils.handleMinifiedObject(localOp); }
+                    pendingOperations.push({ operation: localOp, orig: operation, external: external });
                 });
                 logPendingOperations();
             }
