@@ -22,13 +22,14 @@ define('io.ox/office/portal/action/recentsactions', [
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
     'io.ox/office/tk/io',
+    'io.ox/office/tk/utils/driveutils',
     'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
     'gettext!io.ox/office/portal/main',
     'io.ox/files/toolbar', // important for action links (download in contextmenu)
     'io.ox/mail/detail/links' // this line is important for deep links usage (works with jq delegation)
-], function (Ext, Links, CoreActions, IO, Config, Utils, ContextMenu, gt) {
+], function (Ext, Links, CoreActions, IO, DriveUtils, Config, Utils, ContextMenu, gt) {
 
     'use strict';
 
@@ -56,7 +57,7 @@ define('io.ox/office/portal/action/recentsactions', [
             id: 'recent_document',
 
             draw: function (baton) {
-                var fullFileName = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename;
+                var fullFileName = DriveUtils.getSanitizedFileName(baton.data);
                 var escapedFilePath = '';
                 var escapedFilePathinToolTip = '';
                 var escapedFileName = Utils.escapeHTML(fullFileName);
@@ -105,7 +106,7 @@ define('io.ox/office/portal/action/recentsactions', [
                 divName.append(Utils.createDocumentIcon(fullFileName), divFilename, divPath);
 
                 // check if the document is encrypted add add a overlay icon if true
-                if (Utils.isGuardEncrypted(fullFileName)) {
+                if (DriveUtils.hasGuardExt(fullFileName)) {
                     divDate.append($('<i class="encryption-overlay ' + Utils.getAppBaseName(fullFileName) + ' fa fa-lock" aria-hidden="true"></i>'));
                 }
 
@@ -153,8 +154,8 @@ define('io.ox/office/portal/action/recentsactions', [
          * items in the text/spreadsheet portal.
          *
          * @param {Event} event
-         *  The event which triggered the context menu.
-         *  The event contains the position were the context menu is opened.
+         *  The event which triggered the context menu. The event contains the
+         *  position were the context menu is opened.
          *
          * @param {JQuery} link
          *  The DOM element the context menu is opened for.
@@ -173,7 +174,7 @@ define('io.ox/office/portal/action/recentsactions', [
             // current app name
             var appName = Utils.getAppBaseName(baton.data.filename);
 
-            var encrypted = Utils.isGuardEncrypted(baton.data.filename);
+            var encrypted = DriveUtils.hasGuardExt(baton.data.filename);
 
             var showEditAsNewButton = !encrypted;
 
