@@ -19,11 +19,11 @@ define('io.ox/office/portal/action/templateactions', [
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
-    'io.ox/core/capabilities',
     'gettext!io.ox/office/portal/main'
-], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, Capabilities, gt) {
+], function (Ext, Links, CoreActions, DriveUtils, Config, Utils, ContextMenu, gt) {
 
     'use strict';
 
@@ -178,7 +178,7 @@ define('io.ox/office/portal/action/templateactions', [
             var appBaseName = baton.data.type;
             // the element which should be highlighted, it has to be different in presentation or text/spreadsheet
             var highLightElement = null;
-            var fullFileName = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename;
+            var fullFileName = DriveUtils.getSanitizedFileName(baton.data);
             // the template container
             var templateItem = $('<a class="template-item" tabindex="0">').addClass(appBaseName).attr({
                 'data-toggle': 'tooltip',
@@ -361,7 +361,7 @@ define('io.ox/office/portal/action/templateactions', [
             // Create the "New from template (encrypted)" button in the context menu with
             // eventListener and the invoked action on execution.
             function getNewFromTemplateEncryptedButton(cmenu, self, baton, section) {
-                if (Capabilities.has('guard-docs')) {
+                if (Config.GUARD_AVAILABLE) {
                     var newFromTemplateButton = cmenu.createItemNode('newfromtemplateencrypted', { section: section, content: gt('New from template (encrypted)') });
 
                     newFromTemplateButton.on('click', function () {
@@ -387,7 +387,7 @@ define('io.ox/office/portal/action/templateactions', [
             // Create the New document(text, spreadsheet, presentation) encrypted button in the context menu with
             // eventListener and the invoked action on execution.
             function getNewBlankEncryptedButton(cmenu, baton, section, invokeId, title) {
-                if (Capabilities.has('guard-docs')) {
+                if (Config.GUARD_AVAILABLE) {
                     var newBlankEncryptedButton = cmenu.createItemNode('newblankencrypted', { section: section, content: title });
 
                     newBlankEncryptedButton.on('click', function () {
@@ -638,7 +638,7 @@ define('io.ox/office/portal/action/templateactions', [
             draw: drawLocalItem
         });
 
-        if (Capabilities.has('guard-docs')) {
+        if (Config.GUARD_AVAILABLE) {
 
             // action to create a blank text document encrypted
             new Links.Action(templateExtension + '/action/newencrypted/text', {
