@@ -144,7 +144,7 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                     // prefetch
                     'io.ox/files/mobile-navbar-extensions'
                 ]).done(function (FilePicker, ExtensionRegistry) {
-                    var preselect = Config.get(preselectKey) || DriveUtils.getStandardDocumentsFolderId();
+                    var preselect = Config.getStr(preselectKey) || DriveUtils.getStandardDocumentsFolderId();
                     var extensions = ExtensionRegistry.getEditableExtensions();
                     var filter = extensions.map(function (ext) { return '.' + ext; }).join(',');
 
