@@ -27,7 +27,8 @@ define('io.ox/office/portal/action/toolbaractionstext', [
      */
     return new ToolbarActionsImpl({
         appBaseName: 'text',
-        newDocText: gt('New Text Document')
+        newDocText: gt('New text document'),
+        newDocTextEncrypted: gt('New text document (encrypted)')
     });
 
 });
