@@ -21,28 +21,25 @@ define('io.ox/office/portal/mainhelper', [
     'io.ox/office/tk/io',
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/portal/portalutils',
+    'io.ox/office/portal/portaltour',
     'io.ox/office/portal/collection/documentcollection',
     'io.ox/office/portal/collection/templatecollection',
     'io.ox/office/portal/view/documentview',
     'io.ox/office/portal/view/templateview',
     'io.ox/office/portal/view/toolbarview',
-    'io.ox/office/baseframework/app/guidedtour',
     'io.ox/office/editframework/utils/editconfig',
     'io.ox/office/editframework/app/fileactions',
     'settings!io.ox/office',
     'gettext!io.ox/office/portal/main',
     'less!io.ox/office/portal/style'
-], function (Commons, Capabilities, Notifications, IO, DriveUtils, Utils, DocumentCollection, TemplateCollection, DocumentView, TemplateView, ToolbarView, GuidedTour, Config, FileActions, Settings, gt) {
+], function (Commons, Capabilities, Notifications, IO, DriveUtils, Utils, PortalTour, DocumentCollection, TemplateCollection, DocumentView, TemplateView, ToolbarView, Config, FileActions, Settings, gt) {
 
     'use strict';
 
-    // bug 51700: do not show welcome tours if the standard tour package is not installed
-    var TOURS_PACKAGE_INSTALLED = Config.getDebugUrlFlag('office:show-tours') || require.defined('io.ox/tours/main');
-
     // static class MainHelper ================================================
 
-    var // the exported MainHelper class
-        MainHelper = {};
+    // the exported MainHelper class
+    var MainHelper = {};
 
     // methods ----------------------------------------------------------------
 
@@ -152,18 +149,14 @@ define('io.ox/office/portal/mainhelper', [
                         // to init the bootstrap tooltips in portal
                         $('[data-toggle="tooltip"]').tooltip();
 
-                        // start the welcome tour for this application once (never in Selenium tests)
-                        // bug 51700: do not show any tours if the standard tour package is not installed
-                        if (!Config.AUTOTEST && TOURS_PACKAGE_INSTALLED) {
-                            GuidedTour.runAppTour(PORTAL_MODULE_NAME, { once: true, auto: true });
-                        }
+                        // start the welcome tour
+                        PortalTour.runPortalTour(appBaseName);
+
                     }).fail(appFail);
                 }
 
-                // workaround for bug 51700: hide entry in settings drop-down if the standard tour package is not installed
-                if (!TOURS_PACKAGE_INSTALLED) {
-                    $('#topbar-settings-dropdown li[data-id="default/' + PORTAL_MODULE_NAME + '"]').remove();
-                }
+                // hide entry in settings drop-down if the standard tour package is not installed
+                PortalTour.updateSettingsDropDownMenu(appBaseName);
             }
 
             // yells if something went wrong...
@@ -219,9 +212,7 @@ define('io.ox/office/portal/mainhelper', [
         });
 
         // register as application tour (will create an entry in the settings menu to start the tour)
-        if (!_.device('smartphone')) {
-            GuidedTour.registerAppTour(PORTAL_MODULE_NAME, PORTAL_MODULE_NAME + '/fulltour');
-        }
+        PortalTour.registerPortalTour(appBaseName);
 
         return { getApp: app.getInstance };
     };
