@@ -28,6 +28,9 @@ define('io.ox/office/portal/portaltour', [
     // selector for any tool pane without hidden contents
     var TOOL_PANE_SELECTOR = '.tool-pane:not(.hidden-contents)';
 
+    // bug 51700: do not show welcome tours if the standard tour package is not installed
+    var TOURS_PACKAGE_INSTALLED = Config.getDebugUrlFlag('office:show-tours') || require.defined('io.ox/tours/main');
+
     // debug mode: whether to always show the long version of the tours
     var DEBUG_FULL_TOURS = Config.getDebugUrlFlag('office:full-tours');
 
@@ -43,7 +46,7 @@ define('io.ox/office/portal/portaltour', [
      * @param {String} appBaseName
      *  The base name of the application represented by this tour.
      */
-    var PortalTour = GuidedTour.extend(function (appBaseName, options) {
+    var PortalTour = GuidedTour.extend(function (appBaseName, initOptions) {
 
         // self reference
         var self = this;
@@ -64,11 +67,11 @@ define('io.ox/office/portal/portaltour', [
         var editLaunchOptions = null;
 
         // whether to show the short version of the tour
-        var shortTour = !DEBUG_FULL_TOURS && (options && options.auto && PortalTour.isAnyPortalTourShown());
+        var shortTour = !DEBUG_FULL_TOURS && (initOptions && initOptions.auto && PortalTour.isAnyPortalTourShown());
 
         // base constructor ---------------------------------------------------
 
-        GuidedTour.call(this, appBaseName);
+        GuidedTour.call(this);
 
         // constants ----------------------------------------------------------
 
@@ -201,7 +204,7 @@ define('io.ox/office/portal/portaltour', [
                 // wait for the application window node, and the 'data-doc-loaded' marker that will be set after import
                 .waitFor(this.EDITOR_TOP_PANE_SELECTOR, 10)
                 // highlight the entire edit tool pane (bug 44195: use first embedded tool bar element to prevent positioning problems with full-width pane)
-                .waitForAndReferTo(this.EDITOR_TOOL_PANE_SELECTOR + ' .toolbar:visible:eq(0)', { position: 'bottom', hotspot: true })
+                .waitForAndReferTo(this.EDITOR_TOOL_PANE_SELECTOR + ' .toolbar:visible:eq(0)', { timeout: 10, position: 'bottom', hotspot: true })
                 // once the document has been created, change this step so that it navigates to the existing document
                 .once('show', function () {
                     editApp = this.getApp();
@@ -401,6 +404,57 @@ define('io.ox/office/portal/portaltour', [
         return Config.getFlag(ANY_PORTAL_TOUR_SHOWN_KEY);
     };
 
+    /**
+     * Registers a welcome tour for the specified Documents portal application.
+     *
+     * @param {string} appBaseName
+     *  The base name of the portal application ('text', 'spreadsheet', etc.).
+     */
+    PortalTour.registerPortalTour = function (appBaseName) {
+        if (!_.device('smartphone')) {
+            var moduleName = PortalUtils.getPortalModuleName(appBaseName);
+            var requirePath = moduleName + '/fulltour';
+            var shownKey = PortalUtils.getPortalAppName(appBaseName) + '/fulltour/shown';
+            GuidedTour.registerAppTour(moduleName, requirePath, shownKey);
+        }
+    };
+
+    /**
+     * Starts the welcome tour for the specified Documents portal application
+     * once.
+     *
+     * @param {string} appBaseName
+     *  The base name of the portal application ('text', 'spreadsheet', etc.).
+     *
+     * @returns {JQuery.Promise<PortalTour>}
+     *  A promise that will be resolved with the running tour instance; or that
+     *  will be rejected, if the tour has not been started (e.g. was already
+     *  started before).
+     */
+    PortalTour.runPortalTour = function (appBaseName) {
+        // start the welcome tour for the application once (and never in Selenium tests)
+        // bug 51700: do not show any tours if the standard tour package is not installed
+        if (!Config.AUTOTEST && TOURS_PACKAGE_INSTALLED) {
+            var moduleName = PortalUtils.getPortalModuleName(appBaseName);
+            return GuidedTour.runAppTour(moduleName, { once: true, auto: true });
+        }
+    };
+
+    /**
+     * Hides the menu entry "Show tour for this app" in the global settings
+     * drop-down menu for the specified Documents portal application.
+     *
+     * @param {string} appBaseName
+     *  The base name of the portal application ('text', 'spreadsheet', etc.).
+     */
+    PortalTour.updateSettingsDropDownMenu = function (appBaseName) {
+        // workaround for bug 51700: hide entry in settings drop-down if the standard tour package is not installed
+        if (!TOURS_PACKAGE_INSTALLED) {
+            var moduleName = PortalUtils.getPortalModuleName(appBaseName);
+            $('#topbar-settings-dropdown li[data-id="default/' + moduleName + '"]').remove();
+        }
+    };
+
     // exports ================================================================
 
     return PortalTour;
