@@ -34,6 +34,19 @@ define('io.ox/office/portal/portalutils', [
 
     // static methods ---------------------------------------------------------
 
+    /**
+     * Returns the name of the specified portal application.
+     *
+     * @param {string} appBaseName
+     *  The base name of the portal application (`text`, `spreadsheet`, etc.).
+     *
+     * @returns {string}
+     *  The name of the specified portal application (e.g. "portal/text").
+     */
+    PortalUtils.getPortalAppName = function (appBaseName) {
+        return 'portal/' + appBaseName;
+    };
+
     /**
      * Returns the full module name of the specified portal application.
      *
@@ -44,7 +57,7 @@ define('io.ox/office/portal/portalutils', [
      *  The full module name of the specified portal application.
      */
     PortalUtils.getPortalModuleName = function (appBaseName) {
-        return 'io.ox/office/portal/' + appBaseName;
+        return 'io.ox/office/' + PortalUtils.getPortalAppName(appBaseName);
     };
 
     /**
