@@ -33,7 +33,7 @@ define('io.ox/office/portal/presentation/fulltour', [
      *
      * @extends PortalTour
      */
-    var PresentationFullTour = PortalTour.extend({ constructor: function (initOptions) {
+    var PresentationFullTour = PortalTour.extend(function (initOptions) {
 
         // self reference
         var self = this;
@@ -177,7 +177,7 @@ define('io.ox/office/portal/presentation/fulltour', [
             if (presenterApp) { presenterApp.quit(); }
         });
 
-    } }); // class PresentationFullTour
+    }); // class PresentationFullTour
 
     // exports ================================================================
 
