@@ -13,11 +13,12 @@
  */
 
 define('io.ox/office/portal/spreadsheet/main', [
-    'io.ox/office/portal/mainhelper'
-], function (MainHelper) {
+    'io.ox/office/portal/mainhelper',
+    'gettext!io.ox/office/portal/main'
+], function (MainHelper, gt) {
 
     'use strict';
 
-    return MainHelper.createLauncher('spreadsheet', _.noI18n('Spreadsheet'));
+    return MainHelper.createLauncher('spreadsheet', gt.pgettext('app', 'Spreadsheet'));
 
 });
