@@ -29,7 +29,7 @@ define('io.ox/office/portal/text/fulltour', [
      *
      * @extends PortalTour
      */
-    var TextFullTour = PortalTour.extend({ constructor: function (initOptions) {
+    var TextFullTour = PortalTour.extend(function (initOptions) {
 
         // base constructor ---------------------------------------------------
 
@@ -74,7 +74,7 @@ define('io.ox/office/portal/text/fulltour', [
         // final tour step describing how to restart the tour, return to Drive application with the Back button
         this.restartTourStep().on('back', this.launchDriveApp.bind(this));
 
-    } }); // class TextFullTour
+    }); // class TextFullTour
 
     // exports ================================================================
 
