@@ -13,11 +13,12 @@
  */
 
 define('io.ox/office/portal/text/main', [
-    'io.ox/office/portal/mainhelper'
-], function (MainHelper) {
+    'io.ox/office/portal/mainhelper',
+    'gettext!io.ox/office/portal/main'
+], function (MainHelper, gt) {
 
     'use strict';
 
-    return MainHelper.createLauncher('text', _.noI18n('Text'));
+    return MainHelper.createLauncher('text', gt.pgettext('app', 'Text'));
 
 });
