@@ -13,13 +13,13 @@
  */
 
 define('io.ox/office/portal/view/contextmenu', [
-    'io.ox/office/tk/popup/listmenu',
-    'io.ox/office/tk/utils'
-], function (ListMenu, Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/popup/listmenu'
+], function (Utils, ListMenu) {
 
     'use strict';
 
-    // class Contextmenu ==========================================================
+    // class ContextMenu ======================================================
 
     // global flag if a context menu is open
     var isContextMenuOpenFlag = false;
@@ -36,22 +36,23 @@ define('io.ox/office/portal/view/contextmenu', [
      *  It's necessary to prevent the native context menu later
      *
      */
-    function Contextmenu(e) {
+    var ContextMenu = ListMenu.extend({ constructor: function (event) {
 
-        // After closing an OX app there could still be an invisible text selection active.
-        // Due to this, iOS detects an open softkeyboard and therefore would reduce the boundingBox.
-        // This results in a self closing context menu, when opened at the bottom part from the screen,
-        // because the popup is self closed in the the refreshNode loop.
-        window.getSelection().removeAllRanges();
+        // self reference
+        var self = this;
 
-        var // self reference
-            self = this,
+        // position were the ContextMenu should be opened
+        var x = event.pageX;
+        var y = event.pageY;
 
-            // position were the ContextMenu should be opened
-            x = e.pageX,
-            y = e.pageY;
+        // the identifier of the root application window
+        var windowId = $(event.target).closest('.io-ox-office-portal-main').attr('id');
 
-        ListMenu.call(this, { itemDesign: 'list', anchorBorder: 'right', boundingBox: $('body') });
+        // base constructor ---------------------------------------------------
+
+        ListMenu.call(this, windowId, { itemDesign: 'list', anchorBorder: 'right', boundingBox: $('body') });
+
+        // private methods ----------------------------------------------------
 
         // calculate context menu position and set the anchor
         function setPos() {
@@ -64,7 +65,7 @@ define('io.ox/office/portal/view/contextmenu', [
             }
 
             // open the contextmenu above the finger on touch
-            if (Utils.TOUCH) {
+            if (Utils.TOUCHDEVICE) {
                 y = Math.max(0, y - self.getContentNode().innerHeight());
             }
 
@@ -74,42 +75,49 @@ define('io.ox/office/portal/view/contextmenu', [
 
         // initialization -----------------------------------------------------
 
+        // After closing an OX app there could still be an invisible text selection active.
+        // Due to this, iOS detects an open softkeyboard and therefore would reduce the boundingBox.
+        // This results in a self closing context menu, when opened at the bottom part from the screen,
+        // because the popup is self closed in the the refreshNode loop.
+        window.getSelection().removeAllRanges();
+
         // prevent the default context menu
-        e.preventDefault();
+        event.preventDefault();
 
         // add marker class for additional CSS formatting
-        self.getNode().addClass('portal-context-menu');
+        this.getNode().addClass('portal-context-menu');
 
         //  check and set the position from the contextmenu
-        self.on('popup:show', setPos);
+        this.on('popup:show', setPos);
 
         // manually trigger destroy when the contextmenu is hidden
-        self.on('popup:hide', self.destroy);
+        this.on('popup:hide', self.destroy);
 
         // close the context menu on orientationchange
-        $(window).one('orientationchange', function () {
-            if (self) { // only when a context menu exists (self != undefined)
-                self.hide();
-            }
+        this.listenOnceTo($(window), 'orientationchange', function () {
+            self.hide();
         });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = x = y = null;
         });
-    }
 
-// exports ================================================================
+    } }); // class ContextMenu
+
+    // static methods ---------------------------------------------------------
 
-    //return Contextmenu;
-    var contextmenuObj = ListMenu.extend({ constructor: Contextmenu });
     // getter for the isContextMenuOpenFlag
-    contextmenuObj.isOpen = function () {
+    ContextMenu.isOpen = function () {
         return isContextMenuOpenFlag;
     };
+
     // setter for the isContextMenuOpenFlag
-    contextmenuObj.setOpen = function (state) {
+    ContextMenu.setOpen = function (state) {
         isContextMenuOpenFlag = state;
     };
-    return contextmenuObj;
+
+    // exports ================================================================
+
+    return ContextMenu;
 });
