@@ -95,12 +95,12 @@ define('io.ox/office/presentation/format/pagestyles', [
      */
     function updatePageFormatting(page, mergedAttributes) {
 
-        var // the page attributes of the passed attribute map
-            pageAttributes = mergedAttributes.page,
-            // effective page width (at least 2 cm)
-            pageWidth = Math.max(pageAttributes.width, 2000),
-            // effective page height (at least 2 cm)
-            pageHeight = Math.max(pageAttributes.height, 2000);
+        // the page attributes of the passed attribute map
+        var pageAttributes = mergedAttributes.page;
+        // effective page width (at least 2 cm)
+        var pageWidth = Math.max(pageAttributes.width, 2000);
+        // effective page height (at least 2 cm)
+        var pageHeight = Math.max(pageAttributes.height, 2000);
 
         // Set CSS attributes.
         page.css({
@@ -122,27 +122,29 @@ define('io.ox/office/presentation/format/pagestyles', [
      * @param {TextModel} docModel
      *  The text document model containing instance.
      */
-    function PageStyles(docModel) {
+    var PageStyles = StyleCollection.extend({ constructor: function (docModel) {
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'page', { formatHandler: updatePageFormatting });
+        StyleCollection.call(this, docModel, 'page');
 
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('page', DEFINITIONS);
+        docModel.registerAttributes('page', DEFINITIONS);
+
+        // register the formatting handler for DOM elements
+        this.registerFormatHandler(updatePageFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class PageStyles
+    } }); // class PageStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: PageStyles });
+    return PageStyles;
 
 });
