@@ -30,9 +30,6 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             // list level
             level: { def: 0 },
 
-            lineHeight: { def: LineHeight._115 },
-            // workaround for Bug 47960 & Bug 45951, lineHeight in powerpoint is based on "baseline" instead of "fontsize"
-
             listLabelHidden: { def: false },
 
             listStartValue: { def: -1 },
@@ -127,10 +124,21 @@ define('io.ox/office/presentation/format/paragraphstyles', [
 
                 var height = 0;
                 var fontHeight = Utils.convertLength(mergedAttributes.character.fontSize, 'pt', 'px');
+                var firstSpan;
+                var explicitAttrs;
 
                 if (lineHeight.type === 'fixed') {
                     height = Utils.convertHmmToLength(lineHeight.value, 'px');
                 } else if (lineHeight.type === 'percent') {
+                    // 61284: If percentage is specified, it must be token care of the font height of a span inside the
+                    // paragraph (simplified in this case: using the first span inside the paragraph)
+                    // -> the space before the paragraph changes in PP, if the font height inside the paragraph is modified
+                    // -> checking if the first text span has an implicit height (example task 47960)
+                    firstSpan = paragraph.children('span').first();
+                    if (firstSpan.length) {
+                        explicitAttrs = AttributeUtils.getExplicitAttributes(firstSpan, { family: 'character' });
+                        if (explicitAttrs.fontSize) { fontHeight = Utils.convertLength(explicitAttrs.fontSize, 'pt', 'px'); }
+                    }
                     height = fontHeight * lineHeight.value / 100;
                 } else {
                     Utils.warn('ParagraphStyles.calcSpacingHmm(): invalid line height type', lineHeight.type);
@@ -141,11 +149,6 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                     target = docModel.getTargetChainForNode(paragraph);
                 }
 
-                // use zoom level as workaround for bug 47960 & Bug 48476
-                var fontDesc = docModel.getRenderFont(mergedAttributes.character, target, 10);
-                var normalLineHeight = fontDesc.getNormalLineHeight() / 10;
-                height -= (normalLineHeight - fontHeight);
-                height = Math.max(0, height);
                 return Utils.convertLengthToHmm(height, 'px');
             }
 
