@@ -24,111 +24,185 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
     'use strict';
 
-    var DEFAULT_FONT_SIZE = 16;
-    var MIN_FONT_SIZE = 4;
+    var // The maximum scaled font-size (the characters have 2.3333em)
+        MAX_FONT_SIZE = 16,
 
-    var INDEX_ARRAY = [0, 1, 2, 3, 4, 5];
+        // Steps to check. The maximum steps are 6
+        INDEX_ARRAY = [0, 1, 2, 3, 4, 5],
+
+        // The font sizes steps. Each size has an adder of 1.2
+        FONT_ARRAY = [4, 5.2, 6.4, 7.6, 8.8, 10, 11.2, 12.4, 13.6, 14.8, 14.8, 16];
 
     // mix-in class DynFontSizeMixin ==========================================
-
     function DynFontSizeMixin(app) {
 
-        // self reference (the document model)
-        var self = this;
+        var // self reference (the document model)
+            self = this,
 
-        // all drawings nodes that need to be updated
-        var drawingQueue = $();
+            // all drawings nodes that need to be updated
+            drawingQueue = $(),
+
+            // last step
+            lastStep,
+            checkedSteps;
 
         // private methods ----------------------------------------------------
 
-        function updateStep(textframecontent, textframe, maxHeight, lastHeight, i) {
-            var currentFontSize = parseFloat(textframecontent.css('font-size'));
-            var lineReduction = parseFloat(textframecontent.attr('linereduction')) || 0;
+        /**
+         * Calculating the dynamic font size by binary search.
+         *
+         * @param {jQuery|Node} textFrameContent
+         *  the element which contains the text
+         *
+         * @param {jQuery|Node} clonedTextFrameContent
+         *  a cloned frame which contains the textframe for calculation
+         *
+         * @param {jQuery|Node} clonedTextFrame
+         *  the element which contains the text
+         *
+         * @param {Integer} maxHeight
+         *  the maxHeight of the container
+         *
+         * @param {Integer} i
+         *  current step number
+         *
+         * @returns {Integer|null}
+         *  if the current step found the fitting size null, would be returned.
+         *  if the current step has not found the fitting size, the current height would be returned
+         */
+        function updateStep(textFrameContent, clonedTextFrameContent, clonedTextFrame, maxHeight, i) {
 
-            // dont use jquery postion, because it is cached!!!
-            // var currentHeight = lastP.offsetTop + lastP.offsetHeight;
+            var // the current values
+                currentHeight        = 0,
 
-            var currentHeight = 0;
-            var paraChildren = textframe.children().get();
-            paraChildren.forEach(function (para, index) {
-                para = $(para);
-                // fix for Bug 47960
-                if (index === paraChildren.length - 1 && (para.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS) || para.find('>span:empty').length)) {
-                    return;
-                } else {
-                    currentHeight += para.outerHeight(true);
-                }
-            });
+                newStepId,
 
-            /*
-            console.log('iter', i, 'currentHeight', currentHeight, 'maxHeight', maxHeight, 'currentFontSize', currentFontSize);
-            if (i === 6) {
-                return null;
+                // the cildren of the outer textframe
+                paraChildren = clonedTextFrame.children().get(),
+
+                // if a paragraph with content found, this value is true
+                emptyParagraphsChecked = false;
+
+            /**
+             * Checks if the current height of the content is between 90% and 100% of the container height
+             *
+             * @returns {boolean}
+             */
+            function checkValues() {
+                return currentHeight > maxHeight * 0.95 && currentHeight < maxHeight;
             }
-            */
-            if (currentHeight < maxHeight && currentFontSize === DEFAULT_FONT_SIZE && lineReduction === 0) {
-                //all is fine
-                // console.log('all is fine');
-                return null;
-            } else if (currentHeight < maxHeight * 1.1 && currentHeight > maxHeight * 0.90) {
-                // all is scaled but fine in 90% - 110%
-                // console.log('all is scaled but fine');
+
+            /**
+             * Updates fontSize, fontScale and lineReduction of the current textframe.
+             *
+             * @param {Integer} stepId
+             */
+            function updateTextFrame(stepId) {
+                textFrameContent.css('font-size', FONT_ARRAY[stepId] + 'px');
+                textFrameContent.attr('font-scale', Math.min(FONT_ARRAY[stepId] / MAX_FONT_SIZE, 1));
+                // Bug-57232: line reduction disabled due to jumping issue
+            }
+
+            /**
+             * Updates fontSize, fontScale and lineReduction of the cloned textframe.
+             *
+             * @param {Integer} stepId
+             */
+            function updateClone(stepId) {
+                clonedTextFrameContent.css('font-size', FONT_ARRAY[stepId] + 'px');
+                clonedTextFrameContent.attr('font-scale', Math.min(FONT_ARRAY[stepId] / MAX_FONT_SIZE, 1));
+                // Bug-57232: line reduction disabled due to jumping issue
+                updateHeight();
+            }
+
+            /**
+             * Finding the last paragraph which is not empty. Also check for empty spans inside a paragraph.
+             */
+            function updateHeight() {
+                currentHeight = 0;
+                paraChildren.reverse().forEach(function (para) {
+                    para = $(para);
+                    if (emptyParagraphsChecked) {
+                        // found content before
+                        currentHeight += para.outerHeight(true);
+                    } else if (!para.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS) && !DOM.isEmptyParagraph(para)) {
+                        // found no content before
+                        currentHeight += para.outerHeight(true);
+                        emptyParagraphsChecked = true;
+                    }
+                });
+            }
+
+            if (i === 0) {
+                // Set font-size initial to the middle between min and max font-size.
+                lastStep = 5;
+                updateClone(lastStep);
+            }
+
+            updateHeight();
+
+            if (checkValues()) {
+                updateTextFrame(lastStep);
                 return null;
             } else {
-                var diff = maxHeight / currentHeight;
-
-                if (currentFontSize <= 4 && diff <= 1) {
-                    // console.log('early cut out');
-                    return null;
+                checkedSteps.push(lastStep);
+                // Update to a new font size and line height
+                if (currentHeight > maxHeight) {
+                    // size must be reduced
+                    newStepId = Math.max(lastStep - 1, 0);
                 } else {
-
-                    if (diff > 1) {
-                        diff = diff * 0.5 + 0.5;
-                    } else if (lastHeight === currentHeight && diff > 0.5) {
-                        diff = diff * 0.5 + 0.25;
-                    }
-                    // console.log('have to scale', diff, i);
-
-                    var newFont = diff * currentFontSize;
-                    var newLineReduction = lineReduction;
-                    if (diff < 1) {
-                        newLineReduction += 8;
-                        newLineReduction = Math.min(20, newLineReduction);
-                    }
-
-                    if (i === 0 && (currentFontSize !== DEFAULT_FONT_SIZE || lineReduction !== 0)) {
-                        newFont = DEFAULT_FONT_SIZE;
-                        newLineReduction = 0;
-                    }
-
-                    newFont = Math.min(newFont, DEFAULT_FONT_SIZE);
-                    newFont = Math.max(newFont, MIN_FONT_SIZE);
-                    newLineReduction = Math.min(newLineReduction, 20);
-
-                    textframecontent.css('font-size', newFont + 'px');
-                    textframecontent.attr('font-scale', newFont / DEFAULT_FONT_SIZE);
-                    textframecontent.attr('linereduction', newLineReduction);
+                    // size must be expanded
+                    newStepId = Math.min(lastStep + 1, FONT_ARRAY.length - 1);
                 }
+                if (_.contains(checkedSteps, newStepId)) {
+                    updateTextFrame(newStepId);
+                    return null;
+                }
+                // Setting the new values
+                updateClone(newStepId);
+                lastStep = newStepId;
+            }
+
+            if (i === INDEX_ARRAY.length - 1) {
+                // last step reached and final check of the height
+                if (checkValues()) {
+                    updateTextFrame(lastStep);
+                } else if (currentHeight > maxHeight) {
+                    updateTextFrame(lastStep - 1);
+                } else {
+                    updateTextFrame(lastStep);
+                }
+                return null;
             }
             return currentHeight;
         }
 
         function updateDrawing(drawing) {
-            var $drawing = $(drawing);
-            var textframecontent = $drawing.find('>.textframecontent');
-            var initialFontSize = parseFloat(textframecontent.css('font-size'));
-            var initialLineReduction = parseFloat(textframecontent.attr('linereduction'));
-            var textFrame = textframecontent.find('>.textframe');
-            var drawingHeight = null;
-            var currentHeight = null;
-            var drawingWidth = null;
-            var currentWidth = null;
-            var drawingAttrs = null;
-            var angle = DrawingFrame.getDrawingRotationAngle(self, drawing);
+
+            var $drawing = $(drawing),
+                textframecontent = $drawing.find('>.textframecontent'),
+                initialFontSize = parseFloat(textframecontent.css('font-size')),
+                initialLineReduction = parseFloat(textframecontent.attr('linereduction')) || 0, // avoid NaN
+                textFrame = textframecontent.find('>.textframe'),
+                drawingHeight = null,
+                currentHeight = null,
+                drawingWidth = null,
+                currentWidth = null,
+                drawingAttrs = null,
+
+                // the surrounding DOM for the clonded element
+                hiddenFrame = null,
+                // the clone of the textFrameContent
+                clonedTextFrameContent = null,
+                // the clone of the textFrame
+                clonedTextFrame = null,
+
+                angle = DrawingFrame.getDrawingRotationAngle(self, drawing);
 
             // local method to get left position value for drawing with auto resize and no wrap word,
             // depending on alignment of first paragraph child
             function getLeftPostion() {
+
                 var pAlignment = null;
                 var leftPos = null;
 
@@ -161,6 +235,7 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             // local method to get top position value for drawing with auto resize and wrap word,
             // depending on shape vertical alignment
             function getTopPostion() {
+
                 var vAlignment = null;
                 var topPos = null;
 
@@ -189,17 +264,75 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
                 return Utils.convertLengthToHmm(topPos, 'px');
             }
 
-            if (!textFrame.children().length) {
-                //empty drawing
-                return;
+            /**
+             * Creates the DOM structure for the cloned element and appends it
+             */
+            function createClone() {
+                var clonedDrawing = textframecontent.closest('.drawing').clone();
+
+                clonedTextFrameContent = clonedDrawing.find('.textframecontent');
+                clonedTextFrame = clonedTextFrameContent.find('.textframe');
+
+                hiddenFrame = $('<div class="io-ox-office-main io-ox-office-presentation-main io-ox-office-edit-main">')
+                    .append($('<div class="page formatted-content">')
+                        .append($('<div class="p slide">')
+                            .append(clonedDrawing)
+                        )
+                    );
+
+                Utils.insertHiddenNodes(hiddenFrame);
             }
 
+            /**
+             * Removes everything related to the cloned element
+             */
+            function removeClone() {
+                hiddenFrame.remove();
+            }
+
+            /**
+             * Function which is called so long the INDEX_ARRAY. Each call executes the updateStep function.
+             * If the updateStep function founds the correct height, the next function calls are skipped.
+             *
+             * @param {Integer} i
+             *  current step number
+             */
+            function innerUpdate(i) {
+                if (lastHeight === null) {
+                    return;
+                }
+                lastHeight = updateStep(textframecontent, clonedTextFrameContent, clonedTextFrame, maxHeight, i);
+            }
+
+            function returnFontSize() {
+                var newFontScale = parseFloat(textframecontent.css('font-size'));
+                var newLineReduction = parseFloat(textframecontent.attr('linereduction'));
+
+                if (Math.abs(newFontScale - initialFontSize) < 0.001 && Math.abs(newLineReduction - initialLineReduction) < 0.001) {
+                    return;
+                }
+                return {
+                    attrs: {
+                        shape: {
+                            fontScale: Math.min(newFontScale / MAX_FONT_SIZE, 1),
+                            lineReduction: newLineReduction / 100,
+                            autoResizeText: true,
+                            autoResizeHeight: false,
+                            noAutoResize: false
+                        }
+                    },
+                    drawing: drawing
+                };
+            }
+
+            if (!textFrame.children().length) { return; } // empty drawing
+
             // console.log('updateDrawing', textframecontent.attr('class'));
             if (textframecontent.hasClass('autoresizeheight') || !textframecontent.hasClass('autoresizetext')) {
 
-                if (initialFontSize !== DEFAULT_FONT_SIZE || initialLineReduction !== 0) {
+                if (initialFontSize !== MAX_FONT_SIZE || initialLineReduction !== 0) {
 
-                    textframecontent.css('font-size', DEFAULT_FONT_SIZE + 'px');
+                    textframecontent.css('font-size', MAX_FONT_SIZE + 'px');
                     textframecontent.attr('font-scale', null);
                     textframecontent.attr('linereduction', null);
                 }
@@ -235,51 +368,31 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
                 }
                 return;
             }
+
             // fix for Bug 48665
             var maxHeight = $drawing.data('widthHeightRev') ? $drawing.width() : $drawing.height();
-            maxHeight = maxHeight -/* (parseFloat(textFrame[0].style.top) || 0) -*/ (parseFloat(textFrame[0].style.paddingBottom) || 0);
+            maxHeight -= (parseFloat(textFrame[0].style.paddingBottom) || 0);
+
+            if (!maxHeight) { return; }
 
-            if (!maxHeight) {
-                return;
-            }
             var lastHeight = -1;
 
-            function innerUpdate(i) {
-                if (lastHeight === null) {
-                    return;
-                }
-                lastHeight = updateStep(textframecontent, textFrame, maxHeight, lastHeight, i);
-            }
-
-            function returnFontSize() {
-                var newFontScale = parseFloat(textframecontent.css('font-size'));
-                var newLineReduction = parseFloat(textframecontent.attr('linereduction'));
-
-                if (Math.abs(newFontScale - initialFontSize) < 0.001 && Math.abs(newLineReduction - initialLineReduction) < 0.001) {
-                    return;
-                }
-                return {
-                    attrs: {
-                        shape: {
-                            fontScale: newFontScale / DEFAULT_FONT_SIZE,
-                            lineReduction: newLineReduction / 100,
-                            autoResizeText: true,
-                            autoResizeHeight: false,
-                            noAutoResize: false
-                        }
-                    },
-                    drawing: drawing
-                };
-            }
+            // create a clone for the calculation
+            createClone();
 
+            // call the innerUpdate function related to the INDEX_ARRAY
             var def = null;
-            if (_.browser.IE) {
+            checkedSteps = [];
+            if (_.browser.IE && !_.browser.Edge) {
                 def = self.iterateArraySliced(INDEX_ARRAY, innerUpdate, 'DynFontSizeMixin.updateDrawing', { slice: 1 });
             } else {
                 _.each(INDEX_ARRAY, innerUpdate);
                 def = $.when(true);
             }
 
+            // clean up the cloned elements
+            removeClone();
+
             return def.then(returnFontSize);
         }
 
@@ -359,10 +472,16 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
         //
         //  Because of the 'target'
         function updateDynFontSizeForDrawings(drawings) {
+
             var defs = [];
             var slideID = null;
             // iterating over all drawings
             _.each(drawings, function (drawing) {
+                if ($(drawing).is('.grouped') && DrawingFrame.isAutoResizeHeightDrawingFrame(drawing)) { // convert autfit grouped shapes to no autofit for simplified handling
+                    defs.push($.when({ attrs: { shape: { autoResizeText: false, autoResizeHeight: false, noAutoResize: true } }, drawing: drawing }));
+                    DrawingFrame.getContentNode(drawing).removeClass(DrawingFrame.AUTORESIZEHEIGHT_CLASS); // removing marker class immediately, so that drawing formatting code does not ignore height (57892)
+                    return;
+                }
                 // TODO: operate correct on grouped drawings (width/height are different to ungrouped drawings)
                 // Also no text resize for 'title' place holders
                 if ($(drawing).is('.grouped') || PresentationUtils.isTitlePlaceHolderDrawing(drawing)) { return; }
@@ -372,6 +491,10 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
                 self.appendSlideToDom(slideID); // attaching the slide node to the DOM
 
+                self.listenTo(self.getUndoManager(), 'undo:after redo:after', function () {
+                    updateSlide(slide, slideID, $(drawing));
+                });
+
                 // skip slides if they are not formatted at all -> asking slide format manager
                 if (!self.getSlideFormatManager().isUnformattedSlide(slideID)) {
                     var change = updateSlide(slide, slideID, $(drawing));
