@@ -472,18 +472,26 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                     event.preventDefault();
                     // set focus to the document container (may be located in GUI edit fields)
                     app.getView().grabFocus();
-                    // draw the resizer
-                    TableResize.drawTableCellResizeSelection(self, app.getView(), app.getWindowNode(), resizerNode);
 
-                    // send initial mouse down event to the registered handlers
-                    // The following triggering of the event is necessary to resize the table without a further mousedown
-                    // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
-                    // the resize node. For moving it, a further mousedown/touchstart is requrired. By triggering this event
-                    // again, it is possible to move a resize node already with the first mousedown/touchstart.
-                    resizerNode.trigger(event);
+                    // draw the resizer (-> but not for grouped drawings in ODP (avoiding browser freezing, 59284))
+                    var isGroupedTableNode = app.isODF() && DrawingFrame.isGroupedDrawingFrame(drawingNode);
+
+                    if (!isGroupedTableNode) {
+                        TableResize.drawTableCellResizeSelection(self, app.getView(), app.getWindowNode(), resizerNode);
+
+                        // send initial mouse down event to the registered handlers
+                        // The following triggering of the event is necessary to resize the table without a further mousedown
+                        // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
+                        // the resize node. For moving it, a further mousedown/touchstart is requrired. By triggering this event
+                        // again, it is possible to move a resize node already with the first mousedown/touchstart.
+                        resizerNode.trigger(event);
+                    }
                 }
             } else {
 
+                // Avoiding that the Safari Browser expands a right click to a word selection
+                if (rightClick && _.browser.Safari) { self.getSelection().storeCurrentSelectionState(); }
+
                 // clicked somewhere else: calculate logical selection from browser selection, after browser has processed the mouse event.
                 self.getSelection().processBrowserEvent(event);
             }
