@@ -169,7 +169,9 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                     // the jQueryfied drawing node
                     drawing = $(oneDrawing),
                     // whether this is an image drawing
-                    isImage = drawing.attr('data-type') === 'image';
+                    isImage = drawing.attr('data-type') === 'image',
+                    // whether this is a table drawing
+                    isTable = drawing.attr('data-type') === 'table';
 
                 if (!model || model.destroyed) { return; } // the model might have been destroyed in the meantime
 
@@ -184,8 +186,8 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                     presentationAttrs.phIndex = odfBodyIndex++; // modifying the original presentation attribute
                 }
 
-                // Performance: Grouped images need to be formatted once completely
-                if (isImage) { drawing.addClass('formatrequired'); }
+                // Performance: Grouped images and grouped tables need to be formatted once completely
+                if (isImage || isTable) { drawing.addClass('formatrequired'); }
 
                 drawingStyles.updateElementFormatting(drawing);
 
