@@ -81,11 +81,66 @@ define('io.ox/office/presentation/model/updatedocumentmixin', [
             dumpParagraphCount('validateParagraphNode', self.getValidateParagraphNode().DBG_COUNT);
         }
 
+        /**
+         * Registering a listener function for the 'tab:activated' event, that is triggered after
+         * the first finished activation of a toolbar tab.
+         */
+        function registerFirstTabActivatedHandler() {
+
+            function activateThumbNails() {
+                // adding delay for slide formatting, so that toolbar is really rendered by the browser
+                self.executeDelayed(function () {
+                    self.trigger('slideModel:init:thumbnail'); // starting creation of thumbnails in slide pane
+                }, 'SlideFormatManager.registerFirstTabActivatedHandler', 200);
+            }
+
+            if (app.getUserSettingsValue('showToolbars', true)) {
+                app.getView().getToolBarTabs().one('tab:activated', activateThumbNails);
+            } else {
+                self.waitForImportSuccess(activateThumbNails); // alternative event, triggered earlier
+            }
+        }
+
+        /**
+         * A helper function that collects all functionality that needs to be done, after the
+         * active slide (if it exists) is set.
+         */
+        function postActiveSlideSettings() {
+
+            // making the (empty) slide pane visible, so that the slide is positioned correctly
+            app.getView().getSlidePane().setSidePaneWidthDuringLoad(self.getSlidePaneWidthInDocAttributes());
+
+            // checking the visibility of the page (not visible for empty views)
+            self.checkPageVisibility();
+
+            // making the slide (immediately) visible
+            return app.leaveBusyDuringImport(false, { immediateShow: true, zoomType: (Config.AUTOTEST ? null : 'slide') }).always(function () {
+
+                // Setting contenteditable 'false' to pagecontent node in IE (46752)
+                Utils.handleReadOnly(DOM.getPageContentNode(pagediv));
+
+                // writing some load logging information into the console (only in debug mode)
+                dumpProfilingInformation();
+
+                // registering the handler for the activation of the first tab (then creating of thumbnails in slide pane can start)
+                registerFirstTabActivatedHandler();
+
+                // trigger event to initialize the (empty) SlidePane, before the controller updates the GUI (looks better than vice versa)
+                // -> triggering synchronously so that empty slide pane is immediately visible together with first slide
+                // -> the generation of thumbnails needs its own event ('slideModel:init:thumbnail'), because otherwise the
+                //    visibility of the first slide is deferred dramatically. An alternative would be, to trigger this event
+                //    with a delay, but then slide thumbnail generation competes with toolbar generation.
+                self.trigger('slideModel:init', { isMasterView: self.isMasterView(), activeSlideId: self.getActiveSlideId(), width: self.getSlidePaneWidth(), slideRatio: self.getSlideRatio() });
+            });
+        }
+
         // public methods -----------------------------------------------------
 
         /**
          * Updates the formatting of all elements, after the import operations
          * of the document have been applied.
+         * This function handles also the case, if the document was loaded from
+         * local storage.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when the formatting has been
@@ -94,58 +149,34 @@ define('io.ox/office/presentation/model/updatedocumentmixin', [
         this.updateDocumentFormatting = function () {
 
             var // an object containing all slide IDs and slides
-                allSlides = self.getAllSlides(),
+                allSlides = null,
                 // the id of the active slide (TODO: This is not always the first slide in standard view)
                 // -> this can also be undefined, if there is not slide in the view
-                activeSlide = self.getIdOfFirstSlideOfActiveView(),
+                activeSlide = '',
                 // the format manager
                 slideFormatManager = self.getSlideFormatManager(),
                 // the page styles object
                 pageStyles = self.getPageStyles(),
                 // the object containing the page attributes
-                pageAttributes = pageStyles.getElementAttributes(self.getNode());
-
-            // a helper function that collects all functionality that needs to be done, after the
-            // active slide (if it exists) is set.
-            function postActiveSlideSettings() {
-
-                // making the (empty) slide pane visible, so that the slide is positioned correctly
-                app.getView().getSlidePane().setSidePaneWidthDuringLoad(self.getSlidePaneWidthInDocAttributes());
-
-                // checking the visibility of the page (not visible for empty views)
-                self.checkPageVisibility();
-
-                // making the slides visible
-                app.leaveBusyDuringImport();
-
-                // NO autotest (means: no selenium)
-                if (!Config.AUTOTEST) {
-                    // Setting zoom level to 'Fit to screen width'
-                    app.getView().setZoomType('slide');
-                }
-
-                // Setting contenteditable 'false' to pagecontent node in IE (46752)
-                Utils.handleReadOnly(DOM.getPageContentNode(pagediv));
-
-                // writing some load logging information into the console (only in debug mode)
-                dumpProfilingInformation();
-
-                // trigger event to initialize the SlidePane, before the controller updates the GUI (looks better than vice versa)
-                // -> making slidepane immediately visible, so that user sees previews of available slides
-                self.trigger('slideModel:init', { isMasterView: self.isMasterView(), activeSlideId: self.getActiveSlideId(), width: self.getSlidePaneWidth(), slideRatio: self.getSlideRatio() });
-            }
+                pageAttributes = null,
+                // whether the document is loaded from local storage
+                isLocalStorageImport = self.isLocalStorageImport();
 
             // setting globals
-            // drawingStyles = self.getDrawingStyles();
-            // slideStyles = self.getSlideStyles();
             pagediv = self.getNode();
+            allSlides = self.getAllSlides();
+            activeSlide = self.getIdOfFirstSlideOfActiveView();
+            pageAttributes = self.getPageStyles().getElementAttributes(pagediv);
 
             // setting tasks at the slide format manager
-            slideFormatManager.initializeManager(self.getIdTypeConnectionModel(), self.getStandardSlideOrder(true), self.getMasterSlideOrder(true));
+            slideFormatManager.initializeManager(self.getIdTypeConnectionModel(), self.getStandardSlideOrder(true), self.getMasterSlideOrder(true), { localStorage: isLocalStorageImport });
 
             // hiding all slides
             _.invoke(allSlides, 'addClass', 'invisibleslide');
 
+            // localStorage: Removing superfluous classes at slides that could not be removed when saving file to local storage
+            if (isLocalStorageImport) { _.invoke(allSlides, 'removeClass', 'notselectable'); }
+
             // resetting an existing selection, after all operations are applied
             self.getSelection().resetSelection();
 
@@ -155,20 +186,47 @@ define('io.ox/office/presentation/model/updatedocumentmixin', [
             // update the root page node
             pageStyles.updateElementFormatting(pagediv);
 
-            if (activeSlide) {
+            // Performance: Removing the marker class set from fast load
+            pagediv.removeClass(DOM.HIDDENAFTERATTACH_CLASSNAME);
 
-                // special handling for the first slide -> force formatting of active slide
+            // in localStorage the slides need to be formatted, because of Canvas and because they might have never been
+            // formatted before (example: slide_100 is often not formatted before the document is closed and written into
+            // local storage -> support of class 'slideformatted' in slideFormatManager).
+
+            if (activeSlide) {
                 return slideFormatManager.forceSlideFormatting(activeSlide).done(function () {
                     // activating the first slide after formatting it and its parents completely
                     self.setActiveSlideId(activeSlide, { forceUpdate: true });
-                    postActiveSlideSettings();
-                });
-
+                }).then(postActiveSlideSettings);
             } else {
                 postActiveSlideSettings();
                 return $.when();
             }
+        };
 
+        /**
+         * Handler for loading empty default documents with fast load. It applies html string,
+         * then actions, starts formatting the document, and at the end, leaves busy mode.
+         *
+         * @param {String} markup
+         *  The HTML mark-up to be shown as initial document contents.
+         *
+         * @param {Array} actions
+         *  The operation actions to be applied to finalize the fast import.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the actions have been applied.
+         */
+        this.fastEmptyLoadHandler = function (markup, actions) {
+            // markup is in form of object, parse and get data from mainDocument
+            markup = JSON.parse(markup);
+            self.setFullModelNode(markup.mainDocument);
+
+            self.trigger('fastemptyload:done'); // updating the model
+
+            return self.applyActions(actions, { external: true }).then(function () {
+                return self.updateDocumentFormatting();
+            });
         };
 
         // initialization -----------------------------------------------------
