@@ -16,12 +16,12 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/dateutils',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/dialogs',
     'io.ox/office/tk/locale/localedata',
+    'io.ox/office/tk/dialog/basedialog',
     'io.ox/office/textframework/view/controls',
     'gettext!io.ox/office/presentation/main',
     'less!io.ox/office/presentation/view/dialog/presentationdialogs'
-], function (Utils, DateUtils, Forms, Dialogs, LocaleData, Controls, gt) {
+], function (Utils, DateUtils, Forms, LocaleData, BaseDialog, Controls, gt) {
 
     'use strict';
 
@@ -43,34 +43,35 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
      *
      * @constructor
      *
-     * @extends Dialogs.ModalDialog
+     * @extends BaseDialog
+     *
+     * @param {PresentationView} docView
+     *  The view instance containing this dialog.
      *
-     * @param {PresentationView} view
-     *  The view instance containing this editor instance.
      * @param {Array} [dialogOptions]
      *  Options for filling the dialog
-     * @param {Boolean} [dialogOptions.ftr]
-     *  Footer placeholder exists on slide
-     * @param {String} [dialogOptions.ftrText]
-     *  Text inside footer placeholder
-     * @param {Boolean} [dialogOptions.sldNum]
-     *  Slide number placeholder exists on slide
-     * @param {Boolean} [dialogOptions.dt]
-     *  Datetime placeholder exists on slide
-     * @param {String} [dialogOptions.dtType]
-     *  Datetime placeholder contains date field and has this field type.
-     * @param {String} [dialogOptions.dtText]
-     *  Datetime placeholder contains fixed date as text.
+     *  - {Boolean} [dialogOptions.ftr]
+     *      Footer placeholder exists on slide
+     *  - {String} [dialogOptions.ftrText]
+     *      Text inside footer placeholder
+     *  - {Boolean} [dialogOptions.sldNum]
+     *      Slide number placeholder exists on slide
+     *  - {Boolean} [dialogOptions.dt]
+     *      Datetime placeholder exists on slide
+     *  - {String} [dialogOptions.dtType]
+     *      Datetime placeholder contains date field and has this field type.
+     *  - {String} [dialogOptions.dtText]
+     *      Datetime placeholder contains fixed date as text.
      */
-    function InsertFooterDialog(view, dialogOptions) {
+    var InsertFooterDialog = BaseDialog.extend(function (docView, dialogOptions) {
+
         var
-            self = this,
-            model = view.getDocModel(),
-            numberFormatter = model.getNumberFormatter(),
+            docModel = docView.getDocModel(),
+            numberFormatter = docModel.getNumberFormatter(),
             // fetch locale date formats
             categoryCodesDate = numberFormatter.getCategoryCodes('date'),
             // whether this is an ODF application
-            isODF = model.getApp().isODF(),
+            isODF = docModel.getApp().isODF(),
             // default fall back date option
             defaultDateOption = 'datetime1',
             insertFieldTitle = /*#. Insert footer fields from dialog menu*/ gt('Footer'),
@@ -87,7 +88,11 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, view, { title: insertFieldTitle, width: dialogWidth });
+        BaseDialog.call(this, docView, {
+            title: insertFieldTitle,
+            width: dialogWidth,
+            okLabel: gt('Apply')
+        });
 
         // private methods ----------------------------------------------------
 
@@ -139,7 +144,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
                 });
             } else {
                 localDateFormatList.push({ value: LocaleData.SHORT_DATE, label: getDateTimeRepresentation(LocaleData.SHORT_DATE) },
-                        { value: (isODF ? LocaleData.LONG_DATE : 'datetime1'), label: getDateTimeRepresentation(LocaleData.LONG_DATE) });
+                    { value: (isODF ? LocaleData.LONG_DATE : 'datetime1'), label: getDateTimeRepresentation(LocaleData.LONG_DATE) });
                 if (isODF) { defaultDateOption = LocaleData.SHORT_DATE; }
             }
 
@@ -223,70 +228,51 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             Forms.setButtonKeyHandler(slideNumCheckbox);
         }
 
-        // public methods -----------------------------------------------------
+        function actionHandler(action) {
+            var selectedOption;
+            var formatIndex;
+            var obj = null;
+            var checkedOptions = [];
+            var diffContent;
+            var diffState;
+            var odfRepresentation = null;
 
-        /**
-         * Executes the dialog and performs all necessary steps, if the
-         * user ended the dialog by clicking the Ok button
-         *
-         * @returns {jQuery} $.promise
-         *  The resolved/rejected promise of the executed dialog
-         */
-        this.show = _.wrap(this.show, function (show) {
-            return show.call(this).done(function (action) {
-                var selectedOption;
-                var formatIndex;
-                var obj = null;
-                var checkedOptions = [];
-                var diffContent;
-                var diffState;
-                var odfRepresentation = null;
-
-                if (Forms.isCheckedButtonNode(dateCheckbox)) {
-                    if (Forms.isCheckedButtonNode(autoRadioBtn)) {
-                        selectedOption = $controlArea.find('option:selected');
-                        formatIndex = selectedOption.length ? (selectedOption.index() + 1) : null;
-                        if (isODF) { odfRepresentation = categoryCodesDate[selectedOption.index()]; }
-                        obj = { type: 'dt', automatic: true, formatIndex: formatIndex, representation: isODF ? (odfRepresentation ? odfRepresentation.value : '') : selectedOption[0].text };
-                    } else {
-                        obj = { type: 'dt', automatic: false, representation: dateContainer.find('input').val() };
-                    }
-                    checkedOptions.push(obj);
-                }
-                if (Forms.isCheckedButtonNode(slideNumCheckbox)) {
-                    checkedOptions.push({ type: 'sldNum' });
-                }
-                if (Forms.isCheckedButtonNode(footerTxtCheckbox)) {
-                    checkedOptions.push({ type: 'ftr', ftrText: footerTxtContainer.find('input').val() });
-                }
-
-                if (isODF) {
-                    model.getFieldManager().insertFooterODF(checkedOptions, (action === 'applyall'));
+            if (Forms.isCheckedButtonNode(dateCheckbox)) {
+                if (Forms.isCheckedButtonNode(autoRadioBtn)) {
+                    selectedOption = $controlArea.find('option:selected');
+                    formatIndex = selectedOption.length ? (selectedOption.index() + 1) : null;
+                    if (isODF) { odfRepresentation = categoryCodesDate[selectedOption.index()]; }
+                    obj = { type: 'dt', automatic: true, formatIndex: formatIndex, representation: isODF ? (odfRepresentation ? odfRepresentation.value : '') : selectedOption[0].text };
                 } else {
-
-                    switch (action) {
-                        case 'ok':
-                            diffContent = model.getFieldManager().diffInputContent(dialogOptions, checkedOptions);
-                            diffState = model.getFieldManager().diffStateCheckboxes(dialogOptions, checkedOptions);
-                            model.getFieldManager().insertFooter(diffContent, diffState);
-                            break;
-                        case 'applyall':
-                            model.getFieldManager().insertAllFooters(checkedOptions);
-                    }
+                    obj = { type: 'dt', automatic: false, representation: dateContainer.find('input').val() };
                 }
-            }).always(function () {
-                // blocking keyboard input during applying of operations
-                model.setBlockKeyboardEvent(false);
+                checkedOptions.push(obj);
+            }
+            if (Forms.isCheckedButtonNode(slideNumCheckbox)) {
+                checkedOptions.push({ type: 'sldNum' });
+            }
+            if (Forms.isCheckedButtonNode(footerTxtCheckbox)) {
+                checkedOptions.push({ type: 'ftr', ftrText: footerTxtContainer.find('input').val() });
+            }
 
-                self = model = numberFormatter = categoryCodesDate = dateContainer = applyallBtn = null;
-                $controlArea = dateCheckbox = footerTxtContainer = slideNumCheckbox = footerTxtCheckbox = autoRadioBtn = fixedRadioBtn = null;
-            });
-        });
+            if (isODF) {
+                return docModel.getFieldManager().insertFooterODF(checkedOptions, (action === 'applyall'));
+            }
+
+            switch (action) {
+                case BaseDialog.OK_ACTION:
+                    diffContent = docModel.getFieldManager().diffInputContent(dialogOptions, checkedOptions);
+                    diffState = docModel.getFieldManager().diffStateCheckboxes(dialogOptions, checkedOptions);
+                    return docModel.getFieldManager().insertFooter(diffContent, diffState);
+                case 'applyall':
+                    return docModel.getFieldManager().insertAllFooters(checkedOptions);
+            }
+        }
 
         // initialization -----------------------------------------------------
 
         // close dialog when losing edit rights
-        view.closeDialogOnReadOnlyMode(this);
+        docView.closeDialogOnReadOnlyMode(this);
 
         $controlArea = $('<div class="control-area">');
 
@@ -299,23 +285,16 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
         // create the layout of the dialog
         initControls();
 
-        // set initial control values and initial focus
+        // block keyboard input during applying of operations
         this.on('show', function () {
-            // blocking keyboard input during applying of operations
-            model.setBlockKeyboardEvent(true);
-
-            // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus should not be in an input element
-            Utils.setFocus(self.getOkButton());
+            docModel.setBlockKeyboardEvent(true);
         });
 
+        // handler for the OK button
+        this.setOkHandler(actionHandler);
+
         // add additional button
-        this.addButton('applyall', gt('Apply to all'));
-        applyallBtn = this.getButton('applyall');
-        applyallBtn.detach();
-        applyallBtn.addClass('btn-apply-all btn-primary');
-        this.getFooter().append(applyallBtn);
-        this.getOkButton().children().html(gt('Apply'));
+        applyallBtn = this.createButton('applyall', gt('Apply to all'), { buttonStyle: 'primary', actionHandler: actionHandler });
 
         // ensure proper button order on small devices, because base dialog makes reorder
         if (Utils.SMALL_DEVICE) {
@@ -363,11 +342,17 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             dateContainer.find('select').prop('disabled', true).addClass('disabled');
         });
 
-    } // class InsertFooterDialog
+        this.registerDestructor(function () {
+            docModel.setBlockKeyboardEvent(false);
+            docModel = numberFormatter = categoryCodesDate = dateContainer = applyallBtn = null;
+            $controlArea = dateCheckbox = footerTxtContainer = null;
+            slideNumCheckbox = footerTxtCheckbox = autoRadioBtn = fixedRadioBtn = null;
+        });
+
+    }); // class InsertFooterDialog
 
     // exports ================================================================
 
-    // derive this class from class Dialogs.ModalDialog
-    return Dialogs.ModalDialog.extend({ constructor: InsertFooterDialog });
+    return InsertFooterDialog;
 
 });
