@@ -628,7 +628,16 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
 
         // color picker event handling
         colorPicker.on('group:change', function (event, data) {
-            var attrs = data.type === 'auto' ? TextUtils.getEmptySlideBackgroundAttributes() : { fill: { type: 'solid', color: data, imageUrl: null } };
+            var attrs;
+            if (data.type === 'auto') {
+                attrs = TextUtils.getEmptySlideBackgroundAttributes();
+            } else {
+                attrs = { fill: { type: 'solid', color: data } };
+                if (dialogOptions) {
+                    if (dialogOptions.gradient) { attrs.fill.gradient = null; }
+                    if (dialogOptions.bitmap && dialogOptions.bitmap.imageUrl) { attrs.fill.bitmap = { imageUrl: null }; }
+                }
+            }
 
             docView.handleSlideBackgroundVisibility(slideId, attrs.fill);
             setAlphaPreview(attrs, transpSpinner.getValue());
