@@ -39,10 +39,11 @@ define('io.ox/office/presentation/view/popup/slidepanecontextmenu', [
      */
     function SlidePaneContextMenu(docView, rootNode) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
+
         // TODO enable key like in speadsheet??
         ContextMenu.call(this, docView, rootNode, {
             delay: 200
@@ -62,13 +63,13 @@ define('io.ox/office/presentation/view/popup/slidepanecontextmenu', [
             // remove all existing controls from context menu
             self.destroyAllGroups();
 
-            self.addGroup('slide/insertslide', new Button({ label: gt('Insert slide') }), { focusTarget: rootNode }) // TODO focus target documentieren
-                .addGroup('slide/insertlayoutslide', new Button({ label: gt('Insert layout slide') }), { focusTarget: rootNode })
-                .addGroup('slide/duplicateslides', new Button({ label: gt('Duplicate slide') }), { focusTarget: rootNode })
-                .addGroup('slide/deleteslide', new Button({ label: gt('Delete slide') }), { focusTarget: rootNode })
+            self.addGroup('slide/insertslide', new Button(docView, { label: gt('Insert slide') }), { focusTarget: rootNode }) // TODO focus target documentieren
+                .addGroup('slide/insertlayoutslide', new Button(docView, { label: gt('Insert layout slide') }), { focusTarget: rootNode })
+                .addGroup('slide/duplicateslides', new Button(docView, { label: gt('Duplicate slide') }), { focusTarget: rootNode })
+                .addGroup('slide/deleteslide', new Button(docView, { label: gt('Delete slide') }), { focusTarget: rootNode })
 
-                .addGroup('slide/hideslide', new Button({ label: gt('Hide slide') }), { focusTarget: rootNode })
-                .addGroup('slide/unhideslide', new Button({ label: gt('Unhide slide') }), { focusTarget: rootNode })
+                .addGroup('slide/hideslide', new Button(docView, { label: gt('Hide slide') }), { focusTarget: rootNode })
+                .addGroup('slide/unhideslide', new Button(docView, { label: gt('Unhide slide') }), { focusTarget: rootNode })
 
                 .addSeparator()
                 .addGroup('layoutslidepicker/changelayout', new Controls.ChangeLayoutSlidePicker(docView, {
@@ -81,13 +82,36 @@ define('io.ox/office/presentation/view/popup/slidepanecontextmenu', [
                     // specialized additional parameters
                     iconPos: 'trailing',
                     caret: false,
-                    anchorBorder: 'right bottom top left'
+                    anchorBorder: 'right bottom top left',
+
+                    // speicial handling for odf layout slides
+                    isOdfLayout: docView.getApp().isODF()
                 }));
 
+            if (docView.getApp().isODF()) {
+                self.addSeparator()
+                    .addGroup('layoutslidepicker/changemaster', new Controls.ChangeLayoutSlidePicker(docView, {
+
+                        // overwrites
+                        tooltip: null,
+                        label: gt('Change master'),
+                        icon: 'fa-chevron-right',
+
+                        // specialized additional parameters
+                        iconPos: 'trailing',
+                        caret: false,
+                        anchorBorder: 'right bottom top left',
+
+                        // speicial handling for odf layout slides (but this is change of master slide)
+                        isOdfLayout: false
+                    }));
+            }
+
             self.updateAllGroups(); //Bug 47352
         }
 
         // public methods -----------------------------------------------------
+
         this.getXY = function (event) {
             // TODO doc stick to slide
             if (!event.stickToSlide) {
