@@ -53,14 +53,14 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             $pageNode,
 
-          //$thumbRenderBox,
+            //$thumbRenderBox,
 
             imgNodeBlueprint,
 
             $masterPreviewBlueprint,
             $standardPreviewBlueprint,
 
-          //array_unique = _.unique,
+            //array_unique = _.unique,
 
             isMasterView   = false,
             isStandardView = false,
@@ -94,7 +94,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             CLASS_NAME__EDIT_MODE               = 'edit-mode',
 
-          //CLASS_NAME__THUMB_MODE              = 'thumb-mode',
+            //CLASS_NAME__THUMB_MODE              = 'thumb-mode',
             CLASS_NAME__PREVIEW_MODE            = 'preview-mode',
 
             IS_ODF = false, // boolean value constant that indicates whether the workerd document features ODF or not.
@@ -117,13 +117,13 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             isLayoutMasterSlideFormattingHasBeenForcedOnce = false;
 
-          //REGX_ATTRIBUTE_NAME_WHITELIST = (/^(?:link|href|src|alt)$/);
+            //REGX_ATTRIBUTE_NAME_WHITELIST = (/^(?:link|href|src|alt)$/);
 
         // modify initial `initHandler` with mixin specific `init` functionality via basic function composition.
         //
         initOptions.initHandler = (function (proceed) {
             return function () {
-              //proceed.call(self, arguments); // not necessary.
+                //proceed.call(self, arguments); // not necessary.
 
                 proceed();     // the `PresentationView`s `initHandler` accessible via `initOptions`
                 initHandler(); // the `SlidePreviewMixin`s specific `initHandler` functionality.
@@ -415,7 +415,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         // }
 
         function createLayoutThumb(slideId) {
-          //Utils.info('+++ createLayoutThumb :: slideId', slideId);
+            //Utils.info('+++ createLayoutThumb :: slideId', slideId);
             var
                 $previewThumb = getPreview(slideId)/*.addClass(CLASS_NAME__THUMB_MODE)*/,
                 $layoutThumb = $previewThumb.clone();
@@ -493,21 +493,21 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             return imgNode;
         }
 
-    //  /**
-    //   *  helper
-    //   */
-    //  function createImageFromElementDeferred(node) {
-    //      //var
-    //      //    canvas = createCanvasFromElement(node),
-    //      //    img    = createImageFromCanvas(canvas);
-    //      //
-    //      //return img;
-    //
-    //      return createCanvasFromElementDeferred(node).then(function (canvas) {
-    //
-    //          return createImageFromCanvas(canvas);
-    //      });
-    //  }
+        //  /**
+        //   *  helper
+        //   */
+        //  function createImageFromElementDeferred(node) {
+        //      //var
+        //      //    canvas = createCanvasFromElement(node),
+        //      //    img    = createImageFromCanvas(canvas);
+        //      //
+        //      //return img;
+        //
+        //      return createCanvasFromElementDeferred(node).then(function (canvas) {
+        //
+        //          return createImageFromCanvas(canvas);
+        //      });
+        //  }
 
         /**
          * Sanitizing helper that will preserve any canvas content (in this case,
@@ -524,11 +524,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 targetList = $targetNode.find('canvas').toArray();
 
             sourceList.forEach(function (sourceNode, idx/*, list*/) {
-                var
-                    targetNode = targetList[idx],
-                    imgNode    = createImageFromCanvas(sourceNode);
-
-                $(targetNode).replaceWith(imgNode);
+                $(targetList[idx]).replaceWith(createImageFromCanvas(sourceNode));
             });
         }
 
@@ -704,7 +700,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         }
 
         function putFieldData(data) {
-          //window.console.log('+++ putFieldData - slide ' + getSlideIdFromFieldData(data) + ' still needs to be formatted.');
+            //window.console.log('+++ putFieldData - slide ' + getSlideIdFromFieldData(data) + ' still needs to be formatted.');
             var
                 slideId   = getSlideIdFromFieldData(data),
                 fieldId   = getFieldIdFromFieldData(data),
@@ -769,8 +765,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                         fieldStyle = elmField.style;
 
                     if (isVisibleField) {
-                        fieldStyle.display = 'initial';   // - directly restore an elements style value from e.g. 'none' like
-                                                          //   from an applied css-rule to its default / initial render value.
+                        fieldStyle.display = 'initial';   // - directly restore an elements style value from e.g. 'none' like from an applied css-rule to its default / initial render value.
                         fieldStyle.visibility = 'visible';
                     } else {
                         fieldStyle.visibility = 'hidden';
@@ -786,25 +781,27 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 slideId = getSlideIdFromFieldData(data),
                 attributionItem = attributionMap[slideId];
 
-        //  if (IS_ODF && isMasterView && docModel.isStandardSlideId(slideId)) { return; }
+            //  if (IS_ODF && isMasterView && docModel.isStandardSlideId(slideId)) { return; }
             if (!IS_ODF || !isMasterView || !docModel.isStandardSlideId(slideId)) {
 
                 // - does apply for either non ODF documents only, or,
                 //   if featuring ODF, then for standards slides only.
 
-                if (attributionItem.isMustFormat) { // - preview does not yet exist,
-                                                    //   because attribution has not yet been taken place;
-                    putFieldData(data);             // - do cache slide specific field data.
+                if (!attributionItem || attributionItem.isMustFormat) { // - preview does not yet exist (or not even the registration in the attributionMap),
+                    // because attribution has not yet been taken place;
+                    // - do cache slide specific field data.
+                    putFieldData(data);
 
                 } else {
-                                                    // - preview might exist already;
-                    updateField(data);              // - therefore proceed with updating all slide specific field data.
+                    // - preview might exist already;
+                    // - therefore proceed with updating all slide specific field data.
+                    updateField(data);
                 }
             }
         }
 
         function handleFieldUpdate(evt, fieldDataList) {
-          //window.console.log('+++ handleFieldUpdate +++ fieldDataList : ', fieldDataList);
+            //window.console.log('+++ handleFieldUpdate +++ fieldDataList : ', fieldDataList);
 
             fieldDataList.forEach(handleUpdateField);
 
@@ -839,7 +836,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         // }
 
         var handleFieldUpdateBeforeCompiledView = function (evt, fieldDataList) {
-          //window.console.log('+++ handleFieldUpdateBeforeCompiledView +++ fieldDataList : ', evt, fieldDataList);
+            //window.console.log('+++ handleFieldUpdateBeforeCompiledView +++ fieldDataList : ', evt, fieldDataList);
 
             fieldUpdateCache = fieldUpdateCache.concat(fieldDataList);
         };
@@ -893,19 +890,19 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
          * master/layout slide(s).
          */
         function compileMasterPreviewBlueprint() {
-          //var time = (new Date());
+            //var time = (new Date());
 
             $masterPreviewBlueprint = getSanitizedPreviewBlueprint($pageNode.clone());
 
-          //$masterPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).remove();
+            //$masterPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).remove();
             $masterPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).empty();
 
             $masterPreviewBlueprint.find(SELECTOR__DRAWINGSELECTION_OVERLAY).remove();
 
-          //Utils.info('+++ compileMasterPreviewBlueprint +++');
-          //Utils.info('+++ compileMasterPreviewBlueprint :: $masterPreviewBlueprint ', $masterPreviewBlueprint);
+            //Utils.info('+++ compileMasterPreviewBlueprint +++');
+            //Utils.info('+++ compileMasterPreviewBlueprint :: $masterPreviewBlueprint ', $masterPreviewBlueprint);
 
-          //Utils.info('+++ compileMasterPreviewBlueprint :: time : ', (new Date() - time));
+            //Utils.info('+++ compileMasterPreviewBlueprint :: time : ', (new Date() - time));
         }
 
         /**
@@ -919,19 +916,19 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
          * standard slide(s).
          */
         function compileStandardPreviewBlueprint() {
-          //var time = (new Date());
+            //var time = (new Date());
 
             $standardPreviewBlueprint = getSanitizedPreviewBlueprint($pageNode.clone());
 
             $standardPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).remove();
-          //$standardPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).empty();
+            //$standardPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).empty();
 
             $standardPreviewBlueprint.find(SELECTOR__DRAWINGSELECTION_OVERLAY).remove();
 
-          //Utils.info('+++ compileStandardPreviewBlueprint +++');
-          //Utils.info('+++ compileStandardPreviewBlueprint :: $standardPreviewBlueprint ', $standardPreviewBlueprint);
+            //Utils.info('+++ compileStandardPreviewBlueprint +++');
+            //Utils.info('+++ compileStandardPreviewBlueprint :: $standardPreviewBlueprint ', $standardPreviewBlueprint);
 
-          //Utils.info('+++ compileStandardPreviewBlueprint :: time : ', (new Date() - time));
+            //Utils.info('+++ compileStandardPreviewBlueprint :: time : ', (new Date() - time));
         }
 
         /**
@@ -965,9 +962,9 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         function setLayoutMasterVisibility($preview, layoutId, masterId, showLayoutSlide, showMasterSlide) {
             var
                 $layout = $preview
-                    .find(SELECTOR__LAYOUT_SLIDE).eq(0)
-                    .children('[data-container-id="' + layoutId + '"]').eq(0)
-                    .find(SELECTOR__SLIDE).eq(0),
+                        .find(SELECTOR__LAYOUT_SLIDE).eq(0)
+                        .children('[data-container-id="' + layoutId + '"]').eq(0)
+                        .find(SELECTOR__SLIDE).eq(0),
 
                 $master = $preview
                     .find(SELECTOR__MASTER_SLIDE).eq(0)
@@ -1155,7 +1152,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         function createLayoutFragment(slideId) {
             var
                 $fragmentSource = (docModel.getSlideById(slideId) || $()).parent(SELECTOR__SLIDE_CONTAINER),
-              //$fragmentSource = docModel.getSlideById(slideId).parent(SELECTOR__SLIDE_CONTAINER),
+                //$fragmentSource = docModel.getSlideById(slideId).parent(SELECTOR__SLIDE_CONTAINER),
                 $fragment       = $fragmentSource.clone();
 
             preserveShapes($fragmentSource, $fragment);
@@ -1277,7 +1274,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 followMasterSlideMap = this,
 
                 $preview        = getPreview(slideId),
-              //elmPreview      = $preview[0],
+                //elmPreview      = $preview[0],
 
                 $master,
                 $layout,
@@ -1466,7 +1463,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 $preview        = getPreview(slideId),
                 $container      = $preview ? $preview.find(SELECTOR__PAGE_CONTENT) : $(),
 
-              //elmPreview      = $preview[0],
+                //elmPreview      = $preview[0],
 
                 $contentSource  = docModel.getSlideById(slideId),
                 $content        = $contentSource ? $contentSource.clone() : $(),
@@ -1475,24 +1472,24 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 masterId = docModel.getMasterSlideId(layoutId),
 
                 showLayoutSlide, showMasterSlide;
-/*
-            if (  // necessary after DOM performance optimization
-                  // that deals with 'replacementslide' classified
-                  // and empty surrogate slides, that's content
-                  // is not considered to become ever part of the
-                  // preview store
 
-                ($preview.html() === '')
-                && (
-                    (('outerHTML' in elmPreview) && (elmPreview.outerHTML === '<div></div>'))
-                    || (
-                        (elmPreview.tagName.toLowerCase() === 'div') && (elmPreview.className === '')
-                    )
-                )
-            ) {
-                return;
-            }
-*/
+            // if (  // necessary after DOM performance optimization
+            //      // that deals with 'replacementslide' classified
+            //      // and empty surrogate slides, that's content
+            //      // is not considered to become ever part of the
+            //      // preview store
+            //
+            //    ($preview.html() === '')
+            //    && (
+            //        (('outerHTML' in elmPreview) && (elmPreview.outerHTML === '<div></div>'))
+            //        || (
+            //            (elmPreview.tagName.toLowerCase() === 'div') && (elmPreview.className === '')
+            //        )
+            //    )
+            //) {
+            //    return;
+            //}
+
             preserveShapes($contentSource, $content);
 
             preventContendEditable($content);
@@ -1539,25 +1536,31 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         }
 
         function assignEveryMasterPreviewItemInitially() {
-          //var time = (new Date());
+            //var time = (new Date());
 
             docModel.getMasterSlideOrder().forEach(assignMasterPreviewInitially);
 
-          //Utils.info('+++ assignEveryMasterPreviewItemInitially :: time : ', (new Date() - time));
+            //Utils.info('+++ assignEveryMasterPreviewItemInitially :: time : ', (new Date() - time));
         }
 
         function assignEveryStandardPreviewItemInitially() {
-          //var time = (new Date());
+            //var time = (new Date());
 
             docModel.getStandardSlideOrder().forEach(assignStandardPreviewInitially);
 
-          //Utils.info('+++ assignEveryStandardPreviewItemInitially :: time : ', (new Date() - time));
+            //Utils.info('+++ assignEveryStandardPreviewItemInitially :: time : ', (new Date() - time));
         }
 
         function triggerPreviewFormatting(slideIdList) {
             slideIdList = slideIdList.filter(function (slideId/*, idx, list*/) {
 
-                return attributionMap[slideId].isMustFormat;
+                // Performance: During loading process it can happen, that the first slides are ordered
+                // by the slide pane, before the attributeMap is filled. This is the case, after the
+                // event 'slidepane:init' was replaced by 'slideModel:init:thumbnail' (docs-891).
+                // It the attributeMap is still empty, the corresponding slide must be formatted.
+
+                return !attributionMap[slideId] || attributionMap[slideId].isMustFormat;
+                // return _.isEmpty(attributionMap) ? true : attributionMap[slideId].isMustFormat; // alternative
             });
             docModel.trigger('request:formatting', slideIdList);
         }
@@ -1580,7 +1583,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         }
 
         function compilePreviewStatesInitially() {
-          //var time = (new Date());
+            //var time = (new Date());
 
             attributionMap  = {};
 
@@ -1590,10 +1593,10 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             assignEveryStandardPreviewItemInitially();
             assignEveryMasterPreviewItemInitially();
 
-          //Utils.info('+++ compilePreviewStatesInitially :: time : ', (new Date() - time));
-          //Utils.info('+++ compilePreviewStatesInitially :: attributionMap : ', attributionMap);
-          //Utils.info('+++ compilePreviewStatesInitially :: previewStore : ', previewStore);
-          //Utils.info('+++ compilePreviewStatesInitially :: thumbRegistry : ', thumbRegistry);
+            //Utils.info('+++ compilePreviewStatesInitially :: time : ', (new Date() - time));
+            //Utils.info('+++ compilePreviewStatesInitially :: attributionMap : ', attributionMap);
+            //Utils.info('+++ compilePreviewStatesInitially :: previewStore : ', previewStore);
+            //Utils.info('+++ compilePreviewStatesInitially :: thumbRegistry : ', thumbRegistry);
         }
 
         function compileAllDisplayStates() {
@@ -1601,13 +1604,13 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             isMasterView   = docModel.isMasterView();
             isStandardView = !isMasterView;
 
-          //Utils.info('+++ compileAllDisplayStates :: isMasterView, isStandardView : ', isMasterView, isStandardView);
+            //Utils.info('+++ compileAllDisplayStates :: isMasterView, isStandardView : ', isMasterView, isStandardView);
         }
 
         function handlePreviewCreation(evt, slideIdList) {
-          //Utils.info('+++ ENTER handlePreviewCreation +++');
-          //
-          //compileAllDisplayStates();
+            //Utils.info('+++ ENTER handlePreviewCreation +++');
+            //
+            //compileAllDisplayStates();
 
             var
                 followMasterSlideMap  = {},
@@ -1662,15 +1665,15 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
          * and accordingly triggers the preview update process.
          */
         function handlePreviewUpdate(evt, slideIdLists, followMasterSlideMap) {
-          //Utils.info('+++ ENTER handlePreviewUpdate +++');
-          //
-          //compileAllDisplayStates();
+            //Utils.info('+++ ENTER handlePreviewUpdate +++');
+            //
+            //compileAllDisplayStates();
 
             followMasterSlideMap = followMasterSlideMap || {};
 
             slideIdLists.nonStandardDependend.forEach(function (slideId) {
                 assignMasterPreviewInitially(slideId);
-              //unflagAttributionItemAsMustFormat(slideId); // Important! - do not unflag - depending slides are not necessarily fully atrributed/formated yet.
+                //unflagAttributionItemAsMustFormat(slideId); // Important! - do not unflag - depending slides are not necessarily fully atrributed/formated yet.
                                                             //
                 unflagAttributionItemAsMustFormat(slideId); // - empty slides in master-slave edit-mode for slave view  - https://bugs.open-xchange.com/show_bug.cgi?id=49358
                                                             // - undisplayed slide background changes in slidepane      - https://bugs.open-xchange.com/show_bug.cgi?id=49059
@@ -1690,11 +1693,11 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 unflagAttributionItemAsMustFormat(slideId);
                 reassignMasterPreview.call(followMasterSlideMap, slideId);
             });
-          //slideIdLists.nonStandardIndependend.forEach(reassignMasterPreview, followMasterSlideMap);
+            //slideIdLists.nonStandardIndependend.forEach(reassignMasterPreview, followMasterSlideMap);
 
             slideIdLists.standardDependend.forEach(function (slideId) {
                 assignStandardPreviewInitially(slideId);
-              //unflagAttributionItemAsMustFormat(slideId); // Important! - do not unflag - depending slides are not necessarily fully atrributed/formated yet
+                //unflagAttributionItemAsMustFormat(slideId); // Important! - do not unflag - depending slides are not necessarily fully atrributed/formated yet
                                                             //
                 unflagAttributionItemAsMustFormat(slideId); // - empty slides in master-slave edit-mode for slave view  - https://bugs.open-xchange.com/show_bug.cgi?id=49358
                                                             // - undisplayed slide background changes in slidepane      - https://bugs.open-xchange.com/show_bug.cgi?id=49059
@@ -1714,7 +1717,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 unflagAttributionItemAsMustFormat(slideId);
                 reassignStandardPreview.call(followMasterSlideMap, slideId);
             });
-          //slideIdLists.standardIndependend.forEach(reassignStandardPreview, followMasterSlideMap);
+            //slideIdLists.standardIndependend.forEach(reassignStandardPreview, followMasterSlideMap);
 
             var
                 standardSlideIdList   = [].concat(slideIdLists.standardIndependend, slideIdLists.standardDependend),
@@ -1735,7 +1738,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         }
 
         function handleInsertSlide(evt, data) {
-          //data :: { id: id, isMasterView: isMasterView, documentReloaded: documentReloaded }
+            //data :: { id: id, isMasterView: isMasterView, documentReloaded: documentReloaded }
             var
                 slideId = data.id;
 
@@ -1771,9 +1774,9 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         }
 
         function compileView() {
-          //Utils.info('+++ ENTER compileView +++');
-          //
-          //var time = (new Date());
+            //Utils.info('+++ ENTER compileView +++');
+            //
+            //var time = (new Date());
 
             if (!imgNodeBlueprint) { imgNodeBlueprint = $('<img/>')[0]; }
 
@@ -1786,10 +1789,10 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             computeInitialThumbScaling();
 
             self.getPreview       = getPreview;
-          //self.getPreviewList   = getPreviewList;
+            //self.getPreviewList   = getPreviewList;
 
             self.requestThumb     = requestThumb;
-          //self.requestThumbList = requestThumbList;
+            //self.requestThumbList = requestThumbList;
 
             self.forceLayoutMasterSlideFormatting = forceLayoutMasterSlideFormattingOnlyOnce;
 
@@ -1805,9 +1808,9 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             self.stopListeningTo(docModel, 'slideDateFields:update', handleFieldUpdateBeforeCompiledView);
 
             self.stopListeningTo(docModel, 'masterfield:update', handleFieldUpdateBeforeCompiledView);
-          //self.stopListeningTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
+            //self.stopListeningTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
 
-          //window.console.log('+++ fieldUpdateCache : ', fieldUpdateCache);
+            //window.console.log('+++ fieldUpdateCache : ', fieldUpdateCache);
             handleFieldUpdate({}, fieldUpdateCache);
             handleFieldUpdateBeforeCompiledView = fieldUpdateCache = null;
 
@@ -1815,11 +1818,11 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             self.listenTo(docModel, 'slideDateFields:update', handleFieldUpdate);
 
             self.listenTo(docModel, 'masterfield:update', handleFieldUpdate);
-          //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdate); // please keep this commented line for debugging.
+            //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdate); // please keep this commented line for debugging.
 
             self.listenTo(docModel, 'inserted:slide', handleInsertSlide);
 
-          //Utils.info('+++ compileView :: time : ', (new Date() - time));
+            //Utils.info('+++ compileView :: time : ', (new Date() - time));
 
             self.trigger('slidepreview:init:after', {});
         }
@@ -1831,10 +1834,10 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         //
 
         this.getPreview       = $.noop;
-      //this.getPreviewList   = $.noop;
+        //this.getPreviewList   = $.noop;
 
         this.requestThumb     = $.noop;
-      //this.requestThumbList = $.noop;
+        //this.requestThumbList = $.noop;
 
         this.forceLayoutMasterSlideFormatting = $.noop;
 
@@ -1863,26 +1866,26 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 preventContendEditable($paneNode);
 
                 self.listenTo(slidepane, 'visiblesliderange:changed', function (evt, slideRangeState) {
-                  //window.console.log('+++ slidepreview - visiblesliderange:changed +++ [evt, currentSlideRange, visibleSlideIdList] : ', evt, slideRangeState.slideRanges.current, slideRangeState.slideIdLists.visible);
+                //window.console.log('+++ slidepreview - visiblesliderange:changed +++ [evt, currentSlideRange, visibleSlideIdList] : ', evt, slideRangeState.slideRanges.current, slideRangeState.slideIdLists.visible);
 
                     triggerPreviewFormatting(slideRangeState.slideIdLists.visible);
                 });
             }
-          //Utils.info('+++ initHandler :: $pageNode : ', $pageNode);
+            //Utils.info('+++ initHandler :: $pageNode : ', $pageNode);
 
             self.listenTo(docModel, 'change:activeView:after', compileAllDisplayStates);
 
-            self.listenTo(docModel, 'slideModel:init', compileView);
-          //self.listenTo(docModel, 'formatmanager:init', compileView);                                   // - too late.
-                                                                                                          //
-          //self.listenTo(docModel, 'formatmanager:init', registerSlidestateHandlingBeforeCompiledView);  // - too complicated.
+            self.listenTo(docModel, 'slideModel:init:thumbnail', compileView);
+            //self.listenTo(docModel, 'formatmanager:init', compileView);                                   // - too late.
+
+            //self.listenTo(docModel, 'formatmanager:init', registerSlidestateHandlingBeforeCompiledView);  // - too complicated.
             self.listenTo(docModel, 'slidestate:formatted', handleSlideStateFormattedBeforeCompiledView);
 
             self.listenTo(docModel, 'slideNumFields:update', handleFieldUpdateBeforeCompiledView);
             self.listenTo(docModel, 'slideDateFields:update', handleFieldUpdateBeforeCompiledView);
 
             self.listenTo(docModel, 'masterfield:update', handleFieldUpdateBeforeCompiledView);
-          //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
+            //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
 
             // slide size has changed - e.g. orientation change.
             self.listenTo(docModel, 'slidesize:change', handleSlideSizeChange);
