@@ -430,6 +430,7 @@ define('io.ox/office/presenter/views/mainview', [
                 // exit fullscreen
                 this.fullscreen = false;
                 this.sidebarView.toggleSidebar(this.sidebarBeforeFullscreen);
+                this.toolbarView.$el.removeClass('hidden');
                 this.presenterEvents.trigger('presenter:fullscreen:exit');
 
             } else if (element === this.presentationView.el) {
@@ -437,6 +438,7 @@ define('io.ox/office/presenter/views/mainview', [
                 this.fullscreen = true;
                 this.sidebarBeforeFullscreen = this.sidebarView.opened;
                 this.sidebarView.toggleSidebar(false);
+                this.toolbarView.$el.addClass('hidden');
                 this.presenterEvents.trigger('presenter:fullscreen:enter');
             }
         },
