@@ -21,10 +21,10 @@ define('io.ox/office/presenter/views/presentationview', [
     'io.ox/core/tk/doc-converter-utils',
     'io.ox/core/tk/doc-utils/pageloader',
     'io.ox/office/tk/utils',
+    'static/3rd.party/swiper.js',
     'gettext!io.ox/office/presenter/main',
-    'static/3rd.party/swiper.jquery.js',
     'css!3rd.party/swiper/swiper.css'
-], function (DisposableView, PDFDocument, PDFView, NavigationView, Notification, DocConverterUtils, PageLoader, Utils, gt) {
+], function (DisposableView, PDFDocument, PDFView, NavigationView, Notification, DocConverterUtils, PageLoader, Utils, Swiper, gt) {
 
     'use strict';
 
@@ -33,33 +33,24 @@ define('io.ox/office/presenter/views/presentationview', [
         loopedSlides: 0,
         followFinger: false,
         simulateTouch: false,
-        onlyExternal: false,
         noSwiping: true,
         speed: 0,
         spaceBetween: 0,
         runCallbacksOnInit: false
     };
 
-    var SWIPER_PARAMS_BUTTONS_ENABLED = {
-        onlyExternal: false
-    };
-
-    var SWIPER_PARAMS_BUTTONS_DISABLED = {
-        onlyExternal: true
-    };
-
     var SWIPER_PARAMS_SWIPING_ENABLED = {
+        noSwiping: false,
+        noSwipingClass: 'swiper-no-swiping',    // set back to default
         followFinger: true,
-        simulateTouch: true,
-        onlyExternal: false,
         speed: 300,
         spaceBetween: 100
     };
 
     var SWIPER_PARAMS_SWIPING_DISABLED = {
+        noSwiping: true,
+        noSwipingClass: 'swiper-slide',         // disable swiping for every slide
         followFinger: false,
-        simulateTouch: false,
-        onlyExternal: true,
         speed: 0,
         spaceBetween: 0
     };
@@ -70,20 +61,20 @@ define('io.ox/office/presenter/views/presentationview', [
     /**
      * Creates the HTML mark-up for a slide navigation button.
      *
-     * @param {String} type='left'|'right'
+     * @param {String} type = 'left'|'right'
      *  the button type to create, could be 'left' or 'right'.
      *
-     * @param {String} id
-     *  the CSS id for the button.
+     * @param {String} selectorClass
+     *  the CSS selector class for the button.
      *
      * @returns {jQuery}
      *  the button node.
      */
-    function createNavigationButton(type, id) {
+    function createNavigationButton(type, selectorClass) {
         var button = $('<a href="#" class="swiper-button-control" role="button" aria-controls="presenter-carousel">');
         var icon   = $('<i class="fa" aria-hidden="true">');
 
-        button.attr('id', id);
+        button.addClass(selectorClass);
         button.addClass((type === 'left') ? 'swiper-button-prev  left' : 'swiper-button-next right');
         button.attr((type === 'left') ? {
             //#. button tooltip for 'go to previous presentation slide' action
@@ -140,6 +131,8 @@ define('io.ox/office/presenter/views/presentationview', [
             this.ZOOM_FACTORS = [25, 35, 50, 75, 100, 125, 150, 200, 300, 400];
             // current zoom factor, defaults to 100%
             this.currentZoomFactor = 100;
+            // current scroll position of the page
+            this.currentScrollPosition = { top: 0, left: 0 };
             // the pdf document container
             this.documentContainer = null;
             // create a debounced version of zoom function
@@ -290,6 +283,8 @@ define('io.ox/office/presenter/views/presentationview', [
 
             } else if (tapCount === 2) {
                 this.setZoomLevel(this.getFitScreenZoomFactor());
+                // prevent iOS default double tap zoom
+                if (_.device('iOS')) { event.preventDefault(); }
             }
         },
 
@@ -310,50 +305,107 @@ define('io.ox/office/presenter/views/presentationview', [
          */
         onPinch: (function () {
             var startDistance = 0;
-            var transformScale = 0;
+            var transformScale = 1;
             var zoomFactor;
+            var originX = 0;
+            var originY = 0;
+            var originOffsetX = 0;
+            var originOffsetY = 0;
+            var translateX = 0;
+            var translateY = 0;
+            var lastPhase;
 
-            return function pinchHandler(phase, event, distance /*, midPoint*/) {
+            return function pinchHandler(phase, event, distance, midPoint) {
 
-                var documentPages = this.documentContainer.find('.document-page'),
-                    rtModel = this.app.rtModel,
-                    userId = this.rtConnection.getRTUuid();
+                var rtModel = this.app.rtModel;
+                var userId = this.rtConnection.getRTUuid();
+
+                var activePageNode = this.getActivePageNode();
+                var activeSlideNode = this.getActiveSlideNode();
+                var pageOffset;
+                var slideOffset;
+                var scrollTop;
+                var scrollLeft;
 
                 // no zoom for the presenter
                 if (rtModel.isPresenter(userId)) {
                     return;
                 }
 
+                // workaround for iOS
+                if (phase === 'cancel' && lastPhase === 'move') { phase = 'end'; }
+
+                lastPhase = phase;
+
                 switch (phase) {
                     case 'start':
                         startDistance = distance;
+
+                        originX = midPoint.x;
+                        originY = midPoint.y;
+
+                        pageOffset    = activePageNode.offset();
+                        originOffsetX = originX - pageOffset.left;
+                        originOffsetY = originY - pageOffset.top;
+
+                        //default, if no move event is triggered before end event
+                        transformScale = 1;
+
+                        activePageNode.css({
+                            'transform-origin': originOffsetX + 'px ' + originOffsetY + 'px',
+                            transform: 'translate3d(0px,0px,0) scale(1)'
+                        });
                         break;
 
                     case 'move':
                         transformScale = distance / startDistance;
-                        //transformOriginX = midPoint.x;
-                        //transformOriginY = midPoint.y;
-                        documentPages.css({
-                            //'transform-origin': transformOriginX + 'px ' + transformOriginY + 'px',
-                            transform: 'scale(' + transformScale + ')'
+                        zoomFactor     = transformScale * this.currentZoomFactor;
+
+                        if (zoomFactor > this.getMaxZoomFactor()) {
+                            transformScale = this.getMaxZoomFactor() / this.currentZoomFactor;
+                        } else if (zoomFactor < this.getMinZoomFactor()) {
+                            transformScale = this.getMinZoomFactor() / this.currentZoomFactor;
+                        }
+
+                        translateX = midPoint.x - originX;
+                        translateY = midPoint.y - originY;
+
+                        activePageNode.css({
+                            'transform-origin': originOffsetX + 'px ' + originOffsetY + 'px',
+                            transform: 'translate3d(' + translateX + 'px,' + translateY + 'px,0) scale(' + transformScale + ')'
                         });
                         break;
 
                     case 'end':
-                        zoomFactor = transformScale * this.currentZoomFactor;
-                        zoomFactor = Utils.minMax(zoomFactor, this.getMinZoomFactor(), this.getMaxZoomFactor());
-                        documentPages.css({
-                            //'transform-origin': '50% 50% 0',
-                            transform: 'scale(1)'
-                        });
+                        zoomFactor  = transformScale * this.currentZoomFactor;
+                        zoomFactor  = Utils.minMax(zoomFactor, this.getMinZoomFactor(), this.getMaxZoomFactor());
+
+                        pageOffset  = activePageNode[0].getBoundingClientRect();
+                        slideOffset = activeSlideNode.offset();
+
+                        scrollTop   = slideOffset.top  - pageOffset.top;
+                        scrollLeft  = slideOffset.left - pageOffset.left;
+
+                        // activePageNode.css({
+                        //     'transform-origin': '50% 50% 0',
+                        //     transform: 'translate3d(0px,0px,0) scale(1)'
+                        // });
+
                         this.setZoomLevel(zoomFactor);
+
+                        // store scroll position to be set when calling refresh
+                        this.currentScrollPosition = { top: scrollTop, left: scrollLeft };
+
                         break;
 
                     case 'cancel':
-                        documentPages.css({
-                            //'transform-origin': '50% 50% 0',
-                            transform: 'scale(1)'
-                        });
+                        if (lastPhase === 'start') {
+                            // start event directly followed by cancel event
+                            activePageNode.css({
+                                'transform-origin': '',
+                                transform: ''
+                            });
+                        }
                         break;
 
                     default:
@@ -364,17 +416,16 @@ define('io.ox/office/presenter/views/presentationview', [
 
         /**
          * Handles Swiper slide change end events
-         *
-         * @param {Object} swiper
-         *  the Swiper instance
          */
-        onSlideChangeEnd: function (swiper) {
-            var activeSlideIndex  = swiper.activeIndex;
-            var activeSlideNode   = swiper.slides.eq(activeSlideIndex);
-            var previousSlideNode = swiper.slides.eq(swiper.previousIndex);
+        onSlideChangeEnd: function () {
+            var activeSlideIndex  = this.swiper.activeIndex;
+            var activeSlideNode   = this.getActiveSlideNode();
+            var previousSlideNode = this.getPreviousSlideNode();
 
             this.currentSlideIndex = activeSlideIndex;
 
+            this.currentScrollPosition = { top: 0, left: 0 };
+
             // a11y
             activeSlideNode.attr('aria-selected', 'true');
             previousSlideNode.attr('aria-selected', 'false');
@@ -392,12 +443,9 @@ define('io.ox/office/presenter/views/presentationview', [
 
         /**
          * Handles Swiper slide change start events
-         *
-         * @param {Object} swiper
-         *  the Swiper instance
          */
-        onSlideChangeStart: function (swiper) {
-            this.rtConnection.updateSlide({ activeSlide: swiper.activeIndex });
+        onSlideChangeStart: function () {
+            this.rtConnection.updateSlide({ activeSlide: this.swiper.activeIndex });
         },
 
         /**
@@ -477,6 +525,22 @@ define('io.ox/office/presenter/views/presentationview', [
             }
         },
 
+        /**
+         * Returns the previously active Swiper slide node.
+         *
+         * @returns {jQuery}
+         *  the active node.
+         */
+        getPreviousSlideNode: function () {
+            if (!this.swiper || !this.swiper.slides || !_.isNumber(this.swiper.previousIndex)) {
+                return $();
+            }
+
+            var node = this.swiper.slides.eq(this.swiper.previousIndex);
+            // convert Dom7 node to jQuery before returning
+            return (node && node.length > 0) ? $(node[0]) : $();
+        },
+
         /**
          * Returns the active Swiper slide node.
          *
@@ -487,7 +551,10 @@ define('io.ox/office/presenter/views/presentationview', [
             if (!this.swiper || !this.swiper.slides) {
                 return $();
             }
-            return this.swiper.slides.eq(this.swiper.activeIndex);
+
+            var node = this.swiper.slides.eq(this.swiper.activeIndex);
+            // convert Dom7 node to jQuery before returning
+            return (node && node.length > 0) ? $(node[0]) : $();
         },
 
         /**
@@ -517,19 +584,6 @@ define('io.ox/office/presenter/views/presentationview', [
             return this.numberOfSlides || 0;
         },
 
-        /**
-         * Returns all Swiper slide nodes.
-         *
-         * @returns {jQuery}
-         *  the slide nodes.
-         */
-        getSlides: function () {
-            if (!this.swiper || !this.swiper.slides) {
-                return $();
-            }
-            return this.swiper.slides;
-        },
-
         /**
          * Switches Swiper to the slide with the given index.
          *
@@ -574,7 +628,7 @@ define('io.ox/office/presenter/views/presentationview', [
             }
 
             if (this.swiper && (!rtModel.isJoined(userId) || rtModel.isPresenter(userId))) {
-                this.swiper.slideNext(true, 0);
+                this.swiper.slideNext(0, true);
             }
         },
 
@@ -594,7 +648,7 @@ define('io.ox/office/presenter/views/presentationview', [
             }
 
             if (this.swiper && (!rtModel.isJoined(userId) || rtModel.isPresenter(userId))) {
-                this.swiper.slidePrev(true, 0);
+                this.swiper.slidePrev(0, true);
             }
         },
 
@@ -620,27 +674,23 @@ define('io.ox/office/presenter/views/presentationview', [
 
         /**
          * Updates the Swiper parameters according to the RTModel data.
-         *  Swiping is enabled if:
+         *  Changing slides is enabled if:
          *  - the presentation has not yet been started
          *  - the current user is a participant and has not (yet) joined the presentation
          *  - the current user is the presenter
          */
         updateSwiperParams: function () {
             var rtModel = this.app.rtModel;
-            //var localModel = this.app.localModel;
             var userId  = this.app.rtConnection.getRTUuid();
-            //var enable = !rtModel.isJoined(userId) || rtModel.isPresenter(userId) || localModel.isPresenter(userId);
-            var enable  = !rtModel.isJoined(userId) || rtModel.isPresenter(userId);
+            var enableSlideChange  = !rtModel.isJoined(userId) || rtModel.isPresenter(userId);
+            var enableSwiping;
 
             if (!this.swiper) { return; }
 
+            // on touch devices handle swiping
             if (_.device('touch')) {
-                // on touch devices enable or disable swiping and the buttons
-                this.swiper.params = _.extend(this.swiper.params, (enable ? SWIPER_PARAMS_SWIPING_ENABLED : SWIPER_PARAMS_SWIPING_DISABLED));
-
-            } else {
-                // on non touch devices enable or disable the buttons only
-                this.swiper.params = _.extend(this.swiper.params, (enable ? SWIPER_PARAMS_BUTTONS_ENABLED : SWIPER_PARAMS_BUTTONS_DISABLED));
+                enableSwiping = enableSlideChange && !this.isZoomedIn();
+                _.extend(this.swiper.params, (enableSwiping ? SWIPER_PARAMS_SWIPING_ENABLED : SWIPER_PARAMS_SWIPING_DISABLED));
             }
         },
 
@@ -703,6 +753,16 @@ define('io.ox/office/presenter/views/presentationview', [
                 this.documentContainer.children().eq(pageNumber - 1).find('.document-page') : $();
         },
 
+        /**
+         * Returns the active page index.
+         *
+         * @returns {Number}
+         *  the active page index.
+         */
+        getActivePageIndex: function () {
+            return (this.getActiveSlideIndex() + 1);
+        },
+
         /**
          * Returns the active page node.
          *
@@ -710,7 +770,7 @@ define('io.ox/office/presenter/views/presentationview', [
          *  The active jQuery page node.
          */
         getActivePageNode: function () {
-            return this.getPageNode(this.getActiveSlideIndex() + 1);
+            return this.getPageNode(this.getActivePageIndex());
         },
 
         /**
@@ -810,12 +870,27 @@ define('io.ox/office/presenter/views/presentationview', [
 
                 if (_.isNumber(pageNumberToRefresh)) {
                     // Process the page node
-                    var pageNode = this.getPageNode(pageNumberToRefresh);
-                    this.pageLoader.setPageZoom(pageNode, pageZoom);
+                    var pageNode  = this.getPageNode(pageNumberToRefresh);
+                    var slideNode = this.getActiveSlideNode();
+
+                    this.pageLoader.setPageZoom(pageNode, pageZoom).then(function () {
+                        // after zooming, apply scroll position to active page
+                        if (pageNumberToRefresh === self.getActivePageIndex()) {
+                            // clear CSS transformation
+                            pageNode.css({
+                                'transform-origin': '',
+                                transform: ''
+                            });
+
+                            // apply scroll position
+                            slideNode.scrollTop(self.currentScrollPosition.top).scrollLeft(self.currentScrollPosition.left);
+                        }
+                    });
 
                 } else {
+                    var slides = this.swiper && this.swiper.slides;
                     // empty all pages in case of a complete refresh request
-                    _.each(this.getSlides(), function (slide) {
+                    _.each(slides, function (slide) {
                         var // get page node from slide node
                             page = $(slide).children(':first');
 
@@ -824,6 +899,7 @@ define('io.ox/office/presenter/views/presentationview', [
                         // empty page node and set zoom
                         self.emptyPageNode(page);
                         self.pageLoader.setPageZoom(page, pageZoom);
+
                         // re-attach page node to slide node again
                         page.appendTo(slide);
 
@@ -884,14 +960,19 @@ define('io.ox/office/presenter/views/presentationview', [
             if (!this.pdfDocument) {
                 return;
             }
+
             // forward 'resolved' errors to error handler
             if (_.isObject(pageCount) && (pageCount.cause.length > 0)) {
                 this.pdfDocumentLoadError(pageCount);
                 return;
+            } else  if (!_.isNumber(pageCount)) {
+                this.pdfDocumentLoadError({ cause: 'importError' });
+                return;
             }
 
-            var swiperNextButtonId = _.uniqueId('presenter-button-next-'),
-                swiperPrevButtonId = _.uniqueId('presenter-button-prev-');
+            var uniqueId = _.uniqueId();
+            var swiperNextButtonClass = 'presenter-button-next-' + uniqueId;
+            var swiperPrevButtonClass = 'presenter-button-prev-' + uniqueId;
 
             // configure Swiper
             //
@@ -899,10 +980,14 @@ define('io.ox/office/presenter/views/presentationview', [
             // when a resize events occurs during the processing of a swiper.slideTo() call.
             var swiperParameter = {
                 initialSlide: this.startIndex,
-                nextButton: '#' + swiperNextButtonId,
-                prevButton: '#' + swiperPrevButtonId,
-                onSlideChangeStart: this.onSlideChangeStart.bind(this),
-                onTransitionEnd: this.onSlideChangeEnd.bind(this)
+                navigation: {
+                    nextEl: '.' + swiperNextButtonClass,
+                    prevEl: '.' + swiperPrevButtonClass
+                },
+                on: {
+                    slideChangeTransitionStart: this.onSlideChangeStart.bind(this),
+                    slideChangeTransitionEnd: this.onSlideChangeEnd.bind(this)
+                }
             };
             swiperParameter = _.extend(swiperParameter, SWIPER_PARAMS_DEFAULT);
             // enable swiping on touch devices
@@ -921,8 +1006,8 @@ define('io.ox/office/presenter/views/presentationview', [
             // add navigation buttons
             if (pageCount > 1) {
                 this.carouselRoot.append(
-                    createNavigationButton('left', swiperPrevButtonId),
-                    createNavigationButton('right', swiperNextButtonId)
+                    createNavigationButton('left', swiperPrevButtonClass),
+                    createNavigationButton('right', swiperNextButtonClass)
                 );
             }
 
@@ -947,7 +1032,7 @@ define('io.ox/office/presenter/views/presentationview', [
             }, this);
 
             // initiate swiper
-            this.swiper = new window.Swiper(this.carouselRoot[0], swiperParameter);
+            this.swiper = new Swiper(this.carouselRoot[0], swiperParameter);
             this.pages  = this.$el.find('.document-page');
 
             // render visible PDF pages
@@ -960,6 +1045,7 @@ define('io.ox/office/presenter/views/presentationview', [
             if (_.device('desktop')) {
                 this.pages.on('mousedown mouseup', this.onSlideClick.bind(this));
             }
+
             // resolve the document load Deferred: this document view is fully loaded.
             this.documentLoad.resolve();
             // focus first active slide initially
@@ -974,6 +1060,7 @@ define('io.ox/office/presenter/views/presentationview', [
          */
         pdfDocumentLoadError: function (error) {
             Utils.warn('Presenter - failed loading PDF document. Cause: ', error.cause);
+
             this.$el.append(Notification.createErrorNode(error, { category: 'conversion' }));
             // reject the document load Deferred.
             this.documentLoad.reject();
@@ -1000,11 +1087,15 @@ define('io.ox/office/presenter/views/presentationview', [
 
         /**
          * Calculates the 'fit to page' zoom factor of this document.
+         *
+         * @param {Boolean} ignoreOffset
+         *  If true the 'fit to page' zoom doesn't leave space for slide margins.
+         *
          * @returns {Number} zoom factor
          */
-        getFitScreenZoomFactor: function () {
+        getFitScreenZoomFactor: function (ignoreOffset) {
             var fullscreen          = this.app.mainView.fullscreen;
-            var offset              = fullscreen ? 0 : 40;
+            var offset              = (fullscreen || ignoreOffset) ? 0 : 40;
             var slideHeight         = this.$el.height();
             var slideWidth          = this.$el.width();
             var originalPageSize    = this.pdfDocument.getOriginalPageSize();
@@ -1071,15 +1162,34 @@ define('io.ox/office/presenter/views/presentationview', [
             }
 
             zoomLevel = Utils.minMax(zoomLevel, this.getMinZoomFactor(), this.getMaxZoomFactor());
+            if (zoomLevel === this.currentZoomFactor) {
+                return;
+            }
 
-            var documentTopPosition = this.documentContainer.scrollTop();
+            var activeSlideNode         = this.getActiveSlideNode();
+            var scale                   = zoomLevel / this.currentZoomFactor;
+
+            // the vertical scroll position before zooming
+            var scrollTopBeforeZoom     = activeSlideNode.scrollTop();
+            // the horizontal scroll position before zooming
+            var scrollLeftBeforeZoom    = activeSlideNode.scrollLeft();
+            // the vertical scroll position after zooming
+            var scrollTopAfterZoom      = scrollTopBeforeZoom * scale;
+            // the horizontal scroll position after zooming
+            var scrollLeftAfterZoom     = scrollLeftBeforeZoom * scale;
+
+            // store scroll position to be set when calling refresh
+            this.currentScrollPosition = { top: scrollTopAfterZoom, left: scrollLeftAfterZoom };
 
             // set page zoom to all pages and apply the new size to all page wrappers
             this.currentZoomFactor = zoomLevel;
             this.refreshDebounced();
 
-            // adjust document scroll position according to new zoom
-            this.documentContainer.scrollTop(documentTopPosition * zoomLevel / this.currentZoomFactor);
+            // update document status according to the zoom level
+            this.$el.toggleClass('zoomedIn', this.isZoomedIn());
+
+            // update zoom level specific swiper params
+            this.updateSwiperParams();
 
             //#. text of a presentation zoom level caption
             //#. Example result: "100 %"
@@ -1087,6 +1197,20 @@ define('io.ox/office/presenter/views/presentationview', [
             this.showCaption(gt('%1$d %', Math.round(zoomLevel)));
         },
 
+        /**
+         * Returns true if the document is zoomed that it does no longer fit
+         * to the page, false otherwise.
+         *
+         * @returns {Boolean}
+         *  Wheter the document is zoomed that it doesn't fit to the page.
+         */
+        isZoomedIn: function () {
+            // the zoom factor the document would fit to the page
+            var fitScreenZoomFactor = this.getFitScreenZoomFactor(true);
+
+            return (Math.floor(this.currentZoomFactor) > Math.floor(fitScreenZoomFactor));
+        },
+
         /**
          *  Gets the maximum zoom factor of a document.
          */
@@ -1118,12 +1242,9 @@ define('io.ox/office/presenter/views/presentationview', [
                 //console.info('Presenter - onResize()', 'defaultZoomFactor', fitScreenZoomFactor);
 
                 if (this.swiper) {
-                    this.swiper.onResize();
-                    // workaround for a possible bug from swiper plugin that happens sporadically:
-                    // After an on resize call, the plugin 'resets' the active slide to the beginning.
-                    //this.swiper.slideTo(this.currentSlideIndex);
+                    this.swiper.update();
+                    this.swiper.slides.css('line-height', swiperSlide.height() + 'px');
                 }
-                this.getSlides().css('line-height', swiperSlide.height() + 'px');
 
             }.bind(this));
         },
