@@ -110,7 +110,8 @@ define('io.ox/office/presenter/views/sidebar/slidepeekview', [
 
             } else {
                 // load the preview image
-                var thumbnailUrl = DocConverterUtils.getConverterUrl(params);
+                var thumbnailUrl = DocConverterUtils.getConverterUrl(params, { encodeUrl: true });
+
                 slidePeekImage.attr('src', thumbnailUrl)
                 .on('load', function () {
                     $(this).show();
