@@ -53,7 +53,7 @@ define('io.ox/office/settings/spellchecking', [
     // static methods ---------------------------------------------------------
 
     SpellChecking.isOnlineSpelling = function () {
-        return Config.get(SETTINGS_KEY, true);
+        return Config.getFlag(SETTINGS_KEY, true);
     };
 
     SpellChecking.setOnlineSpelling = function (state) {
