@@ -98,17 +98,13 @@ define('io.ox/office/settings/spellchecklanguagenotification', [
             // - create sanitized and sorted language list from persistent string-value setting
             // - see BUG 54502 [https://bugs.open-xchange.com/show_bug.cgi?id=54502] / 'Set language notification' not stored
 
-            languageWhitelist = Config.get(WHITELIST_SETTINGS_KEY, '');
+            languageWhitelist = Config.getStr(WHITELIST_SETTINGS_KEY) || Config.getArray(WHITELIST_SETTINGS_KEY);
 
             // stay defensive due to older settings of former releases that might have been stored as string type arrays.
             if (typeof languageWhitelist === 'string') {
                 languageWhitelist = languageWhitelist.split(',');
             }
-            if (Array.isArray(languageWhitelist)) {
-                languageWhitelist = languageWhitelist.filter(isValidLanguageKey).sort(ascendingAlphabeticalOrder);
-            } else {
-                languageWhitelist = [];
-            }
+            languageWhitelist = languageWhitelist.filter(isValidLanguageKey).sort(ascendingAlphabeticalOrder);
         }
         return languageWhitelist;
     };
@@ -123,17 +119,13 @@ define('io.ox/office/settings/spellchecklanguagenotification', [
             // - create sanitized and sorted language list from persistent string-value setting
             // - see BUG 54502 [https://bugs.open-xchange.com/show_bug.cgi?id=54502] / 'Set language notification' not stored
 
-            languageBlacklist = Config.get(BLACKLIST_SETTINGS_KEY, '');
+            languageBlacklist = Config.getStr(BLACKLIST_SETTINGS_KEY) || Config.getArray(BLACKLIST_SETTINGS_KEY);
 
             // stay defensive due to older settings of former releases that might have been stored as string type arrays.
             if (typeof languageBlacklist === 'string') {
                 languageBlacklist = languageBlacklist.split(',');
             }
-            if (Array.isArray(languageBlacklist)) {
-                languageBlacklist = languageBlacklist.filter(isValidLanguageKey).sort(ascendingAlphabeticalOrder);
-            } else {
-                languageBlacklist = [];
-            }
+            languageBlacklist = languageBlacklist.filter(isValidLanguageKey).sort(ascendingAlphabeticalOrder);
         }
         return languageBlacklist;
     };
