@@ -13,13 +13,13 @@
  */
 
 define('io.ox/office/settings/templatefolders', [
-    'io.ox/office/tk/dialogs',
     'io.ox/core/notifications',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/tk/dialog/folderpickerdialog',
     'io.ox/office/settings/view/settingslabels',
     'io.ox/mail/detail/links' /* this line is important for deep links usage (works with jq delegation) */
-], function (Dialogs, Notifications, Utils, DriveUtils, Labels) {
+], function (Notifications, Utils, DriveUtils, FolderPickerDialog, Labels) {
 
     'use strict';
 
@@ -42,6 +42,13 @@ define('io.ox/office/settings/templatefolders', [
 
         var myFiles = DriveUtils.getStandardTemplateFolderId();
 
+        var newSection = true;
+
+        // public methods -----------------------------------------------------
+        this.newSection = function () {
+            return newSection;
+        };
+
         this.refresh = function (settings) {
             settings.appendTitle(Utils.getStringOption(options, 'title', ''));
 
@@ -187,15 +194,15 @@ define('io.ox/office/settings/templatefolders', [
                 }
                 busy = true;
 
-                var dialog = new Dialogs.ModalFolderPicker('io-ox-office-settings', {
+                var dialog = new FolderPickerDialog('io-ox-office-settings', {
                     button: Labels.OK_LABEL,
                     height: 350,
-                    title: Utils.getStringOption(options, 'folderPicker', Labels.SELECT_TEMPLATE_FOLDER)
+                    title: Utils.getStringOption(options, 'folderPicker', Labels.SELECT_TEMPLATE_FOLDER),
+                    classes: 'template-picker'
                 });
                 dialog.show().always(function () {
                     busy = false;
-                }).done(function () {
-                    var folder_id = dialog.getSelectedFolderId();
+                }).done(function (folder_id) {
                     if (folder_id && folder_id !== myFiles) {
                         path(folder_id, function (path) {
                             var id = _.last(path).id;
@@ -220,8 +227,6 @@ define('io.ox/office/settings/templatefolders', [
                 settings.appendButton(Utils.getStringOption(options, 'newFolder', Labels.ADD_NEW_TEMPLATE_FOLDER), clickAdd).attr('data-action', 'newtempfolder');
             }
 
-            settings.append($('<div style="display: block; height: 20px">'));
-
         };
     }
 
