@@ -40,7 +40,7 @@ define('io.ox/office/settings/templatemodel', [
          * returns all template folder-ids in one array
          */
         this.getAll = function () {
-            return Config.get(key, []);
+            return Config.getArray(key);
         };
 
         /**
