@@ -38,8 +38,7 @@ define('io.ox/office/settings/units', [
     // private global functions ===============================================
 
     function getStandardUnit() {
-        var unit = Config.get('units/standard');
-        return unit ? unit : LocaleData.UNIT;
+        return Config.getStr('units/standard') || LocaleData.UNIT;
     }
 
     function setStandardUnit(unit) {
