@@ -58,7 +58,7 @@ define('io.ox/office/settings/userdictionary', [
     UserDictionary.getDictionary = function () {
 
         if (!dictionary) {
-            dictionary = Config.get(SETTINGS_KEY, []);
+            dictionary = Config.getArray(SETTINGS_KEY);
         }
 
         return dictionary;
@@ -335,7 +335,8 @@ define('io.ox/office/settings/userdictionary', [
                 role: 'textbox',
                 'aria-label': placeholdertext,
                 placeholder: placeholdertext,
-                type: 'text'
+                type: 'text',
+                spellcheck: false
             }).addClass('form-control');
 
             wordInput.on('input', toggleAddButton);
