@@ -358,7 +358,7 @@ define('io.ox/office/spreadsheet/controller/controller', [
 
             'cell/autofill': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function (fillData) { return docView.autoFill(fillData.border, fillData.count, { invertType: fillData.invertType }); }
+                set: function (fillData) { return docView.autoFill(fillData.direction, fillData.count, fillData.options); }
             },
 
             'cell/autoformula': {
