@@ -14,20 +14,23 @@
 
 define('io.ox/office/spreadsheet/controller/drawingmixin', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/drawinglayer/utils/drawingutils',
-    'io.ox/office/drawinglayer/view/imageutil',
+    'io.ox/office/drawinglayer/utils/imageutils',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/drawing/text/textframeutils',
     'io.ox/office/spreadsheet/view/labels',
-    'io.ox/office/spreadsheet/view/dialogs',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Color, DrawingUtils, ImageUtils, DrawingFrame, Operations, SheetUtils, TextFrameUtils, Labels, Dialogs, gt) {
+], function (Utils, Rectangle, Color, DrawingUtils, ImageUtils, DrawingFrame, Operations, SheetUtils, TextFrameUtils, Labels, gt) {
 
     'use strict';
 
+    // convenience shortcuts
+    var AnchorMode = SheetUtils.AnchorMode;
+
     // maximum size of an image in any direction, in 1/100 mm
     var MAX_IMAGE_SIZE = 21000;
 
@@ -192,7 +195,7 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
 
                         // the original (unrotated) location of the drawing model (nothing to do for squares)
                         var rectangle = drawingModel.getRectangle();
-                        if (!rectangle.square()) {
+                        if (rectangle && !rectangle.square()) {
 
                             // the old and new state of width/height swapping according to the transformation attributes
                             var oldSwappedDims = DrawingUtils.hasSwappedDimensions(oldAttrs);
@@ -201,10 +204,20 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
                             // if the width/height swapping changes due to new rotation angle, add the new anchor attributes
                             if (oldSwappedDims !== newSwappedDims) {
                                 if (newSwappedDims) { rectangle.rotateSelf(); }
-                                attributePool.extendAttributeSet(newAttrSet, drawingCollection.getAttributeSetForRectangle(rectangle));
+                                var anchorAttrs = drawingCollection.generateAnchorAttributes(drawingModel, { rectangle: rectangle });
+                                if (anchorAttrs) { attributePool.extendAttributeSet(newAttrSet, { drawing: anchorAttrs }); }
                             }
                         }
                     }
+
+                    // ODF: vertical flipping needs to be simulated as horizontal flip and 180deg rotation
+                    if (odf && ('flipV' in newAttrs)) {
+                        if (newAttrs.flipV !== drawingModel.isFlippedV()) {
+                            newAttrs.flipH = ('flipH' in newAttrs) ? !newAttrs.flipH : !drawingModel.isFlippedH();
+                            newAttrs.rotation = Utils.mod((('rotation' in newAttrs) ? newAttrs.rotation : drawingModel.getRotationDeg()) + 180, 360);
+                        }
+                        delete newAttrs.flipV;
+                    }
                 }
 
                 return { position: drawingModel.getPosition(), attrs: newAttrSet };
@@ -380,8 +393,8 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
                 return self.execInsertDrawings(drawingDescs);
             });
 
-            // on any error, return a promise rejected with a specific error code
-            return promise.then(null, function () {
+            // on any error, return a specific error code
+            return promise.catch(function () {
                 return SheetUtils.makeRejected('image:insert');
             });
         };
@@ -427,8 +440,8 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
             }
 
             // add the anchor position attributes
-            attributePool.extendAttributeSet(attrSet, drawingCollection.getAttributeSetForRectangle(rectangle));
-            attrSet.drawing.anchorType = 'twoCell';
+            var anchorAttrs = drawingCollection.getAnchorAttributesForRect(AnchorMode.TWO_CELL, rectangle);
+            attributePool.extendAttributeSet(attrSet, { drawing: anchorAttrs });
 
             // insert the image objects into the active sheet
             var drawingType = Labels.getPresetShape(presetId).type;
@@ -463,20 +476,15 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
             // ask user when unsupported drawing objects are going to be deleted
             promise = promise.then(function () {
 
-                // bug 47948: check whether any unsupported (not undoable) drawing object is selected
-                var unsupported = positions.some(function (position) {
-                    return !drawingCollection.getModel(position).isDeepSupported();
+                // bug 47948: check that no unrestorable drawing objects are selected
+                var undoSupported = positions.every(function (position) {
+                    return drawingCollection.getModel(position).isDeepRestorable();
                 });
-                if (!unsupported) { return false; }
+                // return false to generate the undo operations in the next promise step
+                if (undoSupported) { return false; }
 
-                // ask user whether to delete drawing objects that cannot be restored
-                var dialog = new Dialogs.ModalQueryDialog(docView, Labels.DELETE_CONTENTS_QUERY, { title: Labels.DELETE_CONTENTS_TITLE });
-
-                // close dialog automatically after losing edit rights
-                docView.closeDialogOnReadOnlyMode(dialog);
-
-                // show dialog, promise resolves with value true, or rejects
-                return dialog.show();
+                // show query dialog, promise resolves with value true (clear undo stack), or rejects (cancel)
+                return docView.showQueryDialog(Labels.DELETE_CONTENTS_TITLE, Labels.DELETE_CONTENTS_QUERY);
             });
 
             // generate and apply the drawing operations (back to cell selection before deleting the drawing objects)
@@ -561,7 +569,7 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
             // parent item that is enabled if it is possible to insert drawing objects
             'drawing/insert/enable': {
                 parent: 'document/editable/worksheet',
-                enable: function () { return !docView.isSheetLocked(); }
+                enable: function () { return !sheetModel.isLocked(); }
             },
 
             // dialog to insert an image from file system, from Drive, or by URL
@@ -571,7 +579,7 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
                     // leave text edit mode before showing the dialog
                     var promise = docView.leaveTextEditMode();
                     // show the 'Insert Image' dialog
-                    promise = promise.then(function () { return ImageUtils.showInsertImageDialogByType(app, dialogType); });
+                    promise = promise.then(function () { return docView.showInsertImageDialog(dialogType); });
                     // handle the dialog result
                     promise = promise.then(function (imageDesc) { return self.execInsertImages([imageDesc]); });
                     // show warning messages if needed
@@ -589,7 +597,9 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
                     // insert a shape directly on touch devices, or when using the keyboard in the GUI control
                     if (Utils.TOUCHDEVICE || (Utils.getStringOption(options, 'sourceType') !== 'click')) {
                         // insert a shape object into the active cell, show warning messages if needed
-                        var rectangle = docView.getCellRectangle(docView.getActiveCell());
+                        var cellRectangle   = docView.getCellRectangle(docView.getActiveCell()),
+                            rectangle       = new Rectangle(cellRectangle.left, cellRectangle.top, 0, 0);
+
                         return docView.yellOnFailure(self.execInsertShape(presetId, rectangle));
                     }
 
@@ -631,7 +641,10 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
             // The getter returns an array with all selected drawing models.
             'drawing/models': {
                 parent: 'document/editable/drawing',
-                get: function (positions) { return positions.map(drawingCollection.getModel, drawingCollection).filter(_.identity); }
+                get: function (positions) {
+                    // bug 57991: sheet model is not available after document import error
+                    return drawingCollection ? positions.map(drawingCollection.getModel, drawingCollection).filter(Boolean) : [];
+                }
             },
 
             // returns the type identifiers of the selected drawing objects as flag set
@@ -659,7 +672,7 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
             // sheet is unlocked. The getter returns an array with all selected drawing models.
             'drawing/operation': {
                 parent: 'drawing/models',
-                enable: function () { return !docView.isSheetLocked(); }
+                enable: function () { return !sheetModel.isLocked(); }
             },
 
             'drawing/delete': {
@@ -694,9 +707,8 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
 
             // flipping and rotation ------------------------------------------
 
-            // Parent item for drawing objects that can be flipped and rotated. The getter
-            // returns an array with all drawing models contained in the selection that can
-            // be flipped.
+            // Parent item for drawing objects that can be flipped and rotated. The getter returns
+            // an array with all drawing models contained in the selection that can be flipped.
             'drawing/operation/transform': {
                 parent: 'drawing/operation',
                 enable: function () { return this.getValue().length > 0; },
@@ -850,6 +862,7 @@ define('io.ox/office/spreadsheet/controller/drawingmixin', [
                 get: function (drawingModels) { return DrawingUtils.getMixedAttributeValue(drawingModels, 'shape', 'anchor'); },
                 set: function (anchorMode) { return implChangeDrawings(this.getParentValue(), { shape: { anchor: anchorMode } }); }
             }
+
         });
 
         // initialization -----------------------------------------------------
