@@ -13,12 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/controller/namemixin', [
-    'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/tokenarray',
     'io.ox/office/spreadsheet/view/dialogs'
-], function (Utils, SheetUtils, FormulaUtils, TokenArray, Dialogs) {
+], function (SheetUtils, FormulaUtils, TokenArray, Dialogs) {
 
     'use strict';
 
