@@ -15,14 +15,14 @@
 
 define('io.ox/office/spreadsheet/controller/searchmixin', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/spreadsheet/utils/sheetutils',
-    'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, IteratorUtils, SheetUtils, gt) {
+    'io.ox/office/tk/utils/iterator',
+    'io.ox/office/spreadsheet/utils/sheetutils'
+], function (Utils, Iterator, SheetUtils) {
 
     'use strict';
 
     // convenience shortcuts
+    var FilterIterator = Iterator.FilterIterator;
     var RangeArray = SheetUtils.RangeArray;
 
     // mix-in class SearchMixin ===============================================
@@ -108,12 +108,21 @@ define('io.ox/office/spreadsheet/controller/searchmixin', [
          */
         function searchNext(direction, query) {
 
+            // Shape selected, do nothing
+            if (docView.isTextEditMode()) { return null; }
+
             var selection = docView.getSelection();
             var singleCell = docView.isSingleCellSelection();
             var ranges = singleCell ? new RangeArray(cellCollection.getUsedRange()) : selection.ranges;
 
+            // no content available
+            if (ranges.length === 0) {
+                docView.yellMessage('search:nothing', true);
+                return null;
+            }
+
             var iterator = cellCollection.createAddressIterator(ranges, { startAddress: selection.address, startIndex: selection.active, skipStart: true, wrap: true, reverse: (direction === 'prev'), type: 'value', visible: false });
-            iterator = IteratorUtils.createFilterIterator(iterator, function (address) {
+            iterator = new FilterIterator(iterator, function (address) {
                 var isMerged = mergeCollection.isMergedCell(address);
                 var isVisible = isMerged ? !mergeCollection.isHiddenCell(address) : cellCollection.isVisibleCell(address);
                 return isVisible && searchPredicate(address, query);
@@ -121,7 +130,7 @@ define('io.ox/office/spreadsheet/controller/searchmixin', [
 
             var iterResult = iterator.next();
             if (iterResult.done) {
-                docView.yell({ type: 'info', message: gt('Nothing found.') });
+                docView.yellMessage('search:nothing', true);
             } else {
                 selectIteratorCell(iterResult, singleCell);
             }
@@ -144,7 +153,7 @@ define('io.ox/office/spreadsheet/controller/searchmixin', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.all=false]
+         *  - {Boolean} [options.all=false]
          *      If set to true, all occurrences of the search text in the
          *      active sheet will be replaced.
          *
@@ -180,7 +189,7 @@ define('io.ox/office/spreadsheet/controller/searchmixin', [
                 // the cell iterator: visit all value cells and formula cells
                 var iterator = cellCollection.createAddressIterator(ranges, { startAddress: selection.address, wrap: true, type: 'value', visible: true });
                 // filter for cell that match the search query
-                iterator = IteratorUtils.createFilterIterator(iterator, function (address) { return searchPredicate(address, query); });
+                iterator = new FilterIterator(iterator, function (address) { return searchPredicate(address, query); });
 
                 // replace all occurrences of the search text at once
                 if (replaceAll) {
@@ -194,16 +203,14 @@ define('io.ox/office/spreadsheet/controller/searchmixin', [
                     }, 'SearchMixin.searchReplace');
 
                     // generate the cell operations
-                    promise2 = promise2.then(function () {
+                    return promise2.then(function () {
                         return docView.setCellContentsArray(contentsArray);
                     });
-
-                    return promise2;
                 }
 
                 // exit silently, if no more search results are available
                 var iterResult = iterator.next();
-                if (iterResult.done) { return $.when(); }
+                if (iterResult.done) { return; }
 
                 // generate the cell operations for the next matching cell only
                 var address = iterResult.value;
