@@ -69,14 +69,25 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
          *  - 'nearest' (default value): If the specified sheet is hidden,
          *      first searches with the method 'next', and if this fails, with
          *      the method 'prev'.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the new sheet has been
+         *  activated.
          */
         function activateSheet(sheet, method) {
 
-            // Set the new active sheet at the document model. The event handlers
-            // of the 'change:doc:viewattributes' event with do all further
-            // processing and initialization for the new active sheet.
-            var newSheet = docModel.findVisibleSheet(sheet, method);
-            if (newSheet >= 0) { docModel.setActiveSheet(newSheet); }
+            // leave text edit mode before changing the sheet
+            var promise = docView.leaveTextEditMode().then(function () {
+
+                // Set the new active sheet at the document model. The event handlers
+                // of the 'change:doc:viewattributes' event with do all further
+                // processing and initialization for the new active sheet.
+                var newSheet = docModel.findVisibleSheet(sheet, method);
+                if (newSheet >= 0) { docModel.setActiveSheet(newSheet); }
+            });
+
+            // show warning alert if necessary
+            return docView.yellOnFailure(promise);
         }
 
         /**
@@ -465,7 +476,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
                 parent: 'app/valid',
                 enable: function () { return this.getValue() >= 0; },
                 get: function () { return docModel.findVisibleSheet(activeSheet - 1, 'prev'); },
-                set: function () { activateSheet(activeSheet - 1, 'prev'); },
+                set: function () { return activateSheet(activeSheet - 1, 'prev'); },
                 shortcut: { keyCode: 'PAGE_UP', ctrlOrMeta: true, alt: true }
             },
 
@@ -473,7 +484,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
                 parent: 'app/valid',
                 enable: function () { return this.getValue() >= 0; },
                 get: function () { return docModel.findVisibleSheet(activeSheet + 1, 'next'); },
-                set: function () { activateSheet(activeSheet + 1, 'next'); },
+                set: function () { return activateSheet(activeSheet + 1, 'next'); },
                 shortcut: { keyCode: 'PAGE_DOWN', ctrlOrMeta: true, alt: true }
             },
 
