@@ -224,8 +224,6 @@ define('io.ox/office/spreadsheet/controller/tablemixin', [
                         var sortAttrs = Utils.getObjectOption(data.attributes, 'sort', null);
                         // whether some sort attributes have been changed
                         var sortAttrsChanged = false;
-                        // only want to remove sort options of a sinlge column
-                        var unsortSingleColumn = false;
 
                         // check whether sort attributes will change
                         if (sortAttrs) {
@@ -234,47 +232,19 @@ define('io.ox/office/spreadsheet/controller/tablemixin', [
                             sortAttrsChanged = _.some(sortAttrs, function (value, name) {
                                 return oldSortAttrs[name] !== value;
                             });
-                            unsortSingleColumn = sortAttrs.type === 'none';
                         }
 
                         // bug 56313: check for merged ranges before generating the operations
-                        if (sortAttrsChanged && dataRange && mergeCollection.rangesOverlapAnyMergedRange(dataRange)) {
+                        if (sortAttrsChanged && dataRange && mergeCollection.coversAnyMergedRange(dataRange)) {
                             return SheetUtils.makeRejected('sort:merge:overlap');
                         }
 
                         // create and apply the operations for the specified table
                         return sheetModel.createAndApplyOperations(function (generator) {
-
-                            var promise2 = self.createResolvedPromise();
-
-                            // If some sort attributes has changed and we don't want to remove sort settings of a single column
-                            if (sortAttrsChanged && !unsortSingleColumn) {
-
-                                // sort the cells TODO: really needed?? should work automatically with table refresh triggered below
-                                promise2 = promise2.then(function () {
-                                    var startAddress = tableModel.getRange().start;
-                                    return cellCollection.generateSortOperations(generator, dataRange, startAddress, {
-                                        headers: false, // we do NOT give the header row, so we do NOT need to omit it
-                                        orderRules: [{
-                                            index: data.tableCol + startAddress[0],
-                                            orderBy: sortAttrs.descending ? 'descending' : 'ascending'
-                                        }]
-                                    });
-                                });
-
-                                // reset all sort settings (except the current column)
-                                promise2 = promise2.then(function () {
-                                    return tableModel.generateResetAllSortSettings(generator, { skipCol: data.tableCol });
-                                });
-                            }
-
+                            // if changing sort settings of a column, reset the sort settings of all other columns
+                            var resetSort = sortAttrsChanged && (sortAttrs.type !== 'none');
                             // add new settings to current column
-                            promise2 = promise2.then(function () {
-                                return tableModel.generateChangeColumnOperations(generator, data.tableCol, data.attributes);
-                            });
-
-                            return promise2;
-
+                            return tableModel.generateChangeColumnOperations(generator, data.tableCol, data.attributes, { resetSort: resetSort });
                         }, { storeSelection: true });
                     });
 
