@@ -13,11 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/controller/viewmixin', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/config',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils'
-], function (IteratorUtils, Config, SheetUtils, PaneUtils) {
+], function (Iterator, Config, SheetUtils, PaneUtils) {
 
     'use strict';
 
@@ -218,20 +218,21 @@ define('io.ox/office/spreadsheet/controller/viewmixin', [
             // the document locally, or if 'important' sheet view settings have been changed.
             // This is needed to prevent creating new versions of the document after selecting
             // cells or scrolling around, but without editing anything.
-            if (!docView.isEditable()) { return $.when(); }
+            if (!docView.isEditable()) { return this.createResolvedPromise(); }
 
             // whether the document is modified, and view settings can be sent
             var modified = app.isLocallyModified();
 
             // detect if any sheet contains 'important' changed view attributes
             if (!modified) {
-                modified = IteratorUtils.some(docModel.createSheetIterator(), function (sheetModel2) {
+                modified = Iterator.some(docModel.createSheetIterator(), function (sheetModel2) {
                     return sheetModel2.hasChangedViewAttributes();
                 });
             }
 
             // nothing to do (e.g. only selection has been changed, which will not be saved then)
-            if (!modified) { return $.when(); }
+            // -> not generating operation in long running processes (recursive call), 53641
+            if (!modified || docModel.isProcessingActions()) { return this.createResolvedPromise(); }
 
             // generate and apply the operations for the document, and all affected sheets
             return docModel.createAndApplySheetOperations(function (generator) {
@@ -427,6 +428,13 @@ define('io.ox/office/spreadsheet/controller/viewmixin', [
                 parent: 'document/editable/drawing'
             },
 
+            // enabled if the 'Comments' toolbar tab shall be visible in the top pane
+            'view/toolbartab/comments/visible': {
+                // bug 57332: for now, as long as we cannot insert comments, the toolpane
+                // will be hidden, if the sheet does not contain comments
+                parent: ['document/editable/cell', 'comment/available/enabled']
+            },
+
             // tool bars ------------------------------------------------------
 
             // visibility item for the 'Connector' toolbar for drawing objects
@@ -450,10 +458,10 @@ define('io.ox/office/spreadsheet/controller/viewmixin', [
 
             // debugging ------------------------------------------------------
 
-            'debug/highlight/formulas': {
+            'debug/highlight/cells': {
                 parent: 'debug/enabled',
-                get: function () { return docView.getViewAttribute('highlightFormulas'); },
-                set: function (enable) { docView.setViewAttribute('highlightFormulas', enable); }
+                get: function () { return docView.getViewAttribute('highlightCells'); },
+                set: function (enable) { docView.setViewAttribute('highlightCells', enable); }
             }
         });
 
