@@ -39,23 +39,15 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
      *
      * @extends SortedArray
      *
-     * @param {CellModelMatrix} matrix
-     *  Reference to the parent cell matrix containing this cell vector. Will
-     *  be used for exmaple to execute asynchronous loops (instances of this
-     *  class are considered to be mass objects, and therefore will be slim
-     *  objects without mix-in classes, life-time control, etc.).
-     *
      * @param {Boolean} columns
      *  Whether this cell vector is a column vector (true; cells will be sorted
      *  by their row index), or a row vector (false; cells will be sorted by
      *  their column index).
      */
-    var CellModelVector = SortedArray.extend(function (matrix, collection, columns) {
+    var CellModelVector = SortedArray.extend(function (collection, columns) {
 
         // private properties -------------------------------------------------
 
-        // reference to the parent cell matrix
-        this._matrix = matrix;
         // the column/row collection in oppsite direction needed to skip hidden columns/rows
         this._collection = collection;
         // cached subtotal results for all cells in this vector
@@ -160,13 +152,6 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
         return this;
     };
 
-    /**
-     * Releases all properties of this instance.
-     */
-    CellModelVector.prototype.destroy = function () {
-        this._matrix = this._subtotals = null;
-    };
-
     // class CellModelMatrix ==================================================
 
     /**
@@ -192,9 +177,6 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
      */
     var CellModelMatrix = BaseObject.extend({ constructor: function (sheetModel, columns) {
 
-        // self reference
-        var self = this;
-
         // sorter callback function for indexes of cell vectors
         var sorter = columns ? CellModel.col : CellModel.row;
 
@@ -220,7 +202,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  A new instance of a cell model vector.
          */
         function createVector() {
-            return new CellModelVector(self, collection2, columns);
+            return new CellModelVector(collection2, columns);
         }
 
         /**
@@ -400,8 +382,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
         });
 
         this.registerDestructor(function () {
-            matrix.destroyElements();
-            self = sorter = matrix = null;
+            sorter = matrix = null;
         });
 
     } }); // class CellModelMatrix
