@@ -17,10 +17,11 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
     'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/drawinglayer/model/drawingcollection',
+    'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/drawing/drawingcollectionmixin',
     'io.ox/office/spreadsheet/model/drawing/commentmodel'
-], function (Iterator, SortedArray, DrawingCollection, SheetUtils, SheetDrawingCollectionMixin, SheetCommentModel) {
+], function (Iterator, SortedArray, DrawingCollection, Operations, SheetUtils, SheetDrawingCollectionMixin, SheetCommentModel) {
 
     'use strict';
 
@@ -311,8 +312,8 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
         this.applyInsertCommentOperation = function (context) {
 
             // multiple comments must not be located in the same cell
-            var anchor = context.getAddress('start');
-            context.ensure(!this.getByAddress(anchor), 'duplicate anchor address');
+            var anchor = context.getJSONAddress();
+            context.ensure(!this.getByAddress(anchor), 'duplicate anchor address %s', anchor);
 
             // the formatting attributes of the comment drawing frame
             var attrSet = context.getOptObj('attrs');
@@ -327,7 +328,7 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
 
             // create the comment model (via collection base class)
             var commentModel = this.insertModel(addressToPosition(anchor), 'comment', attrSet, settings);
-            context.ensure(commentModel, 'cannot insert comment');
+            context.ensure(commentModel, 'cannot insert comment into cell %s', anchor);
         };
 
         /**
@@ -338,8 +339,9 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
          *  A wrapper representing the 'deleteComment' document operation.
          */
         this.applyDeleteCommentOperation = function (context) {
-            var result = this.deleteModel(addressToPosition(context.getAddress()));
-            context.ensure(result, 'cannot delete comment');
+            var anchor = context.getJSONAddress();
+            var result = this.deleteModel(addressToPosition(anchor));
+            context.ensure(result, 'cannot delete comment from cell %s', anchor);
         };
 
         /**
@@ -353,9 +355,9 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
         this.applyChangeCommentOperation = function (context) {
 
             // operation must refer to an existing cell comment
-            var anchor = context.getAddress('start');
+            var anchor = context.getJSONAddress();
             var commentModel = self.getByAddress(anchor);
-            context.ensure(commentModel, 'invalid anchor address');
+            context.ensure(commentModel, 'no comment found in cell %s', anchor);
 
             // set the new formatting attributes
             if (context.has('attrs')) {
@@ -368,6 +370,56 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
             }
         };
 
+        /**
+         * Callback handler for the document operation "moveComments". Moves
+         * the anchors of multiple comments to new cell addresses, and triggers
+         * 'change:drawing' events.
+         *
+         * @param {SheetOperationContext} context
+         *  A wrapper representing the 'changeComment' document operation.
+         */
+        this.applyMoveCommentsOperation = function (context) {
+
+            // get the source and target anchor addresses
+            var fromAnchors = context.getAddressList('from');
+            var toAnchors = context.getAddressList('to');
+            context.ensure(fromAnchors.length === toAnchors.length, 'anchor from/to count mismatch');
+
+            // collect all comment models before inserting them to prevent address collisions
+            var movedModels = [];
+
+            // move all comments to their destination anchors
+            fromAnchors.forEach(function (fromAnchor, index) {
+
+                // look up the comment model at the old cell anchor
+                var commentModel = this.getByAddress(fromAnchor);
+                context.ensure(commentModel, 'no comment found in cell %s', fromAnchor);
+
+                // get the target anchor position (nothing to do if comment does not move)
+                var toAnchor = toAnchors[index];
+                if (fromAnchor.equals(toAnchor)) { return; }
+
+                // remove comment model from internal collections, collect all models
+                unregisterCommentModel(commentModel);
+                movedModels.push({ model: commentModel, target: toAnchor });
+            }, this);
+
+            // insert all comment models at their new anchor positions
+            movedModels.forEach(function (entry) {
+
+                var commentModel = entry.model;
+                var oldAnchor = commentModel.getAnchor();
+                var newAnchor = entry.target;
+
+                // update the anchor address, and the comment model containers
+                commentModel.setAnchor(newAnchor);
+                registerCommentModel(commentModel);
+
+                // moved anchor address will be notified with a 'move:drawing' event
+                this.trigger('move:drawing', commentModel, oldAnchor);
+            }, this);
+        };
+
         // public methods -----------------------------------------------------
 
         /**
@@ -432,7 +484,7 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
             // create an iterator that filters for the "visibleCells" option
             if (options && options.visibleCells) {
                 iterator = new FilterIterator(iterator, function (commentModel) {
-                    return commentModel.getVisibleAnchorRange() !== null;
+                    return commentModel.getAnchorRectangle({ expandMerged: true }).area() > 0;
                 });
             }
 
@@ -571,6 +623,51 @@ define('io.ox/office/spreadsheet/model/drawing/commentcollection', [
             return promise;
         };
 
+        /**
+         * Generates the operations, and the undo operations, to move multiple
+         * cell comments to new anchor cells. The positions of the drawing
+         * frames will be updated relative to the new anchor cells.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {AddressArray} fromAddresses
+         *  An array of cell addresses specifying the current anchor position
+         *  of the cell comments.
+         *
+         * @param {AddressArray} toAddresses
+         *  An array of cell addresses specifying the new anchor position of
+         *  the cell comments. This array MUST contain exactly the same number
+         *  of cell addresses as parameter "fromAddresses".
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when all operations have been
+         *  generated.
+         */
+        this.generateMoveAnchorOperations = SheetUtils.profileAsyncMethod('CommentCollection.generateMoveAnchorOperations()', function (generator, fromAddresses, toAddresses) {
+
+            // the address properties for the "moveComments" operation
+            var fromStr = fromAddresses.toString(' ');
+            var toStr = toAddresses.toString(' ');
+
+            // generate the "moveComments" undo operation before updating the drawing frames
+            generator.generateSheetOperation(Operations.MOVE_COMMENTS, { from: toStr, to: fromStr }, { undo: true });
+
+            // update the position of all comment drawing frames
+            var promise = this.iterateArraySliced(fromAddresses, function (fromAddress, index) {
+                var commentModel = self.getByAddress(fromAddress);
+                if (!commentModel) { return SheetUtils.makeRejected('operation'); }
+                commentModel.generateMoveAnchorOperations(generator, toAddresses[index]);
+            }, 'CommentCollection.generateMoveAnchorOperations');
+
+            // generate the "moveComments" operation after updating the drawing frames
+            promise = promise.then(function () {
+                generator.generateSheetOperation(Operations.MOVE_COMMENTS, { from: fromStr, to: toStr });
+            });
+
+            return promise;
+        });
+
         // event listeners ----------------------------------------------------
 
         // update position of cell anchors when moving cells in the sheet
