@@ -23,34 +23,9 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
     'use strict';
 
     // convenience shortcuts
+    var UpdateMode = SheetUtils.UpdateMode;
     var Range = SheetUtils.Range;
 
-    // horizontal drawing anchor attribute names
-    var COL_ATTRIBUTE_NAMES = {
-        offset: 'left',
-        size: 'width',
-        startIndex: 'startCol',
-        startOffset: 'startColOffset',
-        endIndex: 'endCol',
-        endOffset: 'endColOffset'
-    };
-
-    // vertical drawing anchor attribute names
-    var ROW_ATTRIBUTE_NAMES = {
-        offset: 'top',
-        size: 'height',
-        startIndex: 'startRow',
-        startOffset: 'startRowOffset',
-        endIndex: 'endRow',
-        endOffset: 'endRowOffset'
-    };
-
-    // rotation/flip drawing attribute names
-    var ROTATE_ATTRIBUTE_NAMES = ['rotation', 'flipH', 'flipV'];
-
-    // the names of all cell anchor attributes in the 'drawing' attribute family
-    var CELL_ANCHOR_ATTR_NAMES = ['anchorType'].concat(_.values(COL_ATTRIBUTE_NAMES)).concat(_.values(ROW_ATTRIBUTE_NAMES)).concat(ROTATE_ATTRIBUTE_NAMES);
-
     // class DrawingModelMixin ================================================
 
     /**
@@ -74,13 +49,13 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Function} [initOptions.generateRestoreOperations]
+     *  - {Function} [initOptions.generateRestoreOperations]
      *      A callback function that will be invoked from the own public method
      *      DrawingModelMixin.generaterestoreOperations() while generating
      *      document operations that will delete this drawing object. An
      *      implementation must generate more undo operations to restore the
      *      complete drawing object.
-     *  @param {Function} [initOptions.generateUpdateFormulaOperations]
+     *  - {Function} [initOptions.generateUpdateFormulaOperations]
      *      A callback function that will be invoked from the own public method
      *      DrawingModelMixin.generateUpdateFormulaOperations() while
      *      generating document operations that involve to update the formula
@@ -91,17 +66,14 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
      */
     function DrawingModelMixin(sheetModel, cloneConstructor, initOptions) {
 
-        // self reference
-        var self = this;
-
         // the document model instance
         var docModel = sheetModel.getDocModel();
 
         // the attribute pool for drawing formatting
         var attributePool = docModel.getDrawingAttributePool();
 
-        // the drawing collection containing this drawing model
-        var drawingCollection = sheetModel.getDrawingCollection();
+        // the drawing collection (or comment collection) containing this drawing model
+        var rootCollection = this.getRootCollection();
 
         // callback handler to generate additional restore operations
         var generateRestoreOperationsHandler = Utils.getFunctionOption(initOptions, 'generateRestoreOperations', null);
@@ -112,139 +84,6 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
         // whether this drawing object is embedded in another drawing object (e.g. group object)
         var embedded = this.isEmbedded();
 
-        // private methods ----------------------------------------------------
-
-        /**
-         * Returns the anchor attributes of this drawing object.
-         *
-         * @returns {Object}
-         *  A copy of the anchor attributes of this drawing object.
-         */
-        function getCellAnchorAttributes() {
-            var drawingAttrs = self.getMergedAttributeSet(true).drawing;
-            return CELL_ANCHOR_ATTR_NAMES.reduce(function (attrs, name) {
-                attrs[name] = drawingAttrs[name];
-                return attrs;
-            }, {});
-        }
-
-        /**
-         * Generates the cell anchor attributes needed to update the location
-         * of this top-level drawing object, after cells have been moved in the
-         * document.
-         *
-         * @param {MoveDescriptor} moveDescs
-         *  An array of move descriptors that specify how to transform the
-         *  location of this drawing object.
-         *
-         * @returns {Object|Null}
-         *  The value null to indicate that this drawing object will be deleted
-         *  from the sheet by the passed move descriptors; otherwise the anchor
-         *  attributes that need to be applied at this drawing object to update
-         *  its location. An empty object indicates that the drawing object
-         *  will not be modified at all.
-         */
-        function generateMoveCellsAttributes(moveDescs) {
-
-            // copy of the current cell anchor attributes, will be recalculated below
-            var anchorAttrs = getCellAnchorAttributes();
-            // the cell range covered by the drawing object
-            var drawingRange = self.getRange();
-
-            // process all move descriptors, returning true indicates to delete the drawing
-            var deleteDrawing = moveDescs.some(function (moveDesc) {
-
-                // nothing to do, if the move descriptor does not cover the drawing object completely
-                if (!moveDesc.containsRange(drawingRange)) { return false; }
-
-                // whether to modify the column or row indexes of the range
-                var columns = moveDesc.columns;
-                // the attribute names according to the passed direction
-                var ATTR_NAMES = columns ? COL_ATTRIBUTE_NAMES : ROW_ATTRIBUTE_NAMES;
-                // the maximum column/row
-                var maxIndex = docModel.getMaxIndex(columns);
-
-                // calculate new column/row indexes; if the drawing object has one-cell or absolute anchor mode,
-                // these attributes will be overwritten when recalculating the inactive anchor attributes
-                if (moveDesc.insert) {
-
-                    // insertion mode: process the target intervals from first to last
-                    moveDesc.targetIntervals.every(function (interval) {
-
-                        // the number of columns/rows to be inserted
-                        var move = interval.size();
-                        // the column/row interval covered by the drawing model
-                        var startIndex = drawingRange.getStart(columns);
-                        var endIndex = drawingRange.getEnd(columns);
-                        // the maximum number of columns/rows the drawing can be moved
-                        var maxMove = Math.min(move, maxIndex - endIndex);
-
-                        // do nothing, if drawing cannot be moved anymore
-                        if (maxMove === 0) { return false; }
-
-                        // move end position, if the columns/rows are inserted inside the drawing object
-                        if (interval.first <= endIndex) {
-                            anchorAttrs[ATTR_NAMES.endIndex] += maxMove;
-                            drawingRange.end.move(maxMove, columns);
-                            // move completely, if the columns/rows are inserted before the drawing object
-                            if (interval.first <= startIndex) {
-                                anchorAttrs[ATTR_NAMES.startIndex] += maxMove;
-                                drawingRange.start.move(maxMove, columns);
-                            }
-                        }
-
-                        // continue to process the target intervals
-                        return true;
-                    });
-
-                    // do not delete drawings when inserting cells
-                    return false;
-                }
-
-                // deletion mode: process the target intervals in reversed order
-                return moveDesc.targetIntervals.someReverse(function (interval) {
-
-                    // the number of columns/rows to be inserted
-                    var move = interval.size();
-                    // the column/row interval covered by the drawing model
-                    var startIndex = drawingRange.getStart(columns);
-                    var endIndex = drawingRange.getEnd(columns);
-
-                    // Delete drawing object with two-cell anchor mode, if it is contained in the deleted column/row
-                    // interval, or if it ends at offset zero in the first column/row after the interval.
-                    if ((anchorAttrs.anchorType === 'twoCell') && (interval.first <= startIndex) && (endIndex <= interval.last)) {
-                        return true;
-                    }
-
-                    // adjust start/end position of drawings overlapping or following the deleted interval
-                    if (interval.last < endIndex) {
-                        // move end position, if the columns/rows are deleted before the end
-                        anchorAttrs[ATTR_NAMES.endIndex] -= move;
-                        drawingRange.end.move(-move, columns);
-                    } else if (interval.first <= endIndex) {
-                        // cut end of drawing object at the deleted interval
-                        if (interval.first === 0) { return true; }
-                        anchorAttrs[ATTR_NAMES.endIndex] = interval.first;
-                        anchorAttrs[ATTR_NAMES.endOffset] = 0;
-                        drawingRange.setEnd(interval.first - 1, columns);
-                    }
-                    if (interval.last < startIndex) {
-                        // move start position, if the columns/rows are deleted before the start
-                        anchorAttrs[ATTR_NAMES.startIndex] -= move;
-                        drawingRange.start.move(-move, columns);
-                    } else if (interval.first <= startIndex) {
-                        // cut start of drawing object at the deleted interval
-                        anchorAttrs[ATTR_NAMES.startIndex] = interval.first;
-                        anchorAttrs[ATTR_NAMES.startOffset] = 0;
-                        drawingRange.setStart(interval.first, columns);
-                    }
-                });
-            });
-
-            // update the inactive anchor attributes according to anchor type (this may return to the old cell anchor)
-            return deleteDrawing ? null : _.extend(anchorAttrs, drawingCollection.getInactiveCellAnchorAttributes(anchorAttrs, { displayAnchor: true }));
-        }
-
         // protected methods --------------------------------------------------
 
         /**
@@ -347,12 +186,11 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  current sheet zoom factor, either relative to its parent object
          *  (sheet area for top-level drawing objects), or always absolute in
          *  the sheet area (according to the passed options); or null, if the
-         *  drawing object is hidden by itself, or is located in a hidden group
-         *  object, or is located entirely in hidden columns or rows and thus
-         *  is invisible.
+         *  drawing object is located entirely in hidden columns or rows and
+         *  thus has no meaningful location.
          */
         this.getRectangle = function (options) {
-            return drawingCollection.getRectangleForModel(this, options);
+            return rootCollection.getRectangleForModel(this, options);
         };
 
         /**
@@ -391,7 +229,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  drawing frame could be found.
          */
         this.getModelFrame = function () {
-            return drawingCollection.getDrawingFrameForModel(this);
+            return rootCollection.getDrawingFrameForModel(this);
         };
 
         /**
@@ -405,9 +243,48 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  details.
          */
         this.refreshModelFrame = function () {
-            return drawingCollection.refreshDrawingFrameForModel(this);
+            return rootCollection.refreshDrawingFrameForModel(this);
         };
 
+        /**
+         * Extracts the anchor attributes from this drawing object.
+         *
+         * @returns {Object}
+         *  The anchor attributes of this drawing object.
+         */
+        this.getAnchorAttributes = function () {
+            return rootCollection.getAnchorAttributesForModel(this);
+        };
+
+        /**
+         * Returns an attribute set that will restore the current state of the
+         * explicit attributes, after they have been changed according to the
+         * passed attribute set. Intended to be used to create undo operations.
+         * This method overwrites the implementation of the base class
+         * AttributedModel, and always adds a complete set of anchor attributes
+         * as expected by the export filters.
+         *
+         * @param {Object} attributeSet
+         *  An (incomplete) attribute set to be merged over the current
+         *  explicit attributes of this instance.
+         *
+         * @returns {Object}
+         *  An attribute set that will restore the current explicit attributes
+         *  after they have been changed according to the passed attributes.
+         */
+        this.getUndoAttributeSet = _.wrap(this.getUndoAttributeSet, function (baseMethod, attributeSet) {
+
+            // create the undo attributes
+            var undoAttrSet = baseMethod.call(this, attributeSet);
+
+            // bug 57983: always add complete set of anchor attributes
+            if (!_.isEmpty(undoAttrSet) && attributeSet.drawing && attributeSet.drawing.anchorType) {
+                _.extend(undoAttrSet.drawing, this.getAnchorAttributes());
+            }
+
+            return undoAttrSet;
+        });
+
         // operation generators -----------------------------------------------
 
         /**
@@ -425,12 +302,16 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  A reference to this instance.
          */
         this.generateChangeOperations = function (generator, attributeSet) {
-            var position = this.getPosition();
+
+            // create the undo attributes; nothing to do if no attribute actually changes
             var undoAttrSet = this.getUndoAttributeSet(attributeSet);
-            if (!_.isEmpty(undoAttrSet)) {
-                generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: undoAttrSet }, { undo: true });
-                generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: attributeSet });
-            }
+            if (_.isEmpty(undoAttrSet)) { return this; }
+
+            // the position of the drawing object to be inserted into the operation
+            var position = this.getPosition();
+
+            generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: undoAttrSet }, { undo: true });
+            generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: attributeSet });
             return this;
         };
 
@@ -446,16 +327,16 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
         this.generateRestoreOperations = function (generator) {
 
             // bug 47948: do not restore unsupported drawing types
-            if (!this.isDeepSupported()) { return this; }
+            if (!this.isDeepRestorable()) { return this; }
 
             // the operation position of the drawing object in the root collection
             var position = this.getPosition();
 
-            // create an 'insertDrawing' operation to restore the drawing model with its attributes
-            var undoProperties = { type: this.getType() };
+            // create an "insertDrawing" operation to restore the drawing model with its attributes
+            var undoProps = { type: this.getType() };
             var attrSet = this.getExplicitAttributeSet(true);
-            if (!_.isEmpty(attrSet)) { undoProperties.attrs = attrSet; }
-            generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProperties, { undo: true });
+            if (!_.isEmpty(attrSet)) { undoProps.attrs = attrSet; }
+            generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProps, { undo: true });
 
             // additional undo operations for complex drawing contents
             if (generateRestoreOperationsHandler) {
@@ -506,19 +387,77 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateUpdateAnchorOperations = function (generator) {
+        this.generateRefreshAnchorOperations = function (generator) {
 
             // nothing to do for embedded drawing objects
             if (embedded) { return this; }
 
-            // update the inactive anchor attributes according to the anchor type of the drawing object
-            var anchorAttrs = getCellAnchorAttributes();
-            _.extend(anchorAttrs, drawingCollection.getInactiveCellAnchorAttributes(anchorAttrs, { displayAnchor: true }));
+            // recalculate the inactive anchor attributes according to the anchor type
+            var anchorAttrs = rootCollection.generateAnchorAttributes(this);
 
             // create a change operation, if some attributes will be changed in this drawing
-            var attributeSet = this.getReducedAttributeSet({ drawing: anchorAttrs });
-            if (!_.isEmpty(attributeSet)) {
-                this.generateChangeOperations(generator, attributeSet);
+            if (anchorAttrs) {
+                this.generateChangeOperations(generator, { drawing: anchorAttrs });
+            }
+
+            return this;
+        };
+
+        /**
+         * Generates the operations and undo operations to change the anchor
+         * mode of this drawing object.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {AnchorMode} anchorMode
+         *  The new display anchor mode for the drawing object.
+         *
+         * @returns {DrawingModelMixin}
+         *  A reference to this instance.
+         */
+        this.generateChangeAnchorModeOperations = function (generator, anchorMode) {
+
+            // nothing to do for embedded drawing objects
+            if (embedded) { return this; }
+
+            // recalculate the inactive anchor attributes according to the anchor type
+            var anchorAttrs = rootCollection.generateAnchorAttributes(this, anchorMode);
+
+            // create a change operation, if some attributes will be changed in this drawing
+            if (anchorAttrs) {
+                this.generateChangeOperations(generator, { drawing: anchorAttrs });
+            }
+
+            return this;
+        };
+
+        /**
+         * Generates the undo operations to restore this drawing object if it
+         * will be deleted implicitly by moving cells (e.g. deleting columns or
+         * rows) in the sheet.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {MoveDescriptor} moveDescs
+         *  An array of move descriptors that specify how the cells in the
+         *  sheet will be moved.
+         *
+         * @returns {DrawingModelMixin}
+         *  A reference to this instance.
+         */
+        this.generateBeforeMoveCellsOperations = function (generator, moveDescs) {
+
+            // nothing to do for embedded drawing objects
+            if (embedded) { return this; }
+
+            // calculate the moved anchor attributes
+            var anchorAttrs = rootCollection.generateAnchorAttributesForMove(this, moveDescs);
+
+            // delete the top-level drawing object if all its parent cells have been deleted
+            if (anchorAttrs === 'delete') {
+                this.generateDeleteOperations(generator);
             }
 
             return this;
@@ -532,25 +471,25 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Object} changeDesc
+         * @param {Object} updateDesc
          *  The properties describing the document change. The properties that
-         *  are expected in this descriptor depend on the change type in its
-         *  'type' property. See method TokenArray.resolveOperation() for more
-         *  details.
+         *  are expected in this descriptor depend on its 'type' property. See
+         *  method TokenArray.resolveOperation() for more details.
          *
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, updateDesc) {
 
             // whether a top-level drawing object is affected by a move operation in its own sheet
-            var topLevelMove = !embedded && (changeDesc.type === 'moveCells') && (changeDesc.sheet === sheetModel.getIndex());
+            var topLevelMove = !embedded && (updateDesc.type === UpdateMode.MOVE_CELLS) && (updateDesc.sheet === sheetModel.getIndex());
             // update the anchor of top-level drawing objects, if cells in the own sheet will be moved (may delete a complete object!)
-            var anchorAttrs = topLevelMove ? generateMoveCellsAttributes(changeDesc.moveDescs) : null;
+            var anchorAttrs = topLevelMove ? rootCollection.generateAnchorAttributesForMove(this, updateDesc.moveDescs) : null;
 
-            // delete the top-level drawing object if all its parent cells have been deleted
-            if (topLevelMove && !anchorAttrs) {
-                return this.generateDeleteOperations(generator);
+            // bug 58155: should not happen anymore, deleting drawings moved to generateBeforeMoveCellsOperations()
+            if (anchorAttrs === 'delete') {
+                Utils.error('DrawingModelMixin.generateUpdateFormulaOperations(): unexpected deleted drawing');
+                return this;
             }
 
             // the formatting attributes to be applied for this drawing object
@@ -558,12 +497,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
 
             // derived classes may generate new operations for child objects, and additional formatting attributes
             if (generateUpdateFormulaOperationsHandler) {
-                attributeSet = generateUpdateFormulaOperationsHandler.call(this, generator, this.getPosition(), changeDesc);
-            }
-
-            // add the new anchor attributes to the attribute set
-            if (!_.isEmpty(anchorAttrs)) {
-                attributeSet = attributePool.extendAttributeSet(attributeSet || {}, { drawing: anchorAttrs });
+                attributeSet = generateUpdateFormulaOperationsHandler.call(this, generator, this.getPosition(), updateDesc);
             }
 
             // reduce the attribute to the attributes that will actually change
@@ -571,14 +505,19 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
                 attributeSet = this.getReducedAttributeSet(attributeSet);
             }
 
+            // add the new anchor attributes to the attribute set (bug 57983: do not reduce these attributes!)
+            if (anchorAttrs) {
+                attributeSet = attributePool.extendAttributeSet(attributeSet || {}, { drawing: anchorAttrs });
+            }
+
             // create a change operation, if some attributes will be changed in this drawing
             if (!_.isEmpty(attributeSet)) {
-                this.generateChangeOperations(generator, attributeSet);
+                this.generateChangeOperations(generator, attributeSet, topLevelMove ? updateDesc.moveDescs : null);
             }
 
             // generate the operations to update all embedded drawing objects
             this.forEachChildModel(function (childModel) {
-                childModel.generateUpdateFormulaOperations(generator, changeDesc);
+                childModel.generateUpdateFormulaOperations(generator, updateDesc);
             });
 
             return this;
@@ -588,13 +527,13 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
 
         // add missing inactive anchor attributes that can be calculated from the existing anchor attributes
         if (!embedded) {
-            var anchorAttrs = drawingCollection.getInactiveCellAnchorAttributes(this.getMergedAttributeSet(true).drawing);
+            var anchorAttrs = rootCollection.getInactiveAnchorAttributes(this.getMergedAttributeSet(true).drawing);
             this.setAttributes({ drawing: anchorAttrs }, { notify: 'never' });
         }
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docModel = sheetModel = attributePool = drawingCollection = cloneConstructor = null;
+            docModel = sheetModel = attributePool = rootCollection = cloneConstructor = null;
         });
 
     } // class DrawingModelMixin
