@@ -14,10 +14,9 @@
 
 define('io.ox/office/spreadsheet/model/drawing/sourcelinkmixin', [
     'io.ox/office/tk/container/valuemap',
-    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (ValueMap, AttributeUtils, SheetUtils, TokenArray) {
+], function (ValueMap, SheetUtils, TokenArray) {
 
     'use strict';
 
@@ -156,14 +155,9 @@ define('io.ox/office/spreadsheet/model/drawing/sourcelinkmixin', [
          * Returns an iterator that visits all token arrays of this instance.
          * The token arrays will be visited in no specific order.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the token arrays have been visited completely.
-         *      No more token arrays are available; this result object does not
-         *      contain any other properties!
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the following
+         *  value properties:
          *  - {TokenArray} value
          *      The token array currently visited.
          *  - {String} key
@@ -323,33 +317,29 @@ define('io.ox/office/spreadsheet/model/drawing/sourcelinkmixin', [
          *  The position of the parent drawing object in the sheet, as expected
          *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
-         * @param {Object} changeDesc
+         * @param {Object} updateDesc
          *  The properties describing the document change. The properties that
-         *  are expected in this descriptor depend on the change type in its
-         *  'type' property. See method TokenArray.resolveOperation() for more
-         *  details.
+         *  are expected in this descriptor depend on its 'type' property. See
+         *  method TokenArray.resolveOperation() for more details.
          *
          * @param {Object} [properties]
          *  Additional properties to be inserted into the document operations.
          */
-        this.implGenerateUpdateFormulaOperations = function (generator, operationName, position, changeDesc, properties) {
+        this.implGenerateUpdateFormulaOperations = function (generator, operationName, position, updateDesc, properties) {
 
             // collect the changed formula expressions
-            var attrSet = {};
+            var operAttrSet = {};
             var undoAttrSet = {};
             this.iterateTokenArrays(function (tokenArray, linkKey, attrName, attrFamily) {
-                tokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
-                    AttributeUtils.insertAttribute(attrSet, attrFamily, attrName, newFormula);
-                    AttributeUtils.insertAttribute(undoAttrSet, attrFamily, attrName, oldFormula);
-                });
+                tokenArray.resolveOperationAttribute('op', updateDesc, attrFamily, attrName, operAttrSet, undoAttrSet);
             });
 
             // generate the operations, if any formula expression has changed
-            if (!_.isEmpty(attrSet)) {
-                var operProperties = _.extend({}, properties, { attrs: attrSet });
-                generator.generateDrawingOperation(operationName, position, operProperties);
-                var undoProperties = _.extend({}, properties, { attrs: undoAttrSet });
-                generator.generateDrawingOperation(operationName, position, undoProperties, { undo: true });
+            if (!_.isEmpty(operAttrSet)) {
+                var operProps = _.extend({}, properties, { attrs: operAttrSet });
+                generator.generateDrawingOperation(operationName, position, operProps);
+                var undoProps = _.extend({}, properties, { attrs: undoAttrSet });
+                generator.generateDrawingOperation(operationName, position, undoProps, { undo: true });
             }
         };
 
