@@ -14,8 +14,8 @@
 
 define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/utils/scheduler',
-    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/triggerobject',
@@ -29,7 +29,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
     'io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor',
     'io.ox/office/spreadsheet/model/formula/deps/formuladictionary',
     'io.ox/office/spreadsheet/model/formula/deps/pendingcollection'
-], function (Utils, Scheduler, IteratorUtils, ValueSet, ValueMap, TriggerObject, Config, SheetUtils, CellOperationsBuilder, FormulaUtils, DependencyUtils, TimerHelper, FormulaDescriptor, SheetDescriptor, FormulaDictionary, PendingCollection) {
+], function (Utils, Iterator, Scheduler, ValueSet, ValueMap, TriggerObject, Config, SheetUtils, CellOperationsBuilder, FormulaUtils, DependencyUtils, TimerHelper, FormulaDescriptor, SheetDescriptor, FormulaDictionary, PendingCollection) {
 
     'use strict';
 
@@ -39,6 +39,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
     var AddressArray = SheetUtils.AddressArray;
     var RangeArray = SheetUtils.RangeArray;
     var Scalar = FormulaUtils.Scalar;
+    var AddressSet = DependencyUtils.AddressSet;
     var FormulaSet = DependencyUtils.FormulaSet;
     var getCellKey = DependencyUtils.getCellKey;
 
@@ -51,9 +52,9 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
      *
      * @extends ValueSet
      */
-    var ResultSet = ValueSet.extend({ constructor: function () {
+    var ResultSet = ValueSet.extend(function () {
         ValueSet.call(this, 'key');
-    } }); // class ResultSet
+    }); // class ResultSet
 
     // public methods ---------------------------------------------------------
 
@@ -336,7 +337,8 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
         function setCalcOnLoadFlag() {
 
             // nothing to do, if 'calculate on load' mode is already activated
-            if (calcOnLoad) { return; }
+            // -> not generating operation in long running processes (recursive call), 53641
+            if (calcOnLoad || docModel.isProcessingActions()) { return; }
 
             // set the 'calcOnLoad' flag via document operation
             generateAndSendOperations(function (generator) {
@@ -345,6 +347,28 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             calcOnLoad = true;
         }
 
+        /**
+         * Checks the current number of formulas. If the maximum allowed number
+         * of formulas (according to server configuration) has been exceeded,
+         * this dependency manager will be detached from all document model
+         * events (this prevents processing any further edit actions from the
+         * document), a "recalc:overflow" event will be triggered (this will
+         * abort the update cycle currently running), and  the "calcOnLoad"
+         * document flag will be set.
+         */
+        var checkFormulaCount = (Config.MAX_FORMULA_COUNT > 0) ? function () {
+
+            // formula count still valid: return true
+            if (formulaCount <= Config.MAX_FORMULA_COUNT) { return true; }
+
+            // detach and deactivate dependency manager
+            self.disconnect();
+            self.trigger('recalc:overflow');
+            setCalcOnLoadFlag();
+            return false;
+
+        } : _.constant(true);
+
         /**
          * Inserts a new formula descriptor into all collections of this
          * dependency manager.
@@ -362,17 +386,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
             // update the total number of formulas
             formulaCount += 1;
-
-            // If the maximum number of formulas has been exceeded, detach this dependency manager
-            // from all document model events (this prevents processing any further edit actions),
-            // trigger the 'recalc:overflow' event (this will abort the update cycle currently
-            // running), and set the 'calcOnLoad' document flag.
-            if (formulaCount > Config.MAX_FORMULA_COUNT) {
-                self.disconnect();
-                self.trigger('recalc:overflow');
-                setCalcOnLoadFlag();
-                return false;
-            }
+            if (!checkFormulaCount()) { return false; }
 
             // register the formula descriptor in the global map
             formulaSet.insert(formulaDesc);
@@ -448,7 +462,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.update=false]
+         *  - {Boolean} [options.update=false]
          *      If set to true, this method will update an existing formula
          *      descriptor, otherwise it will insert a new formula descriptor.
          */
@@ -536,7 +550,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
         var processPendingCollection = DependencyUtils.profileAsyncMethod('processPendingCollection()', function () {
 
             // process the dirty addresses and moved ranges of all sheets
-            return timerHelper.iterate(pendingCollection.changedSheetMap.iterator(), function (pendingSheetData) {
+            return timerHelper.iterate(pendingCollection.changedSheetMap, function (pendingSheetData) {
 
                 // the model, UID, and cell collection of the affected sheet
                 var sheetModel = pendingSheetData.sheetModel;
@@ -578,7 +592,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
                 // removes the specified cell formulas from the internal collections
                 function unregisterFormulaCells(addresses) {
-                    return timerHelper.iterate(addresses.iterator(), function (address) {
+                    return timerHelper.iterate(addresses, function (address) {
                         var formulaKey = getCellKey(sheetUid, address);
                         formulaSet.with(formulaKey, removeFormula);
                     });
@@ -599,8 +613,10 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                         if (!tokenDesc) { return; }
                         var formulaDesc = new FormulaDescriptor(formulaKey, tokenDesc.tokenArray, tokenDesc.refAddress, address, tokenDesc.matrixRange);
 
-                        // recalculate all formula cells, if there is a cell without a valid result type
-                        var recalcFormula = recalcAll;
+                        // recalculate formula cell, if it has been registered in preceding update cycle (bug 56767: even if it is fixed now)
+                        var recalcFormula = recalcAll || pendingSheetData.recalcAddressSet.has(address);
+
+                        // recalculate ALL formula cells, if there is a cell without a valid result type
                         if (!recalcFormula && initialUpdateCycle && !tokenDesc.matrixRange && !isMatchingCellResult(tokenDesc.tokenArray, address)) {
                             DependencyUtils.warn('recalculating all formulas caused by wrong result type in ' + formulaDesc);
                             recalcFormula = recalcAll = pendingCollection.recalcAll = true;
@@ -610,10 +626,12 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                         if (recalcFormula || !formulaDesc.isFixed()) {
                             // immediately escape the loop, if the number of formulas exceeds the configuration limit
                             if (!insertFormula(formulaDesc)) { return Utils.BREAK; }
+                        } else {
+                            DependencyUtils.log('skipped fixed formula ' + formulaDesc);
                         }
 
                         // register the new formula for recalculation
-                        if (recalcFormula) { pendingSheetData.recalcFormulaCells.push(address); }
+                        if (recalcFormula) { pendingSheetData.recalcAddressSet.insert(address); }
                     });
                 }
 
@@ -628,7 +646,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
                     // collect the formatting rules in the new sheet (copied sheets may contain conditional formattings)
                     var ruleIterator = sheetModel.getCondFormatCollection().createModelIterator();
-                    IteratorUtils.forEach(ruleIterator, pendingSheetData.registerTokenModel, pendingSheetData);
+                    Iterator.forEach(ruleIterator, pendingSheetData.registerTokenModel, pendingSheetData);
 
                     pendingSheetData.initialUpdate = false;
                 }
@@ -639,7 +657,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                 // remove all formula descriptors inside the dirty ranges
                 promise = promise.then(function () {
                     var sheetDesc = sheetDescMap.get(sheetUid, null);
-                    return timerHelper.iterate(dirtyRanges.iterator(), function (dirtyRange) {
+                    return timerHelper.iterate(dirtyRanges, function (dirtyRange) {
                         return unregisterFormulaCells(sheetDesc.cellFormulaSet.findAddresses(dirtyRange));
                     });
                 });
@@ -660,10 +678,10 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                 var dirtyModelSet = pendingSheetData.dirtyModelSet;
                 if (!dirtyModelSet.empty()) {
                     promise = promise.then(function () {
-                        return timerHelper.iterate(dirtyModelSet.iterator(), function (tokenModel) {
+                        return timerHelper.iterate(dirtyModelSet, function (tokenModel) {
                             var modelUid = tokenModel.getUid();
                             var refAddress = tokenModel.getRefAddress();
-                            IteratorUtils.forEach(tokenModel.createTokenArrayIterator(), function (tokenArray, iterResult) {
+                            Iterator.forEach(tokenModel.createTokenArrayIterator(), function (tokenArray, iterResult) {
                                 var formulaKey = modelUid + '!' + iterResult.key;
                                 var formulaDesc = new FormulaDescriptor(formulaKey, tokenArray, refAddress, null, null, tokenModel);
                                 if (!formulaDesc.isFixed()) { insertFormula(formulaDesc); }
@@ -738,7 +756,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             promise = promise.then(function () {
                 if (!resultCollection.formulaSet.empty()) { // bug 48014: check MUST be inside promise.then()!
                     return DependencyUtils.takeAsyncTime('refreshing formulas for dirty names and tables...', function () {
-                        return timerHelper.iterate(resultCollection.formulaSet.iterator(), refreshFormula);
+                        return timerHelper.iterate(resultCollection.formulaSet, refreshFormula);
                     });
                 }
             });
@@ -748,13 +766,13 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             if (!pendingCollection.changedLabelsSet.empty()) {
                 promise = promise.then(DependencyUtils.profileAsyncMethod('refreshing formulas for dirty name labels...', function () {
                     // visit all sheets (each sheet descriptor contains its own map of formulas with missing names)...
-                    return timerHelper.iterate(sheetDescMap.iterator(), function (sheetDesc) {
+                    return timerHelper.iterate(sheetDescMap, function (sheetDesc) {
                         // process all defined names with changed label for the current sheet...
-                        return timerHelper.iterate(pendingCollection.changedLabelsSet.iterator(), function (nameModel) {
+                        return timerHelper.iterate(pendingCollection.changedLabelsSet, function (nameModel) {
                             // if the sheet contains formulas with #NAME? errors using the current label...
                             return sheetDesc.missingNamesMap.with(nameModel.getKey(), function (destFormulaSet) {
                                 // visit all these formulas with #NAME? errors...
-                                return timerHelper.iterate(destFormulaSet.iterator(), function (formulaDesc) {
+                                return timerHelper.iterate(destFormulaSet, function (formulaDesc) {
                                     // the formula may have been refreshed already (multiple unresolved names)
                                     if (!resultCollection.formulaSet.has(formulaDesc)) {
                                         refreshFormula(formulaDesc);
@@ -771,7 +789,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
             // Collect all initially dirty formulas from all sheets in the document.
             promise = promise.then(DependencyUtils.profileAsyncMethod('collecting initially dirty formulas...', function () {
-                return timerHelper.iterate(sheetDescMap.iterator(), function (sheetDesc) {
+                return timerHelper.iterate(sheetDescMap, function (sheetDesc) {
 
                     // Add all formulas that are permanently dirty (recalculation mode 'always'). These formulas will
                     // always be recalculated, regardless whether they depend on any dirty cells.
@@ -793,30 +811,28 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                     var pendingSheetData = pendingCollection.getPendingSheetData(sheetModel);
 
                     // the addresses of all formula cells that will be recalculated
-                    var recalcFormulaCells = pendingSheetData ? pendingSheetData.recalcFormulaCells.clone() : new AddressArray();
+                    var recalcAddressSet = pendingSheetData ? pendingSheetData.recalcAddressSet.clone() : new AddressSet();
 
                     // Collect the dirty value cells. Dirty value cells that are formulas by themselves need
                     // to be recalculated (the correct formula result may have been destroyed).
                     var dirtyValueCells = pendingSheetData ? pendingSheetData.dirtyValueCells.reject(function (address) {
                         if (formulaSet.hasKey(getCellKey(sheetUid, address))) {
-                            recalcFormulaCells.push(address);
+                            recalcAddressSet.insert(address);
                             return true;
                         }
                     }) : new AddressArray();
 
                     // nothing more to do without changed formula nor value cells
-                    if (recalcFormulaCells.empty() && dirtyValueCells.empty()) { return; }
-
-                    // remove duplicates from the formula cell addresses
-                    recalcFormulaCells = recalcFormulaCells.unify();
+                    if (recalcAddressSet.empty() && dirtyValueCells.empty()) { return; }
 
                     // join the value cells to ranges for faster lookup of dependent formulas
                     var dirtyValueRanges = RangeArray.mergeAddresses(dirtyValueCells);
 
                     DependencyUtils.withLogging(function () {
                         var sheetName = sheetModel.getName();
-                        if (!recalcFormulaCells.empty()) {
-                            DependencyUtils.log('outdated formula results in ' + sheetName + '!' + RangeArray.mergeAddresses(recalcFormulaCells));
+                        if (!recalcAddressSet.empty()) {
+                            var addresses = new AddressArray(recalcAddressSet.values());
+                            DependencyUtils.log('outdated formula results in ' + sheetName + '!' + RangeArray.mergeAddresses(addresses));
                         }
                         if (!dirtyValueRanges.empty()) {
                             DependencyUtils.log('dirty cells in ' + sheetName + '!' + dirtyValueRanges);
@@ -828,9 +844,9 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
                     // Collect all dirty cell formulas. Cells with changed formula expressions must be recalculated in
                     // order to get a valid initial result.
-                    if (!recalcFormulaCells.empty()) {
+                    if (!recalcAddressSet.empty()) {
                         promise2 = promise2.then(function () {
-                            return timerHelper.iterate(recalcFormulaCells.iterator(), function (address) {
+                            return timerHelper.iterate(recalcAddressSet, function (address) {
                                 var formulaKey = getCellKey(sheetUid, address);
                                 sheetDesc.formulaSet.with(formulaKey, registerDirtyFormula);
                             });
@@ -840,7 +856,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                     // Collect all formulas depending directly on dirty value cells.
                     if (!dirtyValueRanges.empty()) {
                         promise2 = promise2.then(function () {
-                            return timerHelper.iterate(dirtyValueRanges.iterator(), function (range) {
+                            return timerHelper.iterate(dirtyValueRanges, function (range) {
                                 registerDirtyFormulas(lookupDictionary.findFormulasForRange(sheetUid, range));
                             });
                         });
@@ -870,14 +886,14 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                         var newFormulaSet = new FormulaSet();
 
                         // process all formulas whose dependencies have not been calculated yet
-                        var promise2 = timerHelper.iterate(pendingFormulaSet.iterator(), function (sourceFormulaDesc) {
+                        var promise2 = timerHelper.iterate(pendingFormulaSet, function (sourceFormulaDesc) {
 
                             // find all formulas that depend directly on the current formula (ignore formulas from token models)
                             var destFormulaSet = lookupDictionary.findFormulasForFormula(sourceFormulaDesc);
                             if (!destFormulaSet) { return; }
 
                             // process all found formulas depending on the current formula
-                            return timerHelper.iterate(destFormulaSet.iterator(), function (destFormulaDesc) {
+                            return timerHelper.iterate(destFormulaSet, function (destFormulaDesc) {
 
                                 // nothing more to do, if the formula has already been collected
                                 if (resultCollection.formulaSet.has(destFormulaDesc)) { return; }
@@ -890,8 +906,8 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
 
                         // initialize the next iteration cycle
                         return promise2.done(function () {
-                            DependencyUtils.logFormulaSet(newFormulaSet);
                             pendingFormulaSet = newFormulaSet;
+                            DependencyUtils.logFormulaSet(newFormulaSet);
                         });
                     });
                 });
@@ -924,13 +940,16 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
          */
         var sendFormulaResults = DependencyUtils.profileAsyncMethod('sendFormulaResults()', function () {
 
+            // bug 55078: bind the promise chain to own lifetime
+            var promise = self.createResolvedPromise();
+
             // wait for another operations generator process currently running (needed to prevent internal
             // application error due to nested operation generators), this may even abort the entire update
             // cycle, e.g. after deleting a sheet which makes the calculated formula results useless
-            var promise = docModel.waitForActionsProcessed();
+            promise = promise.then(function () { return docModel.waitForActionsProcessed(); });
 
             // write the collected results (synchronously) into the document
-            promise.always(DependencyUtils.profileMethod('updating document contents...', function () {
+            promise.done(DependencyUtils.profileMethod('updating document contents...', function () {
 
                 // generate the cell operations, and send them to the server
                 generateAndSendOperations(function (generator) {
@@ -969,7 +988,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             }));
 
             // refresh all model objects containing dirty formulas locally (without operations)
-            promise.always(DependencyUtils.profileMethod('updating models with token arrays...', function () {
+            promise.done(DependencyUtils.profileMethod('updating models with token arrays...', function () {
 
                 // the dirty models, as sets mapped by sheet UID
                 var dirtyModelMap = new ValueMap();
@@ -1009,16 +1028,16 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.continue=false]
+         *  - {Boolean} [options.continue=false]
          *      If set to true, an update cycle currently running will be
          *      continued. By default, a running update cycle will be aborted,
          *      and a fresh update cycle will be started.
-         *  @param {Boolean} [options.priority=false]
+         *  - {Boolean} [options.priority=false]
          *      If set to true, the update cycle will be started with high
          *      timer priority. If used together with the option 'continue',
          *      the continued update cycle will be swiched from low to high
          *      priority.
-         *  @param {Boolean} [options.volatile=true]
+         *  - {Boolean} [options.volatile=true]
          *      If set to false (default is true!), volatile formulas will NOT
          *      be recalculated (unless they depend on dirty cells). This
          *      option will affect new update cycles only, but not a running
@@ -1047,26 +1066,35 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             self.on('recalc:overflow', abortUpdateCycle);
 
             // starts a new background task (debounced)
-            var runUpdateCycle = self.createDebouncedMethod('DependencyManager.runUpdateCycle', null, Utils.profileAsyncMethod('dependency update cycle', function () {
+            var runUpdateCycle = self.createDebouncedMethod('DependencyManager.runUpdateCycle', null, function () {
+
+                // collect all dirty formulas and the results, used later e.g. in the public method getCellValue()
+                resultCollection = new ResultCollection();
 
                 // trigger the start event (additional delay for initial update after import)
                 var delay = firstUpdate ? DependencyUtils.IMPORT_UPDATE_DELAY : 0;
                 updateTimer = self.executeDelayed(function () { self.trigger('recalc:start'); }, 'DependencyManager.startUpdateCycle', delay);
                 firstUpdate = false;
 
-                // collect all dirty formulas and the results, used later e.g. in the public method getCellValue()
-                resultCollection = new ResultCollection();
+                // wait for running document operation generators before starting update cycle
+                updateTimer = updateTimer.then(function () { return docModel.waitForActionsProcessed(); });
 
-                // Process all pending document changes (changed value cells, changed formula
-                // expressions, moved cells, etc.), before starting to update the token arrays.
-                updateTimer = updateTimer.then(processPendingCollection);
+                // log the asynchronous runtime of the update cycle only, without the preparation work
+                updateTimer = updateTimer.then(Utils.profileAsyncMethod('dependency update cycle', function () {
 
-                // Collect and recalculate all dirty token arrays (all token arrays referring to
-                // dirty cells, unless all formulas have to be recalculated).
-                updateTimer = updateTimer.then(recalcDirtyFormulas);
+                    // Process all pending document changes (changed value cells, changed formula
+                    // expressions, moved cells, etc.), before starting to update the token arrays.
+                    var promise = processPendingCollection();
 
-                // Update the values of the formula cells in the document model.
-                updateTimer = updateTimer.then(sendFormulaResults);
+                    // Collect and recalculate all dirty token arrays (all token arrays referring to
+                    // dirty cells, unless all formulas have to be recalculated).
+                    promise = promise.then(recalcDirtyFormulas);
+
+                    // Update the values of the formula cells in the document model.
+                    promise = promise.then(sendFormulaResults);
+
+                    return promise;
+                }));
 
                 // Notify listeners, and clean up the caches after the update cycle has finished successfully.
                 updateTimer.done(function () {
@@ -1092,10 +1120,8 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                     self.trigger('recalc:cancel');
                 });
 
-                // returning the promise is required by Logger.profileAsyncMethod() method
                 return updateTimer;
-
-            }), { delay: DependencyUtils.UPDATE_DEBOUNCE_DELAY });
+            }, { delay: DependencyUtils.UPDATE_DEBOUNCE_DELAY });
 
             // the implementation of the method startUpdateCycle() returned from local scope
             return function (options) {
@@ -1233,14 +1259,14 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.all=false]
+         *  - {Boolean} [options.all=false]
          *      If set to true, all availavle formulas in the document will be
          *      recalculated, regardless of their diryt state.
-         *  @param {Boolean} [options.volatile=true]
+         *  - {Boolean} [options.volatile=true]
          *      If set to false (default is true!), volatile formulas will NOT
          *      be recalculated (unless they depend on dirty cells). This
          *      option will be ignored, if the option 'all' has been set.
-         *  @param {Number} [options.timeout]
+         *  - {Number} [options.timeout]
          *      The maximum time allowed for the recalculation cycle, in
          *      milliseconds. If the time elapses before all formulas have been
          *      calculated, the recalculation cycle will be aborted, and the
@@ -1378,7 +1404,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
                     var matrix = formulaResult.value;
                     var col1 = matrixRange.start[0];
                     var row1 = matrixRange.start[1];
-                    IteratorUtils.forEach(matrixRange.iterator(), function (address) {
+                    Iterator.forEach(matrixRange, function (address) {
                         var value = matrix.get(address[1] - row1, address[0] - col1);
                         resultSet.insert(address, value, time);
                     });
@@ -1446,8 +1472,8 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
         }());
 
         /**
-         * Resource keys of all unimplemented functions that occur in any
-         * formula known by this dependency manager.
+         * Returns the resource keys of all unimplemented functions that occur
+         * in any formula known by this dependency manager.
          *
          * @returns {Array<String>}
          *  The resource keys of all unimplemented functions that occur in any
@@ -1474,7 +1500,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencymanager', [
             calcOnLoad = docModel.getDocumentAttribute('calcOnLoad');
 
             // initialize dependency manager for all existing sheets after import
-            IteratorUtils.forEach(docModel.createSheetIterator(), registerSheetModel);
+            Iterator.forEach(docModel.createSheetIterator(), registerSheetModel);
 
             // inserted sheet: register all existing formulas (e.g. in a copied sheet)
             this.listenTo(docModel, 'insert:sheet:after', function (event, sheet, sheetModel) {
