@@ -188,7 +188,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
 
         // collect formula descriptors depending on all cell ranges containing the address
         this._rangeSets.with(sheetUid, function (rangeSet) {
-            rangeSet.findByAddress(address).forEach(function (range) {
+            rangeSet.findAllByAddress(address).forEach(function (range) {
                 formulaSet.merge(range.formulaSet);
             });
         }, this);
@@ -216,7 +216,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
 
         // collect formula descriptors depending on all cell ranges overlapping with the range
         this._rangeSets.with(sheetUid, function (rangeSet) {
-            rangeSet.findRanges(range).forEach(function (range) {
+            rangeSet.findAll(range).forEach(function (range) {
                 formulaSet.merge(range.formulaSet);
             });
         }, this);
