@@ -13,15 +13,17 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/deps/dependencyutils'
-], function (SimpleMap, SheetUtils, DependencyUtils) {
+], function (Utils, ValueMap, SheetUtils, DependencyUtils) {
 
     'use strict';
 
     // convenience shortcuts
     var AddressSet = SheetUtils.AddressSet;
+    var FormulaSet = DependencyUtils.FormulaSet;
 
     // class SheetDescriptor ==================================================
 
@@ -34,7 +36,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
      * @property {SheetModel} sheetModel
      *  The model of the sheet represented by this descriptor object.
      *
-     * @property {SimpleMap<FormulaDescriptor>} formulaMap
+     * @property {FormulaSet} formulaSet
      *  The formula descriptors (instances of class FormulaDescriptor) for all
      *  known token arrays of the sheet.
      *
@@ -43,34 +45,32 @@ define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
      *  known cell formulas of the sheet, as property 'formula' in the cell
      *  address objects of an address set.
      *
-     * @property {SimpleMap<SimpleMap<FormulaDescriptor>>} ruleFormulaMaps
-     *  The descriptors of all formulas attached to a condition of a formatting
-     *  rule. The elements of this map are maps of formula descriptors. The
-     *  inner maps are keyed by the UIDs of the parent rule model. The formula
-     *  descriptors are keyed by the complete formula keys of the token arrays
-     *  (the UID of the rule model, combined with the internal keys of the
-     *  token arrays used inside the rule model).
+     * @property {ValueMap<FormulaSet>} modelFormulasMap
+     *  The descriptors of all formulas attached to a token array embedded in a
+     *  model object (e.g. conditions of formatting rules, source link formulas
+     *  of chart data series). The elements of this map are formula descriptor
+     *  sets. The sets are keyed by the UIDs of the parent token model.
      *
-     * @property {SimpleMap<FormulaDescriptor>} missingNamesMap
+     * @property {ValueMap<FormulaSet>} missingNamesMap
      *  The formula descriptors for all known token arrays that contain
      *  references to non-existing defined names. These formulas are considered
      *  to be dirty, if a defined name has been inserted, or an existing defind
      *  name has changed its label, which may result in validating a #NAME?
-     *  error. The property is a map with the labels of missing names as key,
-     *  and stores a formula map (keyed by formula keys) per missing name.
+     *  error. The property is a map with the name keys (the upper-case labels)
+     *  of missing names as key, and stores a formula set per missing name.
      *
-     * @property {SimpleMap<FormulaDescriptor>} recalcAlwaysMap
+     * @property {FormulaSet} recalcAlwaysSet
      *  The formula descriptors for all known token arrays with recalculation
      *  mode 'always'. These formulas will always be recalculated whenever
      *  something in the document has changed, regardless of their
      *  dependencies.
      *
-     * @property {SimpleMap<FormulaDescriptor>} recalcOnceMap
+     * @property {FormulaSet} recalcOnceSet
      *  The formula descriptors for all known token arrays with recalculation
      *  mode 'once'. These formulas will be recalculated once after the
      *  document has been imported, regardless of their dependencies.
      *
-     * @property {SimpleMap<Number>} missingFuncMap
+     * @property {ValueMap<Number>} missingFuncMap
      *  The resource keys of all unimplemented functions that occur in any
      *  formula of the sheet, and the number of occurences.
      */
@@ -78,13 +78,13 @@ define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
 
         this.sheetModel = sheetModel;
 
-        this.formulaMap = new SimpleMap();
+        this.formulaSet = new FormulaSet();
         this.cellFormulaSet = new AddressSet();
-        this.ruleFormulaMaps = new SimpleMap();
-        this.missingNamesMap = new SimpleMap();
-        this.recalcAlwaysMap = new SimpleMap();
-        this.recalcOnceMap = new SimpleMap();
-        this.missingFuncMap = new SimpleMap();
+        this.modelFormulasMap = new ValueMap();
+        this.missingNamesMap = new ValueMap();
+        this.recalcAlwaysSet = new FormulaSet();
+        this.recalcOnceSet = new FormulaSet();
+        this.missingFuncMap = new ValueMap();
 
     } // class SheetDescriptor
 
@@ -94,43 +94,42 @@ define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
      * Inserts the passed formula descriptor into the formula caches of this
      * sheet descriptor.
      *
-     * @param {String} formulaKey
-     *  The formula key of the formula descriptor, used as map key.
-     *
      * @param {FormulaDescriptor} formulaDesc
      *  The formula descriptor to be inserted into the formula caches.
      */
-    SheetDescriptor.prototype.insertFormula = function (formulaKey, formulaDesc) {
+    SheetDescriptor.prototype.insertFormula = function (formulaDesc) {
 
         // insert the formula descriptor into the own maps
-        this.formulaMap.insert(formulaKey, formulaDesc);
+        this.formulaSet.insert(formulaDesc);
         switch (formulaDesc.recalc) {
-            case 'always': this.recalcAlwaysMap.insert(formulaKey, formulaDesc); break;
-            case 'once':   this.recalcOnceMap.insert(formulaKey, formulaDesc);   break;
+            case 'always': this.recalcAlwaysSet.insert(formulaDesc); break;
+            case 'once':   this.recalcOnceSet.insert(formulaDesc);   break;
         }
 
         // insert the formula into the type-specific containers
-        if (formulaDesc.cellAddress) {
+        if (formulaDesc.tokenModel) {
+            var modelUid = formulaDesc.tokenModel.getUid();
+            this.modelFormulasMap.getOrConstruct(modelUid, FormulaSet).insert(formulaDesc);
+        } else if (formulaDesc.cellAddress) {
             var address = formulaDesc.cellAddress.clone();
             this.cellFormulaSet.insert(address).formula = formulaDesc;
-        } else if (formulaDesc.ruleModel) {
-            var parentUid = formulaDesc.ruleModel.getUid();
-            this.ruleFormulaMaps.getOrConstruct(parentUid, SimpleMap).insert(formulaKey, formulaDesc);
+        } else {
+            Utils.error('SheetDescriptor.insertFormula(): unknown formula type');
         }
 
         // map the formula descriptor by missing name labels
-        SimpleMap.forEachKey(formulaDesc.missingNames, function (key) {
-            var formulaMap = this.missingNamesMap.getOrConstruct(key, SimpleMap);
-            formulaMap.insert(formulaKey, formulaDesc);
+        ValueMap.forEachKey(formulaDesc.missingNames, function (key) {
+            var formulaSet = this.missingNamesMap.getOrConstruct(key, FormulaSet);
+            formulaSet.insert(formulaDesc);
         }, this);
 
         // register all unimplemented functions
-        SimpleMap.forEachKey(formulaDesc.missingFuncs, function (key) {
+        ValueMap.forEachKey(formulaDesc.missingFuncs, function (key) {
             this.missingFuncMap.update(key, 0, function (count) { return count + 1; });
         }, this);
 
         DependencyUtils.withLogging(function () {
-            DependencyUtils.log('new dependencies for ' + DependencyUtils.getFormulaLabel(formulaKey) + ': ' + formulaDesc.references);
+            DependencyUtils.log('new dependencies for ' + formulaDesc + ': ' + formulaDesc.references);
         });
     };
 
@@ -138,49 +137,44 @@ define('io.ox/office/spreadsheet/model/formula/deps/sheetdescriptor', [
      * Deletes the specified formula descriptor from the formula caches of this
      * sheet descriptor.
      *
-     * @param {String} formulaKey
-     *  The formula key of the formula descriptor to be deleted.
-     *
-     * @returns {FormulaDescriptor|Null}
-     *  The formula descriptor deleted from this sheet descriptor, or null.
+     * @param {FormulaDescriptor} formulaDesc
+     *  The descriptor of the formula to be deleted.
      */
-    SheetDescriptor.prototype.removeFormula = function (formulaKey) {
-
-        // find and remove an existing descriptor registered for this sheet
-        var formulaDesc = this.formulaMap.remove(formulaKey);
-        if (!formulaDesc) { return null; }
+    SheetDescriptor.prototype.removeFormula = function (formulaDesc) {
 
         // remove the formula descriptor from the own maps
-        this.recalcAlwaysMap.remove(formulaKey);
-        this.recalcOnceMap.remove(formulaKey);
-        SimpleMap.forEachKey(formulaDesc.missingNames, function (key) {
-            this.missingNamesMap.with(key, function (formulaMap) {
-                formulaMap.remove(formulaKey);
-                if (formulaMap.empty()) { this.missingNamesMap.remove(key); }
+        this.formulaSet.remove(formulaDesc);
+        this.recalcAlwaysSet.remove(formulaDesc);
+        this.recalcOnceSet.remove(formulaDesc);
+        ValueMap.forEachKey(formulaDesc.missingNames, function (key) {
+            this.missingNamesMap.with(key, function (formulaSet) {
+                formulaSet.remove(formulaDesc);
+                if (formulaSet.empty()) { this.missingNamesMap.remove(key); }
             }, this);
         }, this);
 
         // remove the formula from the type-specific containers
-        if (formulaDesc.cellAddress) {
-            this.cellFormulaSet.remove(formulaDesc.cellAddress);
-        } else if (formulaDesc.ruleModel) {
-            var parentUid = formulaDesc.ruleModel.getUid();
-            this.ruleFormulaMaps.with(parentUid, function (formulaMap) {
-                formulaMap.remove(formulaKey);
-                if (formulaMap.empty()) {
-                    this.ruleFormulaMaps.remove(parentUid);
+        if (formulaDesc.tokenModel) {
+            var modelUid = formulaDesc.tokenModel.getUid();
+            this.modelFormulasMap.with(modelUid, function (formulaSet) {
+                formulaSet.remove(formulaDesc);
+                if (formulaSet.empty()) {
+                    this.modelFormulasMap.remove(modelUid);
                 }
             }, this);
+        } else if (formulaDesc.cellAddress) {
+            this.cellFormulaSet.remove(formulaDesc.cellAddress);
+        } else {
+            Utils.error('SheetDescriptor.removeFormula(): unknown formula type');
         }
 
         // unregister all unimplemented functions
-        SimpleMap.forEachKey(formulaDesc.missingFuncs, function (key) {
+        ValueMap.forEachKey(formulaDesc.missingFuncs, function (key) {
             var count = this.missingFuncMap.update(key, 0, function (count) { return count - 1; });
             if (count <= 0) { this.missingFuncMap.remove(key); }
         }, this);
 
-        DependencyUtils.log('removed dependencies for ' + DependencyUtils.getFormulaLabel(formulaKey));
-        return formulaDesc;
+        DependencyUtils.log('removed dependencies for ' + formulaDesc);
     };
 
     // exports ================================================================
