@@ -14,6 +14,7 @@
 
 define('io.ox/office/spreadsheet/model/formula/formulautils', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/enum',
     'io.ox/office/tk/utils/logger',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/utils/mathutils',
@@ -24,7 +25,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
     'io.ox/office/spreadsheet/model/formula/utils/formulaerror',
     'io.ox/office/spreadsheet/model/formula/utils/cellref',
     'io.ox/office/spreadsheet/model/formula/utils/sheetref'
-], function (Utils, Logger, SheetUtils, MathUtils, Scalar, Complex, Matrix, Dimension, FormulaError, CellRef, SheetRef) {
+], function (Utils, Enum, Logger, SheetUtils, MathUtils, Scalar, Complex, Matrix, Dimension, FormulaError, CellRef, SheetRef) {
 
     'use strict';
 
@@ -76,7 +77,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Maximum number of function parameters (CalcEngine limitation).
      *
      * @constant
-     * @type {Number}
+     * @type Number
      */
     FormulaUtils.MAX_PARAM_COUNT = 254;
 
@@ -84,7 +85,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Maximum number of references in a reference list.
      *
      * @constant
-     * @type {Number}
+     * @type Number
      */
     FormulaUtils.MAX_REF_LIST_SIZE = 1024;
 
@@ -92,7 +93,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Maximum time available for evaluating a single formula, in milliseconds.
      *
      * @constant
-     * @type {Number}
+     * @type Number
      */
     FormulaUtils.MAX_EVAL_TIME = 2000;
 
@@ -100,7 +101,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Special error code literal to transport the 'unsupported' state.
      *
      * @constant
-     * @type {ErrorCode}
+     * @type ErrorCode
      */
     FormulaUtils.UNSUPPORTED_ERROR = makeInternalErrorCode('unsupported', ErrorCode.NA);
 
@@ -108,7 +109,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Special error code literal to transport the 'circular reference' result.
      *
      * @constant
-     * @type {ErrorCode}
+     * @type ErrorCode
      */
     FormulaUtils.CIRCULAR_ERROR = makeInternalErrorCode('circular', 0);
 
@@ -116,7 +117,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Special error code literal to transport the 'timeout' state.
      *
      * @constant
-     * @type {ErrorCode}
+     * @type ErrorCode
      */
     FormulaUtils.TIMEOUT_ERROR = makeInternalErrorCode('timeout', ErrorCode.NA);
 
@@ -124,10 +125,58 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      * Special error code literal for other internal interpreter errors.
      *
      * @constant
-     * @type {ErrorCode}
+     * @type ErrorCode
      */
     FormulaUtils.INTERNAL_ERROR = makeInternalErrorCode('internal', ErrorCode.NA);
 
+    // enumerations -----------------------------------------------------------
+
+    /**
+     * Enumeration for different formula types that can occur in a spreadsheet
+     * document.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {FormulaType} CELL
+     *  A regular cell formula, a shared formula, or a matrix formula. This
+     *  implies special handling for circular references when interpreting the
+     *  formula.
+     *
+     * @property {FormulaType} NAME
+     *  The definition of a defined name. Reference tokens that will be located
+     *  outside the sheet when relocating them will be wrapped at the sheet
+     *  borders.
+     *
+     * @property {FormulaType} RULE
+     *  The condition value of a rule in a conditional formatting range.
+     *
+     * @property {FormulaType} VALIDATION
+     *  The condition value of a data validation range.
+     *
+     * @property {FormulaType} LINK
+     *  The source link in a model object (e.g. data series source in a chart
+     *  object, or a linked text box).
+     */
+    FormulaUtils.FormulaType = Enum.create('cell name rule validation link');
+
+    /**
+     * Enumeration for different types of filter functions.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {FilterType} SINGLE
+     *  The filter function takes a single filtered range and filter criterion
+     *  (the "IF" functions, e.g. SUMIF or AVERAGEIF).
+     *
+     * @property {FilterType} MULTI
+     *  The filter function takes multiple parameter pairs representing the
+     *  filtered ranges and filter criteria (the "IFS" functions, e.g. SUMIFS,
+     *  AVERAGEIFS, MINIFS, or MAXIFS).
+     */
+    FormulaUtils.FilterType = Enum.create('single multi');
+
     // static methods ---------------------------------------------------------
 
     /**
@@ -283,7 +332,7 @@ define('io.ox/office/spreadsheet/model/formula/formulautils', [
      */
     FormulaUtils.logTokens = FormulaUtils.isLoggingActive() ? function (message, tokens) {
         FormulaUtils.log(message + ': ' + tokens.join(' '));
-    } : $.noop;
+    } : _.noop;
 
     // exports ================================================================
 
