@@ -38,6 +38,11 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
      *
      *************************************************************************/
 
+    // convenience shortcuts
+    var abs = Math.abs;
+    var floor = Math.floor;
+    var ceil = Math.ceil;
+
     // standard options for date parameter iterators (method FormulaContext.iterateNumbers())
     var RCONVERT_ALL_SKIP_EMPTY = { // id: RRR0
         valMode: 'rconvert', // value operands: convert strings to numbers (but not booleans)
@@ -107,30 +112,57 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             }
         }
 
-        return Math.floor((date - nullDate) / DateUtils.MSEC_PER_WEEK) + 1;
+        return floor((date - nullDate) / DateUtils.MSEC_PER_WEEK) + 1;
     }
 
     // workday helpers ----------------------------------------------------
 
-    var WEEKEND_CODES = { 1: /* default */ '0000011', 2: '1000001', 3: '1100000', 4: '0110000', 5: '0011000', 6: '0001100', 7: '0000110', 11: '0000001', 12: '1000000', 13: '0100000', 14: '0010000', 15: '0001000', 16: '0000100', 17: '0000010' };
+    var WEEKEND_PATTERNS = [
+        null,
+        '0000011', // 1 = Sat,Sun
+        '1000001', // 2 = Sun,Mon
+        '1100000', // 3 = Mon,Tue
+        '0110000', // 4 = Tue,Wed
+        '0011000', // 5 = Wed,Thu
+        '0001100', // 6 = Thu,Fri
+        '0000110', // 7 = Fri,Sat
+        null,
+        null,
+        null,
+        '0000001', // 11 = Sun
+        '1000000', // 12 = Mon
+        '0100000', // 13 = Tue
+        '0010000', // 14 = Wed
+        '0001000', // 15 = Thu
+        '0000100', // 16 = Fri
+        '0000010'  // 17 = Sat
+    ];
 
     function getWeekendFromParam(weekend) {
-        if (_.isNull(weekend) || _.isUndefined(weekend)) {
-            weekend = WEEKEND_CODES['1'];
-        } else if (_.isBoolean(weekend)) {
-            if (weekend) {
-                weekend = WEEKEND_CODES['1'];
-            } else {
-                throw ErrorCode.NUM;
-            }
-        } else if (_.isNumber(weekend)) {
-            weekend = WEEKEND_CODES[weekend];
-            if (!weekend) { throw ErrorCode.NUM; }
+
+        // parameter omitted: Saturday/Sunday
+        if (_.isUndefined(weekend)) {
+            return WEEKEND_PATTERNS[1];
         }
-        if (!_.isString(weekend) || !/^[01]{7}$/.test(weekend)) {
-            throw ErrorCode.VALUE;
+
+        // value null (empty parameter, or blank cell) used as zero; booleans used as numbers
+        if ((weekend === null) || (typeof weekend === 'boolean')) {
+            weekend = weekend ? 1 : 0;
         }
-        return weekend;
+
+        // convert numbers to predefiend pattern
+        if (typeof weekend === 'number') {
+            weekend = WEEKEND_PATTERNS[floor(weekend)];
+            if (weekend) { return weekend; }
+            throw ErrorCode.NUM;
+        }
+
+        // strings must consist of 7 binary digits
+        if ((typeof weekend === 'string') && /^[01]{7}$/.test(weekend)) {
+            return weekend;
+        }
+
+        throw ErrorCode.VALUE;
     }
 
     function getWorkDaysPerWeek(weekendCode) {
@@ -214,20 +246,16 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             endDate = tmpDate;
         }
 
-        //---- begin of perf optimization ---------
+        var sliceWeeks = floor(DateUtils.getDaysDiff(startDate, endDate) / 7) * prefix;
+        var restWeeks = floor(daysCounter.value / workDaysPerWeek);
 
-        var sliceWeeks = Math.floor(DateUtils.getDaysDiff(startDate, endDate) / 7) * prefix;
-        var restWeeks = Math.floor(daysCounter.value / workDaysPerWeek);
-
-        var weeks = Math.abs(sliceWeeks) < Math.abs(restWeeks) ? sliceWeeks : restWeeks;
+        var weeks = abs(sliceWeeks) < abs(restWeeks) ? sliceWeeks : restWeeks;
 
         if (weeks < -1 || weeks > 1) {
             startDate = DateUtils.addDaysToDate(startDate, (weeks - prefix) * 7);
             daysCounter.value -= (weeks - prefix) * workDaysPerWeek;
         }
 
-        //---- end of perf optimization ---------
-
         var dayCount = DateUtils.getDaysDiff(startDate, endDate) * prefix;
         for (var i = 0; i <= dayCount; i++) {
             var currentDate = DateUtils.addDaysToDate(startDate, i * prefix);
@@ -291,7 +319,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
         };
 
         var holidayCount = holidays.length;
-        var maxDays = Math.ceil((Math.abs(days) / workDaysPerWeek) * 7) + holidayCount;
+        var maxDays = ceil((abs(days) / workDaysPerWeek) * 7) + holidayCount;
 
         //the safe way
         maxDays *= 2;
@@ -372,7 +400,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             type: 'val:num',
             signature: 'val:str',
             resolve: function (dateText) {
-                return Math.floor(parseDateTime(this, dateText));
+                return floor(parseDateTime(this, dateText));
             }
         },
 
@@ -451,20 +479,20 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
 
                 // implementation of the Gauss algorithm, adapted from OOo source code (sc/source/core/tool/interpr2.cxx)
                 var n = year % 19,
-                    b = Math.floor(year / 100),
+                    b = floor(year / 100),
                     c = year % 100,
-                    d = Math.floor(b / 4),
+                    d = floor(b / 4),
                     e = b % 4,
-                    f = Math.floor((b + 8) / 25),
-                    g = Math.floor((b - f + 1) / 3),
+                    f = floor((b + 8) / 25),
+                    g = floor((b - f + 1) / 3),
                     h = (19 * n + b - d - g + 15) % 30,
-                    i = Math.floor(c / 4),
+                    i = floor(c / 4),
                     k = c % 4,
                     l = (32 + 2 * e + 2 * i - h - k) % 7,
-                    m = Math.floor((n + 11 * h + 22 * l) / 451),
+                    m = floor((n + 11 * h + 22 * l) / 451),
                     o = h + l - 7 * m + 114;
 
-                return DateUtils.makeUTCDate({ Y: year, M: Math.floor(o / 31) - 1, D: o % 31 + 1 });
+                return DateUtils.makeUTCDate({ Y: year, M: floor(o / 31) - 1, D: o % 31 + 1 });
             }
         },
 
@@ -737,7 +765,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             maxParams: 4,
             type: 'val:date',
             format: 'date',
-            signature: 'val:day val:int val:int any',
+            signature: 'val:day val:int val any',
             resolve: function (startDate, days, weekend, holidays) {
                 return workDayIntl(this, startDate, days, weekend, holidays);
             }
