@@ -606,7 +606,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: { ooxml: 8, odf: 7 },
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:date val:num val:num val:num val:int val:bool',
             resolve: function (issue, firstInterest, settlement, rate, par, frequency, mode, calcMethod) {
                 ensureFrequency(frequency);
@@ -624,7 +624,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num val:num val:int',
             resolve: function (issue, settlement, rate, par, mode) {
                 if (rate <= 0 || par <= 0 || issue >= settlement) { throw ErrorCode.NUM; }
@@ -637,7 +637,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 7,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:date val:date val:num val:num val:num val:int',
             resolve: function (cost, purchasedDate, firstEndDate, salvage, period, rate, mode) {
                 if (purchasedDate > firstEndDate || rate <= 0 || salvage < 0 || cost <= 0 || salvage > cost) { throw ErrorCode.NUM; }
@@ -686,7 +686,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 7,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:date val:date val:num val:num val:num val:int',
             resolve: function (cost, purchasedDate, firstEndDate, salvage, period, rate, mode) {
                 if (purchasedDate > firstEndDate || rate <= 0 || salvage < 0 || cost <= 0 || salvage > cost) { throw ErrorCode.NUM; }
@@ -714,7 +714,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency, mode) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -729,7 +729,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency, mode) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -744,7 +744,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency, mode) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -759,7 +759,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency/*, mode*/) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -774,7 +774,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency, mode) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -789,7 +789,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int val:int',
             resolve: function (settlement, maturity, frequency/*, mode*/) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
@@ -804,7 +804,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int val:num val:int val:int val:int',
             resolve: function (rate, periodCount, presValue, startPeriod, endPeriod, payType) {
                 var fRmz, fZinsZ;
@@ -840,7 +840,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int val:num val:int val:int val:int',
             resolve: function (rate, periodCount, presValue, startPeriod, endPeriod, payType) {
                 var fRmz, fKapZ;
@@ -881,7 +881,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:int',
             resolve: function (cost, salvage, life, period, months) {
@@ -916,7 +916,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:num',
             resolve: function (cost, salvage, life, period, factor) {
@@ -931,7 +931,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num val:num val:int',
             resolve: function (settlement, maturity, price, discount, mode) {
                 if (price <= 0 || discount <= 0 || settlement >= maturity) { throw ErrorCode.NUM; }
@@ -945,7 +945,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (dollar, fraction) {
                 if (fraction <= 0) { throw ErrorCode.NUM; }
@@ -967,7 +967,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (dollar, fraction) {
                 if (fraction <= 0) { throw ErrorCode.NUM; }
@@ -989,7 +989,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 5,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num val:num val:int val:int',
             resolve: function (settlement, maturity, coupon, fYield, frequency, mode) {
                 return getDuration.call(this, settlement, maturity, coupon, fYield, frequency, mode);
@@ -1001,7 +1001,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             name: { odf: 'EFFECTIVE' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (rate, period) {
                 if (rate <= 0 || period < 1) { throw ErrorCode.NUM; }
@@ -1015,14 +1015,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             name: { ooxml: null },
             minParams: 3,
             maxParams: 4,
-            type: 'val'
+            type: 'val:num'
         },
 
         FV: {
             category: 'financial',
             minParams: 3,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:int',
             resolve: function (rate, periodCount, pmt, currentValue, payType) {
@@ -1037,7 +1037,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num any',
             resolve: function (principal, scheduleParam) {
                 this.iterateNumbers(scheduleParam, function (sched) {
@@ -1057,7 +1057,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num val:num val:int',
             resolve: function (settlement, maturity, price, discount, mode) {
                 if (price <= 0 || discount <= 0 || settlement >= maturity) { throw ErrorCode.NUM; }
@@ -1071,7 +1071,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:num val:int',
             resolve: function (rate, period, periodCount, currentValue, futureValue, periodType) {
@@ -1088,7 +1088,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             format: 'percent',
             signature: 'any val:num',
             resolve: function (values, guess) {
@@ -1133,7 +1133,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:num val:num',
             resolve: function (rate, period, periodCount, currentValue) {
                 if (rate <= 0) { throw ErrorCode.NUM; }
@@ -1147,7 +1147,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 5,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num val:num val:int val:int',
             resolve: function (settlement, maturity, coupon, fYield, frequency, mode) {
                 var fRet = getDuration.call(this, settlement, maturity, coupon, fYield, frequency, mode);
@@ -1160,7 +1160,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             format: 'percent',
             signature: 'any val:num val:num',
             resolve: function (values, financeRate, reInvestRate) {
@@ -1195,7 +1195,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (rate, periods) {
                 if (periods < 1 || rate <= 0) { throw ErrorCode.NUM; }
@@ -1207,7 +1207,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:num val:num val:int',
             resolve: function (rate, payment, currentValue, futureValue, periodType) {
                 if (rate <= 0) { throw ErrorCode.NUM; }
@@ -1227,7 +1227,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
         NPV: {
             category: 'financial',
             minParams: 2,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num any',
             resolve: function (rate) {
@@ -1245,28 +1245,28 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 8,
             maxParams: 9,
-            type: 'val'
+            type: 'val:num'
         },
 
         ODDFYIELD: { /* not implemented in calc */
             category: 'financial',
             minParams: 8,
             maxParams: 9,
-            type: 'val'
+            type: 'val:num'
         },
 
         ODDLPRICE: { /* not implemented in calc */
             category: 'financial',
             minParams: 7,
             maxParams: 8,
-            type: 'val'
+            type: 'val:num'
         },
 
         ODDLYIELD: {
             category: 'financial',
             minParams: 7,
             maxParams: 8,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:date val:num val:num val:num val:int val:int',
             resolve: function (settlement, maturity, lastInterest, rate, price, discount, frequency, mode) {
                 if (rate < 0 || price <= 0 || discount <= 0 || settlement >= maturity || lastInterest >= settlement) { throw ErrorCode.NUM; }
@@ -1295,13 +1295,13 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             name: { ooxml: '_xlfn.PDURATION' },
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:num',
             resolve: function (rate, currentValue, futureValue) {
                 if (rate <= 0 || currentValue <= 0 || futureValue <= 0) { throw ErrorCode.NUM; }
                 if (_.isUndefined(futureValue)) { futureValue = 0; }
 
-                return (log(futureValue) - log(currentValue)) / (log1p(rate));
+                return (log(futureValue) - log(currentValue)) / log1p(rate);
             }
         },
 
@@ -1309,7 +1309,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:int',
             resolve: function (rate, periodCount, currentValue, futureValue, periodType) {
@@ -1325,7 +1325,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:num val:int',
             resolve: function (rate, period, periodCount, currentValue, futureValue, periodType) {
@@ -1344,7 +1344,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 7,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:day val:day val:num val:num val:int val:int',
             resolve: function (settlement, maturity, rate, fYield, discount, frequency, mode) {
@@ -1360,7 +1360,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:day val:day val:num val:num val:int',
             resolve: function (settlement, maturity, discount, redemption, mode) {
@@ -1375,7 +1375,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 5,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:day val:day val:day val:num val:int',
             resolve: function (settlement, maturity, issue, rate, fYield, mode) {
@@ -1399,7 +1399,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:int',
             resolve: function (rate, periodCount, pmt, futureValue, payType) {
@@ -1414,7 +1414,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             format: 'percent',
             signature: 'val:num val:num val:num val:num val:int val:num',
             resolve: function (periodCount, pmt, currentValue, futureValue, payType, guess) {
@@ -1459,7 +1459,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:date val:date val:num val:num val:int',
             resolve: function (settlement, maturity, price, discount, mode) {
@@ -1475,7 +1475,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             name: { ooxml: '_xlfn.RRI', odf: ['RRI', 'ZGZ'] },
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:num',
             resolve: function (periodCount, currentValue, futureValue) {
                 if (periodCount <= 0 || currentValue <= 0 || futureValue < 0) { throw ErrorCode.NUM; }
@@ -1489,13 +1489,13 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num',
             resolve: function (cost, salvage, life) {
                 if (salvage < 0 || life <= 0) { throw ErrorCode.NUM; }
 
-                return ((cost - salvage) / life);
+                return (cost - salvage) / life;
             }
         },
 
@@ -1503,7 +1503,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num',
             resolve: function (cost, salvage, life, period) {
@@ -1517,14 +1517,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num',
             resolve: function (settlement, maturity, discount) {
                 if (discount <= 0 || settlement > maturity) { throw ErrorCode.NUM; }
 
                 maturity = DateUtils.addDaysToDate(maturity, 1);
 
-                var   nDiff = getDaysDiff(settlement, maturity, 0);
+                var nDiff = getDaysDiff(settlement, maturity, 0);
 
                 if (nDiff > 360) { throw ErrorCode.NUM; }
 
@@ -1537,7 +1537,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:date val:date val:num',
             resolve: function (settlement, maturity, discount) {
@@ -1557,7 +1557,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date val:date val:num',
             resolve: function (settlement, maturity, price) {
                 if (price <= 0 || settlement >= maturity) { throw ErrorCode.NUM; }
@@ -1581,7 +1581,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 5,
             maxParams: 7,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num val:num val:num val:num val:num val:num val:bool',
             resolve: function (cost, salvage, life, startPeriod, endPeriod, factor, noSwitch) {
@@ -1634,7 +1634,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'any any val:num',
             resolve: function (values, dates, guess) {
                 var aValues = this.getNumbersAsArray(values, RCONVERT_ALL_SKIP_EMPTY);
@@ -1702,7 +1702,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             format: 'currency',
             signature: 'val:num any any',
             resolve: function (rate, values, dates) {
@@ -1729,7 +1729,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 6,
             maxParams: 7,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:num val:num val:num val:int val:int',
             resolve: function (settlement, maturity, rate, price, discount, frequency, mode) {
                 if (rate < 0 || price <= 0 || discount <= 0 || settlement >= maturity) { throw ErrorCode.NUM; }
@@ -1744,7 +1744,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 4,
             maxParams: 5,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:num val:num val:int',
             resolve: function (settlement, maturity, price, discount, mode) {
                 if (price <= 0 || discount <= 0 || settlement >= maturity) { throw ErrorCode.NUM; }
@@ -1760,7 +1760,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             category: 'financial',
             minParams: 5,
             maxParams: 6,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:day val:num val:num val:int',
             resolve: function (settlement, maturity, issue, rate, price, mode) {
 
