@@ -31,6 +31,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
 
     // convenience shortcuts
     var MathUtils = FormulaUtils.Math;
+    var FilterType = FormulaUtils.FilterType;
 
     // mathematical constants
     var PI = Math.PI;
@@ -311,7 +312,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
 
                 if (_.isUndefined(mode)) {
                     //TODO: odf correct?!
-                    mode = 0;//(this.fileFormat === 'odf') ? 0 : 1;
+                    mode = 0;//this.ODF ? 0 : 1;
                 }
 
                 if (significance === 0) {
@@ -520,7 +521,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
 
                 if (_.isUndefined(mode)) {
                     //TODO: odf correct?!
-                    mode = 0;//(this.fileFormat === 'odf') ? 0 : 1;
+                    mode = 0;//this.ODF ? 0 : 1;
                 }
                 if (significance === 0 || (number > 0 && significance < 0)) {
                     throw ErrorCode.VALUE;
@@ -1024,7 +1025,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val:num',
             signature: 'ref:val val:any ref:val',
             resolve: function () {
-                return this.aggregateFilteredCells('single', 0, MathUtils.add);
+                return this.aggregateFilteredCells(FilterType.SINGLE, 0, MathUtils.add);
             }
         },
 
@@ -1035,7 +1036,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val:num',
             signature: 'ref:val ref:val val:any',
             resolve: function () {
-                return this.aggregateFilteredCells('multi', 0, MathUtils.add);
+                return this.aggregateFilteredCells(FilterType.MULTI, 0, MathUtils.add);
             }
         },
 
