@@ -38,32 +38,60 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
 
     return {
 
-        // arithmetic operators -----------------------------------------------
+        // unary arithmetic operators -----------------------------------------
 
-        // binary addition operator, or unary plus operator
-        add: {
+        // unary plus operator
+        uplus: {
             name: '+',
             minParams: 1,
-            maxParams: 2,
-            type: 'val',
-            format: 'combine',
-            signature: 'val val:num', // unary plus operator passes all values (no conversion to number)
-            resolve: function (value1, value2) {
-                return this.isMissingOperand(1) ? value1 : (this.convertToNumber(value1) + value2);
-            }
+            maxParams: 1,
+            type: 'val:any',
+            signature: 'val', // passes all values (no conversion to number)
+            resolve: _.identity
         },
 
-        // binary subtraction operator, or unary minus operator
-        sub: {
+        // unary minus operator
+        uminus: {
             name: '-',
             minParams: 1,
+            maxParams: 1,
+            type: 'val:num',
+            signature: 'val:num', // always converts to numbers
+            resolve: function (number) { return -number; }
+        },
+
+        // unary percent operator
+        upct: {
+            name: '%',
+            minParams: 1,
+            maxParams: 1,
+            type: 'val:num',
+            signature: 'val:num',
+            resolve: function (number) { return number / 100; }
+        },
+
+        // binary arithmetic operators ----------------------------------------
+
+        // binary addition operator
+        add: {
+            name: '+',
+            minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             format: 'combine',
-            signature: 'val:num val:num', // unary minus operator always converts to numbers
-            resolve: function (value1, value2) {
-                return this.isMissingOperand(1) ? (-value1) : (value1 - value2);
-            }
+            signature: 'val:num val:num',
+            resolve: MathUtils.add
+        },
+
+        // binary subtraction operator
+        sub: {
+            name: '-',
+            minParams: 2,
+            maxParams: 2,
+            type: 'val:num',
+            format: 'combine',
+            signature: 'val:num val:num',
+            resolve: MathUtils.sub
         },
 
         // binary multiplication operator
@@ -71,7 +99,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '*',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.mul
         },
@@ -81,7 +109,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '/',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.div
         },
@@ -91,21 +119,11 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '^',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.POW
         },
 
-        // unary percent operator
-        pct: {
-            name: '%',
-            minParams: 1,
-            maxParams: 1,
-            type: 'val',
-            signature: 'val:num',
-            resolve: function (number) { return number / 100; }
-        },
-
         // string operators ---------------------------------------------------
 
         // binary string concatenation operator
@@ -113,7 +131,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '&',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:str',
             resolve: function (str1, str2) {
                 // concatenate the URL parts of both operands (fall-back to the regular strings if either URL is missing)
@@ -131,7 +149,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '<',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return this.compareScalars(value1, value2) < 0;
@@ -143,7 +161,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '<=',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return this.compareScalars(value1, value2) <= 0;
@@ -155,7 +173,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '>',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return this.compareScalars(value1, value2) > 0;
@@ -167,7 +185,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '>=',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return this.compareScalars(value1, value2) >= 0;
@@ -179,7 +197,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '=',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return this.equalScalars(value1, value2);
@@ -191,7 +209,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/operators', [
             name: '<>',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val val',
             resolve: function (value1, value2) {
                 return !this.equalScalars(value1, value2);
