@@ -60,7 +60,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 1,
-            type: 'val'
+            type: 'val:str'
         },
 
         BAHTTEXT: {
@@ -68,7 +68,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { odf: 'COM.MICROSOFT.BAHTTEXT' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:num',
             resolve: (function () {
 
@@ -174,7 +174,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int',
             resolve: function (value) {
                 if ((value < 1) || (value > 255)) { throw ErrorCode.VALUE; }
@@ -187,7 +187,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (value) {
                 // TODO: other Unicode characters?
@@ -199,11 +199,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: function (value) {
                 // TODO: not exact, needs code page conversion
-                return (value.length === 0) ? ErrorCode.VALUE : value.charCodeAt(0);
+                if (value.length === 0) { throw ErrorCode.VALUE; }
+                return value.charCodeAt(0);
             }
         },
 
@@ -211,7 +212,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             name: { ooxml: '_xlfn.CONCAT', odf: null },
             minParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'any|mat:pass',
             resolve: function () {
                 // the aggregation function (throws early, if the string length exceeds the limit)
@@ -223,7 +224,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
         CONCATENATE: {
             category: 'text',
             minParams: 1,
-            type: 'val',
+            type: 'val:str',
             // each parameter is a single value (function does not concatenate cell ranges or matrixes!)
             signature: 'val:str',
             resolve: function () {
@@ -237,14 +238,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 1,
-            type: 'val'
+            type: 'val:str'
         },
 
         DOLLAR: {
             category: 'text',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: (function () {
 
@@ -274,7 +275,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:str val:str',
             resolve: function (value1, value2) {
                 return value1 === value2; // exact case-sensitive comparison
@@ -285,7 +286,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:str val:int',
             resolve: function (searchText, text, index) {
                 if (_.isUndefined(index)) { index = 1; }
@@ -305,7 +306,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:str val:int',
             resolve: 'FIND' // TODO: own implementation for multi-byte character sets?
         },
@@ -314,7 +315,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:num val:int val:bool',
             resolve: function (number, places, noGroups) {
 
@@ -337,7 +338,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (text, count) {
                 if (_.isUndefined(count)) { count = 1; }
@@ -351,7 +352,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: 'LEFT' // TODO: own implementation for multi-byte character sets?
         },
@@ -360,7 +361,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: _.property('length')
         },
@@ -370,7 +371,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: 'LEN' // TODO: own implementation for multi-byte character sets?
         },
@@ -379,7 +380,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (text) { return text.toLowerCase(); }
         },
@@ -388,7 +389,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int val:int',
             resolve: function (text, start, count) {
                 this.checkStringIndex(start);
@@ -402,7 +403,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int val:int',
             resolve: 'MID' // TODO: own implementation for multi-byte character sets?
         },
@@ -412,7 +413,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: '_xlfn.NUMBERVALUE' },
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:str val:str',
             resolve: function (text, decSep, groupSep) {
 
@@ -470,7 +471,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'ref:single'
         },
 
@@ -478,7 +479,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (text) {
                 // TODO: the reg-exp does not include all characters that count as letters
@@ -490,7 +491,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 4,
             maxParams: 4,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int val:int val:str',
             resolve: function (oldText, start, count, newText) {
                 this.checkStringIndex(start);
@@ -505,7 +506,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 4,
             maxParams: 4,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int val:int val:str',
             resolve: 'REPLACE' // TODO: own implementation for multi-byte character sets?
         },
@@ -514,7 +515,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (text, repeat) {
                 return this.repeatString(text, repeat);
@@ -525,7 +526,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (text, count) {
                 if (_.isUndefined(count)) { count = 1; }
@@ -539,7 +540,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: 'RIGHT' // TODO: own implementation for multi-byte character sets?
         },
@@ -549,7 +550,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.ROT13' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (text) {
                 return text.replace(/[a-zA-Z]/g, function (a) {
@@ -562,7 +563,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:str val:int',
             resolve: function (searchText, text, index) {
 
@@ -598,7 +599,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:str val:int',
             resolve: 'SEARCH' // TODO: own implementation for multi-byte character sets?
         },
@@ -607,7 +608,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:str val:str val:int',
             resolve: function (text, replaceText, newText, index) {
 
@@ -642,7 +643,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val',
             resolve: function (value) {
                 return _.isString(value) ? value : '';
@@ -653,7 +654,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             recalc: 'once', // result depends on GUI language
             signature: 'val:num val:str',
             resolve: function (number, formatText) {
@@ -668,7 +669,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             name: { ooxml: '_xlfn.TEXTJOIN', odf: null },
             minParams: 3,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:bool any|mat:pass',
             resolve: function (delimiter, skipEmpty) {
 
@@ -699,7 +700,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (text) {
                 // TRIM removes space characters (U+0020) only, no other white-space or control characters
@@ -712,7 +713,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: '_xlfn.UNICHAR' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int',
             resolve: function (value) {
                 if ((value < 1) || (value > 0xFFFF)) { throw ErrorCode.VALUE; }
@@ -728,7 +729,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: '_xlfn.UNICODE' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: function (value) {
                 return (value.length === 0) ? ErrorCode.VALUE : value.charCodeAt(0);
@@ -739,7 +740,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str',
             resolve: function (text) { return text.toUpperCase(); }
         },
@@ -750,7 +751,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: 'DOLLAR'
         },
@@ -759,7 +760,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             category: 'text',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val',
             resolve: function (value) {
                 // text can be converted to number, but boolean values will result in #VALUE!
