@@ -36,7 +36,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/webfuncs', function () {
             hidden: true,
             minParams: 3,
             maxParams: 4,
-            type: 'val'
+            type: 'val:any'
         },
 
         ENCODEURL: {
@@ -44,7 +44,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/webfuncs', function () {
             name: { ooxml: '_xlfn.ENCODEURL', odf: 'COM.MICROSOFT.ENCODEURL' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str'
         },
 
@@ -53,14 +53,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/webfuncs', function () {
             name: { ooxml: '_xlfn.FILTERXML', odf: 'COM.MICROSOFT.FILTERXML' },
             minParams: 1,
             maxParams: 1,
-            type: 'val'
+            type: 'val:str'
         },
 
         HYPERLINK: {
             category: 'web',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:any',
             recalc: 'once',
             signature: 'val:str val:any',
             resolve: function (url, value) {
@@ -74,7 +74,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/webfuncs', function () {
             name: { odf: null },
             hidden: true,
             minParams: 3,
-            type: 'val'
+            type: 'val:any'
         },
 
         WEBSERVICE: {
@@ -83,7 +83,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/webfuncs', function () {
             hidden: true,
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str'
         }
     };
