@@ -13,10 +13,10 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/interpret/filteraggregator', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils'
-], function (IteratorUtils, SheetUtils, FormulaUtils) {
+], function (Iterator, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -222,7 +222,7 @@ define('io.ox/office/spreadsheet/model/formula/interpret/filteraggregator', [
         var matchCounts = this._createMatrix(0);
 
         // visit all entries in the filter ranges with at least one non-blank cell
-        IteratorUtils.forEach(iterator, function (values) {
+        Iterator.forEach(iterator, function (values) {
 
             // count all iterator stops, needed to calculate the completely blank entries
             valueCount += 1;
