@@ -175,6 +175,11 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
                 options.matrixRange = Range.createFromAddressAndSize(options.targetAddress, matrixDim.cols, matrixDim.rows);
             }
 
+            // bug 56629: matrix context without matrix range: resolve as any context
+            if ((contextType === 'mat') && !matrixDim) {
+                contextType = 'any';
+            }
+
             return nameModel.getTokenArray().interpretFormula(contextType, options).value;
         }
 
@@ -460,21 +465,25 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
             var signature = subNode.signature;
             signature.forEach(function (typeData, index) {
 
+                // the base type of the operand
+                var baseType = typeData.baseType;
+                // the matrix context mode for the operand
+                var matSpec = typeData.matSpec;
                 // the operand node to be pushed into the resolver
                 var opNode = subNode.operands[index];
                 // whether the parameter is value type in a value operator
-                var isValueType = (typeData.baseType === 'val') && (descriptor.type === 'val');
+                var isValueType = (baseType === 'val') && (descriptor.type === 'val');
                 // the effective context type for the operand (used to resolve the entire subtree)
-                var opContextType = (typeData.matSpec === 'force') ? 'mat' : typeData.baseType;
+                var opContextType = (matSpec === 'force') ? 'mat' : baseType;
 
                 // If context type for this operator is matrix, and the current parameter is of type value,
                 // and this operator returns a value, pass the matrix context type through to the operand
                 // (resolve nested cell references to matrixes instead of single values).
-                if ((contextType === 'mat') && (isValueType || (typeData.matSpec === 'pass'))) {
+                if ((contextType === 'mat') && (isValueType || (matSpec === 'pass') || (matSpec === 'forward'))) {
                     opContextType = 'mat';
                 }
 
-                var forwardMatrix = isValueType && (opContextType === 'mat');
+                var forwardMatrix = (opContextType === 'mat') && (isValueType || (matSpec === 'forward'));
                 resolver.push(resolveNode.bind(null, opNode, opContextType, forwardMatrix ? matrixDim : null));
             });
 
@@ -844,30 +853,30 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Number} [options.refSheet]
+         *  - {Number} [options.refSheet]
          *      The index of the reference sheet that will be used to resolve
          *      reference tokens and defined names without explicit sheet
          *      reference. If omitted, reference tokens without sheet indexes
          *      will result in #REF! errors.
-         *  @param {Address} [options.refAddress]
+         *  - {Address} [options.refAddress]
          *      The source reference address used to relocate reference tokens
          *      with relative column/row components. If omitted, cell A1 will
          *      be used as source reference cell.
-         *  @param {Address} [options.targetAddress]
+         *  - {Address} [options.targetAddress]
          *      The target reference address used to relocate reference tokens
          *      with relative column/row components. If omitted, cell A1 will
          *      be used as target reference cell.
-         *  @param {Range} [options.matrixRange]
+         *  - {Range} [options.matrixRange]
          *      The entire bounding range of a matrix formula. Used only if the
          *      passed context type is 'mat'. If not set, the matrix size will
          *      be deduced from the operands.
-         *  @param {Boolean} [options.wrapReferences=false]
+         *  - {Boolean} [options.wrapReferences=false]
          *      If set to true, relocated ranges that are located outside the
          *      sheet will be wrapped at the sheet borders.
-         *  @param {Boolean} [options.detectCircular=false]
+         *  - {Boolean} [options.detectCircular=false]
          *      If set to true, trying to dereference a cell reference covering
          *      the target address leads to a circular dependeny error.
-         *  @param {Boolean} [options.recalcDirty=false]
+         *  - {Boolean} [options.recalcDirty=false]
          *      If set to true, all dirty cell formulas referred by the
          *      reference tokens in the passed compiled token tree will be
          *      recalculated recursively using the dependency manager of the
