@@ -14,11 +14,12 @@
 
 define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/parser/tokens'
-], function (Utils, Parser, SheetUtils, FormulaUtils, Tokens) {
+], function (Utils, Class, Parser, SheetUtils, FormulaUtils, Tokens) {
 
     'use strict';
 
@@ -77,7 +78,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *
      * @constructor
      */
-    var ExpressionParserBase = _.makeExtendable(function (docModel, formulaGrammar) {
+    var ExpressionParserBase = Class.extendable(function (docModel, formulaGrammar) {
 
         // the document model
         this.docModel = docModel;
@@ -416,7 +417,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.resolveTable=false]
+     *  - {Boolean} [options.resolveTable=false]
      *      If set to true, and the passed label refers to a table range, a
      *      table reference token will be created.
      *
@@ -735,12 +736,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *
      * @extends ExpressionParserBase
      */
-    var ExpressionParserOOX = ExpressionParserBase.extend({ constructor: function (docModel, formulaGrammar) {
+    var ExpressionParserOOX = ExpressionParserBase.extend(function (docModel, formulaGrammar) {
 
         // base constructor
         ExpressionParserBase.call(this, docModel, formulaGrammar);
 
-    } }); // class ExpressionParserOOX
+    }); // class ExpressionParserOOX
 
     // private methods --------------------------------------------------------
 
@@ -1126,12 +1127,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *
      * @extends ExpressionParserBase
      */
-    var ExpressionParserODFUI = ExpressionParserBase.extend({ constructor: function (docModel, formulaGrammar) {
+    var ExpressionParserODFUI = ExpressionParserBase.extend(function (docModel, formulaGrammar) {
 
         // base constructor
         ExpressionParserBase.call(this, docModel, formulaGrammar);
 
-    } }); // class ExpressionParserODFUI
+    }); // class ExpressionParserODFUI
 
     // protected methods ------------------------------------------------------
 
@@ -1290,12 +1291,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *
      * @extends ExpressionParserBase
      */
-    var ExpressionParserOF = ExpressionParserBase.extend({ constructor: function (docModel, formulaGrammar) {
+    var ExpressionParserOF = ExpressionParserBase.extend(function (docModel, formulaGrammar) {
 
         // base constructor
         ExpressionParserBase.call(this, docModel, formulaGrammar);
 
-    } }); // class ExpressionParserOF
+    }); // class ExpressionParserOF
 
     // virtual methods --------------------------------------------------------
 
