@@ -333,7 +333,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
         var collection = new DescriptorCollection(implementationMap, function (implementation, key) {
 
             // resolve file format dependent properties of the implementation
-            var properties = Utils.mapProperties(implementation, function (value) {
+            var properties = _.mapObject(implementation, function (value) {
                 if (!_.isObject(value) || _.isArray(value) || _.isFunction(value)) { return value; }
                 // if an object, pick a property by file format identifier
                 if (_.isObject(value) && (fileFormat in value)) { return value[fileFormat]; }
@@ -383,9 +383,9 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
             if (_.isNumber(properties.repeatParams)) { descriptor.repeatParams = properties.repeatParams; }
 
             // copy result type and format category
-            var retType = properties.type.split(':');
-            descriptor.type = retType[0];
-            descriptor.valType = retType[1] || 'any';
+            var typeTokens = properties.type.split(':');
+            descriptor.type = typeTokens[0];
+            descriptor.valType = (descriptor.type === 'val') ? (typeTokens[1] || 'any') : null;
             descriptor.format = properties.format;
 
             // convert signature string to an array of parameter descriptors
