@@ -14,9 +14,10 @@
 
 define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils'
-], function (Utils, SheetUtils, FormulaUtils) {
+], function (Utils, Class, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -56,7 +57,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  this token to its text representation for debug logging. Does not
      *  receive any parameter, and must return a string
      */
-    var BaseToken = _.makeExtendable(function (type) {
+    var BaseToken = Class.extendable(function (type) {
 
         // private properties
         this._type = type;
@@ -225,7 +226,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {String} text
      *  The fixed text representation of the token.
      */
-    var FixedToken = BaseToken.extend({ constructor: function (type, text) {
+    var FixedToken = BaseToken.extend(function (type, text) {
 
         // base constructor
         BaseToken.call(this, type);
@@ -233,7 +234,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._text = text;
 
-    } }); // class FixedToken
+    }); // class FixedToken
 
     // public methods ---------------------------------------------------------
 
@@ -303,7 +304,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {String} value
      *  The grammar-independent operator identifier.
      */
-    var OperatorToken = BaseToken.extend({ constructor: function (value) {
+    var OperatorToken = BaseToken.extend(function (value) {
 
         // base constructor
         BaseToken.call(this, 'op');
@@ -311,7 +312,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._value = value;
 
-    } }); // class OperatorToken
+    }); // class OperatorToken
 
     // public methods ---------------------------------------------------------
 
@@ -352,12 +353,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @extends BaseToken
      */
-    var SeparatorToken = BaseToken.extend({ constructor: function () {
+    var SeparatorToken = BaseToken.extend(function () {
 
         // base constructor
         BaseToken.call(this, 'sep');
 
-    } }); // class SeparatorToken
+    }); // class SeparatorToken
 
     // public methods ---------------------------------------------------------
 
@@ -387,12 +388,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Whether this token represents an opening parenthesis (true), or a
      *  closing parenthesis (false).
      */
-    var ParenthesisToken = FixedToken.extend({ constructor: function (open) {
+    var ParenthesisToken = FixedToken.extend(function (open) {
 
         // base constructor
         FixedToken.call(this, open ? 'open' : 'close', open ? '(' : ')');
 
-    } }); // class ParenthesisToken
+    }); // class ParenthesisToken
 
     // public methods ---------------------------------------------------------
 
@@ -415,7 +416,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  The value for this literal token. The special value null is reserved
      *  for empty parameter in a function call, e.g. in the formula =SUM(1,,2).
      */
-    var LiteralToken = BaseToken.extend({ constructor: function (value) {
+    var LiteralToken = BaseToken.extend(function (value) {
 
         // base constructor
         BaseToken.call(this, 'lit');
@@ -423,7 +424,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._value = value;
 
-    } }); // class LiteralToken
+    }); // class LiteralToken
 
     // public methods ---------------------------------------------------------
 
@@ -481,7 +482,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {Matrix} matrix
      *  The matrix literal represented by the token.
      */
-    var MatrixToken = BaseToken.extend({ constructor: function (matrix) {
+    var MatrixToken = BaseToken.extend(function (matrix) {
 
         // base constructor
         BaseToken.call(this, 'mat');
@@ -489,7 +490,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._matrix = matrix;
 
-    } }); // class MatrixToken
+    }); // class MatrixToken
 
     // public methods ---------------------------------------------------------
 
@@ -541,7 +542,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {String} funcKey
      *  The unique resource key of the built-in sheet function.
      */
-    var FunctionToken = BaseToken.extend({ constructor: function (funcKey) {
+    var FunctionToken = BaseToken.extend(function (funcKey) {
 
         // base constructor
         BaseToken.call(this, 'func');
@@ -549,7 +550,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._value = funcKey;
 
-    } }); // class FunctionToken
+    }); // class FunctionToken
 
     // public methods ---------------------------------------------------------
 
@@ -612,7 +613,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  e.g. in [0]!globalname. If null or undefined, the token represents a
      *  reference in the own document (e.g. globalname).
      */
-    var SheetRefToken = BaseToken.extend({ constructor: function (type, docModel, sheet1Ref, sheet2Ref, extDocRef) {
+    var SheetRefToken = BaseToken.extend(function (type, docModel, sheet1Ref, sheet2Ref, extDocRef) {
 
         // base constructor
         BaseToken.call(this, type);
@@ -633,7 +634,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
             sheet1Ref.sheet = sheet;
         }
 
-    } }); // class SheetRefToken
+    }); // class SheetRefToken
 
     // protected methods ------------------------------------------------------
 
@@ -648,10 +649,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {SheetRef|Null} [options.sheet1Ref]
+     *  - {SheetRef|Null} [options.sheet1Ref]
      *      A sheet reference for the first sheet to be returned instead of the
      *      own first sheet reference.
-     *  @param {SheetRef|Null} [options.sheet2Ref]
+     *  - {SheetRef|Null} [options.sheet2Ref]
      *      A sheet reference for the second sheet to be returned instead of
      *      the own second sheet reference.
      *
@@ -676,7 +677,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the reference sheet used to resolve references without
      *      sheets. If omitted, and this token does not contain its own sheet
      *      reference, this method will return null.
@@ -897,7 +898,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Sheet1:Sheet2!A1). If null or undefined, the token will represent a
      *  single sheet reference (e.g. Sheet1!A1).
      */
-    var ReferenceToken = SheetRefToken.extend({ constructor: function (docModel, cell1Ref, cell2Ref, sheet1Ref, sheet2Ref) {
+    var ReferenceToken = SheetRefToken.extend(function (docModel, cell1Ref, cell2Ref, sheet1Ref, sheet2Ref) {
 
         // base constructor
         SheetRefToken.call(this, 'ref', docModel, sheet1Ref, sheet2Ref, null);
@@ -926,7 +927,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
             cell1Ref.row = row;
         }
 
-    } }); // class ReferenceToken
+    }); // class ReferenceToken
 
     // private methods --------------------------------------------------------
 
@@ -996,22 +997,22 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the reference sheet used to resolve missing sheet
      *      references. If omitted, and this token does not contain its own
      *      sheet reference, this method will return null.
-     *  @param {Address} [options.refAddress]
+     *  - {Address} [options.refAddress]
      *      The address of the original reference cell this token is related
      *      to. If omitted, cell A1 will be used instead. If this address is
      *      different to the address resulting from the option 'targetAddress',
      *      the returned range will be relocated according to these two
      *      addresses.
-     *  @param {Address} [options.targetAddress]
+     *  - {Address} [options.targetAddress]
      *      The address of the target cell for relocation. If omitted, cell A1
      *      will be used instead. If this address is different to the address
      *      resulting from the option 'refAddress', the returned range will be
      *      relocated according to these two addresses.
-     *  @param {Boolean} [options.wrapReferences=false]
+     *  - {Boolean} [options.wrapReferences=false]
      *      If set to true, and if the relocated range is located outside the
      *      sheet, the range will be wrapped at the sheet borders.
      *
@@ -1054,11 +1055,11 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the reference sheet used to resolve missing sheet
      *      references. If omitted, and this token does not contain its own
      *      sheet reference, this method will return null.
-     *  @param {Boolean} [options.wrapReferences=false]
+     *  - {Boolean} [options.wrapReferences=false]
      *      If set to true, the resulting range will be wrapped at the sheet
      *      borders.
      *
@@ -1288,10 +1289,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Optional parameters for relocation of range addresses. See method
      *  ReferenceToken.getRange3D() for details. Additionally, the following
      *  options are supported:
-     *  @param {SheetRef|Null} [options.sheet1Ref]
+     *  - {SheetRef|Null} [options.sheet1Ref]
      *      A sheet reference for the first sheet to be used instead of the own
      *      first sheet reference.
-     *  @param {SheetRef|Null} [options.sheet2Ref]
+     *  - {SheetRef|Null} [options.sheet2Ref]
      *      A sheet reference for the second sheet to be used instead of the
      *      own second sheet reference.
      */
@@ -1542,7 +1543,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  [0]!globalname. If null or undefined, the token represents a name in
      *  the own document without document reference (e.g. globalname).
      */
-    var NameToken = SheetRefToken.extend({ constructor: function (docModel, label, sheetRef, extDocRef) {
+    var NameToken = SheetRefToken.extend(function (docModel, label, sheetRef, extDocRef) {
 
         // base constructor
         SheetRefToken.call(this, 'name', docModel, sheetRef, null, extDocRef);
@@ -1550,7 +1551,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._value = label;
 
-    } }); // class NameToken
+    }); // class NameToken
 
     // private methods --------------------------------------------------------
 
@@ -1663,10 +1664,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {SheetRef|Null} [options.sheet1Ref]
+     *  - {SheetRef|Null} [options.sheet1Ref]
      *      An arbitrary sheet reference to be used instead of the own sheet
      *      reference.
-     *  @param {String} [options.label]
+     *  - {String} [options.label]
      *      An arbitrary label to be used to generate the text representation.
      */
     NameToken.prototype.getText = function (formulaGrammar, options) {
@@ -1745,7 +1746,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  formula Module1!myFunc() of a macro call). If null or undefined, the
      *  token represents a globally available macro function.
      */
-    var MacroToken = SheetRefToken.extend({ constructor: function (docModel, label, sheetRef) {
+    var MacroToken = SheetRefToken.extend(function (docModel, label, sheetRef) {
 
         // base constructor
         SheetRefToken.call(this, 'macro', docModel, sheetRef, null, null);
@@ -1753,7 +1754,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // private properties
         this._value = label;
 
-    } }); // class MacroToken
+    }); // class MacroToken
 
     // public methods ---------------------------------------------------------
 
@@ -1775,10 +1776,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {SheetRef|Null} [options.sheet1Ref]
+     *  - {SheetRef|Null} [options.sheet1Ref]
      *      An arbitrary sheet reference to be used instead of the own sheet
      *      reference.
-     *  @param {String} [options.label]
+     *  - {String} [options.label]
      *      An arbitrary label to be used to generate the text representation.
      */
     MacroToken.prototype.getText = function (formulaGrammar, options) {
@@ -1812,29 +1813,29 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptions.regionKey]
+     *  - {String} [initOptions.regionKey]
      *      The resource key of a table region. If omitted, the default region
      *      'DATA' will be referred by the token. Additionally, the combined
      *      regions 'HEADER,DATA' and 'DATA,TOTALS' will be accepted.
-     *  @param {String} [initOptions.col1Name]
+     *  - {String} [initOptions.col1Name]
      *      The name of a single table column referred by this token, or the
      *      name of the first column in a column range. If omitted, the token
      *      will refer to all columns of the table.
-     *  @param {String} [initOptions.col2Name]
+     *  - {String} [initOptions.col2Name]
      *      The name of the second column in a column range. If omitted, the
      *      token will refer to a single column, or all columns of the table.
-     *  @param {Boolean} [initOptions.openWs=false]
+     *  - {Boolean} [initOptions.openWs=false]
      *      Whether to add a space characters after the opening bracket when
      *      generating the text representation of this token.
-     *  @param {Boolean} [initOptions.closeWs=false]
+     *  - {Boolean} [initOptions.closeWs=false]
      *      Whether to add a space characters before the closing bracket when
      *      generating the text representation of this token.
-     *  @param {Boolean} [initOptions.sepWs=false]
+     *  - {Boolean} [initOptions.sepWs=false]
      *      Whether to add a space characters after each separator character
      *      inside a complex table reference when generating the text
      *      representation of this token.
      */
-    var TableToken = BaseToken.extend({ constructor: function (docModel, tableName, initOptions) {
+    var TableToken = BaseToken.extend(function (docModel, tableName, initOptions) {
 
         // base constructor
         BaseToken.call(this, 'table');
@@ -1850,7 +1851,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         this._closeWs = Utils.getBooleanOption(initOptions, 'closeWs', false);
         this._sepWs = Utils.getBooleanOption(initOptions, 'sepWs', false);
 
-    } }); // class TableToken
+    }); // class TableToken
 
     // private methods --------------------------------------------------------
 
@@ -1985,7 +1986,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.tableName]
+     *  - {String} [options.tableName]
      *      An arbitrary table name to be inserted into the text representation
      *      instead of the own table name.
      */
