@@ -13,14 +13,14 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/utils/complex', [
+    'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/errorcode',
     'io.ox/office/spreadsheet/model/formula/utils/mathutils'
-], function (ErrorCode, MathUtils) {
+], function (Utils, ErrorCode, MathUtils) {
 
     'use strict';
 
     // shortcuts to mathematical functions
-    var sqrt = Math.sqrt;
     var exp = Math.exp;
     var log = Math.log;
     var pow = Math.pow;
@@ -205,7 +205,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/complex', [
      *  The absolute value of this complex number.
      */
     Complex.prototype.abs = function () {
-        return sqrt(this.real * this.real + this.imag * this.imag);
+        return Utils.radius(this.real, this.imag);
     };
 
     /**
