@@ -161,6 +161,22 @@ define('io.ox/office/spreadsheet/model/formula/utils/mathutils', [
         return number1 + number2;
     };
 
+    /**
+     * Returns the difference of the passed numbers (useful for callbacks).
+     *
+     * @param {Number} number1
+     *  The minuend.
+     *
+     * @param {Number} number2
+     *  The subtrahend.
+     *
+     * @returns {Number}
+     *  The difference of the passed numbers.
+     */
+    MathUtils.sub = function (number1, number2) {
+        return number1 - number2;
+    };
+
     /**
      * Returns the product of the passed numbers (useful for callbacks).
      *
@@ -407,7 +423,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/mathutils', [
     };
 
     /**
-     * Returns the factorial of the passed number. Throws the #NUM! error code,
+     * Returns the factorial of the passed number. Throws the error code #NUM!,
      * if the passed number is negative or too large.
      *
      * @param {Number} number
@@ -440,6 +456,45 @@ define('io.ox/office/spreadsheet/model/formula/utils/mathutils', [
         };
     }());
 
+    /**
+     * Returns the double factorial of the passed number. Throws the error code
+     * #NUM!, if the passed number is negative or too large.
+     *
+     * @param {Number} number
+     *  The number to calculate the double factorial for.
+     *
+     * @returns {Number}
+     *  The double factorial of the passed number.
+     *
+     * @throws {ErrorCode}
+     *  The #NUM! error code, if the passed number is negative, or too large.
+     */
+    MathUtils.factorial2 = (function () {
+
+        // create and return the cache for all available factorials from 0 to 170
+        var getFactorials = _.once(function () {
+            var FACTORIALS = [];
+            var fact1 = 1;
+            var fact2 = 1;
+            while (isFinite(fact1)) {
+                FACTORIALS.push(fact1);
+                fact1 *= (FACTORIALS.length + 1);
+                if (isFinite(fact2)) {
+                    FACTORIALS.push(fact2);
+                    fact2 *= (FACTORIALS.length + 1);
+                }
+            }
+            return FACTORIALS;
+        });
+
+        // public implementation, will cause to create the cached factorials on first call
+        return function factorial2(number) {
+            var fact = getFactorials()[floor(number)];
+            if (!fact) { throw ErrorCode.NUM; }
+            return fact;
+        };
+    }());
+
     /**
      * Returns the binomial coefficient of the passed input values.
      *
