@@ -13,15 +13,18 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/errorcode',
     'io.ox/office/spreadsheet/utils/address',
     'io.ox/office/spreadsheet/model/formula/utils/scalar',
     'io.ox/office/spreadsheet/model/formula/utils/dimension'
-], function (IteratorUtils, ErrorCode, Address, Scalar, Dimension) {
+], function (Iterator, ErrorCode, Address, Scalar, Dimension) {
 
     'use strict';
 
+    // convenience shortcuts
+    var NestedIterator = Iterator.NestedIterator;
+
     // class Matrix ===========================================================
 
     /**
@@ -48,7 +51,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
      * Maximum number of elements supported in matrixes.
      *
      * @constant
-     * @type {Number}
+     * @type Number
      */
     Matrix.MAX_SIZE = 10000;
 
@@ -314,34 +317,6 @@ define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
         return ((row < rows) && (col < cols)) ? this._array[row][col] : ErrorCode.NA;
     };
 
-    /**
-     * Returns the specified row vector of this matrix.
-     *
-     * @param {Number} row
-     *  The zero-based row index of the vector. MUST be a valid index (not
-     *  negative, less than the number of rows in the matrix).
-     *
-     * @returns {Array<Number|String|Boolean|ErrorCode|Null>}
-     *  The specified row vector of this matrix.
-     */
-    Matrix.prototype.getRow = function (row) {
-        return this._array[row].slice();
-    };
-
-    /**
-     * Returns the specified column vector of this matrix.
-     *
-     * @param {Number} col
-     *  The zero-based column index of the vector. MUST be a valid index (not
-     *  negative, less than the number of columns in the matrix).
-     *
-     * @returns {Array<Number|String|Boolean|ErrorCode|Null>}
-     *  The specified column vector of this matrix.
-     */
-    Matrix.prototype.getCol = function (col) {
-        return this._array.map(function (row) { return row[col]; });
-    };
-
     /**
      * Returns the value of the specified element in this matrix.
      *
@@ -357,6 +332,62 @@ define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
         return this._array[Math.floor(index / cols)][index % cols];
     };
 
+    /**
+     * Returns the specified row vector of this matrix as plain JS array.
+     *
+     * @param {Number} row
+     *  The zero-based row index of the vector. MUST be a valid index (not
+     *  negative, less than the number of rows in the matrix).
+     *
+     * @returns {Array<Number|String|Boolean|ErrorCode|Null>}
+     *  The specified row vector of this matrix.
+     */
+    Matrix.prototype.getRowAsArray = function (row) {
+        return this._array[row].slice();
+    };
+
+    /**
+     * Returns the specified row vector of this matrix.
+     *
+     * @param {Number} row
+     *  The zero-based row index of the vector. MUST be a valid index (not
+     *  negative, less than the number of rows in the matrix).
+     *
+     * @returns {Matrix}
+     *  The specified row vector of this matrix.
+     */
+    Matrix.prototype.getRowVector = function (row) {
+        return Matrix.createRowVector(this.getRowAsArray(row));
+    };
+
+    /**
+     * Returns the specified column vector of this matrix as plain JS array.
+     *
+     * @param {Number} col
+     *  The zero-based column index of the vector. MUST be a valid index (not
+     *  negative, less than the number of columns in the matrix).
+     *
+     * @returns {Array<Number|String|Boolean|ErrorCode|Null>}
+     *  The specified column vector of this matrix.
+     */
+    Matrix.prototype.getColAsArray = function (col) {
+        return this._array.map(function (row) { return row[col]; });
+    };
+
+    /**
+     * Returns the specified column vector of this matrix as plain JS array.
+     *
+     * @param {Number} col
+     *  The zero-based column index of the vector. MUST be a valid index (not
+     *  negative, less than the number of columns in the matrix).
+     *
+     * @returns {Array<Number|String|Boolean|ErrorCode|Null>}
+     *  The specified column vector of this matrix.
+     */
+    Matrix.prototype.getColVector = function (col) {
+        return Matrix.createColVector(this.getColAsArray(col));
+    };
+
     /**
      * Changes the value of the specified element in this matrix.
      *
@@ -531,14 +562,9 @@ define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
      * Creates an iterator that visits all elements contained in this matrix.
      * The elements will be visited row-by-row.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the matrix elements have been visited completely.
-     *      No more elements are available; this result object does not contain
-     *      any other properties!
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Number|String|Boolean|ErrorCode|Null} value
      *      The value of the current matrix element.
      *  - {Number} row
@@ -547,15 +573,10 @@ define('io.ox/office/spreadsheet/model/formula/utils/matrix', [
      *      The zero-based column index of the matrix element.
      */
     Matrix.prototype.iterator = function () {
-
-        // combines the results of the outer row iterator, and the inner element iterator
-        function createIteratorResult(rowResult, colResult) {
+        // create a nested iterator that visits the matrix rows (outer), and the elements in a row (inner)
+        return new NestedIterator(this._array, _.identity, function (rowResult, colResult) {
             return { value: colResult.value, row: rowResult.index, col: colResult.index };
-        }
-
-        // create a nested iterator, that visits the matrix rows (outer), and the elements in a row (inner)
-        var rowIterator = IteratorUtils.createArrayIterator(this._array);
-        return IteratorUtils.createNestedIterator(rowIterator, IteratorUtils.createArrayIterator, createIteratorResult);
+        });
     };
 
     /**
