@@ -155,7 +155,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
      * (for example, strings are always considered to be greater than numbers).
      *
      * @constant
-     * @type {Object<Number>}
+     * @type Object<Number>
      *
      * @property {Number} NULL
      *  Type specifier for the special value null representing a blank cell or
@@ -274,7 +274,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.withCase=false]
+     *  - {Boolean} [options.withCase=false]
      *      If set to true, the strings will be compared case-sensitively.
      *
      * @returns {Boolean}
@@ -298,10 +298,10 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.withCase=false]
+     *  - {Boolean} [options.withCase=false]
      *      If set to true, strings will be compared case-sensitively. By
      *      default, the character case of strings will be ignored.
-     *  @param {Boolean} [options.nullMode='convert']
+     *  - {Boolean} [options.nullMode='convert']
      *      Specifies what happens, if one of the passed values is null, and
      *      the other value is not null (two null values are always equal):
      *      - 'convert' (default): The null value will be replaced with the
@@ -386,7 +386,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.withCase=false]
+     *  - {Boolean} [options.withCase=false]
      *      If set to true, the strings will be compared case-sensitively.
      *      Capital letters will be considered greater than their lower-case
      *      variants. By default, the character case of the strings will be
@@ -447,8 +447,8 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
         }
 
         // compare the strings case-insensitively
-        string1 = string1.toUpperCase();
-        string2 = string2.toUpperCase();
+        string1 = string1.toLowerCase();
+        string2 = string2.toLowerCase();
         return (string1 < string2) ? -1 : (string1 > string2) ? 1 : 0;
     };
 
@@ -507,11 +507,11 @@ define('io.ox/office/spreadsheet/model/formula/utils/scalar', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.withCase=false]
+     *  - {Boolean} [options.withCase=false]
      *      If set to true, strings will be compared case-sensitively. Capital
      *      letters will be considered greater than their lower-case variants.
      *      By default, the character case of strings will be ignored.
-     *  @param {Boolean} [options.nullMode='convert']
+     *  - {Boolean} [options.nullMode='convert']
      *      Specifies what happens, if one of the passed values is null, and
      *      the other value is not null (two null values are always equal):
      *      - 'convert' (default): The null value will be replaced with the
