@@ -62,7 +62,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/sheetref', function () {
      *  The error code of a reference error, used a sheet has been deleted,
      *  e.g. in the formula =#REF!!A1.
      *
-     * @property {Boolean} abs
+     * @param {Boolean} abs
      *  Whether the sheet reference will be marked to be absolute.
      *
      * @returns {SheetRef|Null}
@@ -152,11 +152,11 @@ define('io.ox/office/spreadsheet/model/formula/utils/sheetref', function () {
      *  The document model needed to resolve sheet names.
      *
      * @returns {String|Null}
-     *  The original name of the sheet referred by theis sheet reference; or
+     *  The original name of the sheet referred by this sheet reference; or
      *  null, if this sheet reference cannot be resolved to a sheet name.
      */
-    SheetRef.prototype.resolve = function (docModel) {
-        return (typeof this.sheet === 'number') ? docModel.getSheetName(this.sheet) : this.sheet;
+    SheetRef.prototype.resolve = function (docModel, extDocRef) {
+        return (typeof this.sheet !== 'number') ? this.sheet : extDocRef ? null : docModel.getSheetName(this.sheet);
     };
 
     /**
