@@ -14,14 +14,18 @@
  */
 
 define('io.ox/office/spreadsheet/model/mergecollection', [
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/usedrangecollection'
-], function (ValueMap, SheetUtils, UsedRangeCollection) {
+], function (Iterator, ValueMap, SheetUtils, UsedRangeCollection) {
 
     'use strict';
 
+    // constants ==============================================================
+
     // convenience shortcuts
+    var IndexIterator = Iterator.IndexIterator;
     var MergeMode = SheetUtils.MergeMode;
     var Address = SheetUtils.Address;
     var AddressSet = SheetUtils.AddressSet;
@@ -150,19 +154,22 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         }
 
         /**
-         * Generates the 'mergeCells' operation needed to restore the specified
-         * merged cell ranges. The number of generated operations will be
-         * minimized by grouping consecutive single column ranges and single
-         * row ranges into merge operations with merge type 'horizontal' or
-         * 'vertical'.
+         * Generates the "mergeCells" undo operations needed to restore the
+         * specified merged cell ranges. The number of generated operations
+         * will be minimized by grouping consecutive single column ranges and
+         * single row ranges into merge operations with merge type "horizontal"
+         * or "vertical".
          *
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray} ranges
          *  An array of addresses of merged cell ranges.
+         *
+         * @param {Object} [options]
+         *  Optional parameters for the operation generator.
          */
-        function generateRestoreOperations(generator, ranges) {
+        function generateRangesOperations(generator, ranges, options) {
 
             // generate 'vertical' or 'horizontal' merge operations for single-column/single-row ranges
             function collectAndGenerateOperations(singleRanges, columns) {
@@ -191,7 +198,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                     // create one operation for all adjacent merged ranges
                     var compoundRange = columns ? range1.colRange(0, count) : range1.rowRange(0, count);
-                    generator.generateMergeCellsOperation(compoundRange, (count > 1) ? mergeMode : MergeMode.MERGE, { undo: true });
+                    generator.generateMergeCellsOperation(compoundRange, (count > 1) ? mergeMode : MergeMode.MERGE, options);
                 }
             }
 
@@ -213,7 +220,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // generate undo operations for two-dimensional ranges directly
             if (rangeGroups.range) {
                 rangeGroups.range.forEach(function (range) {
-                    generator.generateMergeCellsOperation(range, MergeMode.MERGE, { undo: true });
+                    generator.generateMergeCellsOperation(range, MergeMode.MERGE, options);
                 });
             }
         }
@@ -335,7 +342,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         this.applyMergeCellsOperation = function (context) {
 
             // the range covered by the operation
-            var range = context.getRange();
+            var range = context.getJSONRange();
             // the method how to merge/unmerge the operation range
             var mergeMode = context.getOptEnum('type', MergeMode, MergeMode.MERGE);
             // all merged ranges deleted from the collection
@@ -351,7 +358,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
             // implicitly remove all merged ranges that overlap with the passed range,
             // regardless of passed type (needed to merge over merged ranges)
-            mergedRangeSet.findRanges(range).forEach(function (mergedRange) {
+            mergedRangeSet.findAll(range).forEach(function (mergedRange) {
                 removeMergedRange(mergedRange);
                 removedRanges.push(mergedRange);
             });
@@ -527,10 +534,31 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
             // find a merged range covering the passed address (it will not start at that address, otherwise
             // it would have been found above, therefore return it for search types 'hidden' and 'all')
-            mergedRange = mergedRangeSet.findByAddress(address).first();
+            mergedRange = mergedRangeSet.findOneByAddress(address);
             return mergedRange ? mergedRange.clone() : null;
         };
 
+        /**
+         * Returns whether any of the passed cell ranges overlaps with at least
+         * one merged cell range in this collection.
+         *
+         * @param {RangeArray|Range} ranges
+         *  An array of cell range addresses, or a single cell range address.
+         *
+         * @param {String} [matchType]
+         *  Specifies which merged ranges from this collection will match. See
+         *  method RangeSet.findIterator() for details.
+         *
+         * @returns {Boolean}
+         *  Whether any of the passed cell ranges contains or overlaps with at
+         *  least one merged cell range.
+         */
+        this.coversAnyMergedRange = function (ranges, matchType) {
+            return RangeArray.some(ranges, function (range) {
+                return mergedRangeSet.findOne(range, matchType);
+            });
+        };
+
         /**
          * Returns the range addresses of all merged cell ranges that overlap
          * with one of the passed ranges.
@@ -538,45 +566,18 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          * @param {RangeArray|Range} ranges
          *  An array of cell range addresses, or a single cell range address.
          *
-         * @param {String} [type='all']
-         *  If set to 'all' or omitted, returns all merged ranges that overlap
-         *  the passed ranges with any cell. If set to 'contain', returns only
-         *  merged ranges that are completely contained in any of the passed
-         *  ranges. If set to 'reference', returns only merged ranges whose
-         *  reference cell is contained in any of the passed ranges.
+         * @param {String} [matchType]
+         *  Specifies which merged ranges from this collection will match. See
+         *  method RangeSet.findIterator() for details.
          *
          * @returns {RangeArray}
          *  The range addresses of all merged ranges that overlap with one of
          *  the passed ranges.
          */
-        this.getMergedRanges = function (ranges, type) {
-
-            // the resulting merged ranges
-            var resultRanges = new RangeArray();
-
-            // process all passed ranges
-            RangeArray.forEach(ranges, function (range) {
-
-                // find all merged ranges overlapping with the current range
-                mergedRangeSet.findRanges(range).forEach(function (mergedRange) {
-                    switch (type) {
-                        case 'reference':
-                            if (range.containsAddress(mergedRange.start)) {
-                                resultRanges.push(mergedRange);
-                            }
-                            break;
-                        case 'contain':
-                            if (range.contains(mergedRange)) {
-                                resultRanges.push(mergedRange);
-                            }
-                            break;
-                        default:
-                            resultRanges.push(mergedRange);
-                    }
-                });
+        this.getMergedRanges = function (ranges, matchType) {
+            return RangeArray.map(ranges, function (range) {
+                return mergedRangeSet.findAll(range, matchType);
             });
-
-            return resultRanges;
         };
 
         /**
@@ -595,27 +596,10 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         this.getBoundingMergedRange = function (range) {
             // if the first found overlapping merged range does not contain the range, no other
             // merged range can contain it either because merged ranges do not overlap each other
-            var mergedRange = mergedRangeSet.findRanges(range).first();
+            var mergedRange = mergedRangeSet.findOne(range);
             return (mergedRange && mergedRange.contains(range)) ? mergedRange.clone() : null;
         };
 
-        /**
-         * Returns whether any of the passed cell ranges overlaps with at least
-         * one merged cell range.
-         *
-         * @param {RangeArray|Range} ranges
-         *  An array of cell range addresses, or a single cell range address.
-         *
-         * @returns {Boolean}
-         *  Whether any of the passed cell ranges contains or overlaps with at
-         *  least one merged cell range.
-         */
-        this.rangesOverlapAnyMergedRange = function (ranges) {
-            return RangeArray.some(ranges, function (range) {
-                return mergedRangeSet.overlaps(range);
-            });
-        };
-
         /**
          * Expands the passed range address, so that it will include all merged
          * ranges it is currently covering partly.
@@ -637,7 +621,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                 // find all merged ranges overlapping with the current range, return the
                 // current range address if no more merged ranges can be found
-                var mergedRanges = pendingRangeSet.findRanges(range);
+                var mergedRanges = pendingRangeSet.findAll(range);
                 if (mergedRanges.empty()) { return range.clone(); }
 
                 // expand the range to all merged ranges, remove them from 'pendingRangeSet'
@@ -671,13 +655,12 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                 // outer cells of the passed range
                 var borderRange = columns ? oldRange.leadingCol() : oldRange.headerRow();
-                // the merged ranges overlapping with the passed border range
-                var mergedRanges = mergedRangeSet.findRanges(borderRange);
                 // copy of the passed range that will be shrunken
                 var newRange = oldRange.clone();
 
                 // reduce the passed range by all found merged ranges that are jutting out
-                mergedRanges.every(function (mergedRange) {
+                var iterator = mergedRangeSet.findIterator(borderRange);
+                Iterator.every(iterator, function (mergedRange) {
                     if (mergedRange.getStart(columns) < oldRange.getStart(columns)) {
                         var index = Math.max(newRange.getStart(columns), mergedRange.getEnd(columns) + 1);
                         if (index > newRange.getEnd(columns)) {
@@ -697,13 +680,12 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                 // outer cells of the passed range
                 var borderRange = columns ? oldRange.trailingCol() : oldRange.footerRow();
-                // the merged ranges overlapping with the passed border range
-                var mergedRanges = mergedRangeSet.findRanges(borderRange);
                 // copy of the passed range that will be shrunken
                 var newRange = oldRange.clone();
 
                 // reduce the passed range by all found merged ranges that are jutting out
-                mergedRanges.every(function (mergedRange) {
+                var iterator = mergedRangeSet.findIterator(borderRange);
+                Iterator.every(iterator, function (mergedRange) {
                     if (oldRange.getEnd(columns) < mergedRange.getEnd(columns)) {
                         var index = Math.min(newRange.getEnd(columns), mergedRange.getStart(columns) - 1);
                         if (index < newRange.getStart(columns)) {
@@ -891,7 +873,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // and add all old merged ranges to the undo generator that need to be restored
             return promise.then(function () {
                 generator.appendOperations(generator2, { undo: true });
-                generateRestoreOperations(generator, restoreRanges);
+                generateRangesOperations(generator, restoreRanges, { undo: true });
             });
         };
 
@@ -929,52 +911,76 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
             // add all merged ranges to the undo generator that need to be restored
             return promise.done(function () {
-                generateRestoreOperations(generator, restoreRanges);
+                generateRangesOperations(generator, restoreRanges, { undo: true });
             });
         };
 
         /**
+         * Generates the operations, and the undo operations, to repeatedly
+         * copy the merged ranges from the source range into the specified
+         * direction.
          *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {Range} range
+         *  The address of the source cell range to be copied.
+         *
+         * @param {Direction} direction
+         *  The direction in which the specified cell range will be expanded.
+         *
+         * @param {Number} count
+         *  The number of columns/rows to extend the cell range into the
+         *  specified direction.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved, when all operations have been
+         *  generated.
          */
-        this.generateAutoFillOperations = SheetUtils.profileAsyncMethod('MergeCollection.generateAutoFillOperations()', function (generator, sourceRange, targetRange, columns, reverse) {
+        this.generateAutoFillOperations = SheetUtils.profileAsyncMethod('MergeCollection.generateAutoFillOperations()', function (generator, range, direction, count) {
 
-            function prepareNewMergedRanges(baseRange) {
-                var newMergedRange = baseRange.clone(),
-                    multiplikator = reverse ? -1 : 1;
+            // the merged ranges to be copied
+            var mergedRanges = this.getMergedRanges(range, 'contain');
+            // the target range to be filled with the merged ranges
+            var targetRange = SheetUtils.getAdjacentRange(range, direction, count);
 
-                newMergedRange.moveBoth(start_col, true);
-                newMergedRange.moveBoth(start_row, false);
-                newMergedRange.moveBoth((targetMerge * sourceSize) * multiplikator, !columns);
-                op_mergedRanges.push(newMergedRange);
+            // first step for undo: delete the merged ranges generated by auto-fill
+            if (!mergedRanges.empty()) {
+                generator.generateMergeCellsOperation(targetRange, MergeMode.UNMERGE, { undo: true });
             }
 
-            var sourceSize              = sourceRange.size(!columns),
-                targetSize              = targetRange.size(!columns),
-                targetMerge             = targetSize / sourceSize,
-                start_col               = sourceRange.start[0],
-                start_row               = sourceRange.start[1],
-                mergedRanges            = self.getMergedRanges(sourceRange, 'contain'),
-                cleanedUpMergedRanges   = [],
-                op_mergedRanges         = new RangeArray();
+            // delete all existing merged ranges from target range (and generate all undo operations to restore them)
+            var promise = this.coversAnyMergedRange(targetRange) ?
+                this.generateMergeCellsOperations(generator, targetRange, MergeMode.UNMERGE) :
+                this.createResolvedPromise();
 
-            mergedRanges.forEach(function (mergedRange) {
-                var currentRange     = mergedRange.clone();
+            // nothing more to do, if no merged ranges exist in the source range
+            if (mergedRanges.empty()) { return promise; }
 
-                currentRange.setStart((currentRange.start[0] - start_col), true);
-                currentRange.setEnd((currentRange.end[0] - start_col), true);
+            // generate the operations to copy the merged ranges
+            promise = promise.then(function () {
 
-                currentRange.setStart((currentRange.start[1] - start_row), false);
-                currentRange.setEnd((currentRange.end[1] - start_row), false);
+                // number of repetitions
+                var columns = !SheetUtils.isVerticalDir(direction);
+                var size = range.size(columns);
+                var cycles = Math.floor(count / size);
+                if (cycles === 0) { return promise; }
 
-                cleanedUpMergedRanges.push(currentRange);
+                // create all merged ranges for the target range
+                var sign = SheetUtils.isLeadingDir(direction) ? -1 : 1;
+                var newMergedRanges = new RangeArray();
+                Iterator.forEach(new IndexIterator(cycles, { offset: 1 }), function (cycle) {
+                    var diff = sign * cycle * size;
+                    mergedRanges.forEach(function (mergedRange) {
+                        newMergedRanges.push(mergedRange.clone().moveBoth(diff, columns));
+                    });
+                });
+
+                // generate the operations (but no undo operations, has been done above already)
+                generateRangesOperations(generator, newMergedRanges);
             });
 
-            while (targetMerge > 0) {
-                cleanedUpMergedRanges.forEach(prepareNewMergedRanges);
-                targetMerge--;
-            }
-
-            return this.generateMergeCellsOperations(generator, op_mergedRanges, MergeMode.MERGE);
+            return promise;
         });
 
         // initialization -----------------------------------------------------
