@@ -845,26 +845,6 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         return fontSizes;
     });
 
-    // private global functions ===============================================
-
-    /**
-     * Returns the precalculated row height for the passed font settings.
-     *
-     * @param {Object} charAttributes
-     *  Character formatting attributes influencing the row height, as used in
-     *  document operations.
-     *
-     * @returns {Number|Null}
-     *  The precalculated row height for the passed font settings, in pixels;
-     *  or null, if no row height is available for the passed font settings.
-     */
-    function getPresetRowHeight(charAttributes) {
-        var presetRowHeights = PIXEL_ROW_HEIGHT_MAP[charAttributes.fontName.toLowerCase()];
-        if (!presetRowHeights) { return null; }
-        var fontSize = Math.round(charAttributes.fontSize);
-        return presetRowHeights[fontSize] || _.last(presetRowHeights);
-    }
-
     // class ModelAttributesMixin =============================================
 
     /**
@@ -891,6 +871,9 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         // the auto-style collection for cells, columns, and rows
         var cellAutoStyles = null;
 
+        // the style sheet collection for table ranges
+        var tableStyles = null;
+
         // shortcut to the drawing attribute pool
         var drawingAttrPool = null;
 
@@ -922,6 +905,26 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return rowHeightFactor || (rowHeightFactor = ooxml ? (100 * Utils.convertLength(1, 'pt', 'mm')) : 1);
         }
 
+        /**
+         * Returns the precalculated row height for the passed font settings.
+         *
+         * @param {Object} charAttributes
+         *  Character formatting attributes influencing the row height, as used
+         *  in document operations.
+         *
+         * @returns {Number|Null}
+         *  The precalculated row height for the passed font settings, in
+         *  pixels; or null, if no row height is available for the passed font
+         *  settings.
+         */
+        function getPresetRowHeight(charAttributes) {
+            var fontName = self.resolveFontName(charAttributes.fontName);
+            var presetRowHeights = PIXEL_ROW_HEIGHT_MAP[fontName.toLowerCase()];
+            if (!presetRowHeights) { return null; }
+            var fontSize = Math.round(charAttributes.fontSize);
+            return presetRowHeights[fontSize] || _.last(presetRowHeights);
+        }
+
         /**
          * Calculates the row height in 1/100 of millimeters to be used for the
          * passed character attributes.
@@ -975,6 +978,16 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return cellAutoStyles;
         };
 
+        /**
+         * Returns the style collection for table ranges of this document.
+         *
+         * @returns {TableStyleCollection}
+         *  The style collection for table ranges of this document.
+         */
+        this.getTableStyles = function () {
+            return tableStyles;
+        };
+
         /**
          * Returns the attribute pool for drawing formatting attributes used by
          * the spreadsheet model. Used to be able to distinguish cell character
@@ -1209,6 +1222,47 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return Utils.convertHmmToLength(calculateRowHeightHmm(charAttributes) * zoom, 'px', 1);
         };
 
+        /**
+         * Extends the passed attribute set in-place with formatting attributes
+         * resolved from a table style sheet. These attributes will be merged
+         * "under" the explicit attributes.
+         *
+         * @param {Object} attributeSet
+         *  The (incomplete) attribute set to be extended in-place with the
+         *  passed table style attributes.
+         *
+         * @param {Object} mergedAttributeSet
+         *  The (complete) merged attribute set used to decide whether the
+         *  passed table attributes will become part of the extended attribute
+         *  set. Only the attributes where this merged attribute set contains
+         *  the same values as the default auto-style can be extended with the
+         *  table style attributes.
+         *
+         * @param {Object} tableAttributeSet
+         *  The attribute set resolved from a table style sheet to be merged
+         *  into the passed (incomplete) attribute set.
+         *
+         * @returns {Object}
+         *  The attribute set passed to this method, that has been extended
+         *  in-place.
+         */
+        this.extendWithTableAttributeSet = function (attributeSet, mergedAttributeSet, tableAttributeSet) {
+            var defaultAttrSet = cellAutoStyles.getDefaultAttributeSet();
+            _.forEach(tableAttributeSet, function (tableAttrs, family) {
+                if (family in mergedAttributeSet) {
+                    var targetAttrs = attributeSet[family] || (attributeSet[family] = {});
+                    var mergedAttrs = mergedAttributeSet[family];
+                    var defaultAttrs = defaultAttrSet[family];
+                    _.forEach(tableAttrs, function (value, name) {
+                        if ((name in mergedAttrs) && _.isEqual(mergedAttrs[name], defaultAttrs[name])) {
+                            targetAttrs[name] = value;
+                        }
+                    });
+                }
+            });
+            return attributeSet;
+        };
+
         // initialization -----------------------------------------------------
 
         // global document attributes registration
@@ -1235,7 +1289,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         this.addStyleCollection(cellStyles = new CellStyleCollection(this));
         this.addStyleCollection(drawingStyles = new DrawingStyleCollection(this));
         this.addStyleCollection(new PageStyleCollection(this));
-        this.addStyleCollection(new TableStyleCollection(this));
+        this.addStyleCollection(tableStyles = new TableStyleCollection(this));
 
         // style collections needed for text in shapes
         this.addStyleCollection(new CharacterStyleCollection(this));
@@ -1266,7 +1320,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = cellAttrPool = cellStyles = cellAutoStyles = drawingStyles = drawingAttrPool = null;
+            self = cellAttrPool = cellStyles = cellAutoStyles = tableStyles = drawingStyles = drawingAttrPool = null;
         });
 
     } // class ModelAttributesMixin
