@@ -13,11 +13,16 @@
  */
 
 define('io.ox/office/spreadsheet/model/operationcontext', [
-    'io.ox/office/editframework/model/operationcontext'
-], function (OperationContext) {
+    'io.ox/office/editframework/model/operationcontext',
+    'io.ox/office/spreadsheet/utils/sheetutils'
+], function (OperationContext, SheetUtils) {
 
     'use strict';
 
+    // convenience shortcuts
+    var Address = SheetUtils.Address;
+    var AddressArray = SheetUtils.AddressArray;
+
     // class SheetOperationContext ============================================
 
     /**
@@ -31,10 +36,121 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      */
     var SheetOperationContext = OperationContext.extend(function (docModel, operation, external, importing) {
         OperationContext.call(this, docModel, operation, external, importing);
+        this._maxAddress = docModel.getMaxAddress();
     }); // class SheetOperationContext
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Parses a cell address from a string in A1 notation.
+     *
+     * @param {string} parseStr
+     *  The string to be parsed.
+     *
+     * @returns {Address}
+     *  The parsed cell address.
+     *
+     * @throws {OperationError}
+     *  If the passed string cannot be parsed to a valid cell address.
+     */
+    SheetOperationContext.prototype.parseAddress = function (parseStr) {
+        var address = Address.parse(parseStr, this._maxAddress);
+        this.ensure(address, 'invalid cell address %s', parseStr);
+        return address;
+    };
+
+    /**
+     * Returns the value of a required cell address property (as string in A1
+     * notation) of the wrapped JSON operation.
+     *
+     * @param {string} propName
+     *  The name of the operation property.
+     *
+     * @returns {Address}
+     *  The cell address of the specified operation property.
+     *
+     * @throws {OperationError}
+     *  If the wrapped operation does not contain a valid cell address property
+     *  with the specified name.
+     */
+    SheetOperationContext.prototype.getAddress = function (propName) {
+        return this.parseAddress(this.getStr(propName));
+    };
+
+    /**
+     * Returns the value of an optional cell address property (as string in A1
+     * notation) of the wrapped JSON operation.
+     *
+     * @param {string} propName
+     *  The name of the operation property.
+     *
+     * @returns {Address|null}
+     *  The cell address of the specified operation property; or null, if the
+     *  property is missing.
+     *
+     * @throws {OperationError}
+     *  If the wrapped operation contains a property with the specified name,
+     *  but the property value is not a valid cell address.
+     */
+    SheetOperationContext.prototype.getOptAddress = function (propName) {
+        return this.has(propName) ? this.getAddress(propName) : null;
+    };
+
+    /**
+     * Parses a cell address list from a string of space-separated addresses in
+     * A1 notation).
+     *
+     * @param {string} parseStr
+     *  The string to be parsed.
+     *
+     * @returns {AddressArray}
+     *  The list of cell addresses.
+     *
+     * @throws {OperationError}
+     *  If the passed string cannot be parsed to a valid cell address list.
+     */
+    SheetOperationContext.prototype.parseAddressList = function (parseStr) {
+        return AddressArray.map(parseStr.split(/\s+/), this.parseAddress, this);
+    };
+
+    /**
+     * Returns the value of a required cell address list property (as string of
+     * space-separated addresses in A1 notation) of the wrapped JSON operation.
+     *
+     * @param {string} propName
+     *  The name of the operation property.
+     *
+     * @returns {AddressArray}
+     *  The list of cell addresses of the specified operation property.
+     *
+     * @throws {OperationError}
+     *  If the wrapped operation does not contain a valid cell address list
+     *  property with the specified name.
+     */
+    SheetOperationContext.prototype.getAddressList = function (propName) {
+        return this.parseAddressList(this.getStr(propName));
+    };
+
+    /**
+     * Returns the value of an optional cell address list property (as string
+     * of space-separated addresses in A1 notation) of the wrapped JSON
+     * operation.
+     *
+     * @param {string} propName
+     *  The name of the operation property.
+     *
+     * @returns {AddressArray|null}
+     *  The list of cell addresses of the specified operation property; or
+     *  null, if the property is missing.
+     *
+     * @throws {OperationError}
+     *  If the wrapped operation contains a property with the specified name,
+     *  but the property value is not a valid cell address list.
+     */
+    SheetOperationContext.prototype.getOptAddressList = function (propName) {
+        return this.has(propName) ? this.getAddressList(propName) : null;
+    };
+
     /**
      * Returns the value of a required column/row interval property of the
      * wrapped JSON operation. The property must be an object with the property
@@ -59,10 +175,10 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation does not contain a valid column/row interval
      *  property with the specified name.
      */
-    SheetOperationContext.prototype.getInterval = function (propName, columns) {
+    SheetOperationContext.prototype.getJSONInterval = function (propName, columns) {
         if (_.isBoolean(propName)) { columns = propName; propName = null; }
         this.ensure(_.isBoolean(columns), 'missing columns flag');
-        var interval = this.docModel.createInterval(propName ? this.getObj(propName) : this.operation, columns, true);
+        var interval = this.docModel.parseJSONInterval(propName ? this.getObj(propName) : this.operation, columns, true);
         this.ensure(interval, 'invalid %s interval', columns ? 'column' : 'row');
         return interval;
     };
@@ -84,14 +200,14 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation contains a property with the specified name,
      *  but the property value is not a valid column/row interval.
      */
-    SheetOperationContext.prototype.getOptInterval = function (propName, columns) {
-        return this.has(_.isBoolean(propName) ? 'start' : propName) ? this.getInterval(propName, columns) : null;
+    SheetOperationContext.prototype.getOptJSONInterval = function (propName, columns) {
+        return this.has(_.isBoolean(propName) ? 'start' : propName) ? this.getJSONInterval(propName, columns) : null;
     };
 
     /**
      * Returns the value of a required cell address property of the wrapped
-     * JSON operation. See method SpreadsheetModel.createAddress() for details
-     * about the format of valid cell addresses.
+     * JSON operation. See method SpreadsheetModel.parseJSONAddress() for
+     * details about the format of valid cell addresses.
      *
      * @param {String} [propName='start']
      *  The name of the operation property. If omitted, the standard property
@@ -104,16 +220,16 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation does not contain a valid cell address property
      *  with the specified name.
      */
-    SheetOperationContext.prototype.getAddress = function (propName) {
-        var address = this.docModel.createAddress(this.getPos(propName || 'start'));
+    SheetOperationContext.prototype.getJSONAddress = function (propName) {
+        var address = this.docModel.parseJSONAddress(this.getPos(propName || 'start'));
         this.ensure(address, 'invalid cell address');
         return address;
     };
 
     /**
      * Returns the value of an optional cell address property of the wrapped
-     * JSON operation. See method SpreadsheetModel.createAddress() for details
-     * about the format of valid cell addresses.
+     * JSON operation. See method SpreadsheetModel.parseJSONAddress() for
+     * details about the format of valid cell addresses.
      *
      * @param {String} [propName='start']
      *  The name of the operation property. If omitted, the standard property
@@ -127,13 +243,13 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation contains a property with the specified name,
      *  but the property value is not a valid cell address.
      */
-    SheetOperationContext.prototype.getOptAddress = function (propName) {
-        return this.has(propName || 'start') ? this.getAddress(propName) : null;
+    SheetOperationContext.prototype.getOptJSONAddress = function (propName) {
+        return this.has(propName || 'start') ? this.getJSONAddress(propName) : null;
     };
 
     /**
      * Returns the value of a required cell range address property of the
-     * wrapped JSON operation. See method SpreadsheetModel.createRange() for
+     * wrapped JSON operation. See method SpreadsheetModel.parseJSONRange() for
      * details about the format of valid cell range addresses.
      *
      * @param {String} [propName]
@@ -148,15 +264,15 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation does not contain a valid cell range address
      *  property with the specified name.
      */
-    SheetOperationContext.prototype.getRange = function (propName) {
-        var range = this.docModel.createRange(propName ? this.getObj(propName) : this.operation);
+    SheetOperationContext.prototype.getJSONRange = function (propName) {
+        var range = this.docModel.parseJSONRange(propName ? this.getObj(propName) : this.operation);
         this.ensure(range, 'invalid cell range address');
         return range;
     };
 
     /**
      * Returns the value of an optional cell range address property of the
-     * wrapped JSON operation. See method SpreadsheetModel.createRange() for
+     * wrapped JSON operation. See method SpreadsheetModel.parseJSONRange() for
      * details about the format of valid cell range addresses.
      *
      * @param {String} [propName]
@@ -172,13 +288,13 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation contains a property with the specified name,
      *  but the property value is not a valid cell range address.
      */
-    SheetOperationContext.prototype.getOptRange = function (propName) {
-        return this.has(propName || 'start') ? this.getRange(propName) : null;
+    SheetOperationContext.prototype.getOptJSONRange = function (propName) {
+        return this.has(propName || 'start') ? this.getJSONRange(propName) : null;
     };
 
     /**
      * Returns the value of a required cell range address array property of the
-     * wrapped JSON operation. See method SpreadsheetModel.createRangeArray()
+     * wrapped JSON operation. See method SpreadsheetModel.parseJSONRanges()
      * for details about the format of valid arrays of cell range addresses.
      *
      * @param {String} [propName='ranges']
@@ -192,15 +308,15 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation does not contain a valid cell range address
      *  array property with the specified name.
      */
-    SheetOperationContext.prototype.getRangeArray = function (propName) {
-        var ranges = this.docModel.createRangeArray(this.getArr(propName || 'ranges'));
+    SheetOperationContext.prototype.getJSONRangeList = function (propName) {
+        var ranges = this.docModel.parseJSONRanges(this.getArr(propName || 'ranges'));
         this.ensure(ranges, 'invalid cell range address array');
         return ranges;
     };
 
     /**
      * Returns the value of an optional cell range address array property of
-     * the wrapped JSON operation. See method SpreadsheetModel.createRangeArray()
+     * the wrapped JSON operation. See method SpreadsheetModel.parseJSONRanges()
      * for details about the format of valid cell range addresses.
      *
      * @param {String} [propName='ranges']
@@ -215,8 +331,8 @@ define('io.ox/office/spreadsheet/model/operationcontext', [
      *  If the wrapped operation contains a property with the specified name,
      *  but the property value is not a valid array of cell range addresses.
      */
-    SheetOperationContext.prototype.getOptRangeArray = function (propName) {
-        return this.has(propName || 'ranges') ? this.getRangeArray(propName) : null;
+    SheetOperationContext.prototype.getOptJSONRangeList = function (propName) {
+        return this.has(propName || 'ranges') ? this.getJSONRangeList(propName) : null;
     };
 
     // exports ================================================================
