@@ -23,6 +23,11 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
 
     'use strict';
 
+    // constants ==============================================================
+
+    // border keys to be processed
+    var BORDER_KEYS = 'tblrdu'.split('');
+
     // class SheetOperationGenerator ==========================================
 
     /**
@@ -362,7 +367,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      * @param {Range} range
      *  The address of the cell range addressed by the operation.
      *
-     * @param {MoveMode} moveMode
+     * @param {Direction} direction
      *  The move mode to be inserted into the 'moveCells' operation.
      *
      * @param {Object} [options]
@@ -372,8 +377,8 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      * @returns {Object}
      *  The created operation object.
      */
-    SheetOperationGenerator.prototype.generateMoveCellsOperation = function (range, moveMode, options) {
-        return this.generateRangeOperation(Operations.MOVE_CELLS, range, { dir: moveMode.toJSON() }, options);
+    SheetOperationGenerator.prototype.generateMoveCellsOperation = function (range, direction, options) {
+        return this.generateRangeOperation(Operations.MOVE_CELLS, range, { dir: direction.toJSON() }, options);
     };
 
     /**
@@ -396,6 +401,29 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
         return this.generateRangeOperation(Operations.MERGE_CELLS, range, { type: mergeMode.toJSON() }, options);
     };
 
+    /**
+     * Creates and appends a new "insertHyperlink" or "deleteHyperlink"
+     * operation.
+     *
+     * @param {Range} range
+     *  The address of the cell range addressed by the operation.
+     *
+     * @param {String|Null} url
+     *  The URL of the hyperlink to be attached to the cell range. If set to
+     *  the empty string or null, existing hyperlinks will be removed instead.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See description of the public method
+     *  SheetOperationGenerator.generateRangeOperation() for details.
+     *
+     * @returns {Object}
+     *  The created operation object.
+     */
+    SheetOperationGenerator.prototype.generateHyperlinkOperation = function (range, url, options) {
+        var opName = url ? Operations.INSERT_HYPERLINK : Operations.DELETE_HYPERLINK;
+        return this.generateRangeOperation(opName, range, url ? { url: url } : null, options);
+    };
+
     /**
      * Creates and appends a new 'moveDrawing' operation.
      *
@@ -611,7 +639,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
             var newBorderAttrs = newAttributeSet.cell;
 
             // update the existing borders of the auto-style, delete other border attributes from the attribute set
-            _.each('tblrdu', function (borderKey) {
+            BORDER_KEYS.forEach(function (borderKey) {
 
                 // nothing to do without an explicit new border attribute
                 var borderName = SheetUtils.getBorderName(borderKey);
@@ -718,7 +746,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
             var newBorderAttrs = newAttributeSet.cell;
 
             // update the existing borders of the auto-style, delete other border attributes from the attribute set
-            _.each('tblrdu', function (borderKey) {
+            BORDER_KEYS.forEach(function (borderKey) {
 
                 // nothing to do without an explicit new border attribute
                 var borderName = SheetUtils.getBorderName(borderKey);
