@@ -226,14 +226,12 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          * Additional data for the current cell range while auto-fill tracking
          * is active. Allowed values are null (auto-fill tracking not active),
          * or an object with the following properties:
-         * - {String} border
-         *      Which border of the selected range will be modified by the
-         *      auto-fill. Allowed values are 'left', 'right', 'top', or
-         *      'bottom'.
+         * - {Direction} direction
+         *      The direction in which the selected range will be expanded.
          * - {Number} count
-         *      The number of columns/rows to extend the selected range with
-         *      (positive values), or to shrink the selected range (negative
-         *      values).
+         *      The number of columns/rows to extend the selected range into
+         *      the specified direction (positive values), or to shrink the
+         *      selected range (negative values).
          * This attribute will be ignored, if the current sheet selection
          * consists of more than one cell range.
          */
@@ -1074,6 +1072,33 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             return docModel.getRowHeight(charAttributes, effectiveZoom);
         };
 
+        /**
+         * Returns the location of this sheet, either in 1/100 of millimeters,
+         * or in pixels according to the current sheet zoom factor.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {Boolean} [options.pixel=false]
+         *      If set to true, the location returned by this method will be in
+         *      pixels according to the current sheet zoom factor. Otherwise,
+         *      the location is in 1/100 of millimeters.
+         *
+         * @returns {Rectangle}
+         *  The location of the entire sheet. The rectangle always starts at
+         *  coordinates (0,0). Its size is equal to the total size of all
+         *  visible columns and rows.
+         */
+        this.getSheetRectangle = function (options) {
+
+            // whether to return pixels
+            var pixel = Utils.getBooleanOption(options, 'pixel', false);
+
+            return new Rectangle(0, 0,
+                pixel ? colCollection.getTotalSize() : colCollection.getTotalSizeHmm(),
+                pixel ? rowCollection.getTotalSize() : rowCollection.getTotalSizeHmm()
+            );
+        };
+
         /**
          * Returns the location of the passed cell range in the sheet, either
          * in 1/100 of millimeters, or in pixels according to the current sheet
@@ -1729,12 +1754,12 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
 
             // the merged sheet attributes
             var sheetAttributes = self.getMergedAttributeSet(true).sheet;
-            // all selected ranges (convert plain JSON data to RangeArray)
-            var selectedRanges = docModel.createRangeArray(sheetAttributes.selectedRanges);
+            // all selected ranges (convert plain JSON data to instance of RangeArray)
+            var selectedRanges = docModel.parseJSONRanges(sheetAttributes.selectedRanges);
             // the array index of the active range (bug 34549: filter may send invalid index)
             var activeIndex = Utils.getIntegerOption(sheetAttributes, 'activeIndex', 0);
-            // address of the active cell (convert plain JSON data to RangeArray)
-            var activeCell = docModel.createAddress(sheetAttributes.activeCell);
+            // address of the active cell (convert plain JSON data to instance of Address)
+            var activeCell = docModel.parseJSONAddress(sheetAttributes.activeCell);
             // the array of selected drawing objects
             var selectedDrawings =  Utils.getArrayOption(sheetAttributes, 'selectedDrawings', []);
             // selection, built from multiple sheet attributes, expanded to merged ranges
