@@ -738,14 +738,14 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         function getModelDescsByRanges(context) {
 
             // the target rangesof the document operation
-            var targetRanges = context.getRangeArray().merge();
+            var targetRanges = context.getJSONRangeList().merge();
             // the validation models to be returned
             var valModelSet = new ValueSet('getUid()');
 
             // process all target ranges contained in the operation
             targetRanges.forEach(function (targetRange) {
                 // get all ranges from the set covered by a validation model
-                targetRangeSet.findRanges(targetRange).forEach(function (range) {
+                targetRangeSet.findAll(targetRange).forEach(function (range) {
                     valModelSet.insert(range.valModel);
                 });
             });
@@ -887,7 +887,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         this.applyInsertOperation = function (context) {
 
             // the target ranges for the data validation
-            var targetRanges = context.getRangeArray();
+            var targetRanges = context.getJSONRangeList();
             // the validation attribute set (mapped by attribute family)
             var attributeSet = { validation: context.operation };
             // the custom reference address (as formula expression)
@@ -964,7 +964,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
                 valModel = modelDesc.model;
 
                 // resolve optional 'ranges' property (throws on error), change target ranges
-                var newTargetRanges = context.getOptRangeArray();
+                var newTargetRanges = context.getOptJSONRangeList();
                 if (newTargetRanges) {
                     removeTargetRanges(valModel);
                     changedRanges = valModel.setTargetRanges(newTargetRanges);
@@ -1012,9 +1012,8 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          *  at all, returns null.
          */
         this.getModelByAddress = function (address) {
-            var targetRanges = targetRangeSet.findByAddress(address);
-            // result is an array with at most one element (target ranges cannot overlap)
-            return targetRanges.empty() ? null : targetRanges.first().valModel;
+            var targetRange = targetRangeSet.findOneByAddress(address);
+            return targetRange ? targetRange.valModel : null;
         };
 
         /**
@@ -1041,7 +1040,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
             // process all target ranges contained in the operation
             RangeArray.forEach(ranges, function (range) {
                 // get all ranges from the set covered by a validation model
-                targetRangeSet.findRanges(range).forEach(function (range) {
+                targetRangeSet.findAll(range).forEach(function (range) {
                     valModelSet.insert(range.valModel);
                 });
             });
