@@ -44,7 +44,7 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
 
             // process the used area of the cell collection
             var usedRange = docView.getCellCollection().getUsedRange();
-            if (!usedRange) { return $.when(); }
+            if (!usedRange) { return self.createResolvedPromise(); }
 
             // rescue the old selection of the active sheet
             var oldSelection = docView.getSelection();
@@ -66,17 +66,12 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
          */
         function setOptimalColumnWidthForSheet(sheetModel) {
 
-            var promise = null;
-            var sheet = sheetModel.getIndex();
-
-            if (docModel.getActiveSheet() === sheet) {
-                promise = setOptimalColumnWidth();
-            } else {
-                promise = self.waitForEvent(docView, 'update:selection:data');
-                promise = promise.then(setOptimalColumnWidth);
-                docModel.setActiveSheet(sheet);
+            if (sheetModel.isActive()) {
+                return setOptimalColumnWidth();
             }
 
+            var promise = self.waitForEvent(docView, 'update:selection:data').then(setOptimalColumnWidth);
+            docModel.setActiveSheet(sheetModel.getIndex());
             return promise;
         }
 
