@@ -96,7 +96,7 @@ define('io.ox/office/spreadsheet/utils/address', [
      *  The zero-based row index.
      *
      * @returns {String}
-     *  A unique string key for this cell address.
+     *  A unique string key for the cell address.
      */
     Address.key = function (col, row) {
         return col + ',' + row;
@@ -224,7 +224,7 @@ define('io.ox/office/spreadsheet/utils/address', [
      *  - Zero, if both cell addresses are equal.
      */
     Address.compare = function (address1, address2) {
-        return Utils.comparePairs(address1[1], address1[0], address2[1], address2[0]);
+        return Utils.compareNumberPairs(address1[1], address1[0], address2[1], address2[0]);
     };
 
     /**
@@ -246,7 +246,7 @@ define('io.ox/office/spreadsheet/utils/address', [
      *  - Zero, if both cell addresses are equal.
      */
     Address.compareVert = function (address1, address2) {
-        return Utils.comparePairs(address1[0], address1[1], address2[0], address2[1]);
+        return Utils.compareNumberPairs(address1[0], address1[1], address2[0], address2[1]);
     };
 
     /**
