@@ -411,9 +411,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *  cell range address, in no specific order.
      */
     AddressSet.prototype.findAddresses = function (range) {
-        var addresses = new AddressArray();
-        Iterator.forEach(this.rangeIterator(range), function (address) { addresses.push(address); });
-        return addresses;
+        return Iterator.toArray(this.rangeIterator(range), new AddressArray());
     };
 
     /**
