@@ -923,6 +923,13 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                 // data
                 oxCellData = {};
 
+            // cell value
+            if (cellModel && cellModel.isError()) {
+                oxCellData.error = formulaGrammar.getErrorName(cellModel.v);
+            } else {
+                oxCellData.value = cellModel ? cellModel.v : null;
+            }
+
             // handle formula
             var opFormula = cellCollection.getFormula(adr, 'op:ooxml');
             if (opFormula) {
@@ -941,7 +948,6 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             } : {};
             oxCellData.styleId = styleId;
             oxCellData.explicit = autoStyles.getExplicitAttributeSet(styleId);
-            oxCellData.value = cellModel ? cellModel.v : null;
 
             return oxCellData;
         }
@@ -951,7 +957,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             // the collection of auto-styles
             autoStyles = docModel.getCellAutoStyles(),
             // formula grammar for native formulas in operations
-            formulaGrammar = docModel.getFormulaGrammar('op'),
+            formulaGrammar = docModel.getFormulaGrammar('op:ooxml'),
             // the cell collection of the passed sheet
             cellCollection = sheetModel.getCellCollection(),
             // the merged ranges covering the passed range
@@ -1276,6 +1282,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
         var // the document model
             docModel = docView.getDocModel(),
+            // formula grammar for native formulas in operations
+            formulaGrammar = docModel.getFormulaGrammar('op:ooxml'),
             // the attribute pool to be used for cell attributes
             attributePool = docModel.getCellAttributePool(),
             // a two dimensional array containing the cell contents
@@ -1453,7 +1461,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                             }
                         }
 
-                        cellData.v = oxCellData ? oxCellData.value : null;
+                        cellData.v = oxCellData.error ? formulaGrammar.getErrorCode(oxCellData.error) : oxCellData.value;
 
                         // styles
                         if (sameDoc) {
