@@ -13,24 +13,35 @@
  */
 
 define('io.ox/office/spreadsheet/utils/intervalset', [
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (ValueSet, SortedArray, Interval, IntervalArray) {
+], function (Iterator, ValueSet, SortedArray, Interval, IntervalArray) {
 
     'use strict';
 
+    // constants ==============================================================
+
     // convenience shortcuts
-    var min = Math.min;
     var max = Math.max;
     var floor = Math.floor;
     var ceil = Math.ceil;
     var log = Math.log;
+    var ArrayIterator = Iterator.ArrayIterator;
+    var FilterIterator = Iterator.FilterIterator;
+    var NestedIterator = Iterator.NestedIterator;
     var SetProto = ValueSet.prototype;
 
     var ZEROS = '000000000';
 
+    var MATCHERS = {
+        contain:   function (interval, element) { return interval.contains(element); },
+        partial:   function (interval, element) { return !interval.contains(element); },
+        reference: function (interval, element) { return interval.containsIndex(element.first); }
+    };
+
     // private global functions ===============================================
 
     /**
@@ -100,6 +111,26 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      */
     var log2 = Math.log2 || function (number) { return log(number) / Math.LN2; };
 
+    function generateTreeIterator(tree, interval) {
+        return function () { return tree.findIterator(interval); };
+    }
+
+    function generateFirstSortedIterator(sorted, interval) {
+        return function () {
+            var desc = sorted.find(fillZeros(interval.last + 1));
+            return new ArrayIterator(sorted.values(), desc ? { end: desc._ai } : null);
+        };
+    }
+
+    function generateLastSortedIterator(sorted, interval) {
+        return function () {
+            var desc = sorted.find(fillZeros(interval.first));
+            if (!desc) { return Iterator.EMPTY; }
+            var array2 = sorted.values();
+            return new ArrayIterator(array2, { begin: desc._ai });
+        };
+    }
+
     // class IntervalTree =====================================================
 
     /**
@@ -146,10 +177,10 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  The effective center index of the bounding interval. MUST be inside the
      *  interval specified by the parameters 'first' and 'last'.
      *
-     * @param {IntervalTree|Null}
+     * @param {IntervalTree|Null} tree1
      *  An existing left subtree for the new tree.
      *
-     * @param {IntervalTree|Null}
+     * @param {IntervalTree|Null} tree2
      *  An existing right subtree for the new tree.
      */
     function IntervalTree(first, last, center, tree1, tree2) {
@@ -230,84 +261,84 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
     };
 
     /**
-     * Returns whether this tree contains an interval that overlaps with the
-     * passed index interval.
+     * Returns an arbitrary interval in this tree that overlaps with the passed
+     * index interval.
      *
      * @param {Interval} interval
-     *  The index interval used to look for an interval in this set.
+     *  The index interval used to look for an interval in this tree.
      *
-     * @returns {Boolean}
-     *  Whether this tree contains an interval overlapping with the passed
-     *  index interval.
+     * @returns {Interval|Null}
+     *  An arbitrary interval in this tree overlapping with the passed index
+     *  interval.
      */
-    IntervalTree.prototype.overlaps = function (interval) {
+    IntervalTree.prototype.findOne = function (interval) {
 
-        if (interval.last < this._center) {
-            var interval1 = this._sorted1.first();
-            return (!!interval1 && (interval1.first <= interval.last)) || (!!this._tree1 && this._tree1.overlaps(interval));
+        // interval in this set starting left-most and covering center (largest leading)
+        var first = this._sorted1.first();
+        // interval in this set ending right-most and covering center (largest trailing)
+        var last = this._sorted2.last();
+
+        // check if the passed interval covers the largest leading or the largest trailing interval
+        var found = first && interval.overlaps(first) ? first : (last && interval.overlaps(last)) ? last : null;
+
+        // find an interval in the the left subtree, if passed interval starts *before* center
+        if (!found && this._tree1 && (interval.first < this._center)) {
+            found = this._tree1.findOne(interval);
         }
 
-        if (this._center < interval.first) {
-            var interval2 = this._sorted2.last();
-            return (!!interval2 && (interval.first <= interval2.last)) || (!!this._tree2 && this._tree2.overlaps(interval));
+        // find an interval in the right subtree, if passed interval ends *after* center
+        if (!found && this._tree2 && (this._center < interval.last)) {
+            found = this._tree2.findOne(interval);
         }
 
-        // interval covers the center point of this tree: non-empty sorted array contains a matching
-        // interval, otherwise search in both trees, if the interval exceeds the center point
-        return !this._sorted1.empty() ||
-            ((interval.first < this._center) && this._tree1 && this._tree1.overlaps(interval)) ||
-            ((this._center < interval.last) && this._tree2 && this._tree2.overlaps(interval));
+        return found;
     };
 
     /**
-     * Returns all intervals in this tree that overlap with the passed index
-     * interval.
+     * Returns an iterator that will visit all intervals in this tree that
+     * overlap with the passed index interval.
      *
      * @param {Interval} interval
      *  The index interval used to look for the intervals in this tree.
      *
-     * @returns {IntervalArray}
-     *  An array with all intervals in this tree overlapping with the passed
-     *  index interval, in no specific order.
+     * @returns {Iterator}
+     *  An iterator that will visit all intervals in this tree overlapping with
+     *  the passed index interval, in no specific order.
      */
-    IntervalTree.prototype.findIntervals = function (interval) {
+    IntervalTree.prototype.findIterator = function (interval) {
 
-        var intervals = new IntervalArray();
+        // all iterators to be visited sequentially
+        var generators = [];
 
-        // passed interval covers the center point of this tree: return all elements of the sorted array
-        var containsCenter = interval.containsIndex(this._center);
-        if (containsCenter) { intervals.append(this._sorted1.values()); }
-
-        // collect all intervals from the left side of the center point
-        if (interval.first < this._center) {
-            // collect all intervals of the left subtree
-            if (this._tree1) {
-                var last1 = min(interval.last, this._center - 1);
-                intervals.append(this._tree1.findIntervals(new Interval(interval.first, last1)));
-            }
-            // collect all intervals from the first-sorted array
-            if (!containsCenter) {
-                var desc1 = this._sorted1.find(fillZeros(interval.last + 1));
-                var array1 = this._sorted1.values();
-                intervals.append(desc1 ? array1.slice(0, desc1._ai) : array1);
-            }
+        // passed interval covers center: collect all intervals from sorted array
+        if (interval.containsIndex(this._center)) {
+            // passed interval covers the center point of this tree: visit all elements of the sorted array
+            generators.push(this._sorted1.iterator.bind(this._sorted1));
         }
 
-        // collect all intervals from the right side of the center point
-        if (this._center < interval.last) {
-            // collect all intervals of the right subtree
-            if (this._tree2) {
-                var first2 = max(interval.first, this._center + 1);
-                intervals.append(this._tree2.findIntervals(new Interval(first2, interval.last)));
-            }
-            // collect all intervals from the last-sorted array
-            if (!containsCenter) {
-                var desc2 = this._sorted2.find(fillZeros(interval.first));
-                if (desc2) { intervals.append(this._sorted2.values().slice(desc2._ai)); }
-            }
+        // visit all intervals of the left subtree, if passed interval starts *before* center
+        if (this._tree1 && (interval.first < this._center)) {
+            generators.push(generateTreeIterator(this._tree1, interval));
         }
 
-        return intervals;
+        // visit all intervals of the right subtree, if passed interval ends *after* center
+        if (this._tree2 && (this._center < interval.last)) {
+            generators.push(generateTreeIterator(this._tree2, interval));
+        }
+
+        // lookup sorted arrays after visiting the subtrees (for better performance as shown in tests)
+        if (interval.last < this._center) {
+            // passed interval ends left of center: collect all overlapping intervals from the first-sorted array
+            generators.push(generateFirstSortedIterator(this._sorted1, interval));
+        } else if (this._center < interval.first) {
+            // passed interval starts right of center: collect all overlapping intervals from the last-sorted array
+            generators.push(generateLastSortedIterator(this._sorted2, interval));
+        }
+
+        // visit the elements of all iterators sequentially
+        return (generators.length === 0) ? Iterator.EMPTY :
+            (generators.length === 1) ? generators[0]() :
+            new NestedIterator(generators, function (gen) { return gen(); });
     };
 
     /**
@@ -489,6 +520,55 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         return this._get(interval.key()) || null;
     };
 
+    /**
+     * Returns the interval object with a single index from this set that has
+     * the exact position of the passed index.
+     *
+     * @param {Number} index
+     *  An index to search for.
+     *
+     * @returns {Interval|Null}
+     *  An interval from this collection with the same start and end position
+     *  as the passed index; otherwise null.
+     */
+    IntervalSet.prototype.getByIndex = function (index) {
+        return this._get(Interval.key(index, index)) || null;
+    };
+
+    /**
+     * Returns an iterator that will visit all intervals in this set that
+     * overlap with the passed index interval.
+     *
+     * @param {Interval} interval
+     *  The index interval used to look for the intervals in this set.
+     *
+     * @param {String} [matchType]
+     *  Specifies which overlapping intervals will be visited:
+     *  - Omitted (default): Visits all intervals in this set that overlap
+     *      somehow with the passed interval (partially or completely).
+     *  - "contain": Visits only the intervals in this set that are completely
+     *      contained in the passed interval.
+     *  - "partial": Visits only the intervals in this set that are NOT
+     *      completely contained in the passed interval.
+     *  - "reference": Visits only the intervals in this set whose start index
+     *      is contained in the passed interval.
+     *
+     * @returns {Iterator}
+     *  An iterator that will visit all intervals in this set overlapping with
+     *  the passed index interval, in no specific order.
+     */
+    IntervalSet.prototype.findIterator = function (interval, matchType) {
+
+        if (!this._tree) { return Iterator.EMPTY; }
+
+        // create the tree iterator
+        var iterator = this._tree.findIterator(interval);
+
+        // filter by specified match type
+        var matcher = matchType ? MATCHERS[matchType] : null;
+        return matcher ? new FilterIterator(iterator, matcher.bind(null, interval)) : iterator;
+    };
+
     /**
      * Returns whether this set contains an interval covering the passed index.
      *
@@ -499,7 +579,21 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  Whether this set contains an interval covering the passed index.
      */
     IntervalSet.prototype.containsIndex = function (index) {
-        return !!this._tree && this._tree.overlaps(new Interval(index));
+        return this.findOneByIndex(index) !== null;
+    };
+
+    /**
+     * Returns an arbitrary interval in this set that covers the passed index.
+     *
+     * @param {Number} index
+     *  The index used to look for an interval in this set.
+     *
+     * @returns {Interval|Null}
+     *  An arbitrary interval in this set that covers the passed index; or
+     *  null, if no interval has been found.
+     */
+    IntervalSet.prototype.findOneByIndex = function (index) {
+        return this.findOne(new Interval(index));
     };
 
     /**
@@ -512,24 +606,37 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  An array with all intervals in this set that cover the passed index, in
      *  no specific order.
      */
-    IntervalSet.prototype.findByIndex = function (index) {
-        return this._tree ? this._tree.findIntervals(new Interval(index)) : new IntervalArray();
+    IntervalSet.prototype.findAllByIndex = function (index) {
+        return this.findAll(new Interval(index));
     };
 
     /**
-     * Returns whether this set contains an interval that overlaps with the
-     * passed index interval.
+     * Returns an arbitrary interval in this set that overlap with the passed
+     * index interval.
      *
      * @param {Interval} interval
      *  The index interval used to look for an interval in this set.
      *
-     * @returns {Boolean}
-     *  Whether this set contains an interval overlapping with the passed index
-     *  interval.
+     * @param {String} [matchType]
+     *  Specifies which overlapping intervals from this set will match. See
+     *  method IntervalSet.findIterator() for details.
+     *
+     * @returns {Interval|Null}
+     *  An arbitrary interval in this set overlapping with the passed index
+     *  interval; or null, if no interval has been found.
      */
-    IntervalSet.prototype.overlaps = function (interval) {
-        // quick check for an exact match
-        return !!this._tree && (this.has(interval) || this._tree.overlaps(interval));
+    IntervalSet.prototype.findOne = function (interval, matchType) {
+
+        if (!this._tree) { return null; }
+
+        // fast lookup if no matcher has been passed
+        if (!matchType) {
+            return this.get(interval) || this._tree.findOne(interval);
+        }
+
+        // create filter iterator, use its first result
+        var result = this.findIterator(interval, matchType).next();
+        return result.done ? null : result.value;
     };
 
     /**
@@ -539,12 +646,17 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      * @param {Interval} interval
      *  The index interval used to look for the intervals in this set.
      *
+     * @param {String} [matchType]
+     *  Specifies which overlapping intervals from this set will match. See
+     *  method IntervalSet.findIterator() for details.
+     *
      * @returns {IntervalArray}
      *  An array with all intervals in this set overlapping with the passed
      *  index interval, in no specific order.
      */
-    IntervalSet.prototype.findIntervals = function (interval) {
-        return this._tree ? this._tree.findIntervals(interval) : new IntervalArray();
+    IntervalSet.prototype.findAll = function (interval, matchType) {
+        var iterator = this.findIterator(interval, matchType);
+        return Iterator.toArray(iterator, new IntervalArray());
     };
 
     /**
