@@ -442,18 +442,28 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * @param {Address} address
      *  The cell address to be transformed.
      *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {Boolean} [options.reverse=false]
+     *      Whether to transform the passed cell address with the reversed
+     *      operation. If this move descriptor represents an 'insert'
+     *      operation, the address will be transformed according to a 'delete'
+     *      operation, and vice versa.
+     *
      * @returns {Address|Null}
      *  The transformed cell address. If the cell would be deleted completely
      *  while deleting columns or rows, or would be shifted outside the sheet
      *  while inserting columns or rows, null will be returned instead.
      */
-    MoveDescriptor.prototype.transformAddress = function (address) {
+    MoveDescriptor.prototype.transformAddress = function (address, options) {
 
         // nothing to do, if the address is not covered by this descriptor
         if (!this.containsAddress(address)) { return address.clone(); }
 
+        // the effective move operation
+        var insert = this.insert !== Utils.getBooleanOption(options, 'reverse', false);
         // the helper function that implements transformation of an address index
-        var transformFunc = this.insert ? transformIndexInsert : transformIndexDelete;
+        var transformFunc = insert ? transformIndexInsert : transformIndexDelete;
         // transform the correct index of the passed address, according to move direction
         var index = transformFunc(this.targetIntervals, address.get(this.columns), this.maxIndex);
 
@@ -469,14 +479,24 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *  The cell addresses to be transformed, as array of cell addresses, or as
      *  single cell address.
      *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {Boolean} [options.reverse=false]
+     *      Whether to transform the passed cell addresses with the reversed
+     *      operation. If this move descriptor represents an 'insert'
+     *      operation, the addresses will be transformed according to a
+     *      'delete' operation, and vice versa.
+     *
      * @returns {AddressArray}
      *  The transformed cell addresses. Cells that would be deleted completely
      *  while deleting columns or rows, or would be shifted outside the sheet
      *  while inserting columns or rows, will not be included into the result.
      */
-    MoveDescriptor.prototype.transformAddresses = function (addresses) {
+    MoveDescriptor.prototype.transformAddresses = function (addresses, options) {
         // AddressArray.map() filters null values automatically
-        return AddressArray.map(addresses, this.transformAddress, this);
+        return AddressArray.map(addresses, function (address) {
+            return this.transformAddress(address, options);
+        }, this);
     };
 
     /**
@@ -488,16 +508,16 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.transformFull=false]
+     *  - {Boolean} [options.transformFull=false]
      *      If set to true, entire column/row ranges will be transformed too.
      *      By default, entire column ranges will not be modified when moving
      *      vertically (through rows), and entire row ranges will not be
      *      modified when moving horizontally (through columns).
-     *  @param {Boolean} [options.expandEnd=false]
+     *  - {Boolean} [options.expandEnd=false]
      *      If set to true, the end position of the range will be expanded, if
      *      new columns will be inserted exactly right of the range, or new
      *      rows will be inserted exactly below the range.
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      Whether to transform the passed range with the reversed operation.
      *      If this move descriptor represents an 'insert' operation, the range
      *      will be transformed according to a 'delete' operation, and vice
@@ -549,16 +569,16 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.expandEnd=false]
+     *  - {Boolean} [options.expandEnd=false]
      *      If set to true, the end position of ranges will also be expanded,
      *      if new columns will be inserted exactly right of a range, or new
      *      rows will be inserted exactly below a range.
-     *  @param {Boolean} [options.transformFull=false]
+     *  - {Boolean} [options.transformFull=false]
      *      If set to true, entire column/row ranges will be transformed too.
      *      By default, entire column ranges will not be modified when moving
      *      vertically (through rows), and entire row ranges will not be
      *      modified when moving horizontally (through columns).
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      Whether to transform the passed ranges with the reversed operation.
      *      If this move descriptor represents an 'insert' operation, the
      *      ranges will be transformed according to a 'delete' operation, and
@@ -590,14 +610,18 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *  An array with move descriptors that will be used to transform the cell
      *  address.
      *
+     * @param {Object} [options]
+     *  Optional parameters. See description of the public prototype method
+     *  MoveDescriptor.prototype.transformAddress() for details.
+     *
      * @returns {Address|Null}
      *  The transformed cell address. If the cell would be deleted completely
      *  while deleting columns or rows, or would be shifted outside the sheet
      *  while inserting columns or rows, null will be returned instead.
      */
-    MoveDescriptor.transformAddress = function (address, moveDescs) {
+    MoveDescriptor.transformAddress = function (address, moveDescs, options) {
         moveDescs.every(function (moveDesc) {
-            return (address = moveDesc.transformAddress(address));
+            return (address = moveDesc.transformAddress(address, options));
         });
         return address;
     };
@@ -614,14 +638,18 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *  An array with move descriptors that will be used to transform the cell
      *  addresses.
      *
+     * @param {Object} [options]
+     *  Optional parameters. See description of the public prototype method
+     *  MoveDescriptor.prototype.transformAddresses() for details.
+     *
      * @returns {AddressArray}
      *  The transformed cell addresses. Cells that would be deleted completely
      *  while deleting columns or rows, or would be shifted outside the sheet
      *  while inserting columns or rows, will not be included into the result.
      */
-    MoveDescriptor.transformAddresses = function (addresses, moveDescs) {
+    MoveDescriptor.transformAddresses = function (addresses, moveDescs, options) {
         moveDescs.some(function (moveDesc) {
-            addresses = moveDesc.transformAddresses(addresses);
+            addresses = moveDesc.transformAddresses(addresses, options);
             return addresses.empty();
         });
         return addresses;
