@@ -61,6 +61,23 @@ define('io.ox/office/spreadsheet/utils/range', [
 
     // static methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for the specified start and end addresses of
+     * a cell range that can be used for example as key in an associative map.
+     *
+     * @param {Address} start
+     *  The start address of a cell range.
+     *
+     * @param {Address} end
+     *  The end address of a cell range.
+     *
+     * @returns {String}
+     *  A unique string key for the cell range address.
+     */
+    Range.key = function (start, end) {
+        return start.key() + ':' + end.key();
+    };
+
     /**
      * Creates a cell range address from the passed column and row indexes. The
      * columns and rows in the resulting cell range address will be ordered
@@ -254,7 +271,7 @@ define('io.ox/office/spreadsheet/utils/range', [
      *  A unique string key for this cell range address.
      */
     Range.prototype.key = function () {
-        return this.start.key() + ':' + this.end.key();
+        return Range.key(this.start, this.end);
     };
 
     /**
