@@ -19,6 +19,9 @@ define('io.ox/office/spreadsheet/utils/range3d', [
 
     'use strict';
 
+    // convenience shortcuts
+    var RangeProto = Range.prototype;
+
     // class Range3D ==========================================================
 
     /**
@@ -36,14 +39,14 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      * @property {Number} sheet2
      *  The zero-based index of the second sheet of this cell range address.
      */
-    var Range3D = Range.extend({ constructor: function (sheet1, sheet2, start, end) {
+    var Range3D = Range.extend(function (sheet1, sheet2, start, end) {
 
         Range.call(this, start, end);
 
         this.sheet1 = sheet1;
         this.sheet2 = sheet2;
 
-    } }); // class Range3D
+    }); // class Range3D
 
     // static methods ---------------------------------------------------------
 
@@ -189,12 +192,11 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  A unique string key for this cell range address.
      */
     Range3D.prototype.key = function () {
-        return this.sheet1 + ':' + this.sheet2 + '!' + Range.prototype.key.call(this);
+        return this.sheet1 + ':' + this.sheet2 + '!' + RangeProto.key.call(this);
     };
 
     /**
-     * Creates a deep clone of this cell range address. Overrides the method
-     * clone() of the base class Range.
+     * Creates a deep clone of this cell range address.
      *
      * @returns {Range3D}
      *  A deep clone of this range address.
@@ -205,7 +207,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
 
     /**
      * Returns whether the passed cell range address is equal to this cell
-     * range address. Overrides the method equals() of the base class Range.
+     * range address.
      *
      * @param {Range3D} range
      *  The other cell range address to be compared to this cell range address.
@@ -215,12 +217,12 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  addresses.
      */
     Range3D.prototype.equals = function (range) {
-        return (this.sheet1 === range.sheet1) && (this.sheet2 === range.sheet2) && Range.prototype.equals.call(this, range);
+        return (this.sheet1 === range.sheet1) && (this.sheet2 === range.sheet2) && RangeProto.equals.call(this, range);
     };
 
     /**
      * Returns whether the passed cell range address differs from this cell
-     * range address. Overrides the method differs() of the base class Range.
+     * range address.
      *
      * @param {Range3D} range
      *  The other cell range address to be compared to this cell range address.
@@ -230,7 +232,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  address.
      */
     Range3D.prototype.differs = function (range) {
-        return (this.sheet1 !== range.sheet1) || (this.sheet2 !== range.sheet2) || Range.prototype.differs.call(this, range);
+        return (this.sheet1 !== range.sheet1) || (this.sheet2 !== range.sheet2) || RangeProto.differs.call(this, range);
     };
 
     /**
@@ -250,7 +252,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  The number of cells covered by this cell range address.
      */
     Range3D.prototype.cells = function () {
-        return this.sheets() * Range.prototype.cells.call(this);
+        return this.sheets() * RangeProto.cells.call(this);
     };
 
     /**
@@ -302,7 +304,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  Whether this cell range address contains the passed cell range address.
      */
     Range3D.prototype.contains = function (range) {
-        return (this.sheet1 <= range.sheet1) && (range.sheet2 <= this.sheet2) && Range.prototype.contains.call(this, range);
+        return (this.sheet1 <= range.sheet1) && (range.sheet2 <= this.sheet2) && RangeProto.contains.call(this, range);
     };
 
     /**
@@ -317,7 +319,63 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  address by at least one cell.
      */
     Range3D.prototype.overlaps = function (range) {
-        return (this.sheet1 <= range.sheet2) && (range.sheet1 <= this.sheet2) && Range.prototype.overlaps.call(this, range);
+        return (this.sheet1 <= range.sheet2) && (range.sheet1 <= this.sheet2) && RangeProto.overlaps.call(this, range);
+    };
+
+    /**
+     * Returns the address of the specified columns in this cell range address.
+     *
+     * @param {Number} index
+     *  The relative column index (the value zero will return the address of
+     *  the leading column in this range).
+     *
+     * @param {Number} [count=1]
+     *  The number of columns covered by the resulting range.
+     *
+     * @returns {Range3D}
+     *  The address of the specified columns in this cell range address.
+     */
+    Range3D.prototype.colRange = function (index, count) {
+        return Range3D.createFromRange(RangeProto.colRange.call(this, index, count), this.sheet1, this.sheet2);
+    };
+
+    /**
+     * Returns the address of the specified rows in this cell range address.
+     *
+     * @param {Number} index
+     *  The relative row index (the value zero will return the address of the
+     *  top row in this range).
+     *
+     * @param {Number} [count=1]
+     *  The number of rows covered by the resulting range.
+     *
+     * @returns {Range3D}
+     *  The address of the specified rows in this cell range address.
+     */
+    Range3D.prototype.rowRange = function (index, count) {
+        return Range3D.createFromRange(RangeProto.rowRange.call(this, index, count), this.sheet1, this.sheet2);
+    };
+
+    /**
+     * Returns the address of the specified columns or rows in this cell range
+     * address.
+     *
+     * @param {Boolean} columns
+     *  Whether to return a column range (true), or a row range (false) of this
+     *  cell range address.
+     *
+     * @param {Number} index
+     *  The relative column/row index (the value zero will return the address
+     *  of the leading column or top row in this range).
+     *
+     * @param {Number} [count=1]
+     *  The number of columns or rows covered by the resulting range.
+     *
+     * @returns {Range3D}
+     *  The address of the specified columns/rows in this cell range address.
+     */
+    Range3D.prototype.lineRange = function (columns, index, count) {
+        return columns ? this.colRange(index, count) : this.rowRange(index, count);
     };
 
     /**
@@ -386,7 +444,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  notation.
      */
     Range3D.prototype.toString = function () {
-        return this.sheet1 + ':' + this.sheet2 + '!' + Range.prototype.toString.call(this);
+        return this.sheet1 + ':' + this.sheet2 + '!' + RangeProto.toString.call(this);
     };
 
     /**
@@ -399,7 +457,7 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  and 'sheet2').
      */
     Range3D.prototype.toJSON = function () {
-        var json = Range.prototype.toJSON.call(this);
+        var json = RangeProto.toJSON.call(this);
         json.sheet1 = this.sheet1;
         json.sheet2 = this.sheet2;
         return json;
