@@ -522,7 +522,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *  column index; or null, if no range has been found.
      */
     RangeArray.prototype.findByCol = function (col) {
-        return _.find(this, function (range) { return range.containsCol(col); }) || null;
+        return this.find(function (range) { return range.containsCol(col); }) || null;
     };
 
     /**
@@ -537,7 +537,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *  index; or null, if no range has been found.
      */
     RangeArray.prototype.findByRow = function (row) {
-        return _.find(this, function (range) { return range.containsRow(row); }) || null;
+        return this.find(function (range) { return range.containsRow(row); }) || null;
     };
 
     /**
@@ -570,7 +570,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *  cell address; or null, if no range has been found.
      */
     RangeArray.prototype.findByAddress = function (address) {
-        return _.find(this, function (range) { return range.containsAddress(address); }) || null;
+        return this.find(function (range) { return range.containsAddress(address); }) || null;
     };
 
     /**
