@@ -13,16 +13,28 @@
  */
 
 define('io.ox/office/spreadsheet/utils/rangeset', [
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
+    'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/rangearray',
     'io.ox/office/spreadsheet/utils/intervalset'
-], function (ValueSet, RangeArray, IntervalSet) {
+], function (Iterator, ValueSet, Range, RangeArray, IntervalSet) {
 
     'use strict';
 
+    // constants ==============================================================
+
     // convenience shortcuts
+    var FilterIterator = Iterator.FilterIterator;
+    var NestedIterator = Iterator.NestedIterator;
     var SetProto = ValueSet.prototype;
 
+    var MATCHERS = {
+        contain:   function (range, element) { return range.contains(element); },
+        partial:   function (range, element) { return !range.contains(element); },
+        reference: function (range, element) { return range.containsAddress(element.start); }
+    };
+
     // private global functions ===============================================
 
     /**
@@ -140,6 +152,61 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
         return this._get(range.key()) || null;
     };
 
+    /**
+     * Returns the cell range address consisting of a single cell from this set
+     * that has the exact position of the passed cell address.
+     *
+     * @param {Address} address
+     *  A cell address to search for.
+     *
+     * @returns {Range|Null}
+     *  An range object from this set with the same start and end address as
+     *  the passed cell address; otherwise null.
+     */
+    RangeSet.prototype.getByAddress = function (address) {
+        return this._get(Range.key(address, address)) || null;
+    };
+
+    /**
+     * Returns an iterator that will visit all cell ranges in this set that
+     * overlap with the passed cell range address.
+     *
+     * @param {Range} range
+     *  The cell range address used to look for the cell ranges in this set.
+     *
+     * @param {String} [matchType]
+     *  Specifies which overlapping cell ranges will be visited:
+     *  - Omitted (default): Visits all cell ranges in this set that overlap
+     *      somehow with the passed cell range (partially or completely).
+     *  - "contain": Visits only the cell ranges in this set that are
+     *      completely  contained in the passed cell range address.
+     *  - "partial": Visits only the cell ranges in this set that are NOT
+     *      completely contained in the passed cell range address.
+     *  - "reference": Visits only the cell ranges in this set whose start
+     *      address is contained in the passed cell range address.
+     *
+     * @returns {Iterator}
+     *  An iterator that will visit all cell ranges in this set overlapping
+     *  with the passed cell range address, in no specific order.
+     */
+    RangeSet.prototype.findIterator = function (range, matchType) {
+
+        // visit all column intervals overlapping with the passed range (do not pass "matchType"
+        // to interval iterator, e.g. "partial" may not match by column but only by row)
+        var iterator = this._colSet.findIterator(range.colInterval());
+
+        // create a nested iterator that visits all row intervals in the columns
+        iterator = new NestedIterator(iterator, function (colInterval) {
+            return colInterval.rowSet.findIterator(range.rowInterval());
+        }, function (colResult, rowResult) {
+            return { value: rowResult.value.range };
+        });
+
+        // filter by specified match type
+        var matcher = matchType ? MATCHERS[matchType] : null;
+        return matcher ? new FilterIterator(iterator, matcher.bind(null, range)) : iterator;
+    };
+
     /**
      * Returns whether this set contains a cell range covering the passed cell
      * address.
@@ -151,10 +218,22 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *  Whether this set contains a cell range covering the passed address.
      */
     RangeSet.prototype.containsAddress = function (address) {
-        var colIntervals = this._colSet.findByIndex(address[0]);
-        return colIntervals.some(function (colInterval) {
-            return colInterval.rowSet.containsIndex(address[1]);
-        });
+        return this.findOneByAddress(address) !== null;
+    };
+
+    /**
+     * Returns an arbitrary cell range in this set that covers the passed cell
+     * address.
+     *
+     * @param {Address} address
+     *  The cell address used to look for a cell range in this set.
+     *
+     * @returns {Range|Null}
+     *  An arbitrary cell range address in this set that covers the passed cell
+     *  address.
+     */
+    RangeSet.prototype.findOneByAddress = function (address) {
+        return this.findOne(new Range(address));
     };
 
     /**
@@ -167,44 +246,26 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *  An array with all cell ranges in this set that cover the passed cell
      *  address, in no specific order.
      */
-    RangeSet.prototype.findByAddress = function (address) {
-        var ranges = new RangeArray();
-        var colIntervals = this._colSet.findByIndex(address[0]);
-        colIntervals.forEach(function (colInterval) {
-            var rowIntervals = colInterval.rowSet.findByIndex(address[1]);
-            rowIntervals.forEach(function (rowInterval) {
-                ranges.push(rowInterval.range);
-            });
-        });
-        return ranges;
+    RangeSet.prototype.findAllByAddress = function (address) {
+        return this.findAll(new Range(address));
     };
 
     /**
-     * Returns whether this set contains a range that overlaps with the passed
-     * cell ranges.
+     * Returns an arbitrary range that overlaps with the passed cell range.
      *
-     * @param {RangeArray|Range} ranges
-     *  An array of cell range addresses, or a single cell range address, used
-     *  to look for overlapping ranges in this set.
+     * @param {Range} range
+     *  The cell range address used to look for overlapping ranges in this set.
      *
-     * @returns {Boolean}
-     *  Whether this set contains a cell range overlapping with the passed cell
-     *  ranges.
+     * @param {String} [matchType]
+     *  Specifies which overlapping cell ranges from this set will match. See
+     *  method RangeSet.findIterator() for details.
+     *
+     * @returns {Range|Null}
+     *  An arbitrary cell range address overlapping with the passed cell range.
      */
-    RangeSet.prototype.overlaps = function (ranges) {
-
-        // quick check for an exact match
-        ranges = RangeArray.get(ranges);
-        if (ranges.some(this.has, this)) { return true; }
-
-        // check each range if it overlaps somehow
-        return ranges.some(function (range) {
-            var rowInterval = range.rowInterval();
-            var colIntervals = this._colSet.findIntervals(range.colInterval());
-            return colIntervals.some(function (colInterval) {
-                return colInterval.rowSet.overlaps(rowInterval);
-            }, this);
-        }, this);
+    RangeSet.prototype.findOne = function (range, matchType) {
+        var result = this.findIterator(range, matchType).next();
+        return result.done ? null : result.value;
     };
 
     /**
@@ -213,21 +274,17 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      * @param {Range} range
      *  The cell range used to look for the ranges in this set.
      *
+     * @param {String} [matchType]
+     *  Specifies which overlapping cell ranges from this set will match. See
+     *  method RangeSet.findIterator() for details.
+     *
      * @returns {RangeArray}
      *  An array with all ranges in this set overlapping with the passed cell
      *  range, in no specific order.
      */
-    RangeSet.prototype.findRanges = function (range) {
-        var ranges = new RangeArray();
-        var rowInterval = range.rowInterval();
-        var colIntervals = this._colSet.findIntervals(range.colInterval());
-        colIntervals.forEach(function (colInterval) {
-            var rowIntervals = colInterval.rowSet.findIntervals(rowInterval);
-            rowIntervals.forEach(function (interval) {
-                ranges.push(interval.range);
-            });
-        });
-        return ranges;
+    RangeSet.prototype.findAll = function (range, matchType) {
+        var iterator = this.findIterator(range, matchType);
+        return Iterator.toArray(iterator, new RangeArray());
     };
 
     /**
