@@ -177,6 +177,14 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      */
     SheetUtils.MAX_SORT_LINES_COUNT = 5000;
 
+    /**
+     * The maximum length of the columns/rows to be sorted.
+     *
+     * @constant
+     * @type Number
+     */
+    SheetUtils.MAX_SORT_LINE_LENGTH = 100;
+
     /**
      * Maximum number of characters for the absolute part of a number formatted
      * with the standard number format (in cells).
@@ -252,7 +260,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
     /**
      * Enumeration for the split modes for a sheet. The JSON string
      * representation of the enumeration values corresponds to the values used
-     * in the sheet formatting attribute 'splitMode'.
+     * in the sheet formatting attribute "splitMode".
      *
      * @constant
      * @type Enum
@@ -271,35 +279,35 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
     SheetUtils.SplitMode = Enum.create('split frozen frozenSplit');
 
     /**
-     * Enumeration for the move modes for cell ranges. The JSON string
-     * representation of the enumeration values corresponds to the values used
-     * in the document operations 'moveCells'.
+     * Enumeration for the direction to move the cells in cell ranges to. The
+     * JSON string representation of the enumeration values corresponds to the
+     * values used in the document operation "moveCells".
      *
      * @constant
      * @type Enum
      *
-     * @property {MoveMode} LEFT
+     * @property {Direction} LEFT
      *  A cell range will be deleted, the following cells right of the cell
      *  range will be moved to the left.
      *
-     * @property {MoveMode} RIGHT
+     * @property {Direction} RIGHT
      *  A cell range will be made blank by moving the existing cells to the
      *  right. Cells moved outside the sheet will be deleted.
      *
-     * @property {MoveMode} UP
+     * @property {Direction} UP
      *  A cell range will be deleted, the following cells below the cell range
      *  will be moved up.
      *
-     * @property {MoveMode} DOWN
+     * @property {Direction} DOWN
      *  A cell range will be made blank by moving the existing cells down.
      *  Cells moved outside the sheet will be deleted.
      */
-    SheetUtils.MoveMode = Enum.create('left right up down');
+    var Direction = SheetUtils.Direction = Enum.create('left right up down');
 
     /**
      * Enumeration for the merge modes for cell ranges. The JSON string
      * representation of the enumeration values corresponds to the values used
-     * in the document operations 'mergeCells'.
+     * in the document operation "mergeCells".
      *
      * @constant
      * @type Enum
@@ -349,6 +357,20 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      */
     SheetUtils.UpdateMode = Enum.create('deleteSheet renameSheet relabelName moveCells cutPaste');
 
+    /**
+     * Enumeration for possible directions to sort a cell range.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {SortDirection} VERTICAL
+     *  Sort the rows of a cell range (from top to bottom).
+     *
+     * @property {SortDirection} HORIZONTAL
+     *  Sort the columns of a cell range (from left to right).
+     */
+    SheetUtils.SortDirection = Enum.create('vertical horizontal');
+
     /**
      * Enumeration for different anchor types of drawing objects.
      *
@@ -679,6 +701,88 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
         return 2 * SheetUtils.getTextPadding(digitWidth) + 1;
     };
 
+    /**
+     * Returns whether the passed direction value is orientated vertically.
+     *
+     * @param {Direction} direction
+     *  The direction to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether the direction value is orientated vertically (true for the
+     *  directions UP and DOWN, false for the directions LEFT and RIGHT).
+     */
+    SheetUtils.isVerticalDir = function (direction) {
+        return (direction === Direction.UP) || (direction === Direction.DOWN);
+    };
+
+    /**
+     * Returns whether the passed direction value is orientated to the leading
+     * border of a bounding box.
+     *
+     * @param {Direction} direction
+     *  The direction to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether the direction value is orientated to the leading border (true
+     *  for the directions LEFT and UP, false for the directions RIGHT and
+     *  DOWN).
+     */
+    SheetUtils.isLeadingDir = function (direction) {
+        return (direction === Direction.LEFT) || (direction === Direction.UP);
+    };
+
+    /**
+     * Returns the direction value for the specified orientation.
+     *
+     * @param {Boolean} vertical
+     *  Whether to move vertically (true, directions UP or DOWN), or
+     *  horizontally (false, directions LEFT or RIGHT).
+     *
+     * @param {Boolean} leading
+     *  Whether to move to the leading border (true, directions LEFT or UP), or
+     *  to the trailing border (false, directions RIGHT or DOWN).
+     *
+     * @returns {Direction}
+     *  The resulting direction.
+     */
+    SheetUtils.getDirection = function (vertical, leading) {
+        return vertical ? (leading ? Direction.UP : Direction.DOWN) : (leading ? Direction.LEFT : Direction.RIGHT);
+    };
+
+    /**
+     * Returns the address of a cell range adjacent to the passed cell range
+     * address.
+     *
+     * @param {Range} range
+     *  The original range address.
+     *
+     * @param {Direction} direction
+     *  The direction how to move to the adjacent range.
+     *
+     * @param {Number} size
+     *  The size of the adjacent range.
+     *
+     * @returns {Range}
+     *  The address of the adjacent range.
+     */
+    SheetUtils.getAdjacentRange = function (range, direction, size) {
+
+        // whether to modify column or row indexes
+        var columns = !SheetUtils.isVerticalDir(direction);
+        // the resulting range
+        var targetRange = range.clone();
+
+        if (SheetUtils.isLeadingDir(direction)) {
+            targetRange.start.move(-size, columns);
+            targetRange.end.set(range.start.get(columns) - 1, columns);
+        } else {
+            targetRange.start.set(range.end.get(columns) + 1, columns);
+            targetRange.end.move(size, columns);
+        }
+
+        return targetRange;
+    };
+
     /**
      * Returns whether the specified address is an origin cell in the merged
      * range according to the passed merge mode.
