@@ -15,13 +15,13 @@
 define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/utils/tracking',
-    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/control/radiogroup',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/spreadsheet/view/popup/sheetcontextmenu',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Forms, Tracking, IteratorUtils, RadioGroup, AppObjectMixin, SheetContextMenu, gt) {
+], function (Utils, Forms, Iterator, Tracking, RadioGroup, AppObjectMixin, SheetContextMenu, gt) {
 
     'use strict';
 
@@ -118,7 +118,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             showAllSheetButtons();
 
             // get total width of all buttons (bug 35869: round down, browsers may report slightly oversized width due to text nodes)
-            var buttonsWidth = Math.floor(sheetButtons.last().offset().left + sheetButtons.last().outerWidth() - sheetButtons.first().offset().left);
+            var buttonsWidth = Math.floor(sheetButtons.last().offset().left + sheetButtons.last().width() - sheetButtons.first().offset().left);
             if (buttonsWidth <= groupWidth) { return; }
 
             // collect position information of all buttons (performance: once for all buttons, before manipulating DOM again)
@@ -128,7 +128,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
                 var buttonOffset = buttonNode.offset().left - leadingOffset;
                 return {
                     offset: buttonOffset,
-                    leadingWidth: buttonOffset + buttonNode.outerWidth(),
+                    leadingWidth: buttonOffset + buttonNode.width(),
                     trailingWidth: buttonsWidth - buttonOffset
                 };
             });
@@ -149,7 +149,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
                 scrollable = true;
 
                 // get total width of all buttons, including scroll buttons, and inner remaining width
-                totalWidth = nextButton.offset().left + nextButton.outerWidth() - prevButton.offset().left;
+                totalWidth = nextButton.offset().left + nextButton.width() - prevButton.offset().left;
                 remainingWidth = groupWidth - (totalWidth - buttonsWidth);
 
                 // hide leading sheet tabs
@@ -185,18 +185,18 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
             // shrink single visible sheet button, if still oversized
             var sheetButton = sheetButtons.eq(firstIndex);
-            if ((firstIndex === lastIndex) && (remainingWidth < sheetButton.outerWidth())) {
-                sheetButton.width(remainingWidth - (sheetButton.outerWidth() - sheetButton.width()));
+            if ((firstIndex === lastIndex) && (remainingWidth < sheetButton.width())) {
+                sheetButton.css({ width: remainingWidth });
                 return;
             }
 
             // add the first hidden sheet button after the last visible, if there is some space left
             if (lastIndex + 1 === buttonPositions.length) { return; }
             remainingWidth -= buttonPositions[lastIndex + 1].offset;
-            if (remainingWidth >= 30) {
+            if (remainingWidth >= 45) {
                 sheetButton = sheetButtons.eq(lastIndex + 1);
                 Forms.showNodes(sheetButton, true);
-                sheetButton.width(remainingWidth - (sheetButton.outerWidth() - sheetButton.width()));
+                sheetButton.css({ width: remainingWidth });
             }
         }
 
@@ -449,7 +449,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
             // create buttons for all visible sheets
             var iterator = docModel.createSheetIterator({ supported: true, visible: true });
-            IteratorUtils.forEach(iterator, function (sheetModel, iterResult) {
+            Iterator.forEach(iterator, function (sheetModel, iterResult) {
                 var sheetLabel = _.noI18n(iterResult.name);
                 self.createOptionButton(iterResult.sheet, {
                     icon: sheetModel.isLocked() ? 'fa-lock' : null,
