@@ -127,7 +127,8 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
                     // create the list entry
                     var options = (label.length === 0) ?
                         { label: BLANK_CELLS_LABEL, labelStyle: 'font-style:italic;', sortIndex: { value: null, display: '' } } :
-                        { label: _.noI18n(label), sortIndex: { value: cellData.value, display: label }, attributes: { role: 'checkbox' } };
+                        { label: _.noI18n(label), sortIndex: { value: cellData.value, display: label } };
+                    options.attributes = { role: 'checkbox' };
                     self.createOptionButton(key, options);
                 });
 
