@@ -37,14 +37,14 @@ define('io.ox/office/spreadsheet/view/control/formatcategorygroup', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class RadioGroup.
      */
-    function FormatCategoryGroup(docView, initOptions) {
+    var FormatCategoryGroup = RadioGroup.extend({ constructor: function (docView, initOptions) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        RadioGroup.call(this, Utils.extendOptions({
+        RadioGroup.call(this, docView, Utils.extendOptions({
             toggleValue: 'standard'
         }, initOptions));
 
@@ -86,11 +86,10 @@ define('io.ox/office/spreadsheet/view/control/formatcategorygroup', [
             self = docView = initOptions = null;
         });
 
-    } // class FormatCategoryGroup
+    } }); // class FormatCategoryGroup
 
     // exports ================================================================
 
-    // derive this class from class RadioGroup
-    return RadioGroup.extend({ constructor: FormatCategoryGroup });
+    return FormatCategoryGroup;
 
 });
