@@ -14,11 +14,11 @@
 
 define('io.ox/office/spreadsheet/view/control/formatcodepicker', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/control/radiolist',
     'io.ox/office/spreadsheet/view/labels',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, SimpleMap, RadioList, Labels, gt) {
+], function (Utils, ValueMap, RadioList, Labels, gt) {
 
     'use strict';
 
@@ -47,11 +47,11 @@ define('io.ox/office/spreadsheet/view/control/formatcodepicker', [
         var numberFormatter = docView.getDocModel().getNumberFormatter();
 
         // a map used to resolve alternative format codes to list entries in this control
-        var formatCodeMap = new SimpleMap();
+        var formatCodeMap = new ValueMap();
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             label: Labels.MORE_LABEL,
             //#. special number format codes for different categories of number formats
             tooltip: gt.pgettext('format-code', 'Format codes')
