@@ -117,7 +117,7 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
             });
 
             // show the 'unmerge' list item, if at least one range overlaps with a merged range
-            showUnmergeItem = mergeCollection.rangesOverlapAnyMergedRange(ranges);
+            showUnmergeItem = mergeCollection.coversAnyMergedRange(ranges);
         }
 
         // initialization -----------------------------------------------------
