@@ -51,43 +51,30 @@ define('io.ox/office/spreadsheet/view/control/sortmenubutton', [
             label: gt.pgettext('sort', 'Sorting'),
             smallerVersion: { hideLabel: true }
         }, initOptions, {
-            value: function () {
-                return { orderRules: [{ orderBy: 'toggle' }] };
-            }
+            value: 'toggle'
         }));
 
         // private methods ----------------------------------------------------
 
         /**
-         * Updates the icon according to the sort state.
+         * Updates the icon according to the sort order.
          */
-        function updateHandler(sortState) {
-
-            var rules = sortState.orderRules,
-                state = 'ascending';
-
-            if (rules.length > 0 && rules[0].orderBy) {
-                state = rules[0].orderBy;
-            }
-
-            switch (state) {
+        function updateHandler(sortOrder) {
+            switch (sortOrder) {
                 case 'ascending':
                     self.setIcon(Labels.SORT_ASC_BUTTON_OPTIONS.icon);
                     break;
                 case 'descending':
                     self.setIcon(Labels.SORT_DESC_BUTTON_OPTIONS.icon);
                     break;
-                case 'custom':
-                    self.setIcon('fa-cogs');
-                    break;
             }
         }
 
         // initialization -----------------------------------------------------
 
         // create all drop-down menu items
-        this.addGroup('cell/sort', new Button(docView, _.extend({ value: { orderRules: [{ orderBy: 'ascending' }] } }, Labels.SORT_ASC_BUTTON_OPTIONS)));
-        this.addGroup('cell/sort', new Button(docView, _.extend({ value: { orderRules: [{ orderBy: 'descending' }] } }, Labels.SORT_DESC_BUTTON_OPTIONS)));
+        this.addGroup('cell/sort', new Button(docView, _.extend({ value: 'ascending' }, Labels.SORT_ASC_BUTTON_OPTIONS)));
+        this.addGroup('cell/sort', new Button(docView, _.extend({ value: 'descending' }, Labels.SORT_DESC_BUTTON_OPTIONS)));
         this.addSeparator();
         this.addGroup('cell/sort/dialog', new Button(docView, Labels.SORT_CUSTOM_BUTTON_OPTIONS));
 
