@@ -36,7 +36,7 @@ define('io.ox/office/spreadsheet/view/control/subtotallist', [
      * @param {Object} [initOptions]
      *  Optional parameters. Will be passed to the base class RadioList.
      */
-    function SubtotalList(docView, initOptions) {
+    var SubtotalList = RadioList.extend({ constructor: function (docView, initOptions) {
 
         // self reference
         var self = this;
@@ -49,7 +49,7 @@ define('io.ox/office/spreadsheet/view/control/subtotallist', [
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             tooltip: gt('Type of the subtotal value')
         }, initOptions));
 
@@ -67,7 +67,7 @@ define('io.ox/office/spreadsheet/view/control/subtotallist', [
             var label = '';
 
             // format finite numbers with the number format of the active cell
-            if (_.isNumber(value) && _.isFinite(value)) {
+            if (Utils.isFiniteNumber(value)) {
 
                 // different formatting and special handling according to subtotal type
                 if ((type === 'cells') || (type === 'numbers')) {
@@ -190,11 +190,10 @@ define('io.ox/office/spreadsheet/view/control/subtotallist', [
             self = docView = initOptions = numberFormatter = formulaGrammar = null;
         });
 
-    } // class SubtotalList
+    } }); // class SubtotalList
 
     // exports ================================================================
 
-    // derive this class from class RadioList
-    return RadioList.extend({ constructor: SubtotalList });
+    return SubtotalList;
 
 });
