@@ -23,13 +23,13 @@ define('io.ox/office/spreadsheet/view/controls', [
     'io.ox/office/spreadsheet/view/control/cellbordercolorpicker',
     'io.ox/office/spreadsheet/view/control/cellstylepicker',
     'io.ox/office/spreadsheet/view/control/mergecellspicker',
-    'io.ox/office/spreadsheet/view/control/namedrangesmenubutton',
+    'io.ox/office/spreadsheet/view/control/namesmenubutton',
     'io.ox/office/spreadsheet/view/control/sortmenubutton',
     'io.ox/office/spreadsheet/view/control/activesheetgroup',
     'io.ox/office/spreadsheet/view/control/activesheetlist',
     'io.ox/office/spreadsheet/view/control/subtotallist',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, EditControls, Labels, AlignmentPicker, FormatCategoryGroup, FormatCategoryPicker, FormatCodePicker, CellBorderColorPicker, CellStylePicker, MergeCellsPicker, NamedRangesMenuButton, SortMenuButton, ActiveSheetGroup, ActiveSheetList, SubtotalList, gt) {
+], function (Utils, EditControls, Labels, AlignmentPicker, FormatCategoryGroup, FormatCategoryPicker, FormatCodePicker, CellBorderColorPicker, CellStylePicker, MergeCellsPicker, NamesMenuButton, SortMenuButton, ActiveSheetGroup, ActiveSheetList, SubtotalList, gt) {
 
     'use strict';
 
@@ -58,7 +58,7 @@ define('io.ox/office/spreadsheet/view/controls', [
         CellBorderColorPicker: CellBorderColorPicker,
         CellStylePicker: CellStylePicker,
         MergeCellsPicker: MergeCellsPicker,
-        NamedRangesMenuButton: NamedRangesMenuButton,
+        NamesMenuButton: NamesMenuButton,
         SortMenuButton: SortMenuButton,
         ActiveSheetGroup: ActiveSheetGroup,
         ActiveSheetList: ActiveSheetList,
@@ -202,6 +202,30 @@ define('io.ox/office/spreadsheet/view/controls', [
 
     // class CellBorderStylePicker ============================================
 
+    // predefined border styles (line width, line style) supported by OOXML
+    var BORDER_OOXML_PRESET_STYLES = [
+        { value: 'single:hair',       label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'Hair line'),                         style: 'solid',      width: 0 },
+        { value: 'single:thin',       label: /*#. border line style (width 1 pixel, solid) */ gt.pgettext('borders', 'Thin line'),                            style: 'solid',      width: 1 },
+        { value: 'dashed:thin',       label: /*#. border line style (width 1 pixel, dashed) */ gt.pgettext('borders', 'Dashed thin line'),                    style: 'dashed',     width: 1 },
+        { value: 'dotted:thin',       label: /*#. border line style (width 1 pixel, dotted) */ gt.pgettext('borders', 'Dotted thin line'),                    style: 'dotted',     width: 1 },
+        { value: 'dashDot:thin',      label: /*#. border line style (width 1 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash thin line'),            style: 'dashDot',    width: 1 },
+        { value: 'dashDotDot:thin',   label: /*#. border line style (width 1 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash thin line'),   style: 'dashDotDot', width: 1 },
+        { value: 'single:medium',     label: /*#. border line style (width 2 pixels, solid) */ gt.pgettext('borders', 'Medium line'),                         style: 'solid',      width: 2 },
+        { value: 'dashed:medium',     label: /*#. border line style (width 2 pixels, dashed) */ gt.pgettext('borders', 'Dashed medium line'),                 style: 'dashed',     width: 2 },
+        { value: 'dashDot:medium',    label: /*#. border line style (width 2 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash medium line'),          style: 'dashDot',    width: 2 },
+        { value: 'dashDotDot:medium', label: /*#. border line style (width 2 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash medium line'), style: 'dashDotDot', width: 2 },
+        { value: 'single:thick',      label: /*#. border line style (width 3 pixels, solid) */ gt.pgettext('borders', 'Thick line'),                          style: 'solid',      width: 3 },
+        { value: 'double:thick',      label: /*#. border line style (width 3 pixels, double line) */ gt.pgettext('borders', 'Double line'),                   style: 'solid',      width: 1, count: 2 }
+    ];
+
+    // all available simple border line styles for ODF files
+    var BORDER_ODF_LINE_STYLES = [
+        { value: 'single', label: /*#. Border line style: a solid single line */ gt.pgettext('borders', 'Single'),  style: 'solid' },
+        { value: 'double', label: /*#. Border line style: a solid double line */ gt.pgettext('borders', 'Double'),  style: 'solid', count: 2 },
+        { value: 'dotted', label: /*#. Border line style: a dotted single line */ gt.pgettext('borders', 'Dotted'), style: 'dotted' },
+        { value: 'dashed', label: /*#. Border line style: a dashed single line */ gt.pgettext('borders', 'Dashed'), style: 'dashed' }
+    ];
+
     /**
      * A picker control for cell border styles. The available list entries will
      * depend on the current file format.
@@ -215,7 +239,7 @@ define('io.ox/office/spreadsheet/view/controls', [
      */
     SpreadsheetControls.CellBorderStylePicker = EditControls.BorderStylePicker.extend({ constructor: function (docView) {
 
-        var PRESET_STYLES = docView.getApp().isOOXML() ? Labels.BORDER_OOXML_PRESET_STYLES : Labels.BORDER_ODF_LINE_STYLES;
+        var PRESET_STYLES = docView.getApp().isOOXML() ? BORDER_OOXML_PRESET_STYLES : BORDER_ODF_LINE_STYLES;
 
         EditControls.BorderStylePicker.call(this, docView, PRESET_STYLES, {
             dropDownVersion: { label: Labels.BORDER_STYLE_LABEL }
@@ -252,6 +276,32 @@ define('io.ox/office/spreadsheet/view/controls', [
 
     } }); // class CellProtectionMenuButton
 
+    // class CommentMenuButton =========================================
+
+    /**
+     * A compound button with options to change the cell protection settings.
+     *
+     * @constructor
+     *
+     * @extends CompoundButton
+     *
+     * @param {SpreadsheetView} docView
+     *  The spreadsheet view containing this instance.
+     */
+    SpreadsheetControls.CommentMenuButton = CompoundButton.extend({ constructor: function (docView, initOptions) {
+
+        CompoundButton.call(this, docView, Utils.extendOptions({
+            label: gt('Comment'),
+            tooltip: gt('Comment-Handling'),
+            autoHideGroups: true,
+            smallerVersion: { hideLabel: true }
+        }, initOptions));
+
+        this.addGroup('comment/toggle', new Button(docView, { label: gt('Show/Hide'),   tooltip: gt('Toggle visibility of selected comment') }));
+        this.addGroup('comment/delete', new Button(docView, { label: gt('Delete'),      tooltip: gt('Delete selected comment') }));
+
+    } }); // class CommentMenuButton
+
     // class DynamicSplitCheckBox =============================================
 
     /**
@@ -439,9 +489,11 @@ define('io.ox/office/spreadsheet/view/controls', [
      */
     SpreadsheetControls.SheetTableStylePicker = EditControls.TableStylePicker.extend({ constructor: function (docView) {
 
-        EditControls.TableStylePicker.call(this, docView, {
-            firstRow: true,
-            bandsHor: true,
+        function getStyleFlags() {
+            return docView.getControllerItemValue('table/flags');
+        }
+
+        EditControls.TableStylePicker.call(this, docView, getStyleFlags, {
             additionalItems: [NO_TABLE_STYLE_ITEM]
         });
 
