@@ -15,10 +15,10 @@
 
 define('io.ox/office/spreadsheet/view/dialog/definednamedialog', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/dialogs',
+    'io.ox/office/tk/dialog/inputdialog',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Dialogs, SheetUtils, gt) {
+], function (Utils, InputDialog, SheetUtils, gt) {
 
     'use strict';
 
@@ -31,37 +31,36 @@ define('io.ox/office/spreadsheet/view/dialog/definednamedialog', [
      *
      * @constructor
      *
-     * @extends ModalInputDialog
+     * @extends InputDialog
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view instance that has created this dialog.
      *
      * @param {Function} actionHandler
      *  The callback function invoked when the OK button of the dialog has
-     *  been clicked (will be passed as 'validator' option to the dialog).
-     *  Receives the current label and formula entered in the dialog, and MUST
-     *  return a boolean value or a promise that states whether the operation
-     *  using that label and formula expression has been finished successfully.
-     *  In case of an error, the dialog will be kept open with its current
-     *  settings.
+     *  been clicked. Receives the current label and formula entered in the
+     *  dialog, and MUST return a boolean value or a promise that states
+     *  whether the operation using that label and formula expression has been
+     *  finished successfully. In case of an error, the dialog will be kept
+     *  open with its current settings.
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptions.label='']
+     *  - {String} [initOptions.label='']
      *      The initial label for the defined name to be shown when the dialog
      *      is opened.
-     *  @param {String} [initOptions.formula='']
+     *  - {String} [initOptions.formula='']
      *      The initial formula expression to be shown when the dialog is
      *      opened.
-     *  @param {Number|Null} [initOptions.sheet=null]
+     *  - {Number|Null} [initOptions.sheet=null]
      *      The initial value for the sheet selector (null for globally defined
      *      names, or the index of a sheet for sheet-local names) to be shown
      *      when the dialog is opened.
-     *  @param {Boolean} [initOptions.change=false]
+     *  - {Boolean} [initOptions.change=false]
      *      False for a dialog that is used to create a new defined name, or
      *      true for a dialog that is used to change an existing defined name.
      */
-    var DefinedNameDialog = Dialogs.ModalInputDialog.extend({ constructor: function (docView, actionHandler, initOptions) {
+    var DefinedNameDialog = InputDialog.extend(function (docView, actionHandler, initOptions) {
 
         // self reference
         var self = this;
@@ -74,14 +73,13 @@ define('io.ox/office/spreadsheet/view/dialog/definednamedialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalInputDialog.call(this, docView, {
+        InputDialog.call(this, docView, {
             title: changeName ? gt('Change name') : gt('Insert name'),
             okLabel: changeName ? gt('Change') : gt('Insert'),
             inputLabel: gt('Name'),
             value: Utils.getStringOption(initOptions, 'label', ''),
             maxLength: SheetUtils.MAX_NAME_LENGTH,
-            placeholder: gt('Enter name'),
-            validator: function () { return actionHandler.call(self, getNameLabel(), getNameFormula(), getNameSheet()); }
+            placeholder: gt('Enter name')
         });
 
         // private methods ----------------------------------------------------
@@ -119,34 +117,6 @@ define('io.ox/office/spreadsheet/view/dialog/definednamedialog', [
             return Utils.getIntegerOption(initOptions, 'sheet', null); // TODO: from drop-down control
         }
 
-        // public methods -----------------------------------------------------
-
-        /**
-         * Shows the dialog.
-         *
-         * @returns {jQuery.Promise}
-         *  A promise representing the dialog. Will be resolved after the
-         *  action handler callback function has been invoked successfully; or
-         *  will be rejected, if the dialog has been canceled, or if the
-         *  document has switched to read-only mode.
-         */
-        this.show = _.wrap(this.show, function (show) {
-            return show.call(this).then(null, function (result) {
-
-                // reopen the dialog, if the action handler has failed
-                if (result === 'invalid') {
-                    return new DefinedNameDialog(docView, actionHandler, {
-                        label: getNameLabel(),
-                        formula: getNameFormula(),
-                        sheet: getNameSheet(),
-                        change: changeName
-                    }).show();
-                }
-
-                return result;
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         // close dialog automatically after losing edit rights
@@ -157,17 +127,12 @@ define('io.ox/office/spreadsheet/view/dialog/definednamedialog', [
         formulaField.val(Utils.getStringOption(initOptions, 'formula', ''));
         this.getContentNode().append($('<label>').text(gt('Formula')), formulaField);
 
-        // set initial focus
-        this.on('show', function () {
-            // Also for IPad because since IOS 9, body is not scrolled when code triggers focus on input element
-            if (Utils.SMALL_DEVICE || Utils.IOS) {
-                _.defer(function () { Utils.setFocus(self.getCancelButton()); });
-            } else {
-                Utils.setFocus(self.getInputNode()).select();
-            }
-        });
+        // register the action handler for the OK button
+        this.setOkHandler(function () {
+            return actionHandler.call(this, getNameLabel(), getNameFormula(), getNameSheet());
+        }, { keepOpen: 'fail' });
 
-    } }); // class DefinedNameDialog
+    }); // class DefinedNameDialog
 
     // exports ================================================================
 
