@@ -1724,14 +1724,14 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
                 // fail, if fill mode wants to change parts of a matrix formula
                 case 'fill':
-                    if (cellCollection.rangesOverlapAnyMatrix(docView.getSelectedRanges(), { partial: true })) {
+                    if (cellCollection.coversAnyMatrixRange(docView.getSelectedRanges(), 'partial')) {
                         return keepEditMode('formula:matrix:change');
                     }
                     break;
 
                 // fail, if another matrix formula overlapping with the active cell would be changed
                 case 'matrix':
-                    if (!updateMatrix && cellCollection.rangesOverlapAnyMatrix(matrixRange, { partial: true })) {
+                    if (!updateMatrix && cellCollection.coversAnyMatrixRange(matrixRange, 'partial')) {
                         return keepEditMode('formula:matrix:change');
                     }
                     break;
