@@ -96,12 +96,15 @@ define('io.ox/office/spreadsheet/view/edit/texteditorbase', [
         // callback handler that returns the browser focus target node (required)
         var focusResolver = initOptions.focusResolver;
 
-        // current text edit mode (instance of enum EditMode, null if no edit mode is active)
+        // whether text edit mode is currently active
         var editActive = false;
 
         // the active (focused) grid pane instance
         var editGridPane = null;
 
+        // current promise for leaving edit mode (repeated calls)
+        var activeLeavePromise = null;
+
         // base constructor ---------------------------------------------------
 
         TriggerObject.call(this, docView);
@@ -235,6 +238,11 @@ define('io.ox/office/spreadsheet/view/edit/texteditorbase', [
          */
         this.leaveEditMode = function (options) {
 
+            // method may be called repeatedly while leaving edit mode
+            if (activeLeavePromise) {
+                return activeLeavePromise;
+            }
+
             // nothing to do, if text edit mode is not active
             if (!editActive) {
                 return this.createResolvedPromise();
@@ -261,7 +269,11 @@ define('io.ox/office/spreadsheet/view/edit/texteditorbase', [
                 _.defer(function () { self.grabFocus(); });
             });
 
-            return promise;
+            // cache running promise, reset the promise after leaving edit mode
+            activeLeavePromise = promise;
+            return promise.always(function () {
+                activeLeavePromise = null;
+            });
         };
 
         /**
