@@ -326,8 +326,9 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             var scrollTop = (scrollTopRatio > 0) ? Math.round(rowHeaderPane.getScrollPos() / scrollTopRatio) : 0;
 
             // restrict size of layer root node to size of sheet
-            var layerRootWidth = Math.min(layerRectangle.width, docView.getSheetWidth() - layerRectangle.left);
-            var layerRootHeight = Math.min(layerRectangle.height, docView.getSheetHeight() - layerRectangle.top);
+            var sheetRect = docView.getSheetRectangle();
+            var layerRootWidth = Math.min(layerRectangle.width, sheetRect.width - layerRectangle.left);
+            var layerRootHeight = Math.min(layerRectangle.height, sheetRect.height - layerRectangle.top);
 
             // calculate the effective offsets according to current scroll position
             var offsetLeft = Math.max(-2 * layerRootWidth, layerRectangle.left - colHeaderPane.getScrollPos() + scrollLeft - hiddenWidth);
@@ -957,7 +958,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                             var currentRange = createRangeFromContentsObject(item.address, item.contents);
 
                             // unmerge cells if necessary
-                            if ((currentRange.cells() > 1) && mergeCollection.rangesOverlapAnyMergedRange(currentRange)) {
+                            if ((currentRange.cells() > 1) && mergeCollection.coversAnyMergedRange(currentRange)) {
                                 promise3 = promise3.then(function () {
                                     return mergeCollection.generateMergeCellsOperations(generator, currentRange, MergeMode.UNMERGE);
                                 });
@@ -1771,6 +1772,8 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             // nothing to return in hidden grid panes
             if (!layerRectangle) { return null; }
 
+            // the total size of the sheet
+            var sheetRect = docView.getSheetRectangle();
             // the absolute position of the layer root node
             var layerOffset = layerRootNode.offset();
             // whether to restrict sheet coordinates to the sheet area
@@ -1778,11 +1781,11 @@ define('io.ox/office/spreadsheet/view/gridpane', [
 
             // calculate horizontal sheet offset in pixels, test for overflow
             var left = event.pageX - layerOffset.left + layerRectangle.left;
-            if (restricted && ((left < 0) || (left >= docView.getSheetWidth()))) { return null; }
+            if (restricted && ((left < 0) || (left >= sheetRect.width))) { return null; }
 
             // calculate vertival sheet offset in pixels, test for overflow
             var top = event.pageY - layerOffset.top + layerRectangle.top;
-            if (restricted && ((top < 0) || (top >= docView.getSheetHeight()))) { return null; }
+            if (restricted && ((top < 0) || (top >= sheetRect.height))) { return null; }
 
             return { left: left, top: top };
         };
