@@ -16,14 +16,13 @@
 define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/container/valueset',
-    'io.ox/office/textframework/utils/dom',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/model/drawing/text/textframeutils',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/core/tk/nodetouch' // activates $.enableTouch() function, not used otherwise (keep at end of list)
-], function (Utils, ValueSet, DOMUtils, DrawingFrame, SheetUtils, PaneUtils, TextFrameUtils, DrawingUtils) {
+], function (Utils, ValueSet, DrawingFrame, SheetUtils, PaneUtils, TextFrameUtils, DrawingUtils) {
 
     'use strict';
 
@@ -31,6 +30,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
     var PI_180 = Math.PI / 180;
 
     // convenience shortcuts
+    var Direction = SheetUtils.Direction;
     var Address = SheetUtils.Address;
     var Range = SheetUtils.Range;
 
@@ -554,10 +554,10 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 maxTrailingRows = Math.min(maxRows, Math.max(0, visibleRange.end[1] - origRange.end[1]));
 
                 // check whether the original range contains at least one merged range
-                hasMergedRange = docView.getMergeCollection().rangesOverlapAnyMergedRange(origRange);
+                hasMergedRange = docView.getMergeCollection().coversAnyMergedRange(origRange);
 
                 // render selected range with modified auto-fill style
-                sheetModel.setViewAttribute('autoFillData', { border: 'bottom', count: 0 });
+                sheetModel.setViewAttribute('autoFillData', { direction: Direction.DOWN, count: 0 });
             }
 
             // updates the auto fill area according to the passed tracking event
@@ -584,15 +584,15 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 // calculate the auto-fill data from target range
                 if (deleteMode) {
                     // delete mode: always delete from trailing border
-                    autoFillData.border = columns ? 'right' : 'bottom';
+                    autoFillData.direction = SheetUtils.getDirection(!columns, false);
                     autoFillData.count = range.getStart(columns) - origRange.getEnd(columns) - 1;
                 } else if (leading) {
                     // expand leading range border
-                    autoFillData.border = columns ? 'left' : 'top';
+                    autoFillData.direction = SheetUtils.getDirection(!columns, true);
                     autoFillData.count = Math.min(origRange.getStart(columns) - range.getStart(columns), columns ? maxLeadingCols : maxLeadingRows);
                 } else {
                     // expand trailing range border
-                    autoFillData.border = columns ? 'right' : 'bottom';
+                    autoFillData.direction = SheetUtils.getDirection(!columns, false);
                     autoFillData.count = Math.min(range.getEnd(columns) - origRange.getEnd(columns), columns ? maxTrailingCols : maxTrailingRows);
                 }
 
@@ -614,10 +614,10 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                 // apply auto-fill operation
                 if (apply) {
-                    var autoFillData = sheetModel.getViewAttribute('autoFillData');
-                    autoFillData.invertType = event.altKey || false;
+                    var itemValue = _.clone(sheetModel.getViewAttribute('autoFillData'));
+                    itemValue.options = { copy: event.altKey };
                     // bug 39533: via controller for busy screen etc.
-                    docView.executeControllerItem('cell/autofill', autoFillData);
+                    docView.executeControllerItem('cell/autofill', itemValue);
                 }
 
                 // reset the view attribute
@@ -659,7 +659,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             // the drawing collection of the active sheet
             var drawingCollection = null;
             // the total size of the sheet, in pixels
-            var sheetWidth = 0, sheetHeight = 0;
+            var sheetRect = null;
             // information for all selected drawing objects
             var drawingDescSet = new ValueSet('key');
             // descriptor for the active (tracked) drawing object
@@ -836,8 +836,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                 // initialize information for all selected drawing objects
                 drawingCollection = docView.getDrawingCollection();
-                sheetWidth = docView.getSheetWidth();
-                sheetHeight = docView.getSheetHeight();
+                sheetRect = docView.getSheetRectangle();
                 drawingDescSet.clear();
                 boundRect = null;
                 diffAngle = tempMoveX = tempMoveY = 0;
@@ -900,9 +899,9 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 // restrict movement of the drawing objects to the sheet area
                 if (moveMode) {
                     minMoveX = -boundRect.left;
-                    maxMoveX = sheetWidth - boundRect.right();
+                    maxMoveX = sheetRect.width - boundRect.right();
                     minMoveY = -boundRect.top;
-                    maxMoveY = sheetHeight - boundRect.bottom();
+                    maxMoveY = sheetRect.height - boundRect.bottom();
                 }
 
                 // restrict resizing the drawing objects individually
@@ -913,10 +912,10 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                         var skipRestricting = (drawingModel.getRotationDeg() !== 0) || drawingModel.isFlippedH() || drawingModel.isFlippedV();
                         var minSkipValue = -50000; // TODO: arbitrary big values for min and max, smarter algorithm is required for rotated/flipped shapes
                         var maxSkipValue = 50000; // see bug #52636 for more
-                        drawingDesc.minScaleX = skipRestricting ? minSkipValue : getMinScale(rect.left, rect.width, sheetWidth, reverseX);
-                        drawingDesc.maxScaleX = skipRestricting ? maxSkipValue : getMaxScale(rect.left, rect.width, sheetWidth, reverseX);
-                        drawingDesc.minScaleY = skipRestricting ? minSkipValue : getMinScale(rect.top, rect.height, sheetHeight, reverseY);
-                        drawingDesc.maxScaleY = skipRestricting ? maxSkipValue : getMaxScale(rect.top, rect.height, sheetHeight, reverseY);
+                        drawingDesc.minScaleX = skipRestricting ? minSkipValue : getMinScale(rect.left, rect.width, sheetRect.width, reverseX);
+                        drawingDesc.maxScaleX = skipRestricting ? maxSkipValue : getMaxScale(rect.left, rect.width, sheetRect.width, reverseX);
+                        drawingDesc.minScaleY = skipRestricting ? minSkipValue : getMinScale(rect.top, rect.height, sheetRect.height, reverseY);
+                        drawingDesc.maxScaleY = skipRestricting ? maxSkipValue : getMaxScale(rect.top, rect.height, sheetRect.height, reverseY);
                     });
                 }
                 if (rotateMode) {
