@@ -161,10 +161,6 @@ define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
 
         // initialization -----------------------------------------------------
 
-        this.on('popup:beforeshow', function () {
-            self.registerFocusableNodes($('.clipboard'));
-        });
-
         this.on('popup:hide', function () {
             self.destroyAllGroups();
             filterGroup = sortGroup = null;
