@@ -18,9 +18,10 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/editframework/utils/color',
+    'io.ox/office/editframework/utils/border',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/view/render/renderutils'
-], function (Utils, ValueMap, BaseObject, AppObjectMixin, Color, SheetUtils, RenderUtils) {
+], function (Utils, ValueMap, BaseObject, AppObjectMixin, Color, Border, SheetUtils, RenderUtils) {
 
     'use strict';
 
@@ -178,6 +179,19 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
                 mergedAttrSet = _.copy(mergedAttrSet, true);
             });
 
+            // updates the rendering priority of all border lines in the rmerged attribute set
+            function setBorderPrio(attributSet, borderPrio) {
+                if (attributSet.cell) {
+                    OUTER_BORDER_NAMES.forEach(function (borderName) {
+                        var border = attributSet.cell[borderName];
+                        var mergedBorder = mergedAttrSet.cell[borderName];
+                        if (border && !mergedBorder.prio && Border.isEqual(border, mergedBorder)) {
+                            mergedBorder.prio = borderPrio;
+                        }
+                    });
+                }
+            }
+
             // merge the outer borders of another auto-style
             if (_.isString(borderStyleId)) {
                 ensureClonedAttributeSet();
@@ -197,6 +211,9 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
                 var newParsedFormat = numberFormatter.getParsedFormatForAttributes(mergedAttrSet.cell);
                 formatChanged = oldParsedFormat !== newParsedFormat;
 
+                // update border priority (conditional border always wins against adjacent cell border)
+                setBorderPrio(condAttrSet, 1);
+
                 // detect whether the text color has been set explicitly
                 explicitTextColor = hasExplicitTextColor(condAttrSet);
             }
@@ -205,6 +222,8 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
             if (tableAttrSet) {
                 ensureClonedAttributeSet();
                 docModel.extendWithTableAttributeSet(mergedAttrSet, mergedAttrSet, tableAttrSet);
+                // update border priority (cell border always wins against table style border)
+                setBorderPrio(tableAttrSet, -1);
             }
 
             // if the text color has not been set explicitly by the passed attributes, it may be part of the auto-style itself
