@@ -533,7 +533,7 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
                     // the inner rectangle of the cell, without trailing border lines
                     var rect = element.innerRect;
                     // leave some space to the cell borders (width of lines used in the icon)
-                    var padding = IconRenderer.getLineWidth(rect.height, 1);
+                    var padding = IconRenderer.getLineWidth(odf ? rect.height : style.rowHeight, 1);
                     // the effective size of the available space, according to file format
                     var availSize = odf ? Math.min(rect.width, rect.height) : style.rowHeight;
                     // create a new, or reuse an existing, icon renderer
@@ -884,17 +884,16 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
                     // with their tracking handles. If the lower or right boundary of the sheet
                     // is visible, the canvas may contain some rendering artifacts that will
                     // not be overdrawn or cleared later.
-                    var sheetWidth = sheetModel.getColCollection().getTotalSize();
-                    var sheetHeight = sheetModel.getRowCollection().getTotalSize();
-                    var oversizeWidth = newRectangle.right() - sheetWidth;
-                    var oversizeHeight = newRectangle.bottom() - sheetHeight;
+                    var sheetRect = sheetModel.getSheetRectangle({ pixel: true });
+                    var oversizeWidth = newRectangle.right() - sheetRect.width;
+                    var oversizeHeight = newRectangle.bottom() - sheetRect.height;
                     if ((oversizeWidth > 0) || (oversizeHeight > 0)) {
                         cellCanvas.render(function (context) {
                             if (oversizeWidth > 0) {
-                                context.clearRect(sheetWidth, newRectangle.top, oversizeWidth, newRectangle.height);
+                                context.clearRect(sheetRect.width, newRectangle.top, oversizeWidth, newRectangle.height);
                             }
                             if (oversizeHeight > 0) {
-                                context.clearRect(newRectangle.left, sheetHeight, newRectangle.width, oversizeHeight);
+                                context.clearRect(newRectangle.left, sheetRect.height, newRectangle.width, oversizeHeight);
                             }
                         });
                     }
