@@ -285,8 +285,9 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
             var fontSize = Math.round(9 * docView.getZoomFactor());
 
             // the container element for all text lines
-            var padding = Math.round(3 * docView.getZoomFactor());
-            var textFrame = $('<div class="textframe" style="padding:' + padding + 'px;">');
+            var paddingX = Math.round(3 * docView.getZoomFactor());
+            var paddingY = Math.round(docView.getZoomFactor());
+            var textFrame = $('<div class="textframe" style="padding:' + paddingY + 'px ' + paddingX + 'px;">');
 
             // append all text lines as separate paragraph elements
             commentModel.getText().split('\n').forEach(function (textLine) {
@@ -315,20 +316,21 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
             var drawingFrame = commentFrameManager.getDrawingFrame(commentModel);
             // the cell overlay node with the indicator corner
             var overlayNode = drawingFrame.data('overlayNode');
-            // the visible part of the anchor range
-            var anchorRange = commentModel.getVisibleAnchorRange();
+            // the location of the anchor cell (with merged range), in pixels
+            var anchorRect = commentModel.getAnchorRectangle({ pixel: true, expandMerged: true });
 
             // hide overlay nodes of comments in hidden columns/rows
-            overlayNode.toggleClass('hidden', !anchorRange);
+            var hidden = anchorRect.area() === 0;
+            overlayNode.toggleClass('hidden', hidden);
 
             // comment in hidden cell: immediately hide the drawing frame
-            if (!anchorRange) {
+            if (hidden) {
                 toggleFrameClass(drawingFrame, 'hidden', true);
                 return false;
             }
 
             // update the position and size of the overlay node
-            var cellRect = gridPane.convertToLayerRectangle(docView.getRangeRectangle(anchorRange));
+            var cellRect = gridPane.convertToLayerRectangle(anchorRect);
             overlayNode.css(cellRect.expandSelf(0, 0, -1, -1).toCSS());
             return true;
         }
