@@ -414,7 +414,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
             var rowCollection = docView.getRowCollection();
 
             // create drop-down buttons for all visible table ranges with activated filter/sorting
-            docView.getTableCollection().findTables(layerRange).forEach(function (tableModel) {
+            docView.getTableCollection().findTables(layerRange, { autoFilter: true }).forEach(function (tableModel) {
 
                 // bug 51782, bug 51456: do not render buttons without header row, or if buttons are disabled explicitly
                 if (!tableModel.areButtonsVisible()) { return; }
