@@ -49,7 +49,7 @@ define('io.ox/office/spreadsheet/view/render/highlightrenderer', [
         var docView = gridPane.getDocView();
 
         // the range highlight layer (container for the highlighted ranges of formulas)
-        var highlightLayerNode = gridPane.createLayerNode('highlight-layer');
+        var highlightLayerNode = gridPane.createLayerNode('highlight-layer', { after: 'selection-layer' });
 
         // the active range layer (container for the active range selected in cell edit mode)
         var activeRangeLayerNode = gridPane.createLayerNode('active-layer');
