@@ -78,9 +78,8 @@ define('io.ox/office/spreadsheet/view/render/iconrenderer', [
     /**
      * A map with names and RGB values of all colors used in icon sets.
      *
-     * @type {Object<String, String>}
-     *
      * @constant
+     * @type Object<String>
      */
     IconRenderer.COLORS = {
         BLACK: '#555',
@@ -261,7 +260,7 @@ define('io.ox/office/spreadsheet/view/render/iconrenderer', [
      */
     IconRenderer.prototype.drawPath = function (path, color, mode) {
         if (color) { this.context.setFillStyle(IconRenderer.COLORS[color]); }
-        this.context.setLineStyle({ width: this.LW, style: '#333' }).drawPath(path, mode);
+        this.context.setLineStyle({ width: this.LW, style: 'black' }).drawPath(path, mode);
         return this;
     };
 
