@@ -148,7 +148,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             if (headerElement.mergeDescs) { return headerElement.mergeDescs; }
 
             // find all merged ranges covering the specified row
-            headerElement.mergeDescs = mergedRangeSet.findRanges(docModel.makeRowRange(row)).map(function (mergedRange) {
+            headerElement.mergeDescs = mergedRangeSet.findAll(docModel.makeRowRange(row)).map(function (mergedRange) {
                 return mergedRange.mergeDesc;
             });
 
@@ -701,8 +701,8 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         var oldOverflowR = element.hasOverflowText(true);
 
                         // find and store descriptor of a merged range covering the cell element
-                        var mergedRanges = mergedRangeSet.findByAddress(element.address);
-                        element.merged = mergedRanges.empty() ? null : mergedRanges.first().mergeDesc;
+                        var mergedRange = mergedRangeSet.findOneByAddress(element.address);
+                        element.merged = mergedRange ? mergedRange.mergeDesc : null;
 
                         // update cell formatting and all text settings
                         updateCellElement(element);
