@@ -47,6 +47,11 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *
      * @constructor
      *
+     * @property {Number} prio
+     *  Rendering priority of the border line. Border with higher priority are
+     *  always stronger than borders with lower priority, regardless of their
+     *  styles (line width etc.).
+     *
      * @property {String} style
      *  Effective dash style of the border line: one of 'solid', 'dotted',
      *  'dashed', 'dashDot', or 'dashDotDot'.
@@ -86,6 +91,9 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      */
     function BorderDescriptor(docModel, gridColor, border) {
 
+        // rendering priority of the border
+        this.prio = border.prio || 0;
+
         // initial line width, in pixels (rounded according to canvas pixel resolution, zero is hair line),
         // restricted to minimum cell size to prevent that left/right or top/bottom border lines of a cell overlay each other
         this.width = Math.min(Utils.convertHmmToLength(border.width, 'px', GRID_LINE_WIDTH), SheetUtils.MIN_CELL_SIZE);
@@ -164,6 +172,10 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (!border1) { return border2; }
         if (!border2) { return border1; }
 
+        // compare rendering priority (higher number wins)
+        if (border1.prio > border2.prio) { return border1; }
+        if (border1.prio < border2.prio) { return border2; }
+
         // compare border width (hair lines first)
         if (border1.hair && !border2.hair) { return border2; }
         if (!border1.hair && border2.hair) { return border1; }
