@@ -168,32 +168,35 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             selection.ranges[selection.active].active = true;
 
             // adjust single range for auto-fill tracking
-            if ((selection.ranges.length === 1) && _.isObject(autoFillData)) {
+            if ((selection.ranges.length === 1) && autoFillData) {
 
                 // the selected cell range
                 var firstRange = selection.ranges.first();
-                // whether to expand/shrink the leading or trailing border
-                var leading = /^(left|top)$/.test(autoFillData.border);
+                // auto-fill direction and count
+                var fillDir = autoFillData.direction;
+                var fillCount = autoFillData.count;
                 // whether to expand/shrink columns or rows
-                var columns = /^(left|right)$/.test(autoFillData.border);
+                var vertical = SheetUtils.isVerticalDir(fillDir);
+                // whether to expand/shrink the leading or trailing border
+                var leading = SheetUtils.isLeadingDir(fillDir);
 
                 activeRange = firstRange.clone();
-                if (autoFillData.count >= 0) {
+                if (fillCount >= 0) {
                     // adjust range for auto-fill mode
                     if (leading) {
-                        firstRange.start.move(-autoFillData.count, columns);
+                        firstRange.start.move(-fillCount, !vertical);
                     } else {
-                        firstRange.end.move(autoFillData.count, columns);
+                        firstRange.end.move(fillCount, !vertical);
                     }
                 } else {
                     // adjust range for deletion mode
                     firstRange.collapsed = true;
-                    if (-autoFillData.count < firstRange.size(columns)) {
+                    if (-fillCount < firstRange.size(!vertical)) {
                         // range partly covered
                         if (leading) {
-                            activeRange.start.move(-autoFillData.count, columns);
+                            activeRange.start.move(-fillCount, !vertical);
                         } else {
-                            activeRange.end.move(autoFillData.count, columns);
+                            activeRange.end.move(fillCount, !vertical);
                         }
                     } else {
                         // special marker for deletion of the entire range
@@ -276,7 +279,7 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
 
                 // additional mark-up for single-range selection
                 if (selection.ranges.length === 1) {
-                    if (Utils.TOUCHDEVICE && !_.isObject(autoFillData)) {
+                    if (Utils.TOUCHDEVICE && !autoFillData) {
                         // add resize handlers for selection on touch devices
                         rangeMarkup += '<div class="select resizers">' + createResizerMarkup(range, true) + createResizerMarkup(range, false) + '</div>';
                     } else {
