@@ -322,6 +322,11 @@ define('io.ox/office/spreadsheet/view/toolbars', [
 
         // create the controls of this tool bar
         this.addGroup('table/stylesheet', new Controls.SheetTableStylePicker(docView), { visibleKey: 'document/ooxml' });
+        this.addSeparator();
+        this.addGroup('cell/sort', new Controls.SortMenuButton(docView));
+        this.addSeparator();
+        //this.addGroup('table/filter', new Controls.FilterButton(docView));
+        this.addGroup('table/refresh', new Controls.RefreshButton(docView));
 
         // destroy all class members on destruction
         this.registerDestructor(function () { docView = null; });
