@@ -43,11 +43,6 @@ define('io.ox/office/text/app/application', [
 
     'use strict';
 
-    var Blob = window.Blob;
-    var atob = window.atob;
-    var ArrayBuffer = window.ArrayBuffer;
-    var Uint8Array = window.Uint8Array;
-
     var characterCountPerLine = 80;
     var textFragmentMaxLength = characterCountPerLine;
 
@@ -170,23 +165,31 @@ define('io.ox/office/text/app/application', [
     //
     // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
     // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
-    function hasNonConvertibleContent(node) {
-        var isNonConvertibleContent = false,
-
+    //
+    // bugfix Bug #58768 - "Misleading alert for empty 'document content as email"
+    // Follow up for Bug #58402.
+    //
+    function getContentConversionMeasures(node) {
+        var
             contentNode = DOM.getPageContentNode(node).eq(0),
 
             textContent = contentNode.text(),
             imageCollection = contentNode.find('img'),
-            canvasCollection = contentNode.find('canvas');
+            canvasCollection = contentNode.find('canvas'),
 
-        isNonConvertibleContent = (
-            (canvasCollection.length >= 1)
-            || (
+            containsNeitherImageNorText = (
                 (imageCollection.length === 0)
-                && (textContent.length === 0)
-            )
-        );
-        return isNonConvertibleContent;
+                && (
+                    (textContent.length === 0)
+                    || (/^[\s\t\n]+$/).test(textContent)
+                )
+            ),
+            containsShapes = (canvasCollection.length >= 1);
+
+        return {
+            isEmpty: (!containsShapes && containsNeitherImageNorText),
+            isNotConvertible: (containsShapes || containsNeitherImageNorText)
+        };
     }
 
     // class TextApplication ==================================================
@@ -431,7 +434,8 @@ define('io.ox/office/text/app/application', [
                     return ConverterUtils.sendConverterRequest(fileModel, {
                         documentformat: 'pdf',
                         saveas_filename: fileName,
-                        saveas_folder_id: DriveUtils.getStandardTrashFolderId()
+                        saveas_folder_id: DriveUtils.getStandardTrashFolderId(),
+                        revtag: _.uniqueId('mail-attmt-')
                     });
                 });
 
@@ -502,23 +506,35 @@ define('io.ox/office/text/app/application', [
 
                 // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
                 // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
-                isNonConvertibleContent = hasNonConvertibleContent(rootNode),
+                //
+                // bugfix Bug #58768 - "Misleading alert for empty 'document content as email"
+                // Follow up for Bug #58402.
+                //
+                conversionMeasures = getContentConversionMeasures(rootNode),
 
                 // the existing selection
                 startPosition = selection.getStartPosition(), endPosition = selection.getEndPosition();
 
             selection.selectAll();
-            if (!self.isEditable()) { selection.restoreBrowserSelection({ forceWhenReadOnly: true }); }
+            if (!self.isEditable()) {
+                selection.restoreBrowserSelection({ forceWhenReadOnly: true });
+            }
             htmlFragmentString = Export.getHTMLFromSelection(editor/*, { isEncodeBase64: false }*/);
-            selection.setTextSelection(startPosition, endPosition); // restoring the existing selection
-            if (!self.isEditable()) { selection.restoreBrowserSelection({ forceWhenReadOnly: true }); }
 
+            selection.setTextSelection(startPosition, endPosition); // restoring the existing selection
+            if (!self.isEditable()) {
+                selection.restoreBrowserSelection({ forceWhenReadOnly: true });
+            }
             htmlFragmentString = htmlFragmentString.replace((/\s+'=""\s+/g), ' '); // fixing some html syntax errors.
 
             return sanitizeBase64ImageUrlsDeferred(htmlFragmentString).then(function (htmlFragmentString) {
                 return {
                     // isMainlyNonConvertibleContent: isMainlyNonConvertibleContent,
-                    isNonConvertibleContent: isNonConvertibleContent,
+                    isNotConvertible: conversionMeasures.isNotConvertible,
+                    isEmpty: conversionMeasures.isEmpty,
+
+                    // isEmpty: (!containsShapes && containsNeitherImageNorText),
+                    // isNotConvertible: (containsShapes || containsNeitherImageNorText)
 
                     title:   titleText,
                     content: htmlFragmentString
