@@ -113,6 +113,21 @@ define('io.ox/office/text/app/controller', [
                         isListType = docModel.getListCollection().isNumberingList(listStyleId, listLevel);
                         break;
                 }
+
+                // check, if the ID belongs to a predefined list style (so that a nice selection can be done, if this is no predefined list style (58368))
+                if (isListType && !docModel.getListCollection().getPredefinedListStyles()[listStyleId]) {
+                    // -> if this is not a predefined list style, it is required to find that list style, that matches the list item at the corresponding level
+                    var predefinedListStyles = (listType === 'bullet') ? docModel.getPredefinedBulletListStyles() : docModel.getPredefinedNumberedListStyles();
+                    var compareLevel = docModel.getListCollection().getListLevel(listStyleId, listLevel);
+                    var key = 'listLevel' + listLevel; // searching that list style, that has the same list definition at the specified level.
+
+                    _.find(predefinedListStyles, function (oneListStyle, id) {
+                        var searchLevel = oneListStyle.definition[key];
+                        var found = (searchLevel.numberFormat === compareLevel.numberFormat) && (searchLevel.levelText === compareLevel.levelText);
+                        if (found) { shortListStyleId = id; } // highlighting the best list icon
+                        return found;
+                    });
+                }
             }
 
             // return empty string, if list type in attributes does not match list type in item user data
@@ -431,13 +446,13 @@ define('io.ox/office/text/app/controller', [
 
             // toggle default bullet list, or select bullet type
             'paragraph/list/bullet': {
-                parent: ['paragraph/attributes', 'insert/comment/odf/supported'],
+                parent: ['paragraph/attributes', 'insert/listindrawing/odf/supported'],
                 get: _.partial(getListStyleId, 'bullet'),
                 set: _.partial(setListStyleId, 'bullet')
             },
             // toggle default numbered list, or select numbering type
             'paragraph/list/numbered': {
-                parent: ['paragraph/attributes', 'insert/comment/odf/supported'],
+                parent: ['paragraph/attributes', 'insert/listindrawing/odf/supported'],
                 get: _.partial(getListStyleId, 'numbering'),
                 set: _.partial(setListStyleId, 'numbering')
             },
@@ -647,6 +662,10 @@ define('io.ox/office/text/app/controller', [
                 enable: function () { return app.isODF() || !docModel.isCommentFunctionality(); }
             },
 
+            'insert/listindrawing/odf/supported': {
+                enable: function () { return docModel.checkTextListAvailability(); }
+            },
+
             'insert/margin/supported': {
                 enable: function () { return !docModel.isHeaderFooterEditState(); }
             },
