@@ -1373,7 +1373,8 @@ define('io.ox/office/text/format/listcollection', [
                         if (attrs.paragraph.listStyleId !== '' && paragraphStyle === prevParaStyle && isArrayDefinitionEqual(this.getList(attrs.paragraph.listStyleId), listDefinition)) {
                             listId = attrs.paragraph.listStyleId; // continuing the list of the previous paragraph
                         } else {
-                            listId = checkPreviousSingleParagraphList(paragraph, paragraphAttrs, listDefinition); // check if a single paragraph list must be continued
+                            var continuedId = checkPreviousSingleParagraphList(paragraph, paragraphAttrs, listDefinition); // check if a single paragraph list must be continued
+                            if (continuedId) { listId = continuedId; } // only change listId, if there is a previous paragraph
                         }
                         prevParagraph = null;
                     }
