@@ -70,7 +70,9 @@ define('io.ox/office/text/format/paragraphstyles', [
             cell: function (paragraph) { return DOM.isCellContentNode(paragraph.parent()) ? paragraph.closest('td') : null; }
         },
 
-        canvas = new Canvas(Canvas.SINGLETON);
+        canvas = new Canvas(Canvas.SINGLETON),
+
+        defaultIndentFirstLineValue = 635;
 
     // private static functions ===============================================
 
@@ -127,7 +129,7 @@ define('io.ox/office/text/format/paragraphstyles', [
 
         // note: borderInside must not be compared here
         return  Utils.hasEqualProperties(attributes1, attributes2,
-                ['borderLeft', 'borderRight', 'borderTop', 'borderBottom', 'listStyleId', 'listLevel', 'indentLeft', 'indentRight', 'indentFirstLine']);
+            ['borderLeft', 'borderRight', 'borderTop', 'borderBottom', 'listStyleId', 'listLevel', 'indentLeft', 'indentRight', 'indentFirstLine']);
     }
 
     /**
@@ -625,17 +627,19 @@ define('io.ox/office/text/format/paragraphstyles', [
                 if (explicitParaAttributes.indentLeft) { leftMargin += explicitParaAttributes.indentLeft; }
                 if (explicitParaAttributes.indentRight) { rightMargin += explicitParaAttributes.indentRight; }
                 if (_.isNumber(explicitParaAttributes.indentFirstLine) && (explicitParaAttributes.indentFirstLine !== 0 || _.isNumber(explicitParaAttributes.indentLeft))) {
-                    var lI = explicitParaAttributes.indentLeft ? explicitParaAttributes.indentLeft - 635 : 635;
                     // first line indent, negative values represent hanging indents
-                    var lFl = explicitParaAttributes.indentFirstLine ? Math.abs(explicitParaAttributes.indentFirstLine) :  0;
+                    var lFl = explicitParaAttributes.indentFirstLine ||  0;
                     // text indent is left indent minus special indent like first line or hanging
-                    textIndent -= lI - lFl;
+                    if (docModel.getApp().isODF() && explicitParaAttributes.listLabelHidden) { defaultIndentFirstLineValue = 0; } // (52818)
+                    textIndent = lFl + defaultIndentFirstLineValue;
                     collectedAttrs.textIndent = Utils.convertHmmToLength(textIndent, 'px', 1) + 'px';
                 }
 
                 // explicit attribute for left indent needs to handle the indent of a list (47090)
                 if (listObject && listObject.indent && explicitParaAttributes && explicitParaAttributes.indentLeft) {
-                    leftMargin -= listObject.indent;
+                    if (!(docModel.getApp().isODF() && explicitParaAttributes.listLabelHidden)) { // not for ODF with empty list label (52818)
+                        leftMargin -= listObject.indent;
+                    }
                 }
             }
 
