@@ -24,6 +24,13 @@ define('io.ox/office/text/format/stylesheetmixin', [
 
     'use strict';
 
+    /**
+     * The warning text for an invalid name for a paragraph style, to be
+     * used in the text input dialog asking for the name of a new or
+     * renamed paragraph style (56349).
+     */
+    var INVALID_NAME_WARNING = gt('Invalid name for a paragraph style.');
+
     // mix-in class StylesheetMixin ============================================
 
     /**
@@ -85,7 +92,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 var startChar = _.clone(paraPos);
                 var endChar = _.clone(paraPos);
                 startChar.push(0);
-                endChar.push(paraLength);
+                endChar.push(paraLength - 1);
 
                 generator.generateOperation(Operations.SET_ATTRIBUTES, {
                     attrs: getCharClearAttributes(),
@@ -158,7 +165,8 @@ define('io.ox/office/text/format/stylesheetmixin', [
 
         // methods ------------------------------------------------------------
 
-        this.showInsertNewStyleDialog = function (name) {
+        this.showInsertNewStyleDialog = function () {
+
             var baseAttributes = getCurrentParaAttributes();
             var para = $('<div>');
             var span = $('<span>');
@@ -166,14 +174,6 @@ define('io.ox/office/text/format/stylesheetmixin', [
             para.data({ attributes: { paragraph: baseAttributes.paragraph } });
             span.data({ attributes: { paragraph: baseAttributes.character } });
 
-            var counter = 1;
-
-            var validator = function (newName) {
-                var engNewName = getEnglishName(newName);
-                var oldStyleId = getFuzzyStyleId(newName, engNewName);
-                return oldStyleId ? getExistsAlreadyWarningText(oldStyleId) : null;
-            };
-
             para.addClass('caption');
             para.css({
                 display: 'block',
@@ -195,13 +195,12 @@ define('io.ox/office/text/format/stylesheetmixin', [
 
             span.appendTo(para);
 
-            if (!name) {
+            var counter = 1;
+            var name = null;
+            do {
                 name = gt('style %1$d', counter);
-                while (paraStyles.containsStyleSheetByName(name)) {
-                    counter++;
-                    name = gt('style %1$d', counter);
-                }
-            }
+                counter += 1;
+            } while (paraStyles.containsStyleSheetByName(name));
 
             var selection = self.getSelection();
             var activeRootNode = selection.getRootNode();
@@ -225,6 +224,13 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 span.text(name);
             }
 
+            function validator(newName) {
+                if (/^\s+$/.test(newName)) { return INVALID_NAME_WARNING; } // 56349
+                var engNewName = getEnglishName(newName);
+                var oldStyleId = getFuzzyStyleId(newName, engNewName);
+                return oldStyleId ? getExistsAlreadyWarningText(oldStyleId) : null;
+            }
+
             var dialog = new Dialogs.InputValidateDialog(app.getView(), {
                 title: gt('Create paragraph style'),
                 value: name,
@@ -232,14 +238,12 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 maxLength: 100
             });
 
-            dialog.on('show', function () {
-                dialog.append(para);
-            });
+            dialog.append(para);
 
-            var def = dialog.show();
+            // action handler for the OK button
+            dialog.setOkHandler(function () {
 
-            def = def.then(function () {
-                var styleId = dialog.getText();
+                var styleId = this.getText();
                 var selection = self.getSelection();
 
                 var startPos = selection.getStartPosition();
@@ -260,15 +264,11 @@ define('io.ox/office/text/format/stylesheetmixin', [
                     });
 
                     generateOverwriteStyleIdOp(localGenerator, paraPos, paraNode, styleId);
-
                     self.applyOperations(localGenerator);
                 });
-            }, function (result) {
-                // reopen the dialog if the style name entered in this dialog is invalid
-                return (result === 'invalid') ? self.showInsertNewStyleDialog(dialog.getText()) : result;
             });
 
-            return def;
+            return dialog.show();
         };
 
         this.showRenameStyleDialog = function (styleId, fieldName) {
@@ -277,6 +277,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
             var styleLabel = Utils.translateWordFromDatabase(styleName, paragraphEngToLocale);
 
             function validator(newName) {
+                if (/^\s+$/.test(newName)) { return INVALID_NAME_WARNING; } // 56349
                 var engNewName = getEnglishName(newName);
                 var oldStyleId = getFuzzyStyleId(newName, engNewName);
                 if (newName === styleName || newName === styleLabel) { return null; }
@@ -290,11 +291,12 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 maxLength: 100
             });
 
-            var def = dialog.show();
+            // action handler for the OK button
+            dialog.setOkHandler(function () {
 
-            def = def.then(function () {
-                var newName = dialog.getText();
+                var newName = this.getText();
                 var localGenerator = self.createOperationGenerator();
+
                 localGenerator.generateOperation(Operations.CHANGE_STYLESHEET, {
                     type: 'paragraph',
                     styleId: styleId,
@@ -304,12 +306,9 @@ define('io.ox/office/text/format/stylesheetmixin', [
                     custom: paraStyles.isCustom(styleId)
                 });
                 self.applyOperations(localGenerator);
-            }, function (result) {
-                // reopen the dialog if the style name entered in this dialog is invalid
-                return (result === 'invalid') ? self.showRenameStyleDialog(styleId, dialog.getText()) : null;
             });
 
-            return def;
+            return dialog.show();
         };
 
         this.changeStylesheet = function (styleId) {
@@ -321,11 +320,17 @@ define('io.ox/office/text/format/stylesheetmixin', [
             var paraPos = _.initial(startPos);
             var paraNode = self.getCurrentRootNode();
             var localGenerator = self.createOperationGenerator();
+            var styleSheets = self.getStyleCollection('paragraph');
 
             self.getUndoManager().enterUndoGroup(function () {
 
                 self.doCheckImplicitParagraph(startPos);
 
+                // register pending style sheet via 'insertStyleSheet' operation before modifying it
+                if (styleSheets.isDirty(styleId)) {
+                    self.generateInsertStyleOp(localGenerator, 'paragraph', styleId);
+                }
+
                 localGenerator.generateOperation(Operations.CHANGE_STYLESHEET, {
                     attrs: baseAttributes,
                     type: 'paragraph',
