@@ -116,6 +116,13 @@ define('io.ox/office/text/format/tablecellstyles', [
                 def: 0
             },
 
+            /**
+             * Vertical align of the content of the table cell.
+             */
+            alignVert: {
+                def: 'top'
+            },
+
             /**
              * Vertical merge of table cells.
              */
@@ -190,6 +197,9 @@ define('io.ox/office/text/format/tablecellstyles', [
 
             // the cell attributes
             var cellAttrs = mergedAttributes.cell;
+            cell.children('.cell').attr({
+                verticalalign: cellAttrs.alignVert
+            });
 
             cell.css({
                 backgroundColor: docModel.getCssColor(cellAttrs.fillColor, 'fill'),
@@ -218,6 +228,11 @@ define('io.ox/office/text/format/tablecellstyles', [
             if (mergeVert === 'continue') {
                 cellContentNode.attr('contenteditable', false);
                 cellContentNode.css('visibility', 'hidden');
+            // } else {
+            //     // TODO: This needs to be updated, if client can modify value of 'mergeVert' property.
+            //              This is for example the case after deleting or inserting new rows.
+            //     cellContentNode.attr('contenteditable', true);
+            //     cellContentNode.css('visibility', '');
             }
 
             cell.attr('mergeVert', mergeVert); // setting marker attribute at cell
@@ -244,12 +259,12 @@ define('io.ox/office/text/format/tablecellstyles', [
             // the cell attributes
             var cellAttrs = mergedAttributes.cell;
 
-            // horizontal span size
-            cell.attr('colspan', cellAttrs.gridSpan);
-
             // Hiding vertically merged cells to avoid impression of data loss (56291)
             handleVerticallyMergedTableCells(cell, cellAttrs);
 
+            // horizontal span size
+            cell.attr('colspan', cellAttrs.gridSpan);
+
             // update CSS attributes
             updateGenericFormatting(cell, mergedAttributes);
             cell.css({
