@@ -711,14 +711,14 @@ define('io.ox/office/text/model/listhandlermixin', [
         };
 
         /**
-         * Check, whether at a specified position the list auto detection shall be executed. In
-         * the text application there are not limitations yet.
+         * Check, whether at a specified position the list auto detection shall be executed.
          *
          * @returns {Boolean}
          *  Whether the list auto detection can be executed at the current position.
          */
         this.isAutoDetectionPosition = function () {
-            return true;
+            // in the text application the list detection must not happen in ODT files in shapes and frames.
+            return self.checkTextListAvailability();
         };
 
         /**
