@@ -677,6 +677,16 @@ define('io.ox/office/text/model/model', [
 
         };
 
+        /**
+         * Check, whether at the current position, a list can be inserted. This is in ODT not always the case (58663).
+         *
+         * @returns {Boolean}
+         *   Whether a list can be inserted at the current position.
+         */
+        this.checkTextListAvailability = function () {
+            return !app.isODF() || !self.getSelection().isAnyDrawingSelection() || self.isFullOdfTextframeFunctionality();
+        };
+
         // initialization -----------------------------------------------------
 
         pagediv = self.getNode();
