@@ -403,6 +403,9 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 }
             } else {
 
+                // Avoiding that the Safari Browser expands a right click to a word selection
+                if (rightClick && _.browser.Safari) { selection.storeCurrentSelectionState(); }
+
                 // clicked somewhere else: calculate logical selection from browser selection,
                 // after browser has processed the mouse event
                 selection.processBrowserEvent(event);
