@@ -37,6 +37,25 @@ define('io.ox/office/text/model/updatedocumentmixin', [
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Helper function to prepare the html content loaded from local storage before formatting
+         * the complete document content. This is necessary, if the user gets additional operations
+         * sent from the server during loading the document from local storage.
+         */
+        function prepareLocalStorageContent() {
+
+            // the content node of the page
+            var pageContentNode = DOM.getPageContentNode(self.getNode());
+            // the page layout object
+            var pageLayout = self.getPageLayout();
+
+            // removing all existing space maker nodes, because they are not yet connected to their
+            // corresponding drawings. Therefore after the full formatting there would be superfluous
+            // space maker nodes.
+            pageContentNode.find(DOM.DRAWING_SPACEMAKER_NODE_SELECTOR).remove();
+            pageLayout.getHeaderFooterPlaceHolder().find(DOM.DRAWINGPLACEHOLDER_NODE_SELECTOR).remove();
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -136,6 +155,14 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                 // the page attributes object
                 pageAttributes = pageStyles.getElementAttributes(editdiv);
 
+            // in special cases, this function is called, even though the document was loaded from local storage
+            // (additional operations were sent from the server). In this case some cleanup of the loaded strings
+            // from local storage is required
+            if (self.isLocalStorageImport()) { prepareLocalStorageContent(); }
+
+            // Collect all paragraphs with drawings to recalculate after drawing calculation.
+            var paragraphWithDrawingCollector = $();
+
             self.setPageAttributes(pageAttributes);
             self.setPageMaxHeight(Utils.convertHmmToLength(pageAttributes.page.height - pageAttributes.page.marginTop - pageAttributes.page.marginBottom, 'px', 1));
             self.setPagePaddingLeft(Utils.convertHmmToLength(pageAttributes.page.marginLeft, 'px', 1));
@@ -180,21 +207,25 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                     self.getParagraphStyles().updateElementFormatting(element);
                     updateFormatProgress(currentProgressTicks += 1);
 
+                    // Bug 56523: Tabs are calculated different dependent from loading process. This is because the
+                    // width of the drawings with activated fast-load are not calculated before. Done by collecting all
+                    // paragraphs with drawings to recalculate after drawings calculation
+                    if (element.children('div.drawing').length > 0) {
+                        paragraphWithDrawingCollector = paragraphWithDrawingCollector.add(element);
+                    }
+
                 } else if (DrawingFrame.isDrawingFrame(element)) {
 
                     // TODO: validate DOM of paragraphs embedded in text frames
                     self.getDrawingStyles().updateElementFormatting(element);
                     updateFormatProgress(currentProgressTicks += 1);
-                    if (Utils.SMALL_DEVICE && $(element).hasClass('float')) {
-                        //verticalOffsetNode.remove();
-                        $(element).parent().find('.float.offset').remove();
-
-                        $(element).removeClass('float left right').addClass('inline').css('margin', '0 1mm');
-                        $(element).css({ width: 'auto' });
-                    }
 
                     // adding an implicit paragraph into shapes without paragraph (50644)
-                    if (!app.isODF()) { DrawingFrame.checkEmptyTextShape(self, element); }
+                    if (!app.isODF()) {
+                        if (DrawingFrame.checkEmptyTextShape(self, element)) { // if new empty textframe is inserted, reformat is required
+                            self.getDrawingStyles().updateElementFormatting(element); // #56145
+                        }
+                    }
 
                     // also updating all paragraphs inside text frames (not searching twice for the drawings)
                     self.implParagraphChangedSync($(element).find(DOM.PARAGRAPH_NODE_SELECTOR));
@@ -233,6 +264,11 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                 });
             }
 
+            // recalculate paragraphs with drawings
+            function updateParagraphsWithDrawing() {
+                return self.iterateArraySliced(paragraphWithDrawingCollector, updateElementFormatting, 'UpdateDocumentMixin.updateElementFormatting 2');
+            }
+
             // dumps profiling information to browser console
             function dumpProfilingInformation() {
                 var tableCount,
@@ -300,7 +336,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                 splitListNodes = splitListNodes.add(headerFooterFormattingNodes);
                 self.firstPartOfDocumentFormatting(splitListNodes);
                 initialPbPromise = pageLayout.callInitialPageBreaks();
-                app.leaveBusyDuringImport();
+                app.leaveBusyDuringImport(null, { immediateShow: true });
             } else {
                 // add header and footer to formatting nodes
                 formattingNodes = formattingNodes.add(headerFooterFormattingNodes);
@@ -311,6 +347,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
 
             this.iterateArraySliced(formattingNodes, updateElementFormatting, 'UpdateDocumentMixin.updateElementFormatting')
                 // .then(updateDrawingGroups)
+                .then(updateParagraphsWithDrawing)
                 .then(updateListFormatting)
                 .then(function () { return pageLayout.callInitialPageBreaks({ triggerEvent: true }); })
                 .then(function () { return self.startParagraphMarginColorAndBorderFormating(); }) // must be after page-breaks
@@ -392,7 +429,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
             markup = JSON.parse(markup);
             self.setFullModelNode(markup.mainDocument);
 
-            return self.applyActions(actions, { external: true, useStorageData: false }).done(function () {
+            return self.applyActions(actions, { external: true }).done(function () {
                 self.firstPartOfDocumentFormatting();
                 self.getPageLayout().callInitialPageBreaks({ triggerEvent: true });
             });
@@ -403,27 +440,35 @@ define('io.ox/office/text/model/updatedocumentmixin', [
          */
         this.setDefaultPaperFormat = function () {
             var attrs = self.getStyleCollection('page').getElementAttributes(self.getNode());
+            var promise = null;
 
             if (attrs.page) {
                 var page = _.copy(attrs.page, true),
                     width = null,
-                    height = null;
+                    height = null,
+                    deltaWidth = 0,
+                    deltaHeight = 0,
+                    maxDelta = 2;
 
-                var loaclePaperSize = Utils.getPaperSizeByLocale(Config.LOCALE);
+                var localePaperSize = Utils.getPaperSizeByLocale(Config.LOCALE);
 
-                if (page.width !== loaclePaperSize.width || page.height !== loaclePaperSize.Height) {
-                    width = loaclePaperSize.width;
-                    height = loaclePaperSize.height;
+                if (page.width !== localePaperSize.width || page.height !== localePaperSize.height) {
+                    width = localePaperSize.width;
+                    height = localePaperSize.height;
+                    deltaWidth = (localePaperSize.width > page.width) ? (localePaperSize.width - page.width) : (page.width - localePaperSize.width);
+                    deltaHeight = (localePaperSize.height > page.height) ? (localePaperSize.height - page.height) : (page.height - localePaperSize.height);
                 }
 
-                if (width !== null) {
+                if (deltaWidth > maxDelta || deltaHeight > maxDelta) {
                     app.stopOperationDistribution(function () {
-                        self.setPaperFormat({ width: width, height: height, marginLeft: page.marginLeft, marginRight: page.marginRight }, page);
+                        promise = self.setPaperFormat({ width: width, height: height, marginLeft: page.marginLeft, marginRight: page.marginRight }, page);
                         self.getUndoManager().clearUndoActions();
+                        return promise;
                     });
                 }
             }
 
+            return promise ? promise : $.when();
         };
 
         // initialization -----------------------------------------------------
