@@ -83,7 +83,7 @@ define('io.ox/office/textframework/components/field/basefield', [
         };
 
         this.isAuthor = function (type) {
-            return type === 'author' || type === 'author-name' || type === 'AUTHOR';
+            return (/^AUTHOR/i).test(type) || type === 'author-name' || type === 'creator';
         };
 
         /**
@@ -165,8 +165,8 @@ define('io.ox/office/textframework/components/field/basefield', [
          */
         this.formatPageFieldInstruction = function (number, format, numPages) {
 
-            if (!format) {
-                Utils.warn('basefield.formatPageFieldInstruction(): missing format type!');
+            if (!_.isNumber(number)) {
+                Utils.warn('basefield.formatPageFieldInstruction(): invalid number argument!');
                 return '';
             }
 
@@ -182,13 +182,15 @@ define('io.ox/office/textframework/components/field/basefield', [
             }
 
             // OOXML format codes
-            if (/ALPHABETIC/.test(format)) { return Formatter.formatAlphabetic(number, 'repeat'); }
-            if (/alphabetic/.test(format)) { return Formatter.formatAlphabetic(number, 'repeat', { lower: true }); }
-            if (/ROMAN/.test(format)) { return Formatter.formatRoman(number, 4); }
-            if (/roman/.test(format)) { return Formatter.formatRoman(number, 4, { lower: true }); }
-            if (/ArabicDash/.test(format) && !numPages) { return '- ' + number + ' -'; }
-            if (/Hex/.test(format) && numPages) { return number.toString(16); }
-            if (/Ordinal/.test(format) && numPages) { return number + '.'; }
+            if (_.isString(format)) {
+                if (/ALPHABETIC/.test(format)) { return Formatter.formatAlphabetic(number, 'repeat'); }
+                if (/alphabetic/.test(format)) { return Formatter.formatAlphabetic(number, 'repeat', { lower: true }); }
+                if (/ROMAN/.test(format)) { return Formatter.formatRoman(number, 4); }
+                if (/roman/.test(format)) { return Formatter.formatRoman(number, 4, { lower: true }); }
+                if (/ArabicDash/.test(format) && !numPages) { return '- ' + number + ' -'; }
+                if (/Hex/.test(format) && numPages) { return number.toString(16); }
+                if (/Ordinal/.test(format) && numPages) { return number + '.'; }
+            }
             return number.toString();
         };
 
