@@ -295,25 +295,27 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          * @param {jQuery.Event} event
          *  The jQuery event object.
          *
-         * @param {Function} options
+         * @param {Object} [options]
          *  Passed selection options.
-         *
+         *  @param {Boolean} [options.simpleTextSelection=false]
          */
         function checkHighlighting(event, options) {
-            var isSimpleTextSelection = Utils.getBooleanOption(options, 'simpleTextSelection', false),
-                domPos = null,
-                node = null,
-                atEndOfSpan = null,
-                relevantEvents = ['mousedown', 'mouseup', 'touchstart', 'touchend'],
-                browserEvent = (options && options.event) ? options.event : null,
-                mouseTouchEvent = _.isObject(browserEvent) && _.contains(relevantEvents, browserEvent.type),
-                rightClick = _.isObject(browserEvent) && (browserEvent.type === 'mousedown') && (browserEvent.button === 2);
+            var isSimpleTextSelection = Utils.getBooleanOption(options, 'simpleTextSelection', false);
+            var domPos = null;
+            var node = null;
+            var atEndOfSpan = null;
+            var relevantEvents = ['mousedown', 'mouseup', 'touchstart', 'touchend'];
+            var browserEvent = (options && options.event) ? options.event : null;
+            var mouseTouchEvent = _.isObject(browserEvent) && _.contains(relevantEvents, browserEvent.type);
+            var rightClick = _.isObject(browserEvent) && (browserEvent.type === 'mousedown') && (browserEvent.button === 2);
+            var isFieldCollectionEmpty = complexField.isEmpty() && simpleField.isEmpty();
+            var skipHighlighting = (isFieldCollectionEmpty || isSimpleTextSelection || selection.hasRange());
 
             function isBeforeCxFldStart(element) {
                 return DOM.isRangeMarkerStartNode(element) && DOM.getRangeMarkerType(element) === 'field';
             }
 
-            if ((complexField.isEmpty() && simpleField.isEmpty()) || isSimpleTextSelection || selection.hasRange()) {
+            if (!self.isHighlightState() && skipHighlighting) {
                 return;
             } else {
                 domPos = Position.getDOMPosition(selection.getRootNode(), selection.getStartPosition());
@@ -388,6 +390,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
             if (!fieldValue) {
                 if (!fieldFormat) { return; } // no data to update, exit
+                if (fieldFormat === 'default') { fieldFormat = LocaleData.SHORT_DATE; } // #54713
                 fieldValue = getDateTimeRepresentation(fieldFormat);
             }
 
@@ -436,7 +439,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 isComplex = true,
                 representation,
                 attrs = {},
-                type;
+                type,
+                instruction;
 
             if (currentlyHighlightedNode) { // simple field
                 node = currentlyHighlightedNode;
@@ -457,8 +461,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                         operation = { start: pos, attrs: { character: { autoDateField: state } } };
                         model.extendPropertiesWithTarget(operation, target);
                         generator.generateOperation(Operations.COMPLEXFIELD_UPDATE, operation);
-
                         model.applyOperations(generator.getOperations());
+
+                        instruction = DOM.getComplexFieldInstruction(node);
                     } else {
                         if (app.isODF()) {
                             type = 'date';
@@ -470,10 +475,12 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                         operation = { start: pos, type: type, representation: representation, attrs: attrs };
                         model.extendPropertiesWithTarget(operation, target);
                         generator.generateOperation(Operations.FIELD_UPDATE, operation);
-
                         model.applyOperations(generator.getOperations());
 
+                        instruction = DOM.getFieldInstruction(node);
                     }
+                    // on activating auto update, refresh the date
+                    if (state) { self.updateByInstruction(node, instruction, { complex: isComplex }); }
                 });
             } else {
                 Utils.warn('fieldmanager.setDateFieldToAutoUpdate(): invalid position for field node!');
@@ -498,19 +505,25 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          *  Optional parameters:
          *  @param {Boolean} [options.complex=false]
          *      If field is simple or complex type.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved immediately in case of simple field,
+         *  or when the promise from complex field update is resolved.
          */
         this.updateByInstruction = function (node, instruction, options) {
             var isComplex = Utils.getBooleanOption(options, 'complex', false);
+            var promise = $.when();
 
             if (instruction) {
                 if (isComplex) {
-                    complexField.updateByInstruction(node, instruction);
+                    promise = complexField.updateByInstruction(node, instruction); // updateToc returns promise
                 } else {
                     simpleField.updateByInstruction(node, instruction);
                 }
             } else {
                 Utils.warn('FieldManager.updateByInstruction(): missing instruction!');
             }
+            return promise;
         };
 
         /**
@@ -650,8 +663,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             var instruction = DOM.getComplexFieldInstruction(node);
             var isTOCfield = instruction && (/TOC/i).test(instruction);
             var tooltipText = gt('Table of Contents. Right click...');
+            var isRotatedShape = (node && node.length) ? node.parentsUntil('.page', '.rotated-drawing').length > 0 : false;
 
-            if (!isTOCfield && currentlyHighlightedId !== id) { // no highlighting of toc fields, #50504
+            if (!isRotatedShape && !isTOCfield && currentlyHighlightedId !== id) { // no highlighting of toc fields, #50504
                 rangeMarker.highLightRange(id, 'cx-field-highlight');
             }
             // set tooltip to table of contents field element, if hyperlink switch is set in instruction
@@ -698,20 +712,15 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          *      If its right click or not.
          */
         this.createEnterHighlight = function (field, options) {
-            var // id of the highlighted field
-                id = DOM.getComplexFieldMemberId(field),
-                isSimpleField = Utils.getBooleanOption(options, 'simpleField', false),
-                isMouseTouchEvent = Utils.getBooleanOption(options, 'mouseTouchEvent', false),
-                isRightClick = Utils.getBooleanOption(options, 'rightClick', false),
-                fieldinstruction = null,
-                node = null,
-                complexFieldNode = null,
-                fieldFormats,
-                isDateTimeField,
-                isSupportedFormat,
-                isNotChangeTracked;
-
-            options = {};
+            var id = DOM.getComplexFieldMemberId(field); // id of the highlighted field
+            var isSimpleField = Utils.getBooleanOption(options, 'simpleField', false);
+            var isMouseTouchEvent = Utils.getBooleanOption(options, 'mouseTouchEvent', false);
+            var isRightClick = Utils.getBooleanOption(options, 'rightClick', false);
+            var fieldinstruction = null;
+            var node = null;
+            var complexFieldNode = null;
+            var fieldFormats, isDateTimeField, isSupportedFormat, isNotChangeTracked;
+            var localOptions = {};
 
             if (isSimpleField) {
                 if (currentlyHighlightedId || currentlyHighlightedNode) {
@@ -720,7 +729,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 currentlyHighlightedNode = $(field);
                 currentlyHighlightedNode.addClass('sf-highlight');
 
-                options.autoDate = !DOM.isFixedSimpleField(field, app.isODF());
+                localOptions.autoDate = !DOM.isFixedSimpleField(field, app.isODF());
                 fieldinstruction = { type: DOM.getFieldInstruction(field) };
 
                 if (fieldinstruction.type && app.isODF() && (simpleField.isCurrentDate(fieldinstruction.type) || simpleField.isCurrentTime(fieldinstruction.type))) {
@@ -730,25 +739,27 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 } else {
                     fieldinstruction = simpleField.cleanUpAndExtractType(fieldinstruction.type);
                 }
-                if (!fieldinstruction.instruction) {
-                    fieldinstruction.instruction = 'default';
-                }
+                // fallback to default
+                fieldinstruction.instruction = fieldinstruction.instruction || 'default';
             } else {
+                complexFieldNode = self.getComplexField(id);
                 if (currentlyHighlightedId !== id) {
                     if (currentlyHighlightedId || currentlyHighlightedNode) {
                         self.removeEnterHighlight();
                     }
                     currentlyHighlightedId = id;
-                    rangeMarker.highLightRange(id, 'cx-field-highlight');
-                }
-                complexFieldNode = self.getComplexField(currentlyHighlightedId);
 
+                    // make no highlighting inside rotated shapes and rotated group shapes
+                    if (!$(complexFieldNode).parentsUntil('.page', '.rotated-drawing').length) {
+                        rangeMarker.highLightRange(id, 'cx-field-highlight');
+                    }
+                }
                 if (!complexFieldNode) {
                     Utils.warn('fieldmanager.createEnterHighlight(): failed to fetch complex field node!');
                     self.removeEnterHighlight();
                     return;
                 }
-                options.autoDate = DOM.isAutomaticDateField(complexFieldNode);
+                localOptions.autoDate = DOM.isAutomaticDateField(complexFieldNode);
                 fieldinstruction = DOM.getComplexFieldInstruction(complexFieldNode);
                 fieldinstruction = complexField.cleanUpAndExtractType(fieldinstruction);
             }
@@ -770,14 +781,12 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
             if (highlightedFieldType && isSupportedFormat && isMouseTouchEvent && !isRightClick && isNotChangeTracked) {
                 fieldFormatPopupTimeout = self.executeDelayed(function () {
-                    app.getView().showFieldFormatPopup(fieldinstruction, node, options);
+                    app.getView().showFieldFormatPopup(fieldinstruction, node, localOptions);
                 }, 'FieldManager.createEnterHighlight', 500);
             }
 
             // for debugging ->
-//            if (!highlightedFieldType) {
-//                Utils.error('no highlightedFieldType');
-//            }
+            // if (!highlightedFieldType) { Utils.error('no highlightedFieldType'); }
         };
 
         /**
@@ -807,7 +816,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             var node,
                 instruction,
                 atEndOfSpan,
-                domPos;
+                domPos,
+                promise = null;
 
             if (currentlyHighlightedNode) { // simple field
                 node = currentlyHighlightedNode;
@@ -833,8 +843,10 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             } else if (currentlyHighlightedId) { // complex field
                 node = self.getComplexField(currentlyHighlightedId);
                 instruction = DOM.getComplexFieldInstruction(node);
-                self.updateByInstruction(node, instruction, { complex: true });
+                promise = self.updateByInstruction(node, instruction, { complex: true });
             }
+
+            return promise ? promise : $.when();
         };
 
         /**
@@ -886,9 +898,10 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                         // #42671 and #45752
                         selection.swichToValidRootNode(field);
                         options = isSimpleField ? null : { complex: true };
-                        self.updateByInstruction(field, instruction, options);
+                        return self.updateByInstruction(field, instruction, options);
                     }
                 }
+                return $.when();
             }
 
             if (self.fieldsAreInDocument()) {
@@ -901,20 +914,22 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                             generateDef.abort();
                         }
                     },
-                    warningLabel: gt('Sorry, updating of all fields in document will take some time.')
+                    warningLabel: gt('Updating all fields in document will take some time.')
                 });
 
-                // iterate objects
-                generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, 'FieldManager.updateAllFields')
-                .always(function () {
-                    // leave busy state
-                    app.getView().leaveBusy().grabFocus();
-                });
+                return model.getUndoManager().enterUndoGroup(function () {
+                    // iterate objects
+                    generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, 'FieldManager.updateAllFields')
+                        .progress(function (partialProgress) {
+                            // add progress handling
+                            var progress = 0.2 + (partialProgress * 0.8);
+                            app.getView().updateBusyProgress(progress);
+                        }).always(function () {
+                            // leave busy state
+                            app.getView().leaveBusy().grabFocus();
+                        });
 
-                // add progress handling
-                generateDef.progress(function (partialProgress) {
-                    var progress = 0.2 + (partialProgress * 0.8);
-                    app.getView().updateBusyProgress(progress);
+                    return generateDef;
                 });
             }
         };
@@ -1130,6 +1145,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             }
 
             self.addSimpleFieldToCollection(fieldNode, target);
+            if (model.getPageLayout().isIdOfMarginalNode(target)) {
+                fieldNode.addClass(DOM.MARGINAL_NODE_CLASSNAME); // #54118
+            }
 
             // validate paragraph, store new cursor position
             model.implParagraphChanged(span.parentNode);
@@ -1452,7 +1470,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 highlightedNode = currentlyHighlightedNode,
                 highlightedId = currentlyHighlightedId,
                 isSpecialField = false,
-                isFixedDate;
+                isFixedDate,
+                complexFieldNode,
+                rangeEndMarkerNode;
 
             // hide popup
             self.destroyFieldPopup();
@@ -1475,9 +1495,19 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 }
 
             } else if (highlightedId) { // complex field
-                fieldNodePos = Position.getOxoPosition(rootNode, complexField.getComplexField(highlightedId));
+                complexFieldNode = complexField.getComplexField(highlightedId);
+                rangeEndMarkerNode = rangeMarker.getEndMarker(highlightedId);
+                if (!complexFieldNode) {
+                    Utils.error('fieldManager.updateFieldFormatting(): missing field node for the id: ', highlightedId);
+                    return;
+                }
+                if (!rangeEndMarkerNode) {
+                    Utils.error('fieldManager.updateFieldFormatting(): missing range end node for field id: ', highlightedId);
+                    return;
+                }
+                fieldNodePos = Position.getOxoPosition(rootNode, complexFieldNode);
                 startPos = Position.increaseLastIndex(fieldNodePos);
-                endPos = Position.getOxoPosition(rootNode, rangeMarker.getEndMarker(highlightedId));
+                endPos = Position.getOxoPosition(rootNode, rangeEndMarkerNode);
                 node = complexField.getComplexField(highlightedId);
                 if (node.length && DOM.isSpecialField(node)) {
                     isSpecialField = true;
@@ -1495,10 +1525,19 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                             }
                         }
 
-                        model.deleteSelected(); // we delete content between field node and range end.
-                        complexField.updateComplexFieldFormat(fieldType, format, fieldNodePos, highlightedId);
-                        if (isSpecialField) {
-                            complexField.convertToSpecialField(highlightedId, selection.getRootNodeTarget(), fieldType);
+                        if (model.getChangeTrack().isActiveChangeTracking()) {
+                            complexField.updateComplexFieldFormat(fieldType, format, fieldNodePos, highlightedId);
+                            if (isSpecialField) {
+                                complexField.convertToSpecialField(highlightedId, selection.getRootNodeTarget(), fieldType);
+                            }
+                            return $.when();
+                        } else {
+                            return model.deleteSelected().done(function () {
+                                complexField.updateComplexFieldFormat(fieldType, format, fieldNodePos, highlightedId);
+                                if (isSpecialField) {
+                                    complexField.convertToSpecialField(highlightedId, selection.getRootNodeTarget(), fieldType);
+                                }
+                            });
                         }
                     });
                 }
@@ -1745,12 +1784,10 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             });
 
             self.waitForImportSuccess(function () {
-                if (model.isLocalStorageImport() || model.isFastLoadImport()) {
-                    complexField.refreshComplexFields(model.isLocalStorageImport(), model.isFastLoadImport());
-                    simpleField.refreshSimpleFields();
-                    // refreshing also the range marker model, if it was not done before
-                    rangeMarker.refreshModel({ onlyOnce: true });
-                }
+                complexField.refreshComplexFields(model.isLocalStorageImport(), model.isFastLoadImport());
+                simpleField.refreshSimpleFields();
+                // refreshing also the range marker model, if it was not done before
+                rangeMarker.refreshModel({ onlyOnce: true });
                 // resolve import success for update fields callback
                 deferred2.resolve();
 
@@ -1770,11 +1807,11 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                     }
                 } else {
                     localFormatList.date.push({ option: LocaleData.SHORT_DATE, value: getDateTimeRepresentation(LocaleData.SHORT_DATE) },
-                            { option: LocaleData.LONG_DATE, value: getDateTimeRepresentation(LocaleData.LONG_DATE) });
+                        { option: LocaleData.LONG_DATE, value: getDateTimeRepresentation(LocaleData.LONG_DATE) });
                 }
                 // append two most common time formats in date menu
                 localFormatList.date.push({ option: LocaleData.SHORT_TIME, value: getDateTimeRepresentation(LocaleData.SHORT_TIME) },
-                        { option: LocaleData.LONG_TIME, value: getDateTimeRepresentation(LocaleData.LONG_TIME) });
+                    { option: LocaleData.LONG_TIME, value: getDateTimeRepresentation(LocaleData.LONG_TIME) });
 
                 // fill in time codes
                 if (categoryCodesTime.length) {
@@ -1783,7 +1820,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                     });
                 } else {
                     localFormatList.time.push({ option: LocaleData.SHORT_TIME, value: getDateTimeRepresentation(LocaleData.SHORT_TIME) },
-                            { option: LocaleData.LONG_TIME, value: getDateTimeRepresentation(LocaleData.LONG_TIME) });
+                        { option: LocaleData.LONG_TIME, value: getDateTimeRepresentation(LocaleData.LONG_TIME) });
                 }
             });
 
