@@ -627,13 +627,27 @@ define('io.ox/office/textframework/components/field/simplefield', [
 
             _.each(allSimpleFields, function (id, fieldEntry) {
                 var field = self.getSimpleField(fieldEntry);
-                if (app.isEditable() && !DOM.isFixedSimpleField(field, app.isODF()) && (!DOM.isMarginalNode(field) || !DOM.isInsideHeaderFooterTemplateNode(model.getNode(), field))) {
+                var fieldInstruction = DOM.getFieldInstruction(field);
+                var isDateTimeField = fieldInstruction && (self.isCurrentDate(fieldInstruction) || self.isCurrentTime(fieldInstruction));
+                var isFixed = DOM.isFixedSimpleField(field, app.isODF());
+                var selectedDrawing;
+
+                if (app.isEditable() && isDateTimeField && !isFixed && (!DOM.isMarginalNode(field) || !DOM.isInsideHeaderFooterTemplateNode(model.getNode(), field))) {
                     // if previously updated field is marginal, and this is not, leave header edit state
                     selection.swichToValidRootNode(field);
-                    self.updateDateTimeField(field, DOM.getFieldInstruction(field));
+                    self.updateDateTimeField(field, fieldInstruction);
                     returnOriginalCursorPos = true;
                     if (pageLayout.isIdOfMarginalNode(id) && model.isHeaderFooterEditState() && DOM.isHeaderOrFooter(selection.getRootNode())) {
+                        // clear possible leftover selection on drawings and textframes
+                        if (selection.getSelectionType() === 'drawing') {
+                            selectedDrawing = selection.getSelectedDrawing();
+                        }
+                        if (selection.isAdditionalTextframeSelection()) {
+                            selectedDrawing = selection.getSelectedTextFrameDrawing();
+                        }
+                        if (selectedDrawing && selectedDrawing.length) { DrawingFrame.clearSelection(selectedDrawing); }
                         pageLayout.getHeaderFooterPlaceHolder().children('.' + id).empty().append(selection.getRootNode().children().clone(true));
+                        if (selectedDrawing && selectedDrawing.length) { selection.drawDrawingSelection(selectedDrawing); }
                     }
                 }
             });
@@ -788,9 +802,9 @@ define('io.ox/office/textframework/components/field/simplefield', [
 
                 if (selection.hasRange()) {
                     return model.deleteSelected()
-                    .done(function () {
-                        doInsertField();
-                    });
+                        .done(function () {
+                            doInsertField();
+                        });
                 }
 
                 doInsertField();
