@@ -15,13 +15,12 @@
 define('io.ox/office/textframework/components/hyperlink/hyperlink', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
-    'io.ox/office/tk/dialogs',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position'
-], function (Utils, KeyCodes, Dialogs, AttributeUtils, HyperlinkUtils, Operations, DOM, Position) {
+], function (Utils, KeyCodes, AttributeUtils, HyperlinkUtils, Operations, DOM, Position) {
 
     'use strict';
 
@@ -347,7 +346,10 @@ define('io.ox/office/textframework/components/hyperlink/hyperlink', [
             if (url) {
                 // for the setAttributes operation, it is necessary to reduce the end position by '1'
                 // -> otherwise following text spans behind 'space' or 'enter' receive also the url.
-                if (hyperlinkSelection && hyperlinkSelection.end) { hyperlinkSelection.end--; }
+                if (hyperlinkSelection && hyperlinkSelection.end) {
+                    hyperlinkSelection.end--;
+                    if (hyperlinkSelection.end < hyperlinkSelection.start) { hyperlinkSelection.start = hyperlinkSelection.end; } // avoiding inverse selections
+                }
                 // generating the return object from the found selection
                 result = createResultFromHyperlinkSelection(position, hyperlinkSelection);
                 result.url = url;
