@@ -170,7 +170,7 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                 // the searched range marker with the specified id
                 marker = null;
 
-            marginalNode = model.getRootNode(target, index, { allowMarginalUpdate: false }); // option required because of 40199 (TODO: Needs to be removed again)
+            marginalNode = model.getRootNode(target, index);
 
             if (marginalNode) {
                 marker = _.find(marginalNode.find(selector), function (marker) { return DOM.getRangeMarkerId(marker) === id; });
@@ -409,13 +409,17 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
          *  The position of the range marker. Currently supported are 'start'
          *  and 'end'.
          *
+         * @param {Object} [attrs]
+         *  Attributes to be applied at the new range component, as map of
+         *  attribute maps (name/value pairs), keyed by attribute family.
+         *
          * @param {String} [target]
          *  The target corresponding to the specified logical start position.
          *
          * @returns {Boolean}
          *  Whether the range marker has been inserted successfully.
          */
-        this.insertRangeHandler = function (start, id, type, position, target) {
+        this.insertRangeHandler = function (start, id, type, position, attrs, target) {
 
             var // whether this is a range marker for the start or the end of a range
                 rangeMarkerTypeClass = (position === 'end') ? DOM.RANGEMARKER_ENDTYPE_CLASS : DOM.RANGEMARKER_STARTTYPE_CLASS,
@@ -451,12 +455,15 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
             // splitting text span to insert range marker node
             rangeMarkerNode.insertAfter(textSpan);
 
+            // Adding attribute set to range marker node, if specified
+            if (attrs) { model.getCharacterStyles().setElementAttributes(rangeMarkerNode, attrs); }
+
             // adding the range marker node in the collection of all range markers
             // -> this also needs to be done after loading document from fast load or using local storage
             addIntoRangeMarkerCollection(rangeMarkerNode, id, target);
 
             // complex fields highlight
-            if (position === 'end' && type === 'field') {
+            if (model.isImportFinished() && position === 'end' && type === 'field') {
                 model.getFieldManager().markFieldForHighlighting(id);
                 // converts page fields in header&footer to special fields
                 if (target && model.getPageLayout().isIdOfMarginalNode(target)) {
@@ -611,7 +618,11 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                 isMultiLine = ((startPos.y + startNodeHeight) !== (endPos.y + endNodeHeight));
 
                 // adding simple correction factors for spans with different font sizes
-                textSpan = Utils.findNextSiblingNode(startNode, 'span');
+                if (DOM.isSpecialField(startNode.next())) {
+                    textSpan = startNode.next().children('span').first();
+                } else {
+                    textSpan = Utils.findNextSiblingNode(startNode, 'span');
+                }
                 correction = textSpan ? Utils.convertCssLength($(textSpan).css('font-size'), 'px', 1) - Utils.convertCssLength($(startNode).css('font-size'), 'px', 1) : 0;
 
                 startPos.y -= correction;
