@@ -381,6 +381,9 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
          *
          * @param {String} replacement
          *  The replacement for the found text occurences.
+         *
+         * @returns {jQuery.Promise}
+         *  A jQuery promise object.
          */
         this.replaceSearchResult = function (id, replacement) {
 
@@ -406,7 +409,9 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // the index inside the logical position that need to be updated
                 changeIndex = 0,
                 // currently active root node
-                activeRootNode = model.getCurrentRootNode();
+                activeRootNode = model.getCurrentRootNode(),
+                // the deferred return value
+                def = self.createDeferred('SearchHandler.replaceSearchResult');
 
             // helper function to remove highlighting from a specified result
             function removeHighlighting(oneResult) {
@@ -436,7 +441,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
             if (!currentResult) {
                 currentSearchResultId = 0;
-                return;
+                return $.when();
             }
 
             // handling search results that cannot be replaced, because the contain additional content,
@@ -447,7 +452,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // removing the current result from the list of all results
                 updateSearchResults(currentResult);
                 // ... but do not replace this search result
-                return;
+                return $.when();
             }
 
             if (model.useSlideMode()) {
@@ -506,26 +511,32 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // finally delete the previous text.
                 startPosition[startPosition.length - 1] += replacement.length;
                 selection.setTextSelection(startPosition, endPosition);
-                model.deleteSelected();
 
-                // reset indicator
-                replaceOperation = false;
+                return model.deleteSelected().done(function () {
+
+                    // reset indicator
+                    replaceOperation = false;
+
+                    // update all positions that are in the same paragraph or table cell. Also handle
+                    // all following positions inside text frames, that are in the same paragraph (40911)
+                    changeIndex = currentResult.start.length - 1;
+
+                    for (var updateId = id + 1; updateId < searchResults.length; updateId++) {
+                        result = searchResults[updateId];
+                        if (result && Position.hasSameParentComponentAtSpecificIndex(currentResult.start, result.start, changeIndex) && (currentResult.start[changeIndex] < result.start[changeIndex]) && hasSameTarget(currentResult, result)) {
+                            result.start[changeIndex] += textDelta;
+                            result.end[changeIndex] += textDelta;
+                        }
+                    }
+
+                    // remove replaced result from search results
+                    updateSearchResults(currentResult);
+
+                    def.resolve();
+                });
             });
 
-            // update all positions that are in the same paragraph or table cell. Also handle
-            // all following positions inside text frames, that are in the same paragraph (40911)
-            changeIndex = currentResult.start.length - 1;
-
-            for (var updateId = id + 1; updateId < searchResults.length; updateId++) {
-                result = searchResults[updateId];
-                if (result && Position.hasSameParentComponentAtSpecificIndex(currentResult.start, result.start, changeIndex) && (currentResult.start[changeIndex] < result.start[changeIndex]) && hasSameTarget(currentResult, result)) {
-                    result.start[changeIndex] += textDelta;
-                    result.end[changeIndex] += textDelta;
-                }
-            }
-
-            // remove replaced result from search results
-            updateSearchResults(currentResult);
+            return def.promise();
         };
 
         /**
@@ -535,8 +546,8 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
          *  The replacement for the found text occurences.
          */
         this.replaceSelectedSearchResult = function (replacement) {
-            this.replaceSearchResult(currentSearchResultId, replacement);
-            selectSearchResult(currentSearchResultId);
+            var replacePromise = self.replaceSearchResult(currentSearchResultId, replacement);
+            replacePromise.done(function () { selectSearchResult(currentSearchResultId); });
         };
 
         /**
@@ -1031,20 +1042,26 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // apply generated operations
                 applyDef = model.applyOperations(generator, { async: true })
                 // set cursor behind last replacement text
-                .done(function () {
-                    selection.setTextSelection(initialStart);
-                    replaceOperation = false;
-                    model.setGUITriggeredOperation(false);
-                })
-                // leave busy state and close undo group
-                .always(function () {
-                    app.getView().leaveBusy().grabFocus();
-                    undoDef.resolve();
-                })
-                // add progress handling
-                .progress(function (progress) {
-                    app.getView().updateBusyProgress(progress);
-                });
+                    .done(function () {
+                        if (!Position.isValidTextPosition(model.getCurrentRootNode(), initialStart)) { // the position might no longer be valid after replacing content (58543)
+                            initialStart = Position.findValidSelection(model.getCurrentRootNode(), initialStart, selection.getEndPosition(), selection.getLastDocumentPosition(), model.useSlideMode());
+                            initialStart = initialStart.start;
+                        }
+
+                        selection.setTextSelection(initialStart);
+
+                        replaceOperation = false;
+                        model.setGUITriggeredOperation(false);
+                    })
+                    // leave busy state and close undo group
+                    .always(function () {
+                        app.getView().leaveBusy().grabFocus();
+                        undoDef.resolve();
+                    })
+                    // add progress handling
+                    .progress(function (progress) {
+                        app.getView().updateBusyProgress(progress);
+                    });
 
                 return undoDef.promise();
 
