@@ -968,6 +968,9 @@ define('io.ox/office/textframework/components/table/table', [
                 uiPriority: tableStyles.getUIPriority(tableStyleId)
             };
 
+            // adding property 'fallbackValue' to themed colors inside the specified attributes
+            if (editor.getApp().isODF() && tableStyleAttributes.attrs) { editor.addFallbackValueToThemeColors(tableStyleAttributes.attrs); }
+
             // parent is optional, should not be send with null or empty string (46937)
             if (tableStyleAttributes.parent === null || tableStyleAttributes.parent === '') { delete tableStyleAttributes.parent; }
 
@@ -1618,15 +1621,17 @@ define('io.ox/office/textframework/components/table/table', [
      * @param {Array<Number>} position
      *  The logical position of the table.
      *
-     * @param {OperationsGenerator} generator
+     * @param {OperationGenerator} generator
      *  The operations generator
      */
     Table.removeTableAttributes = function (docModel, rootNode, tableNode, position, generator) {
 
         var // the options for the table operation
             tableOperationOptions = {},
+            // the attribute pool used for table attributes
+            attributePool = docModel.getTableStyles().getAttributePool(),
             // remove all explicit table attributes
-            tableAttributes = docModel.buildNullAttributes('table');
+            tableAttributes = attributePool.buildNullValues('table');
 
         // exclude some table attributes
         delete tableAttributes.width;
@@ -1648,7 +1653,7 @@ define('io.ox/office/textframework/components/table/table', [
             var // the options for the cell operation
                 cellOperationOptions = {},
                 // remove all explicit cell attributes
-                cellAttributes = docModel.buildNullAttributes('cell'),
+                cellAttributes = attributePool.buildNullValues('cell'),
                 // the old element attributes
                 oldAttrs = null;
 
