@@ -428,6 +428,12 @@ define('io.ox/office/textframework/format/characterstyles', [
                     case 'percent':
                         // 'lineHeight.value' is a value in percent
                         height = normalLineHeight * lineHeight.value / 100;
+
+                        // -> handling of Bug 47960 & Bug 45951, lineHeight in PP is based on "baseline" instead of "fontsize" -> factor 1.15
+                        // -> not using 'LineHeight._115' as default value, because a switch from '1.0' to '1.1' in the paragraph settings
+                        //    of PP leads to operation with 110 % line height. This must increase the existing lineheight, and not decrease it,
+                        //    as it would be, if the lineheight is changed from 115% (the default) to 110%. (61284)
+                        if (docModel.getApp().isPresentationApp()) { height *= 1.15; }
                         break;
                     case 'normal':
                         height = normalLineHeight;
