@@ -80,7 +80,7 @@ define('io.ox/office/textframework/format/paragraphstyles', [
     var NBSP = '\xa0';
 
     // maps fill character attribute values to fill characters
-    var TAB_FILL_CHARS = { dot: '.', hyphen: '-', underscore: '_' };
+    var TAB_FILL_CHARS = { dot: '.', hyphen: '-', underscore: '_', middleDot: '·' };
 
     // class ParagraphStyles ==================================================
 
@@ -167,7 +167,7 @@ define('io.ox/office/textframework/format/paragraphstyles', [
          * depending on the position and the remaining size of
          * the following nodes.
          *
-         * @param {Object} tabStop
+         * @param {Number} tabStopPos
          *  The right aligned tab stop.
          *
          * @param {jQuery} tabNode
@@ -180,7 +180,7 @@ define('io.ox/office/textframework/format/paragraphstyles', [
          *  The width of the right aligned tab stop. May be zero if the
          *  tab stop is not active.
          */
-        function calcRightAlignTabstop(tabStop, tabNode, tabNodePosHMM) {
+        function calcRightAlignTabstop(tabStopPos, tabNode, tabNodePosHMM) {
             var nextNodes = tabNode.nextAll(),
                 node,
                 rightPos = tabNodePosHMM,
@@ -188,7 +188,7 @@ define('io.ox/office/textframework/format/paragraphstyles', [
 
             // Loop through all following nodes and sum up their width. Exceeding
             // the tab stop position or a new tab stops the iteration.
-            for (i = 0; i < len && rightPos < tabStop.pos; i++) {
+            for (i = 0; i < len && rightPos < tabStopPos; i++) {
                 node = $(nextNodes.get(i));
                 if (DOM.isTabNode(node)) {
                     break;
@@ -196,10 +196,10 @@ define('io.ox/office/textframework/format/paragraphstyles', [
                 rightPos += Utils.convertLengthToHmm(node.width(), 'px');
             }
 
-            if (rightPos < tabStop.pos) {
+            if (rightPos < tabStopPos) {
                 // Active right aligned tab stop. Subtract at least 1/10mm
                 // rounding error regarding position values from the browser.
-                width = tabStop.pos - rightPos - 10;
+                width = tabStopPos - rightPos - 10;
                 width = Math.max(0, width);
             }
 
@@ -303,13 +303,10 @@ define('io.ox/office/textframework/format/paragraphstyles', [
                 topFirst = firstNode.length ? Utils.convertLengthToHmm(firstNode.position().top, 'px') : 0;
                 heightFirst = firstNode.length ? Utils.convertLengthToHmm(firstNode.height(), 'px') : 0;
 
-                //reset all tab sizes, for a much cleaner new calculating
-                //(for example changing text-alignment from justify to left)
                 paragraph.children(DOM.TAB_NODE_SELECTOR).each(function () {
+                    //reset all tab sizes, for a much cleaner new calculating
+                    //(for example changing text-alignment from justify to left)
                     $(this).css('width', 0);
-                });
-
-                paragraph.children(DOM.TAB_NODE_SELECTOR).each(function () {
 
                     var // the current tab node of the paragraph
                         tabNode = $(this),
@@ -343,7 +340,13 @@ define('io.ox/office/textframework/format/paragraphstyles', [
                         indentFirstLineTabStopIndex = 0;
 
                     function calcLeftTab() { return Math.max(0, tabStop.pos - (leftHMM % tabStop.pos)); }
-                    function calcRightTab() { return calcRightAlignTabstop(tabStop, tabNode, leftHMM); }
+                    function calcRightTab() {
+                        var paraParent = paragraph.parent();
+                        var paraWidth = paraParent.hasClass('cellcontent') ? Utils.convertLengthToHmm(paraParent.width()) : (Utils.convertLengthToHmm(paragraph.width()) + marginLeft);
+                        // smaller value wins (for example in tables, para width is smaller than tabstop width)
+                        var effTabStopPos = Math.min(tabStop.pos, paraWidth);
+                        return calcRightAlignTabstop(effTabStopPos, tabNode, leftHMM);
+                    }
                     function calcMiddleTab() { return (calcLeftTab() + calcRightTab()) / 2; }
 
                     if (mergedAttributes.paragraph.alignment === 'center') {
