@@ -512,7 +512,7 @@ define('io.ox/office/textframework/format/tablestyles', [
                 promise = self.iterateArraySliced(rowNodes, updateRowFormatting, 'TableStyles.updateTableFormatting');
                 promise.always(function () {
                     if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); } // (48370)
-                    docModel.trigger('table:formatting:done');
+                    docModel.trigger('table:formatting:done', table);
                 });
 
             } else {
@@ -520,7 +520,7 @@ define('io.ox/office/textframework/format/tablestyles', [
                 promise = self.executeDelayed(function () {
                     rowNodes.each(function () { updateRowFormatting(this); });
                     if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); } // (48370)
-                    docModel.trigger('table:formatting:done');
+                    docModel.trigger('table:formatting:done', table);
                 }, 'TableStyles.updateTableFormatting');
             }
 
@@ -529,8 +529,9 @@ define('io.ox/office/textframework/format/tablestyles', [
 
         // inserts the table style sheet described by the passed parameters, if it does not exist yet, and marks it as dirty
         function insertMissingTableStyle(styleId, styleName, uiPriority, category, attrs) {
-            // check by style sheet name (they are always loaded in English from Word, while ste style IDs are localized)
-            if (!self.containsStyleSheetByName(styleName)) {
+            // check by style sheet name (they are always loaded in English from Word, while the style IDs are localized)
+            // In Presentation app the style IDs are unique and never translated (55470)
+            if (!self.containsStyleSheet(styleId) && !self.containsStyleSheetByName(styleName)) {
                 self.createDirtyStyleSheet(styleId, styleName, attrs, { priority: uiPriority, category: category });
             } else {
                 self.setStyleOptions(styleId, { category: category, priority: uiPriority });
@@ -719,7 +720,16 @@ define('io.ox/office/textframework/format/tablestyles', [
         };
     };
 
-    TableStyles.getBorderStyleFromAttributes = function (attributes) {
+    /**
+     * Calculates unique border width from all border attributes and returns it.
+     *
+     * @param {Object} attributes
+     * @param {Boolean|Undefined} [skipBorderInside]
+     *  Presentation doesn't use borderInsideHor and borderInsideVert, skip them.
+     *
+     * @returns {Number}
+     */
+    TableStyles.getBorderStyleFromAttributes = function (attributes, skipBorderInside) {
 
         var allWidths = [];
         var width = 'none';
@@ -729,8 +739,8 @@ define('io.ox/office/textframework/format/tablestyles', [
             if (Border.isVisibleBorder(attributes.borderRight)) { allWidths.push(attributes.borderRight.width); }
             if (Border.isVisibleBorder(attributes.borderTop)) { allWidths.push(attributes.borderTop.width); }
             if (Border.isVisibleBorder(attributes.borderBottom)) { allWidths.push(attributes.borderBottom.width); }
-            if (Border.isVisibleBorder(attributes.borderInsideHor)) { allWidths.push(attributes.borderInsideHor.width); }
-            if (Border.isVisibleBorder(attributes.borderInsideVert)) { allWidths.push(attributes.borderInsideVert.width); }
+            if (!skipBorderInside && Border.isVisibleBorder(attributes.borderInsideHor)) { allWidths.push(attributes.borderInsideHor.width); }
+            if (!skipBorderInside && Border.isVisibleBorder(attributes.borderInsideVert)) { allWidths.push(attributes.borderInsideVert.width); }
         }
 
         allWidths = _.uniq(allWidths);
@@ -777,7 +787,7 @@ define('io.ox/office/textframework/format/tablestyles', [
     TableStyles.getLightShadingTableStyleAttributes = function (colorValue) {
 
         var SINGLE_BORDER_LINE = { style: 'single', color: { type: 'scheme', value: colorValue }, width: 35 },
-            BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'tint', value: 24706 }] },
+            BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'lumMod', value: 20000 }, { type: 'lumOff', value: 80000 }] },
             ROW_CELL_ATTRIBUTES = { borderLeft: Border.NONE, borderTop: SINGLE_BORDER_LINE, borderRight: Border.NONE, borderBottom: SINGLE_BORDER_LINE, borderInsideHor: Border.NONE, borderInsideVert: Border.NONE },
             BAND_CELL_ATTRIBUTES = { borderLeft: Border.NONE, borderRight: Border.NONE, borderInsideHor: Border.NONE, borderInsideVert: Border.NONE, fillColor: BAND_COLOR };
 
@@ -801,7 +811,7 @@ define('io.ox/office/textframework/format/tablestyles', [
     TableStyles.getMediumShading1TableStyleAttributes = function (colorValue) {
 
         var SCHEME_COLOR = { type: 'scheme', value: colorValue },
-            BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'tint', value: 24706 }] },
+            BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'lumMod', value: 20000 }, { type: 'lumOff', value: 80000 }] },
             SINGLE_BORDER_LINE = { style: 'single', color: SCHEME_COLOR, width: 35 },
             DOUBLE_BORDER_LINE = { style: 'double', color: SCHEME_COLOR, width: 26 };
 
@@ -834,7 +844,7 @@ define('io.ox/office/textframework/format/tablestyles', [
 
         var SCHEME_COLOR = { type: 'scheme', value: colorValue },
             BACK_COLOR = { type: 'scheme', value: 'background1' },
-            BAND_COLOR = { type: 'scheme', value: 'background1', transformations: [{ type: 'shade', value: 84706 }] },
+            BAND_COLOR = { type: 'scheme', value: 'background1', transformations: [{ type: 'lumMod', value: 95000 }] },
             SINGLE_BORDER_LINE = { style: 'single', color: Color.AUTO, width: 79 },
             DOUBLE_BORDER_LINE = { style: 'double', color: Color.AUTO, width: 26 },
             NORTH_CELL_ATTRIBUTES = { borderLeft: Border.NONE, borderTop: SINGLE_BORDER_LINE, borderRight: Border.NONE, borderBottom: SINGLE_BORDER_LINE, borderInsideHor: Border.NONE, borderInsideVert: Border.NONE };
@@ -873,14 +883,14 @@ define('io.ox/office/textframework/format/tablestyles', [
 
     TableStyles.getMediumGrid1TableStyleAttributes = function (colorValue) {
 
-        var BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'tint', value: 49804 }] },
+        var BAND_COLOR = { type: 'scheme', value: colorValue, transformations: [{ type: 'lumMod', value: 40000 }, { type: 'lumOff', value: 60000 }] },
             SINGLE_BORDER_LINE = { style: 'single', color: { type: 'scheme', value: colorValue }, width: 35 },
             THICK_BORDER_LINE = { style: 'single', color: { type: 'scheme', value: colorValue }, width: 79 };
 
         return {
             wholeTable: {
                 table: { borderLeft: SINGLE_BORDER_LINE, borderTop: SINGLE_BORDER_LINE, borderRight: SINGLE_BORDER_LINE, borderBottom: SINGLE_BORDER_LINE, borderInsideHor: SINGLE_BORDER_LINE, borderInsideVert: SINGLE_BORDER_LINE },
-                cell: { fillColor: { type: 'scheme', value: colorValue, transformations: [{ type: 'tint', value: 24706 }] } },
+                cell: { fillColor: { type: 'scheme', value: colorValue, transformations: [{ type: 'lumMod', value: 20000 }, { type: 'lumOff', value: 80000 }] } },
                 paragraph: { lineHeight: LineHeight.SINGLE, marginBottom: 0 }
             },
             firstRow: { character: { bold: true } },
@@ -897,7 +907,6 @@ define('io.ox/office/textframework/format/tablestyles', [
         return {
             wholeTable: {
                 cell: {
-                    fillType: 'none',
                     borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
                     borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
                     borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
@@ -910,11 +919,11 @@ define('io.ox/office/textframework/format/tablestyles', [
             band1Hor: { cell: { fillType: 'solid', fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: (isODF ? 'tint' : 'alpha'), value: 20000 }] } } }, // 52757, ODP, using 'tint' instead of 'alpha' for fallback value
             band1Vert: { cell: { fillType: 'solid', fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: (isODF ? 'tint' : 'alpha'), value: 20000 }] } } },
             firstRow: {
-                cell: { fillType: 'none', borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
+                cell: { borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
                 character: { bold: true }
             },
             lastRow: {
-                cell: { fillType: 'none', borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
+                cell: { borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
                 character: { bold: true }
             }
         };
@@ -1038,12 +1047,11 @@ define('io.ox/office/textframework/format/tablestyles', [
         };
     };
 
-    // Table grid, no style
+    // Table grid, no style (but not setting fillType to 'none' (55588))
     TableStyles.getTableGridPresentation = function (colorValue) {
         return {
             wholeTable: {
                 cell: {
-                    fillType: 'none',
                     borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
                     borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
                     borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
@@ -1060,7 +1068,6 @@ define('io.ox/office/textframework/format/tablestyles', [
         return {
             wholeTable: {
                 cell: {
-                    fillType: 'none',
                     borderLeft: { style: 'none' },
                     borderRight: { style: 'none' },
                     borderBottom: { style: 'none' },
