@@ -336,6 +336,15 @@ define.async('io.ox/office/textframework/model/clipboardmixin', [
                                         depth: depth
                                     });
 
+                                } else if (DOM.isMailInlineImageNode(child)) {
+                                    // The image URL points to a mail inline image. Replace the url with a base64 data URL.
+                                    result.push({
+                                        operation: Operations.INSERT_DRAWING,
+                                        type: 'image',
+                                        data: DOM.getBase64FromImageNode(child),
+                                        depth: depth
+                                    });
+
                                 } else {
                                     // The image src is an external web URL or already a base64 data URL
                                     result.push({ operation: Operations.INSERT_DRAWING, type: 'image', data: child.src, depth: depth });
