@@ -441,13 +441,11 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // a collector for all drawing attributes of the child drawings
             var allNewDrawingAttributes = [];
             // an optional rotation angle of the group
-            var groupRotationAngle = DrawingFrame.isRotatedDrawingNode(drawingGroupNode) ? DrawingFrame.getDrawingRotationAngle(self, drawingGroupNode) : 0;
+            var groupRotationAngle = DrawingFrame.getDrawingRotationAngle(self, drawingGroupNode) || 0;
             // the jQuery offset of the complete slide
             var slideOffset = drawingGroupNode.closest(DOM.SLIDE_SELECTOR).offset();
             // the current zoom factor
             var zoomFactor = app.getView().getZoomFactor();
-            // the explicit drawing attributes of the group
-            var drawingGroupAttrs = null;
             // group horizontal flip property
             var groupFlipH = DrawingFrame.isFlippedHorz(drawingGroupNode);
             // group vertical flip property
@@ -455,22 +453,72 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // difference in horizontal and vertical flip of the drawing group
             var groupFlipXor = groupFlipH !== groupFlipV;
 
-            // saving the original positions in the gropuAttrsContainer
-            drawingGroupAttrs = AttributeUtils.getExplicitAttributes(drawingGroupNode);
-            if (drawingGroupAttrs && drawingGroupAttrs.drawing) { saveRequiredDrawingAttributes(groupAttrsContainer, drawingGroupAttrs.drawing); }
+            // reset transformation of group parent draiwng, if needed
+            if (groupRotationAngle || groupFlipH || groupFlipV) { $(drawingGroupNode).css({ transform: 'rotate(0deg)' }); }
 
-            // iterating over all child drawings
+            // reading value of upper left corner of the unrotated drawing
+            var groupDrawingOffset = $(drawingGroupNode).offset();
+            var newParentDrawingAttrs = {
+                left: Utils.convertLengthToHmm((groupDrawingOffset.left - slideOffset.left) / zoomFactor, 'px'),
+                top: Utils.convertLengthToHmm((groupDrawingOffset.top - slideOffset.top) / zoomFactor, 'px'),
+                width: Utils.convertLengthToHmm($(drawingGroupNode).width(), 'px'),
+                height: Utils.convertLengthToHmm($(drawingGroupNode).height(), 'px'),
+                rotation: groupRotationAngle,
+                flipH: groupFlipH,
+                flipV: groupFlipV
+            };
+
+            if (groupRotationAngle || groupFlipH || groupFlipV) {
+                // first run - save child attrs before ungroup if transformation is applied
+                _.each(allChildDrawings, function (drawing) {
+                    var // the rotation angle of one child drawing
+                        drawingAngle = DrawingFrame.getDrawingRotationAngle(self, drawing) || 0,
+                        // the jQuerified drawing
+                        $drawing = $(drawing),
+                        // the jQuery offset of one drawing
+                        drawingOffset = null,
+                        // the explicit drawing attributes of the child
+                        drawingAttrs = null,
+                        // drawing horizontal flip property
+                        drawingFlipH = DrawingFrame.isFlippedHorz(drawing),
+                        // drawing vertical flip property
+                        drawingFlipV = DrawingFrame.isFlippedVert(drawing);
+
+                    if (drawingAngle || drawingFlipH || drawingFlipV) { $(drawing).css({ transform: '' }); } // rotating back the child drawing
+
+                    // reading value of upper left corner of the unrotated drawing
+                    drawingOffset = $drawing.offset();
+                    drawingAttrs = {
+                        left: Utils.convertLengthToHmm((drawingOffset.left - groupDrawingOffset.left) / zoomFactor, 'px') + newParentDrawingAttrs.left,
+                        top: Utils.convertLengthToHmm((drawingOffset.top - groupDrawingOffset.top) / zoomFactor, 'px') + newParentDrawingAttrs.top,
+                        width: Utils.convertLengthToHmm($drawing.width(), 'px'),
+                        height: Utils.convertLengthToHmm($drawing.height(), 'px'),
+
+                        rotation: drawingAngle,
+                        flipH: drawingFlipH,
+                        flipV: drawingFlipV
+                    };
+                    DrawingFrame.setCssTransform(drawing, drawingAngle, drawingFlipH, drawingFlipV);
+
+                    saveRequiredDrawingAttributes(childAttrsContainer, drawingAttrs);
+                });
+
+                // rotating back the parent drawing
+                DrawingFrame.setCssTransform($(drawingGroupNode), groupRotationAngle, groupFlipH, groupFlipV);
+            }
+            // saving the original positions in the gropuAttrsContainer
+            saveRequiredDrawingAttributes(groupAttrsContainer, newParentDrawingAttrs);
+
+            // second run - iterating over all child drawings
             _.each(allChildDrawings, function (drawing) {
                 var // the rotation angle of one child drawing
-                    drawingAngle = DrawingFrame.isRotatedDrawingNode(drawing) ? DrawingFrame.getDrawingRotationAngle(self, drawing) : 0,
+                    drawingAngle = DrawingFrame.getDrawingRotationAngle(self, drawing) || 0,
                     // the negative drawing angle of the group
                     completeDrawingAngle = 0,
                     // the jQuerified drawing
                     $drawing = $(drawing),
                     // the jQuery offset of one drawing
                     drawingOffset = null,
-                    // the explicit drawing attributes of the child
-                    drawingAttrs = null,
                     // drawing horizontal flip property
                     drawingFlipH = DrawingFrame.isFlippedHorz(drawing),
                     // drawing vertical flip property
@@ -487,10 +535,6 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                     completeDrawingAngle = groupFlipXor ? -(360 - groupRotationAngle) : -groupRotationAngle;
                     // assigning the negative group rotation to the child drawing so that there is no remaining rotation
                     if (completeDrawingAngle !== 0) { DrawingFrame.setCssTransform(drawing, completeDrawingAngle, mergedFlipH, mergedFlipV); }
-                    // saving the original positions in the childAttrsContainer (only for rotated drawings to generate undo operation)
-                    drawingAttrs = AttributeUtils.getExplicitAttributes(drawing);
-                    // saving the values for 'left', 'top', 'width', 'height' and 'rotation' of the grouped drawing
-                    if (drawingAttrs && drawingAttrs.drawing) { saveRequiredDrawingAttributes(childAttrsContainer, drawingAttrs.drawing); }
                 }
 
                 // reading value of upper left corner of the unrotated drawing
