@@ -14,9 +14,10 @@
 
 define('io.ox/office/textframework/model/stringconvertermixin', [
     'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/editframework/utils/operationutils',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/textutils'
-], function (DrawingFrame, DOM, Utils) {
+], function (DrawingFrame, OperationUtils, DOM, Utils) {
 
     'use strict';
 
@@ -199,29 +200,37 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                         node.removeData('tracking-options');
                     }
 
-                    // removing spell check information at node
-                    self.getSpellChecker().clearSpellcheckHighlighting(node);
-
                     // handling jQuery data objects
                     dataObject = node.data();
+
+                    // removing spell check information at nodes
+                    self.getSpellChecker().clearSpellcheckHighlighting(node, dataObject);
+
+                    if (app.isPresentationApp()) {
+                        if (DOM.isSlideNode(node)) {
+                            // for slides some additional data must be saved
+                            dataObject = self.prepareSlideNodesForStorage(node, dataObject);
+                        } else if (DOM.isDrawingFrame(node)) {
+                            // drawing handling: saving list styles from model at drawing and  renaming source of image to avoid too many image requests, when attaching the string to the DOM
+                            dataObject = self.prepareDrawingNodesForStorage(node, dataObject);
+                        }
+                    }
+
                     if (_.isObject(dataObject) && !_.isEmpty(dataObject)) {
                         if (dataObject[DOM.DRAWINGPLACEHOLDER_LINK]) { delete dataObject[DOM.DRAWINGPLACEHOLDER_LINK]; }  // no link to other drawing allowed
                         if (dataObject[DOM.DRAWING_SPACEMAKER_LINK]) { delete dataObject[DOM.DRAWING_SPACEMAKER_LINK]; }  // no link to other drawing allowed
                         if (dataObject[DOM.COMMENTPLACEHOLDER_LINK]) { delete dataObject[DOM.COMMENTPLACEHOLDER_LINK]; }  // no link to other comment allowed
                         dataKeys = dataKeys.concat(_.keys(dataObject));
+
+                        // DOCS-892: Minifying the dataObject to reduce string length in local storage
+                        // The dataObject is a direct reference to the jQuery data object. There might be
+                        // cases, when it is better to clone this object, because 'handleMinifiedObject'
+                        // modifies the object. During closing the document, generating a clone is
+                        // superfluous (see also 55226).
+                        OperationUtils.handleMinifiedObject(dataObject);
+
                         node.attr('jquerydata', JSON.stringify(dataObject));  // different key -> not overwriting isempty value
                         // Utils.log('Saving data: ' + this.nodeName + ' ' + this.className + ' : ' + JSON.stringify($(this).data()));
-
-                        // handling images that have the session used in the src attribute
-                        // Avoiding error 403 during saving the document in the console (Bug 37640)
-                        if (DOM.isImageNode(node)) {
-                            var imgNode = node.find('img'),
-                                srcAttr = imgNode.attr('src');
-                            if (_.isString(srcAttr) && (srcAttr.length > 0)) {
-                                imgNode.attr('src', null);
-                                imgNode.attr(DOM.LOCALSTORAGE_SRC_OVERRIDE, srcAttr.replace(/\bsession=(\w+)\b/, 'session=_REPLACE_SESSION_ID_'));
-                            }
-                        }
                     }
 
                     def.resolve();
@@ -235,13 +244,20 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                 return def.promise();
             }  // end of 'prepareNodeForStorage'
 
+            // appending all slides to the DOM
+            if (app.isPresentationApp()) { self.appendAllSlidesToDom(); }
+
             // removing drawing selections
             if (selection.getSelectionType() === 'drawing') {
-                selectedDrawing = selection.getSelectedDrawing();
-                DrawingFrame.clearSelection(selectedDrawing);
-                // removing additional tracking handler options, that are specific for OX Text (Chrome only)
-                selectedDrawing.removeData('trackingOptions');
-                selectedDrawing.removeData('tracking-options');
+                selectedDrawing = selection.getSelectedDrawings();
+                _.each(selectedDrawing, function (drawing) { // drawing must be jQueryfied
+                    DrawingFrame.clearSelection(drawing);
+                    // clear crop frame from currently active crop drawings
+                    if (selection.isCropMode()) { self.exitCropMode(); }
+                    // removing additional tracking handler options, that are specific for OX Text (Chrome only)
+                    drawing.removeData('trackingOptions');
+                    drawing.removeData('tracking-options');
+                });
             }
 
             // removing selections around 'additional' text frame selections
@@ -267,6 +283,8 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
 
             // removing active header/footer context menu, if exists
             if (self.isHeaderFooterEditState()) {
+                // first clean up drawing in placeholder node, and then leave edit mode
+                self.getPageLayout().clearSelectionFromPlaceholderNode(self.getActiveTarget());
                 self.getPageLayout().leaveHeaderFooterEditMode();
             }
 
@@ -286,23 +304,29 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
             paddingBottomInfo = self.getNode().children(DOM.PAGECONTENT_NODE_SELECTOR).css('padding-bottom');
             self.getNode().children(DOM.PAGECONTENT_NODE_SELECTOR).children(':first').attr('pagecontentattr', JSON.stringify({ 'padding-bottom': paddingBottomInfo }));
 
-            // Second layer: Handling the drawing layer (taking care of order in allNodesCollector)
-            if (self.getDrawingLayer().containsDrawingsInPageContentNode()) { allNodesCollector.push({ extension: '_DL', selector: DOM.DRAWINGLAYER_NODE_SELECTOR, allNodes: self.getNode().children(DOM.DRAWINGLAYER_NODE_SELECTOR).find('*') }); }
+            if (app.isTextApp()) {
+                // Second layer in OX Text: Handling the drawing layer (taking care of order in allNodesCollector)
+                if (self.getDrawingLayer().containsDrawingsInPageContentNode()) { allNodesCollector.push({ extension: '_DL', selector: DOM.DRAWINGLAYER_NODE_SELECTOR, allNodes: self.getNode().children(DOM.DRAWINGLAYER_NODE_SELECTOR).find('*') }); }
+                // Third layer in OX Text: Handling the header/footer placeholder layer (taking care of order in allNodesCollector)
+                if (self.getPageLayout().hasContentHeaderFooterPlaceHolder()) { allNodesCollector.push({ extension: '_HFP', selector: DOM.HEADER_FOOTER_PLACEHOLDER_SELECTOR, allNodes: self.getNode().children(DOM.HEADER_FOOTER_PLACEHOLDER_SELECTOR).find('*') }); }
+                // Fourth layer in OX Text: Handling the comment layer (taking care of order in allNodesCollector)
+                if (!self.getCommentLayer().isEmpty()) { allNodesCollector.push({ extension: '_CL', selector: DOM.COMMENTLAYER_NODE_SELECTOR, allNodes: self.getNode().children(DOM.COMMENTLAYER_NODE_SELECTOR).find('*') }); }
+            }
 
-            // Third layer: Handling the header/footer placeholder layer (taking care of order in allNodesCollector)
-            if (self.getPageLayout().hasContentHeaderFooterPlaceHolder()) { allNodesCollector.push({ extension: '_HFP', selector: DOM.HEADER_FOOTER_PLACEHOLDER_SELECTOR, allNodes: self.getNode().children(DOM.HEADER_FOOTER_PLACEHOLDER_SELECTOR).find('*') }); }
-
-            // Fourth layer: Handling the comment layer (taking care of order in allNodesCollector)
-            if (!self.getCommentLayer().isEmpty()) { allNodesCollector.push({ extension: '_CL', selector: DOM.COMMENTLAYER_NODE_SELECTOR, allNodes: self.getNode().children(DOM.COMMENTLAYER_NODE_SELECTOR).find('*') }); }
+            // Fifth and sixth layer: Master slide layer and layout slide layer of presentation application
+            if (app.isPresentationApp()) {
+                allNodesCollector.push({ extension: '_LSL', selector: DOM.LAYOUTSLIDELAYER_SELECTOR, allNodes: self.getNode().children(DOM.LAYOUTSLIDELAYER_SELECTOR).find('*') });
+                if (!app.isODF()) { allNodesCollector.push({ extension: '_MSL', selector: DOM.MASTERSLIDELAYER_SELECTOR, allNodes: self.getNode().children(DOM.MASTERSLIDELAYER_SELECTOR).find('*') }); }
+            }
 
             // iterating over all nodes (first page content, then drawing layer, ...)
             var promise = self.iterateArraySliced(allNodesCollector, function (oneLayer) {
 
                 return self.iterateArraySliced(oneLayer.allNodes, prepareNodeForStorage, 'StringConverterMixin.getFullModelDescription')
-                .done(function () {
-                    // collecting the html strings for each layer
-                    allHtmlStrings.push({ extension: oneLayer.extension, htmlString: self.getNode().children(oneLayer.selector).html() });
-                });
+                    .done(function () {
+                        // collecting the html strings for each layer
+                        allHtmlStrings.push({ extension: oneLayer.extension, htmlString: self.getNode().children(oneLayer.selector).html() });
+                    });
             }, 'StringConverterMixin.getFullModelDescription');
 
             return promise.then(function () {
@@ -345,6 +369,10 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                 isDrawingLayer = Utils.getBooleanOption(options, 'drawingLayer', false),
                 // whether the html string describes the header/footer layer (loaded from local storage)
                 isHeaderFooterLayer = Utils.getBooleanOption(options, 'headerFooterLayer', false),
+                // whether the html string describes the master slide layer (loaded from local storage)
+                isMasterSlideLayer = Utils.getBooleanOption(options, 'masterSlideLayer', false),
+                // whether the html string describes the layout slide layer (loaded from local storage)
+                isLayoutSlideLayer = Utils.getBooleanOption(options, 'layoutSlideLayer', false),
                 // eather the page content node, parent of the editdiv, or headerFooterContainer node
                 contentNode = null;
 
@@ -355,7 +383,17 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                     parentNode = null;
 
                 if (self.useSlideMode()) {
-                    parentNode = self.getNode();
+                    if (usedLocalStorage) {
+                        if (isMasterSlideLayer) {
+                            parentNode = self.getOrCreateMasterSlideLayerNode();
+                        } else if (isLayoutSlideLayer) {
+                            parentNode = self.getOrCreateLayoutSlideLayerNode();
+                        } else {
+                            parentNode = self.getNode().children(DOM.PAGECONTENT_NODE_SELECTOR);
+                        }
+                    } else {
+                        parentNode = self.getNode();
+                    }
                 } else if (isDrawingLayer) {
                     parentNode = self.getDrawingLayer().getDrawingLayerNode();
                 } else if (isCommentLayer) {
@@ -380,22 +418,18 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
 
             if (htmlString) {
 
-                // Avoiding error 403 during loading the document in the console (35405)
-                // -> replacing the '_REPLACE_SESSION_ID_' before it is inserted into the DOM
-                // -> this is a problem, if the user really uses this replacement string in the dom
-                htmlString = htmlString.replace(/\bsession=_REPLACE_SESSION_ID_\b/g, 'session=' + ox.session);
-
                 // setting the content node for each layer
                 contentNode = getStringParentNode();
 
+                // Performance: Hiding the page node, IE seems to parse the DOM completely // TODO -> Checking for using local storage
+                if (app.isPresentationApp()) { contentNode.children(DOM.PAGECONTENT_NODE_SELECTOR).addClass(DOM.HIDDENAFTERATTACH_CLASSNAME); }
+
                 // setting new string to editdiv node
                 contentNode
                     .html(htmlString)
                     .find('[jquerydata], [nonjquerydata]')
                     .each(function () {
                         var node = $(this),
-                            imgNode = null,
-                            srcAttr = null,
                             characterAttributes = null,
                             key = null;
 
@@ -410,7 +444,7 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                                 }
                                 node.removeAttr('nonjquerydata');
                             } catch (ex) {
-                                Utils.error('Failed to parse attributes: ' + node.attr('jquerydata') + ' Exception message: ' + ex.message);
+                                Utils.error('FastLoad: Failed to parse attributes (nonjquerydata): ' + node.attr('nonjquerydata') + ' Exception message: ' + ex.message);
                             }
                         }
 
@@ -419,6 +453,9 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                             try {
                                 dataObject = JSON.parse(node.attr('jquerydata'));
 
+                                // DOCS-892: Expanding the dataObject to get usable attributes from local storage or fast load string
+                                OperationUtils.handleMinifiedObject(dataObject, '', true);
+
                                 // No list style in comments in odt: 38829 (simply removing the list style id)
                                 if (app.isODF() && !usedLocalStorage && isCommentLayer && DOM.isParagraphNode(node) && dataObject.attributes && dataObject.attributes.paragraph && dataObject.attributes.paragraph.listStyleId) { delete dataObject.attributes.paragraph.listStyleId; }
 
@@ -442,18 +479,11 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
 
                                 node.removeAttr('jquerydata');
                             } catch (ex) {
-                                Utils.error('Failed to parse attributes: ' + node.attr('jquerydata') + ' Exception message: ' + ex.message);
+                                Utils.error('FastLoad: Failed to parse attributes (jquerydata): ' + node.attr('jquerydata') + ' Exception message: ' + ex.message);
                             }
                         }
 
-                        if (DOM.isImageNode(node)) {
-                            imgNode = node.find('img');
-                            srcAttr = imgNode.attr(DOM.LOCALSTORAGE_SRC_OVERRIDE);
-                            if (_.isString(srcAttr) && (srcAttr.length > 0)) {
-                                imgNode.attr('src', srcAttr);
-                                imgNode.attr(DOM.LOCALSTORAGE_SRC_OVERRIDE, null);
-                            }
-                        } else if (!app.isODF() && DrawingFrame.isShapeDrawingFrame(node)) {
+                        if (!app.isODF() && DrawingFrame.isShapeDrawingFrame(node)) {
                             removeEmptyTextFrameNodesInDrawing(node); // removing empty text frames without paragraphs (no paragraphs in special shapes, 50349)
                         }
 
@@ -474,6 +504,10 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                     }
                 });
 
+                // Performance: Hiding slides immediately, IE seems to parse the DOM completely
+                // -> the slide format manager removes this marker class, before slide is formatted
+                if (app.isPresentationApp()) { contentNode.find(DOM.SLIDE_SELECTOR).addClass(DOM.HIDDENAFTERATTACH_CLASSNAME); }
+
                 // setting table cell attribute 'contenteditable' to true for non-MSIE browsers (task 33642)
                 // -> this is not necessary, if the document was loaded from the local storage
                 if (!usedLocalStorage) {
