@@ -294,6 +294,7 @@ define('io.ox/office/textframework/model/updatelistsmixin', [
                             numType = paraAttributes.bullet.numType || 'arabicPeriod';
                             textChar = self.createNumberedListItem((isEmptyParagraph && !app.isODF()) ? (listItemCounter[listCounterId][listLevel] + 1) : listItemCounter[listCounterId][listLevel], numType);
                             displayFontName = paraAttributes.bulletFont.name ? paraAttributes.bulletFont.name : null;
+                            if (app.isODF()) { displayFontName = null; } // not using specified font in numbered lists in ODT (55671)
                         }
 
                         numberingElement = DOM.createListLabelNode(noListLabel ? '' : textChar);
@@ -307,10 +308,11 @@ define('io.ox/office/textframework/model/updatelistsmixin', [
 
                         if (imageUrl) {
 
-                            var absUrl = app.getServerModuleUrl(IO.FILTER_MODULE_NAME, { action: 'getfile', get_filename: imageUrl });
+                            var absUrl = app.getServerModuleUrl(IO.FILTER_MODULE_NAME, { action: 'getfile', get_filename: imageUrl }, { uid: false });
                             var image = $('<div>', { contenteditable: false });
                             var img = $('<img>', { src: absUrl });
                             var baseLine = null;
+                            var isEMConverted = false;
 
                             if (!target && AttributeUtils.isCharacterFontThemed(followingTextAttributes)) {
                                 target = docModel.getThemeTargets(para);
@@ -319,21 +321,28 @@ define('io.ox/office/textframework/model/updatelistsmixin', [
                             if (paraAttributes.bulletSize.type === 'followText') {
                                 baseLine = 0.8 * docModel.getRenderFont(followingTextAttributes, target).getBaseLineOffset();
                             } else if (paraAttributes.bulletSize.type === 'percent') {
-                                baseLine = Utils.convertToEM(Utils.round((paraAttributes.bulletSize.size / 100) * followingTextAttributes.fontSize, 1), 'pt');
+                                baseLine = Utils.convertToEM(Utils.round((paraAttributes.bulletSize.size / 100) * 0.8 * followingTextAttributes.fontSize, 1), 'pt'); // using factor 0.8 looks more precise
+                                isEMConverted = true;
                             } else {
+                                isEMConverted = true;
                                 baseLine = Utils.convertToEM(paraAttributes.bulletSize.size, 'pt');
                             }
 
-                            // fix for Bug 47859 & Bug 48025
-                            image.css('height', Utils.convertToEM(baseLine, 'px'));
-                            img.css('height', Utils.convertToEM(baseLine, 'px'));
+                            // see 47859/48025/55478/55510
+                            if (isEMConverted) {
+                                image.css('height', baseLine);
+                                img.css('height', baseLine);
+                            } else {
+                                image.css('height', Utils.convertToEM(baseLine, 'px'));
+                                img.css('height', Utils.convertToEM(baseLine, 'px'));
+                            }
 
                             image.addClass('drawing')
-                            .addClass('bulletdrawing')
-                            .data('url', imageUrl)
-                            .append(
-                                $('<div>').append(img)
-                            );
+                                .addClass('bulletdrawing')
+                                .data('url', imageUrl)
+                                .append(
+                                    $('<div>').append(img)
+                                );
 
                             numberingElement.prepend(image);
 
