@@ -95,6 +95,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
          */
         var renderCollaborativeSelectionDebounced = this.createDebouncedMethod('RemoteSelection.renderCollaborativeSelectionDebounced', null, function () {
             if (Config.SHOW_REMOTE_SELECTIONS) {
+
                 // first, clear all old selection nodes from the DOM
                 rootNode.find('.collaborative-overlay').children().remove();
 
@@ -109,13 +110,15 @@ define('io.ox/office/textframework/selection/remoteselection', [
          * Create a Overlay with the username to show the remote username for a selection.
          * @param {type} username name of the user
          * @param {type} className classname for the overlay
+         * @param {String} clientId Id of the client
          * @param {jQuery} UserName Overlay
          */
-        function getUserNameOverlay(username, className) {
-            var usernameOverlay = document.createElement('div');
+        function createUserNameOverlay(username, className, clientId) {
+            var usernameOverlay = $(document.createElement('div'));
             // draw user name
-            usernameOverlay.setAttribute('class', 'collaborative-username ' + className);
-            $(usernameOverlay).text(username);
+            usernameOverlay.addClass('collaborative-username ' + className);
+            usernameOverlay.attr('data-clientid', clientId);
+            usernameOverlay.text(username);
 
             return usernameOverlay;
         }
@@ -185,6 +188,9 @@ define('io.ox/office/textframework/selection/remoteselection', [
                 var drawingNode;
                 var rotation = 0;
                 var drawingAttrs;
+                var setUsernameRotation = false;
+                var flipH = false;
+                var flipV = false;
                 // if the drawing is rotatet only select the frame and not the text
                 if (slideMode && userSelection.type !== 'drawing') {
                     drawingNode = DrawingFrame.getDrawingNode($(Position.getDOMPosition(activeRootNode, userSelection.start, true).node));
@@ -225,8 +231,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                     }
                     drawingAttrs = drawingAttrs ? drawingAttrs : AttributeUtils.getExplicitAttributes(drawingNode);
                     rotation = 0;
-                    var flipH = false;
-                    var flipV = false;
+
                     if (drawingAttrs && drawingAttrs.drawing) {
                         flipH = Utils.getBooleanOption(drawingAttrs.drawing, 'flipH', false);
                         flipV = Utils.getBooleanOption(drawingAttrs.drawing, 'flipV', false);
@@ -243,7 +248,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                         left -= rect.left;
                     }
 
-                    usernameOverlay = getUserNameOverlay(username, className);
+                    usernameOverlay = createUserNameOverlay(username, className, client.userId);
 
                     // Set the selection frame position and size attributes
                     $(selectionOverlayGroup).css({
@@ -254,12 +259,6 @@ define('io.ox/office/textframework/selection/remoteselection', [
                         transform: DrawingUtils.getCssTransform(rotation, flipH, flipV)
                     });
 
-                    $(usernameOverlay).css({
-                        top: 0,
-                        left: 0,
-                        transform: DrawingUtils.getCssTransform(0, flipH, flipV)
-                    });
-
                     selectionOverlayGroup.append(drawingOverlay);
                     selectionOverlayGroup.append(usernameOverlay);
 
@@ -267,15 +266,17 @@ define('io.ox/office/textframework/selection/remoteselection', [
                     // The namespace is to remove the event handler without the function.
                     drawingNode.on({
                         'mouseenter.remoteselection': function () {
-                            $(usernameOverlay).show();
+                            usernameOverlay.show();
                         },
                         'mouseleave.remoteselection': function () {
-                            $(usernameOverlay).hide();
+                            usernameOverlay.hide();
                         }
                     });
-
+                    usernameOverlay.show();
+                    usernameOverlay.css('display', 'inherit');
                     drawingNodesWithHandlers.push(drawingNode);
                     drawingOverlay.setAttribute('class', 'selection-overlay drawing ' + className);
+                    setUsernameRotation = true;
                 } else {
                     var caretHandle = $('<div>').addClass('collaborative-cursor-handle'),
                         caretOverlay = $('<div>').addClass('collaborative-cursor'),
@@ -284,13 +285,15 @@ define('io.ox/office/textframework/selection/remoteselection', [
                         physicalPosition = calculatePhysicalPosition(selectionAnchorPoint, selectionFocusPoint),
                         isRangeSelection = physicalPosition.anchor.top !== physicalPosition.focus.top || physicalPosition.anchor.left !== physicalPosition.focus.left;
 
-                    usernameOverlay = getUserNameOverlay(username, className);
+                    usernameOverlay = createUserNameOverlay(username, className, client.userId);
 
                     // draw user cursors and names
-                    $(usernameOverlay).css('top', physicalPosition.focus.height);
+                    usernameOverlay.css('top', physicalPosition.focus.height);
                     caretOverlay.css({ top: physicalPosition.focus.top, left: physicalPosition.focus.left, height: physicalPosition.focus.height }).addClass(className);
                     caretOverlay.append(usernameOverlay, caretHandle);
-                    caretHandle.hover(function () { $(usernameOverlay).show(); }, function () { $(usernameOverlay).hide(); });
+                    caretHandle.hover(function () { $(usernameOverlay).show(); }, function () { usernameOverlay.hide(); });
+                    usernameOverlay.show();
+                    usernameOverlay.css('display', 'inherit');
                     overlay.append(caretOverlay);
 
                     // if remote selection is in header/footer, fix z-index collision.
@@ -370,7 +373,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                                 $(selectionOverlay).css({ top: physicalPosition.range.top, left: physicalPosition.range.left, width: physicalPosition.range.width, height: caretHeight });
                                 selectionOverlayGroup.append(selectionOverlay);
 
-                                $(usernameOverlay).css('top', caretHeight);
+                                usernameOverlay.css('top', caretHeight);
                                 caretOverlay.css({ top: physicalPosition.range.top, left: physicalPosition.focus.left, height: caretHeight }).addClass(className);
                             } else { // multi line selection area
 
@@ -408,7 +411,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
                                 caretHeight = focusSelection.height;
 
-                                $(usernameOverlay).css('top', caretHeight);
+                                usernameOverlay.css('top', caretHeight);
                                 caretOverlay.css({ top: focusSelection.top, left: rangeSelection.left + tailWidth, height: caretHeight }).addClass(className);
 
                                 selectionOverlayGroup.append(headOverlay, bodyOverlay, tailOverlay);
@@ -421,9 +424,50 @@ define('io.ox/office/textframework/selection/remoteselection', [
                     }
                 }
 
-                if (!_.isBoolean(client.selectionChanged)) { $(usernameOverlay).show(); }  // 36800
-
+                if (!_.isBoolean(client.selectionChanged)) {
+                    usernameOverlay.show(); // 36800
+                }
+                usernameOverlay.show();
+                usernameOverlay.css('display', 'inherit');
                 overlay.append(selectionOverlayGroup);
+                if (setUsernameRotation) {
+                    var userHeight = usernameOverlay.height(); //clientSize ? clientSize.height : 0;
+                    var userWidth = usernameOverlay.width(); //clientSize ? clientSize.width : 0;
+                    var usernameCSS;
+                    if (rotation >= 316 || rotation <= 45) {
+                        //top
+                        usernameCSS = {
+                            top: 0,
+                            left: 0,
+                            transform: DrawingUtils.getCssTransform(0, flipH, flipV)
+                        };
+                    } else if (rotation >= 136 && rotation <= 225) {
+                        // bottom
+                        usernameCSS = {
+                            top: Math.ceil(parseFloat(drawingNode.css('height')) - userHeight),
+                            left: Math.ceil(parseFloat(drawingNode.css('width')) - userWidth - 12),
+                            transform: DrawingUtils.getCssTransform(0, !flipH, !flipV)
+                        };
+                    } else {
+                        var isLeft = rotation >= 46 && rotation <= 135 && !flipH && !flipV;
+                        var isRight = rotation >= 226 && rotation <= 315;
+                        if (isLeft || (isRight && (flipV || flipH))) {
+                            usernameCSS = {
+                                top: Math.ceil(parseFloat(drawingNode.css('height')) - userWidth / 2 - userHeight + 2),
+                                left: Math.ceil(-userWidth / 2 + 2),
+                                transform: DrawingUtils.getCssTransform(90, !flipH || (flipH && flipV), !flipV || (flipH && flipV))
+                            };
+                        } else {
+                            // right
+                            usernameCSS = {
+                                top:  Math.ceil(userWidth / 2 - userHeight / 2 + 6),
+                                left: Math.ceil(-userWidth / 2 + 2 + parseFloat(drawingNode.css('width')) - userHeight),
+                                transform: DrawingUtils.getCssTransform(90, flipH && !flipV, flipV && !flipH)
+                            };
+                        }
+                    }
+                    $(usernameOverlay).css(usernameCSS);
+                }
             });
 
             // show user name for a second
