@@ -20,10 +20,10 @@ define('io.ox/office/textframework/utils/export', [
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/color',
 
-    'io.ox/office/drawinglayer/view/drawingframe',
-    'io.ox/office/drawinglayer/view/imageutil'
+    'io.ox/office/drawinglayer/utils/imageutils',
+    'io.ox/office/drawinglayer/view/drawingframe'
 
-], function (Utils, DOM, HyperlinkUtils, Color, DrawingFrame, Image) {
+], function (Utils, DOM, HyperlinkUtils, Color, ImageUtils, DrawingFrame) {
 
     'use strict';
 
@@ -76,7 +76,10 @@ define('io.ox/office/textframework/utils/export', [
 
             if (allDrawingsInSelection.length > 0) {
                 _.each(allDrawingsInSelection, function (drawing) {
-                    returnValue.append(parseSelection(docModel, selection, drawing, { type: 'html' }), '<span>&#8203;</span>');
+                    returnValue.append(parseSelection(docModel, selection, drawing, { type: 'html' }));
+                    if (_.device('android')) {
+                        returnValue.append('<span>&#8203;</span>');
+                    }
                 });
             } else {
                 returnValue.append('<div>');
@@ -122,7 +125,7 @@ define('io.ox/office/textframework/utils/export', [
                 metaElement.attr('data-ox-origin-id', clipboardOriginId);
             }
         }
-        if (resultDiv.children().length === 1) {
+        if (_.device('android') && resultDiv.children().length === 1) {
             resultDiv.append('<span>&#8203;</span>');
         }
         return resultDiv.html();
@@ -231,22 +234,21 @@ define('io.ox/office/textframework/utils/export', [
     function extractImage(docModel, drawing, options) {
         var attributes  = drawing.first().data('attributes');
 
-        if (Utils.getStringOption(options, 'type', 'html') === 'html') {
-            var width        = Utils.convertHmmToLength(attributes.drawing.width, 'px', 1),
-                height       = Utils.convertHmmToLength(attributes.drawing.height, 'px', 1),
-                imageNode    = $(drawing).find('img'),
-                imageUrl     = attributes.image.imageUrl,
-                base64String = attributes.image.imageData;
+        if (Utils.getStringOption(options, 'type', 'html') !== 'html') { return attributes.drawing.name; }
 
-            if (!base64String) {
-                base64String = DOM.getBase64FromImageNode(imageNode, Image.getMimeTypeFromImageUri(imageUrl));
-            }
+        var width        = Utils.convertHmmToLength(attributes.drawing.width, 'px', 1);
+        var height       = Utils.convertHmmToLength(attributes.drawing.height, 'px', 1);
+        var imageUrl     = attributes.image.imageUrl;
+        var base64String = attributes.image.imageData;
 
-            var imgNode = $('<img src="' + base64String + '" width="' + width + 'px" height="' + height + 'px">');
-            return applyFillAndLineStyles(imgNode, docModel, drawing)[0];
+        if (!base64String && DOM.isDocumentImageNode(drawing)) {
+            base64String = DOM.getBase64FromImageNode(drawing, ImageUtils.getMimeTypeFromImageUri(imageUrl));
         }
 
-        return attributes.drawing.name;
+        var imageSrc  = base64String ? base64String : imageUrl;
+        var imageNode = $('<img src="' + imageSrc + '" width="' + width + 'px" height="' + height + 'px">');
+
+        return applyFillAndLineStyles(imageNode, docModel, drawing)[0];
     }
 
     function extractTable(drawing, options) {
@@ -615,7 +617,7 @@ define('io.ox/office/textframework/utils/export', [
                 tmpNode = $('<img>');
                 img = node.find('img');
                 if (isEncodeBase64 && DOM.isDocumentImageNode(node)) {
-                    tmpNode.attr('src', DOM.getBase64FromImageNode(node, Image.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(node, 'get_filename'))));
+                    tmpNode.attr('src', DOM.getBase64FromImageNode(node, ImageUtils.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(node, 'get_filename'))));
                 } else {
                     tmpNode.attr('src', img.attr('src'));
                 }
