@@ -56,6 +56,10 @@ define('io.ox/office/textframework/utils/listutils', [
         switch (format.toLowerCase()) {
             case 'decimal':
                 return value.toString();
+            case 'decimalzero':
+                var strValue = value.toString();
+                if (strValue.length === 1) { strValue = '0' + strValue; }
+                return strValue;
             case 'lowerletter':
                 return Formatter.formatAlphabetic(value, 'repeat', { lower: true });
             case 'upperletter':
