@@ -60,7 +60,11 @@ define('io.ox/office/textframework/utils/snapshot', [
             // the margin at the page, that is used for centering the page including comment layer
             commentMargin = null,
             // the current root node (in which content is deleted, inserted, or gets new attributes)
-            currentRootNode = model.getCurrentRootNode();
+            currentRootNode = model.getCurrentRootNode(),
+            // Spreadsheet app: The text frame node inside the currently active drawing node
+            textFrameNode = null,
+            // An array, that contains objects with the keys 'startPosition' and 'endPosition' for the logical position(s).
+            allPositions = null;
 
         // base constructors --------------------------------------------------
 
@@ -112,13 +116,14 @@ define('io.ox/office/textframework/utils/snapshot', [
             // saving the operation state number
             osn = model.getOperationStateNumber();
 
-            // adding all slides into the page, before creating snapshot
-            if (model.useSlideMode()) { model.appendAllSlidesToDom(); }
+            if (app.isPresentationApp()) { // OX Presentation specific nodes
 
-            // saving the current content node
-            contentNode = DOM.getPageContentNode(pageNode).clone(true, true);
+                // adding all slides into the page, before creating snapshot
+                model.appendAllSlidesToDom();
+
+                // saving the current content node
+                contentNode = DOM.getPageContentNode(pageNode).clone(true, true);
 
-            if (model.useSlideMode()) { // OX Presentation specific nodes
                 activeSlideId = model.getActiveSlideId();
 
                 // getting the layer nodes for master and layout slides
@@ -136,7 +141,13 @@ define('io.ox/office/textframework/utils/snapshot', [
                 // saving the values for 'mainSlideCounter', 'activeSlideId' and 'isMasterView'
                 modelData = model.getModelDataObject();
 
-            } else { // OX Text specific nodes
+                // saving the logical position(s) to restore drawing selections
+                allPositions = model.getSelection().getAllLogicalPositions();
+
+            } else if (app.isTextApp()) { // OX Text specific nodes
+
+                // saving the current content node
+                contentNode = DOM.getPageContentNode(pageNode).clone(true, true);
 
                 // saving the comment layer node
                 if (commentLayerNode.length > 0) {
@@ -163,6 +174,9 @@ define('io.ox/office/textframework/utils/snapshot', [
                     // saving the header wrapper node
                     if (footerWrapperNode.length > 0) { footerWrapper = footerWrapperNode.clone(true, true); }
                 }
+            } else if (app.isSpreadsheetApp()) {
+                // saving the text frame inside the currently active drawing node
+                textFrameNode = pageNode.find('.drawing.edit-active > .content > .textframe').clone(true, true);
             }
 
         });
@@ -175,9 +189,19 @@ define('io.ox/office/textframework/utils/snapshot', [
         this.apply = Utils.profileMethod('Snapshot.applySnapshot(): ', function () {
 
             var // the page content node
-                currentContentNode = DOM.getPageContentNode(pageNode);
+                currentContentNode = null;
 
-            // replacing the main content node
+            if (app.isSpreadsheetApp()) {
+                // replacing the text frame inside the active drawing node is sufficient in Spreadsheet app
+                currentContentNode = pageNode.find('.drawing.edit-active > .content > .textframe');
+                currentContentNode.replaceWith(textFrameNode);
+                // setting the OSN
+                model.setOperationStateNumber(osn);
+                return; // fast exit for Spreadsheet app
+            }
+
+            // replacing the main content node in
+            currentContentNode = DOM.getPageContentNode(pageNode);
             currentContentNode.replaceWith(contentNode);
 
             // restoring header and footer wrapper as children of the page (should never be necessary)
@@ -240,6 +264,17 @@ define('io.ox/office/textframework/utils/snapshot', [
             return commentMargin;
         };
 
+        /**
+         * Returns the stored allPositions object. This is an array, that contains objects
+         * with the keys 'startPosition' and 'endPosition'. If the logical positions are not
+         * saved, null is returned.
+         *
+         * @returns {Object[]|Null}
+         */
+        this.getStoredPositions = function () {
+            return allPositions;
+        };
+
         // initialization -----------------------------------------------------
 
         /**
