@@ -508,7 +508,7 @@ define('io.ox/office/textframework/utils/textutils', [
      * @return {Array} Array of HTMLElements
      *  returns a sorted Array all absolute drawings in textdrawinglayer and textcontent,
      */
-    TextUtils.getAllAbsoluteDrawingsOnPage = logger.profileMethod('TextUtils.getAllAbsoluteDrawingsOnNode()', function (targetRootNode, pageNumber) {
+    TextUtils.getAllAbsoluteDrawingsOnPage = logger.profileMethod('TextUtils.getAllAbsoluteDrawingsOnPage()', function (targetRootNode, pageNumber) {
         var subSelector = '.drawing.absolute:not(.grouped)';
         var selector = '>.textdrawinglayer >' + subSelector + '[page-number="' + pageNumber + '"]';
 
@@ -690,7 +690,7 @@ define('io.ox/office/textframework/utils/textutils', [
      *  The attributes required to remove the drawing background.
      */
     TextUtils.getEmptyDrawingBackgroundAttributes = function () {
-        return TextUtils.NO_DRAWING_BACKGROUND;
+        return _.copy(TextUtils.NO_DRAWING_BACKGROUND, true);
     };
 
     /**
@@ -700,7 +700,7 @@ define('io.ox/office/textframework/utils/textutils', [
      *  The attributes required to remove the slide background.
      */
     TextUtils.getEmptySlideBackgroundAttributes = function () {
-        return TextUtils.NO_SLIDE_BACKGROUND;
+        return _.copy(TextUtils.NO_SLIDE_BACKGROUND, true);
     };
 
     /**
