@@ -30,15 +30,15 @@ define('io.ox/office/textframework/view/control/commentfiltergroup', [
      */
     function CommentFilterGroup(docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the comments in the document model
-            commentLayer = docView.getDocModel().getCommentLayer();
+        // the comments in the document model
+        var commentLayer = docView.getDocModel().getCommentLayer();
 
         // base constructor ---------------------------------------------------
 
-        CheckGroup.call(this, { matcher: matcher, sorted: sortComparator, boxed: false, checkAll: true });
+        CheckGroup.call(this, docView, { matcher: matcher, sorted: sortComparator, boxed: false, checkAll: true });
 
         // private methods ----------------------------------------------------
 
