@@ -74,6 +74,30 @@ define('io.ox/office/textframework/view/controls', [
 
     } }); // class ParagraphAlignmentGroup
 
+    // class ParaVertAlignmentGroup ==========================================
+
+    /**
+     * A picker control for vertical text alignment in paragraphs.
+     *
+     * @constructor
+     *
+     * @extends RadioGroup
+     */
+    TextControls.ParaVertAlignmentGroup = RadioGroup.extend({ constructor: function (docView, initOptions) {
+
+        RadioGroup.call(this, docView, Utils.extendOptions({
+            tooltip: Labels.TEXT_VERT_ALIGNMENT_LABEL
+        }, initOptions));
+
+        // set accessible name - WCAG 2.0 Success Criterion 4.1.2
+        this.getNode().attr({ 'aria-label': Labels.TEXT_VERT_ALIGNMENT_LABEL, 'aria-labelledby': 'dummy' });
+
+        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
+            this.createOptionButton(style.value, { icon: style.icon, tooltip: style.label });
+        }, this);
+
+    } }); // class ParaVertAlignmentGroup
+
     // class ParagraphAlignmentPicker =========================================
 
     /**
@@ -97,6 +121,28 @@ define('io.ox/office/textframework/view/controls', [
 
     } }); // class ParagraphAlignmentPicker
 
+    /**
+     * A picker control for vertical text alignment in paragraphs.
+     *
+     * @constructor
+     *
+     * @extends RadioGroup
+     */
+    TextControls.ParaVertAlignmentPicker = RadioList.extend({ constructor: function (docView, initOptions) {
+
+        RadioList.call(this, docView, Utils.extendOptions({
+            icon: 'docs-cell-v-align-middle',
+            label: Labels.TEXT_VERT_ALIGNMENT_LABEL,
+            tooltip: Labels.TEXT_VERT_ALIGNMENT_TOOLTIP,
+            updateCaptionMode: 'icon'
+        }, initOptions));
+
+        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
+            this.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        }, this);
+
+    } }); // class ParaVertAlignmentPicker
+
     // class TextBoxAlignmentPicker ===========================================
 
     /**
@@ -131,6 +177,40 @@ define('io.ox/office/textframework/view/controls', [
 
     } }); // class TextBoxAlignmentPicker
 
+    // class TableAlignmentPicker ===========================================
+
+    /**
+     * A picker control for horizontal and vertical alignment of paragraphs in
+     * text boxes.
+     *
+     * @constructor
+     *
+     * @extends CompoundButton
+     */
+    TextControls.TableAlignmentPicker = CompoundButton.extend({ constructor: function (docView, initOptions) {
+
+        CompoundButton.call(this, docView, Utils.extendOptions({
+            icon: 'docs-para-align-left',
+            tooltip: gt('Paragraph alignment'),
+            updateCaptionMode: 'none'
+        }, initOptions));
+
+        var horizontalGroup = new RadioGroup(docView);
+        _.each(Labels.PARA_ALIGNMENT_STYLES, function (style) {
+            horizontalGroup.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        });
+        this.addSectionLabel(gt('Horizontal alignment'));
+        this.addGroup('paragraph/alignment', horizontalGroup);
+
+        var verticalGroup = new RadioGroup(docView);
+        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
+            verticalGroup.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        });
+        this.addSectionLabel(gt('Vertical alignment'));
+        this.addGroup('table/verticalalignment', verticalGroup);
+
+    } }); // class TableAlignmentPicker
+
     // class ParagraphSpacingPicker ===========================================
 
     /**
