@@ -42,6 +42,31 @@ define('io.ox/office/textframework/view/labels', [
      */
     TextLabels.PARA_ALIGNMENT_LABEL = /*#. horizontal text alignment in a paragraph */ gt('Paragraph alignment');
 
+    /**
+     * @constant
+     */
+    TextLabels.PARA_ALIGNMENT_LABEL = /*#. horizontal text alignment in a paragraph */ gt('Paragraph alignment');
+
+    /**
+     * @constant
+     */
+    TextLabels.TEXT_VERT_ALIGNMENT_LABEL = /*#. vertical text alignment in a shape */ gt('Text alignment');
+
+    /**
+     * @constant
+     */
+    TextLabels.TEXT_ALIGNMENT_IN_SHAPE_LABEL = /*#. horizontal and vertical text alignment in a shape */ gt('Text alignment');
+
+    /**
+     * @constant
+     */
+    TextLabels.TEXT_VERT_ALIGNMENT_TOOLTIP = /*#. vertical text alignment in a shape */ gt('Align text vertically inside textbox');
+
+    /**
+     * @constant
+     */
+    TextLabels.TEXT_ALIGNMENT_IN_SHAPE_TOOLTIP = /*#. horizontal and vertical text alignment in a shape */ gt('Align text horizontally and vertically inside textbox');
+
     /**
      * @constant
      */
@@ -188,6 +213,16 @@ define('io.ox/office/textframework/view/labels', [
      */
     TextLabels.CREATE_STYLE_LABEL_TOOLTIP = gt('Create new style from selection');
 
+    /**
+     * A text label or tool tip for a 'Format Painter' control.
+     *
+     * @type String
+     * @constant
+     */
+    TextLabels.FORMAT_PAINTER_LABEL =
+        //#. copy formatting from one location and apply it to other objects
+        gt('Format painter');
+
     // fields options --------------------------------------------------------
 
     /**
