@@ -15,15 +15,14 @@
 define('io.ox/office/textframework/view/popup/universalcontextmenu', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/editframework/view/popup/editcontextmenu',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/view/controls',
     'io.ox/office/textframework/view/labels',
-    'io.ox/office/baseframework/view/popup/contextmenu',
-    'io.ox/office/editframework/view/control/languagepicker',
+    'io.ox/office/textframework/view/controls',
     'io.ox/office/drawinglayer/view/drawingframe',
     'gettext!io.ox/office/textframework/main'
-], function (Utils, AttributeUtils, Dom, Position, Controls, Labels, ContextMenu, LanguagePicker, DrawingFrame, gt) {
+], function (Utils, AttributeUtils, EditContextMenu, Dom, Position, Labels, Controls, DrawingFrame, gt) {
 
     'use strict';
 
@@ -39,9 +38,9 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
      *
      * @constructor
      *
-     * @extends ContextMenu
+     * @extends EditContextMenu
      */
-    function UniversalContextMenu(docView, initOptions) {
+    var UniversalContextMenu = EditContextMenu.extend({ constructor: function (docView, initOptions) {
 
         var // self reference
             self = this,
@@ -76,7 +75,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
         // base constructor ---------------------------------------------------
 
-        ContextMenu.call(this, docView, editDiv, Utils.extendOptions({
+        EditContextMenu.call(this, docView, editDiv, Utils.extendOptions({
             delay: Utils.getNumberOption(initOptions, 'delay', 0)
         }, initOptions));
 
@@ -150,17 +149,18 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
         }
 
         function initMenu() {
-            var controller = docView.getApp().getController();
 
             // remove all existing controls from context menu
             self.destroyAllGroups();
             self.setToolTip('');
 
-            if (enableKeys.every(controller.isItemEnabled, controller)) {
+            // add clipboard commands
+            self.addClipboardEntries().addSeparator();
 
+            if (enableKeys.every(docView.isControllerItemEnabled, docView)) {
                 // Is Drawing
                 if (Dom.isDrawingFrame(eleType)) {
-                    if (!Dom.isInCommentNode(node)) {
+                    if (!Dom.isInsideCommentLayerNode(editDiv, node)) {
                         prepareDrawingMenu();
                         self.updateAllGroups(); //Bug 47352
                         return;
@@ -200,6 +200,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
                 self.updateAllGroups(); //Bug 47352
             }
         }
+
         // preparation of context menus ---------------------------------------
         /**
          * Prepares the context menu for text
@@ -209,26 +210,34 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
             var effectiveUrl = isRangeSelected ? null : characterAttrs.url;
 
-            if (Dom.isChangeTrackNode(node) && !isRangeSelected) {
+            function prepareChangeTrackMenu() {
                 self.addGroup('acceptSelectedChangeTracking', new Button(docView, Labels.ACCEPT_CURRENT_OPTIONS))
                     .addGroup('rejectSelectedChangeTracking', new Button(docView, Labels.REJECT_CURRENT_OPTIONS))
                     .addGroup('acceptChangeTracking', new Button(docView, Labels.ACCEPT_ALL_OPTIONS))
                     .addGroup('rejectChangeTracking', new Button(docView, Labels.REJECT_ALL_OPTIONS));
+            }
 
+            if (Dom.isChangeTrackNode(node) && !isRangeSelected) {
+                prepareChangeTrackMenu();
             } else if (fieldManager.isHighlightState() && !docModel.useSlideMode()) {
                 if (fieldManager.isSupportedFieldType()) {
-                    if (characterAttrs.anchor) {
-                        self.addGroup('goToAnchor', new Button(docView, Labels.GO_TO_ANCHOR_LABEL));
+                    var fieldNode = fieldManager.getSelectedFieldNode();
+                    if (Dom.isChangeTrackNode(fieldNode.prev()) && !isRangeSelected) { // fetch prev field node = range start, as field is not changetracked
+                        prepareChangeTrackMenu(); // #56660
+                    } else {
+                        if (characterAttrs.anchor) {
+                            self.addGroup('goToAnchor', new Button(docView, Labels.GO_TO_ANCHOR_LABEL));
+                        }
+                        if (fieldManager.supportsFieldFormatting() && !isRangeSelected) {
+                            self.addGroup('editField', new Button(docView, Labels.EDIT_FIELD_OPTIONS));
+                        }
+                        if (fieldManager.isTableOfContentsHighlighted()) {
+                            self.addGroup('document/inserttoc', new Controls.TocPicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Table of contents layouts'), tooltip: gt('Change current layout'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, anchorBorder: 'right left' }));
+                        }
+                        self.addGroup('updateField', new Button(docView, Labels.UPDATE_FIELD_OPTIONS))
+                            .addSeparator();
+                        self.addGroup('updateAllFields', new Button(docView, Labels.UPDATE_ALL_FIELDS_OPTIONS));
                     }
-                    if (fieldManager.supportsFieldFormatting()) {
-                        self.addGroup('editField', new Button(docView, Labels.EDIT_FIELD_OPTIONS));
-                    }
-                    if (fieldManager.isTableOfContentsHighlighted()) {
-                        self.addGroup('document/inserttoc', new Controls.TocPicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Table of contents layouts'), tooltip: gt('Change current layout'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, anchorBorder: 'right left' }));
-                    }
-                    self.addGroup('updateField', new Button(docView, Labels.UPDATE_FIELD_OPTIONS))
-                    .addSeparator();
-                    self.addGroup('updateAllFields', new Button(docView, Labels.UPDATE_ALL_FIELDS_OPTIONS));
                 }
             } else {
                 // Spellcheck
@@ -263,9 +272,13 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
                     // Normal Text
                 } else {
                     buildNormalTextMenu();
-                    if (!Utils.SMALL_DEVICE && !docModel.useSlideMode()) {
+                    if (!Utils.SMALL_DEVICE && docView.getApp().isTextApp()) {
+                        self.addGroup('paragraph/attrs/dialog', new Button(docView, { label: /*#. Context menu entry to open dialog with paragraph properties. */ gt('Paragraph') }));
                         self.addGroup(null, new Controls.InTextStyleContextSubMenu(docView, { autoCloseParent: false, autoHideGroups: true, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false }));
                     }
+                    if (docView.getApp().isTextApp()) {
+                        addNumberingListValueMenu();
+                    }
                     addLanguageGroupToMenu();
                 }
             }
@@ -294,7 +307,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             var normalTextBtn = new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false });
 
             normalTextBtn
-                .addGroup('image/insert/dialog',        new Button(docView, Labels.INSERT_IMAGE_OPTIONS))
+                .addGroup('image/insert/dialog',        new Button(docView, _.extend({ value: 'drive' }, Labels.INSERT_IMAGE_OPTIONS)))
                 .addGroup('textframe/insert',           new Controls.InsertTextFrameButton(docView, { icon: null }))
                 .addGroup('comment/insert',             new Button(docView, Labels.INSERT_COMMENT_OPTIONS))
                 .addGroup('character/hyperlink/dialog', new Button(docView, Labels.INSERT_HYPERLINK_OPTIONS));
@@ -308,12 +321,21 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             self.addGroup(null, normalTextBtn);
         }
 
+        /**
+         * Adding the list numbering buttons to the context menu.
+         */
+        function addNumberingListValueMenu() {
+            self.addSeparator()
+                .addGroup('paragraph/list/startListWithOne', new Button(docView, { label: gt('Start list with first value') }))
+                .addGroup('paragraph/list/continueList', new Button(docView, { label: gt('Continue list numbering') }));
+        }
+
         /**
          * Add the Language Group to the context menu.
          */
         function addLanguageGroupToMenu() {
             self.addSeparator()
-                .addGroup('character/language', new LanguagePicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Language'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, showListIcons: false, anchorBorder: 'right left', showAllLanguages: false }));
+                .addGroup('character/language', new Controls.LanguagePicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Language'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, showListIcons: false, anchorBorder: 'right left', showAllLanguages: false }));
         }
 
         /**
@@ -339,7 +361,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
                 .addGroup('table/delete',        new Button(docView, { label: gt('Delete table') }))
                 .addSeparator()
                 .addGroup(null, new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false })
-                    .addGroup('image/insert/dialog',        new Button(docView, Labels.INSERT_IMAGE_OPTIONS))
+                    .addGroup('image/insert/dialog',        new Button(docView, _.extend({ value: 'drive' }, Labels.INSERT_IMAGE_OPTIONS)))
                     .addGroup('textframe/insert',           new Controls.InsertTextFrameButton(docView, { icon: null }))
                     .addGroup('comment/insert',             new Button(docView, Labels.INSERT_COMMENT_OPTIONS))
                     .addGroup('character/hyperlink/dialog', new Button(docView, Labels.INSERT_HYPERLINK_OPTIONS))
@@ -379,11 +401,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
             eleType = _.last(arrDomTree);
 
-            if (!enableKeys.every(controller.isItemEnabled, controller)) {
-                if (isRangeSelected) {
-                    event.preventDefault();
-                    return;
-                }
+            if (!enableKeys.every(controller.isItemEnabled, controller) && !isRangeSelected) {
                 var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
                 if (!characterAttrs.url) {
                     event.preventDefault();
@@ -454,11 +472,10 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             selection = spellChecker = fieldManager = null;
         });
 
-    } // class UniversalContextMenu
+    } }); // class UniversalContextMenu
 
     // exports ================================================================
 
-    // derive this class from class ContextMenu
-    return ContextMenu.extend({ constructor: UniversalContextMenu });
+    return UniversalContextMenu;
 
 });
