@@ -60,7 +60,27 @@ define('io.ox/office/tk/config', [
      *  not exist, this method will return the default value.
      */
     Config.getFlag = function (key, def) {
-        return Config.get(key, def === true) === true;
+        var flag = Config.get(key, null);
+        return (typeof flag === 'boolean') ? flag : (def === true);
+    };
+
+    /**
+     * Returns the state of a specific string configuration property.
+     *
+     * @param {String} key
+     *  The key of a specific string configuration property.
+     *
+     * @param {String} [def=""]
+     *  The default value, if the configuration property specified with the
+     *  parameter 'key' does not exist.
+     *
+     * @returns {String}
+     *  The state of the specified configuration property. If the property does
+     *  not exist, this method will return the default value.
+     */
+    Config.getStr = function (key, def) {
+        var str = Config.get(key, null);
+        return (typeof str === 'string') ? str : (def || '');
     };
 
     /**
@@ -82,12 +102,27 @@ define('io.ox/office/tk/config', [
      *  not exist, this method will return the default value.
      */
     Config.getInt = function (key, def, min) {
-        var int = Config.get(key, def);
-        if (typeof int !== 'number') { int = 0; }
+        var int = Config.get(key, null);
+        if (typeof int !== 'number') { int = (typeof def === 'number') ? def : 0; }
         if (typeof min === 'number') { int = Math.max(int, min); }
         return Math.floor(int);
     };
 
+    /**
+     * Returns the state of a specific array configuration property.
+     *
+     * @param {String} key
+     *  The key of a specific array configuration property.
+     *
+     * @returns {Array<Any>}
+     *  The state of the specified configuration property. If the property does
+     *  not exist, this method will return an empty array.
+     */
+    Config.getArray = function (key) {
+        var array = Config.get(key, null);
+        return Array.isArray(array) ? array : [];
+    };
+
     /**
      * Sets a value of a specific configuration property. Be careful
      * to only set single properties.
@@ -114,9 +149,8 @@ define('io.ox/office/tk/config', [
             return obj;
         }, value);
 
-        // Call merge with update tree to prevent that the whole
-        // tree is sent to the backend
-        return settings.set(key, value).merge(updateTree);
+        // call merge() with update tree to prevent that the whole tree is sent to the backend
+        return settings.reload().then(function () { return settings.set(key, value).merge(updateTree); });
     };
 
     /**
