@@ -13,12 +13,16 @@
  */
 
 define('io.ox/office/tk/container/container', [
-    'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils'
-], function (Utils, IteratorUtils) {
+    'io.ox/office/tk/utils/class',
+    'io.ox/office/tk/utils/iterator'
+], function (Class, Iterator) {
 
     'use strict';
 
+    // convenience shortcuts
+    var ObjectIterator = Iterator.ObjectIterator;
+    var TransformIterator = Iterator.TransformIterator;
+
     // private global functions ===============================================
 
     function getCallback(args) {
@@ -27,7 +31,7 @@ define('io.ox/office/tk/container/container', [
 
         // bind callback function to context
         if (typeof callback === 'function') {
-            return callback.bind(args[1]);
+            return args[1] ? callback.bind(args[1]) : callback;
         }
 
         // performance shortcut for few number of arguments
@@ -53,7 +57,7 @@ define('io.ox/office/tk/container/container', [
      *
      * @constructor
      */
-    var Container = _.makeExtendable(function () {
+    var Container = Class.extendable(function () {
 
         // the internal storage of this container
         this._cont = {};
@@ -119,6 +123,46 @@ define('io.ox/office/tk/container/container', [
         });
     };
 
+    /**
+     * Invokes the passed constructor, and returns the new class instance.
+     *
+     * @param {Function} Ctor
+     *  The class constructor function.
+     *
+     * @param {Arguments} args
+     *  Arguments passed to the calling function.
+     *
+     * @param {Number} offset
+     *  The index of the first argumnet in the passed arguments array to be
+     *  passed to the class constructor.
+     *
+     * @returns {Object}
+     *  The new class instance.
+     */
+    Container.constructElement = function (Ctor, args, offset) {
+
+        // number of arguments to be passed to the constructor
+        var length = args.length - offset;
+
+        // performance shortcut for few number of arguments
+        switch (length) {
+            case 0: return new Ctor();
+            case 1: return new Ctor(args[offset]);
+            case 2: return new Ctor(args[offset], args[offset + 1]);
+            case 3: return new Ctor(args[offset], args[offset + 1], args[offset + 2]);
+        }
+
+        // shorten the passed arguments, and convert them to a real array
+        args = Array.prototype.slice.call(args, offset);
+
+        // construct a new instance with arbitrary number of arguments on the fly
+        return (function () {
+            function Helper() { return Ctor.apply(this, args); }
+            Helper.prototype = Ctor.prototype;
+            return new Helper();
+        }());
+    };
+
     // protected methods ------------------------------------------------------
 
     /**
@@ -202,7 +246,13 @@ define('io.ox/office/tk/container/container', [
      *  Whether this container contains exactly one element.
      */
     Container.prototype.single = function () {
-        return Utils.hasSingleProperty(this._cont);
+        // avoid helpers with O(n) complexity, such as _.size() or Object.keys()
+        var count = 0;
+        for (var key in this._cont) { // eslint-disable-line no-unused-vars
+            count += 1;
+            if (count > 1) { break; }
+        }
+        return count === 1;
     };
 
     /**
@@ -248,7 +298,7 @@ define('io.ox/office/tk/container/container', [
      *  (1) {Any} value
      *      The value of the element with the specified key.
      *
-     * @param {Object} context
+     * @param {Object} [context]
      *  The calling context for the callback function.
      *
      * @returns {Any}
@@ -306,47 +356,32 @@ define('io.ox/office/tk/container/container', [
      * Returns an iterator that visits all elements in this container. The
      * elements will be visited in no specific order.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the container has been visited completely. No more
-     *      elements are available; this result object does not contain any
-     *      other properties!
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Any} value
-     *      The value of the element currently visited. This property will be
-     *      omitted, if the iterator is done (see property 'done').
+     *      The value of the element currently visited.
      *  - {String} key
-     *      The key of the element currently visited. This property will be
-     *      omitted, if the iterator is done (see property 'done').
+     *      The key of the element currently visited.
      */
     Container.prototype.iterator = function () {
-        return IteratorUtils.createObjectIterator(this._cont);
+        return new ObjectIterator(this._cont);
     };
 
     /**
      * Returns an iterator that visits the keys of all elements in this
      * container. The keys will be visited in no specific order.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the container has been visited completely. No more
-     *      elements are available; this result object does not contain any
-     *      other properties!
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {String} value
-     *      The key of the element currently visited. This property will be
-     *      omitted, if the iterator is done (see property 'done').
+     *      The key of the element currently visited.
      *  - {Any} element
-     *      The value of the element currently visited. This property will be
-     *      omitted, if the iterator is done (see property 'done').
+     *      The value of the element currently visited.
      */
     Container.prototype.keyIterator = function () {
-        var iterator = IteratorUtils.createObjectIterator(this._cont);
-        return IteratorUtils.createTransformIterator(iterator, function (value, iterResult) {
+        return new TransformIterator(this, function (value, iterResult) {
             return { value: iterResult.key, element: value };
         });
     };
@@ -881,6 +916,22 @@ define('io.ox/office/tk/container/container', [
         return this;
     };
 
+    /**
+     * Convenience method to destroy all elements of this container, and clear
+     * the container afterwards. All elements MUST be objects with a method
+     * destroy().
+     *
+     * @returns {Container}
+     *  A reference to this (now empty) container.
+     */
+    Container.prototype.destroyElements = function () {
+        var cont = this._cont;
+        for (var key in cont) {
+            cont[key].destroy();
+        }
+        return this.clear();
+    };
+
     // exports ================================================================
 
     return Container;
