@@ -14,11 +14,17 @@
 
 define('io.ox/office/tk/container/sortedarray', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils'
-], function (Utils, IteratorUtils) {
+    'io.ox/office/tk/utils/class',
+    'io.ox/office/tk/utils/iterator',
+    'io.ox/office/tk/container/container'
+], function (Utils, Class, Iterator, Container) {
 
     'use strict';
 
+    // convenience shortcuts
+    var ArrayIterator = Iterator.ArrayIterator;
+    var TransformIterator = Iterator.TransformIterator;
+
     // class ElementDescriptor ================================================
 
     /**
@@ -77,7 +83,7 @@ define('io.ox/office/tk/container/sortedarray', [
      *  strings, or date objects). The function _.identity can be passed to
      *  sort the array elements by themselves.
      */
-    var SortedArray = _.makeExtendable(function (sorter) {
+    var SortedArray = Class.extendable(function (sorter) {
 
         this._array = [];
         this._sorter = sorter;
@@ -296,6 +302,50 @@ define('io.ox/office/tk/container/sortedarray', [
         return value;
     };
 
+    /**
+     * Returns the array element at the specified sort index, or constructs and
+     * inserts a new array element.
+     *
+     * @param {Number} index
+     *  The sort index associated with the array element (as returned by the
+     *  'sorter' callback function passed to the constructor).
+     *
+     * @param {Function} Ctor
+     *  A class constructor function for missing array elements. Receives all
+     *  following parameters passed to this method.
+     *
+     * @param {Any} [...]
+     *  All following parameters will be passed to the class constructor.
+     *
+     * @returns {Any}
+     *  The array element for the passed sort index.
+     */
+    SortedArray.prototype.getOrConstruct = function (index, Ctor) {
+        return this.getOrCreate(index, function () {
+            return Container.constructElement(Ctor, this, 2);
+        }, arguments);
+    };
+
+    /**
+     * Returns the number of existing elements contained in the passed sort
+     * index interval.
+     *
+     * @param {Any} first
+     *  The sort index of the first array element.
+     *
+     * @param {Any} last
+     *  The sort index of the last array element (closed interval).
+     *
+     * @returns {Number}
+     *  The number of all existing elements contained in the specified index
+     *  interval.
+     */
+    SortedArray.prototype.intervalSize = function (first, last) {
+        var desc1 = this.find(first, 'next');
+        var desc2 = this.find(last, 'prev');
+        return (desc1 && desc2) ? Math.max(0, desc2._ai - desc1._ai + 1) : 0;
+    };
+
     /**
      * Returns all elements contained in the passed sort index interval.
      *
@@ -343,27 +393,22 @@ define('io.ox/office/tk/container/sortedarray', [
      * @param {Boolean} [reverse=false]
      *  Whether to visit the array elements in reversed order.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the elements have been visited completely. No more
-     *      array elements are available; this result object does not contain
-     *      any other properties!
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Any} value
      *      The array element currently visited.
      *  - {Any} index
-     *      The sort index of the array element (as returned by the 'sorter'
+     *      The sort index of the array element (as returned by the "sorter"
      *      callback function passed to the constructor) currently visited by
      *      the iterator (NOT the internal array index).
      */
     SortedArray.prototype.iterator = function (reverse) {
 
         // create an array iterator that visits all elements in this array, and provides the sort index instead of array index
-        var iterator = IteratorUtils.createArrayIterator(this._array, reverse ? { reverse: true } : null);
+        var iterator = new ArrayIterator(this._array, reverse ? { reverse: true } : null);
         var sorter = this._sorter;
-        return IteratorUtils.createTransformIterator(iterator, function (value, result) {
+        return new TransformIterator(iterator, function (value, result) {
             result.index = sorter(value);
             return result;
         }, this);
@@ -384,18 +429,13 @@ define('io.ox/office/tk/container/sortedarray', [
      *  Whether to visit the array elements in reversed order. The element with
      *  the sort index passed to the parameter 'last' will be visited first.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the interval has been visited completely. No more
-     *      array elements are available; this result object does not contain
-     *      any other properties!
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Any} value
      *      The array element currently visited.
      *  - {Any} index
-     *      The sort index of the array element (as returned by the 'sorter'
+     *      The sort index of the array element (as returned by the "sorter"
      *      callback function passed to the constructor) currently visited by
      *      the iterator (NOT the internal array index).
      */
@@ -404,13 +444,13 @@ define('io.ox/office/tk/container/sortedarray', [
         // find the first array element to be visited (fast binary search)
         var desc = this.find(reverse ? last : first, reverse ? 'prev' : 'next');
         if (!desc || (reverse ? (desc.index < first) : (last < desc.index))) {
-            return IteratorUtils.ALWAYS_DONE_ITERATOR;
+            return Iterator.EMPTY;
         }
 
         // create an array iterator that visits all elements in this array until the iterator leaves the passed interval
-        var iterator = IteratorUtils.createArrayIterator(this._array, { reverse: reverse, begin: desc._ai });
+        var iterator = new ArrayIterator(this._array, { reverse: reverse, begin: desc._ai });
         var sorter = this._sorter;
-        return IteratorUtils.createTransformIterator(iterator, function (value) {
+        return new TransformIterator(iterator, function (value) {
             var index = sorter(value);
             var done = reverse ? (index < first) : (last < index);
             return done ? { done: true } : { value: value, index: index };
@@ -486,6 +526,18 @@ define('io.ox/office/tk/container/sortedarray', [
         return desc.value;
     };
 
+    /**
+     * Convenience method to destroy all elements of this array, and clear the
+     * array afterwards. All elements MUST be objects with a method destroy().
+     *
+     * @returns {SortedArray}
+     *  A reference to this (now empty) array.
+     */
+    SortedArray.prototype.destroyElements = function () {
+        this.forEach(function (element) { element.destroy(); });
+        return this.clear();
+    };
+
     // exports ================================================================
 
     return SortedArray;
