@@ -83,7 +83,7 @@ define('io.ox/office/tk/control/checkbox', [
 
         // add special marker classes used to adjust formatting
         this.getNode().addClass('check-box');
-        Forms.checkButtonNodes(this.getButtonNode(), false, checkOptions);
+        updateHandler(false);
 
         // register an update handler that updates the check mark
         this.registerUpdateHandler(updateHandler);
