@@ -44,11 +44,11 @@ define('io.ox/office/tk/control/checkgroup', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class
      *  ButtonGroup. Additionally, the following options are supported:
-     *  @param {Boolean} [initOptions.boxed=false]
+     *  - {Boolean} [initOptions.boxed=false]
      *      If set to true, the icons to visualize the unchecked and checked
      *      state will contain rectangular boxes. Otherwise, unchecked state is
      *      simply empty space, and checked state is a simple check mark.
-     *  @param {Boolean} [initOptions.checkAll=false]
+     *  - {Boolean} [initOptions.checkAll=false]
      *      If set to true, an additional special check box with the label
      *      'Select all' will be shown on top of all other check boxes.
      *      Clicking this check box will switch the state of all other check
@@ -206,7 +206,7 @@ define('io.ox/office/tk/control/checkgroup', [
         if (Utils.getBooleanOption(initOptions, 'checkAll', false)) {
 
             // create and insert the 'Select all' check box
-            selectAllNode = $(Forms.createButtonMarkup({ label: SELECT_ALL_LABEL })).addClass('select-all');
+            selectAllNode = $(Forms.createButtonMarkup({ label: SELECT_ALL_LABEL, attributes: { role: 'checkbox' } })).addClass('select-all');
             Forms.checkButtonNodes(selectAllNode, false, { design: design });
             this.addChildNodes(selectAllNode);
 
