@@ -133,10 +133,10 @@ define('io.ox/office/tk/control/group', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptions.classes]
+     *  - {String} [initOptions.classes]
      *      Additional CSS classes that will be set at the root DOM node of
      *      this instance.
-     *  @param {String} [initOptions.role]
+     *  - {String} [initOptions.role]
      *      An ARIA role attribute that will be set at the root DOM node of
      *      this instance.
      */
@@ -249,7 +249,7 @@ define('io.ox/office/tk/control/group', [
                     case 'tap':
                     case 'click':
                         // Forms.setButtonKeyHandler() triggers 'click' events with 'keyCode' field
-                        eventOptions.sourceType = ('keyCode' in sourceEvent) ? 'keyboard' : 'click';
+                        eventOptions.sourceType = ('keyCode' in sourceEvent && _.isNumber(sourceEvent.keyCode)) ? 'keyboard' : 'click';
                         // click events from keyboard: keep focus on button after SPACE or TAB key (see Forms.setButtonKeyHandler() method)
                         eventOptions.preserveFocus = (sourceEvent.keyCode === KeyCodes.SPACE) || (sourceEvent.keyCode === KeyCodes.TAB);
                         // pass type of the source event
@@ -554,11 +554,11 @@ define('io.ox/office/tk/control/group', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {jQuery.Event} [options.sourceEvent]
+         *  - {jQuery.Event} [options.sourceEvent]
          *      The source event that has caused the new event. This source
          *      event may influence the focus behavior, (e.g.: browser focus is
          *      kept on a button, if the SPACE key has been used).
-         *  @param {Boolean} [options.preserveFocus]
+         *  - {Boolean} [options.preserveFocus]
          *      If specified, forces to preserve the browser focus regardless
          *      of the passed source event.
          *
