@@ -33,16 +33,22 @@ define('io.ox/office/tk/control/spinfield', [
      *
      * @extends TextField
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  spin field object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the TextField base class.
-     *  If the option 'validator' exists, it MUST be an instance of
+     *  If the option 'validator' exists, it MUST be an instance of the class
      *  TextField.NumberValidator (or a sub class). Alternatively, the options
      *  supported by the constructor of the class TextField.NumberValidator can
      *  be passed. In this case, a new instance of TextField.NumberValidator
      *  will be created automatically based on these options. Additionally, the
      *  following options are supported:
      */
-    function SpinField(initOptions) {
+    function SpinField(windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -50,9 +56,6 @@ define('io.ox/office/tk/control/spinfield', [
         // the number validator of this spin field
         var validator = Utils.getObjectOption(initOptions, 'validator') || new TextField.NumberValidator(initOptions);
 
-        // whether to turn of spin controls
-        var spinEnabled = Utils.getBooleanOption(initOptions, 'spinEnabled', true);
-
         // whether the unit is percentage
         var percentageUnit = Utils.getBooleanOption(initOptions, 'percentageUnit', false);
 
@@ -61,7 +64,7 @@ define('io.ox/office/tk/control/spinfield', [
 
         // base constructors --------------------------------------------------
 
-        TextField.call(this, Utils.extendOptions({ keyboard: 'number' }, initOptions, { validator: validator }));
+        TextField.call(this, windowId, Utils.extendOptions({ keyboard: 'number' }, initOptions, { validator: validator }));
 
         // private methods ----------------------------------------------------
 
@@ -133,7 +136,7 @@ define('io.ox/office/tk/control/spinfield', [
 
             // handler for 'tracking:end' and 'tracking:cancel' events: return focus to text field
             function trackingEndHandler() {
-                self.executeDelayed(function () { Utils.setFocus(self.getInputNode()); }, { infoString: 'SpinField: createSpinButton' });
+                self.executeDelayed(function () { Utils.setFocus(self.getInputNode()); }, 'SpinField.createSpinButton');
             }
 
             // add the caret symbol
@@ -190,27 +193,25 @@ define('io.ox/office/tk/control/spinfield', [
 
         // initialization -----------------------------------------------------
 
-        if (spinEnabled) {
-            // add special marker class used to adjust formatting, add spin buttons
-            this.getNode().addClass('spin-field').append(
-                $('<div>').addClass('spin-wrapper').append(createSpinButton(true), createSpinButton(false))
-            );
+        // add special marker class used to adjust formatting, add spin buttons
+        this.getNode().addClass('spin-field').append(
+            $('<div>').addClass('spin-wrapper').append(createSpinButton(true), createSpinButton(false))
+        );
 
-            // add ARIA attributes (note: role 'spinbutton' would be correct but doesn't work with VoiceOver)
-            this.getInputNode().attr({ role: 'slider', 'aria-valuemin': validator.getMin(), 'aria-valuemax': validator.getMax() });
+        // add ARIA attributes (note: role 'spinbutton' would be correct but doesn't work with VoiceOver)
+        this.getInputNode().attr({ role: 'slider', 'aria-valuemin': validator.getMin(), 'aria-valuemax': validator.getMax() });
 
-            // register event handlers
-            this.getInputNode().on('keydown', inputKeyDownHandler);
+        // register event handlers
+        this.getInputNode().on('keydown', inputKeyDownHandler);
 
-            // bug 46846: initial click on a spin button before this control is focused needs
-            // to be deferred until the base class TextField has processed the focus events
-            this.on('group:focus', function () {
-                if (pendingStep !== null) {
-                    changeValue(pendingStep);
-                    pendingStep = null;
-                }
-            });
-        }
+        // bug 46846: initial click on a spin button before this control is focused needs
+        // to be deferred until the base class TextField has processed the focus events
+        this.on('group:focus', function () {
+            if (pendingStep !== null) {
+                changeValue(pendingStep);
+                pendingStep = null;
+            }
+        });
 
         // register input field update handler
         this.registerUpdateHandler(updateHandler);
