@@ -14,8 +14,9 @@
 
 define('io.ox/office/tk/io', [
     'io.ox/core/http',
-    'io.ox/office/tk/utils'
-], function (CoreHTTP, Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/scheduler'
+], function (CoreHTTP, Utils, Scheduler) {
 
     'use strict';
 
@@ -27,7 +28,7 @@ define('io.ox/office/tk/io', [
      */
     var IO = {};
 
-// constants --------------------------------------------------------------
+    // constants --------------------------------------------------------------
 
     /**
      * The name of the document filter server module.
@@ -41,40 +42,6 @@ define('io.ox/office/tk/io', [
 
     // public methods ---------------------------------------------------------
 
-    /**
-     * Creates a function that returns a promise which will be resolved or
-     * rejected depending on the result of the passed filter callback function.
-     * Intended to be used in promise chains to modify the state of a promise
-     * depending on the result data.
-     *
-     * @param {Function} filter
-     *  A function that receives and filters the response of a resolved promise
-     *  as first parameter. If this function returns undefined, the promise
-     *  created by the method will be rejected. Otherwise, the promise will be
-     *  resolved with the return value of this filter function.
-     *
-     * @param {Object} [context]
-     *  The context object that will be bound to the passed filter function.
-     *
-     * @returns {Function}
-     *  A new function that returns a promise that will be resolved or rejected
-     *  depending on the result of the passed filter callback function.
-     */
-    IO.createDeferredFilter = function (filter, context) {
-
-        // create and return a function that call the filter and returns a resolved/rejected promise
-        return function (response) {
-
-            // the resulting deferred object
-            var deferred = new $.Deferred();
-            // call passed filter callback
-            var value = _.isObject(response) ? filter.call(context, response) : undefined;
-
-            // resolve the deferred object, if the value returned by the filter function is not undefined
-            return _.isUndefined(value) ? deferred.reject(response) : deferred.resolve(value);
-        };
-    };
-
     /**
      * Sends a request to the server and returns a promise waiting for the
      * response.
@@ -88,16 +55,9 @@ define('io.ox/office/tk/io', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.method='GET']
+     *  - {String} [options.method='GET']
      *      The request method. Must be an upper-case string (for example,
      *      'GET', 'POST', etc.). Defaults to 'GET'.
-     *  @param {Function} [options.resultFilter]
-     *      A function that will be called if the request returns successfully,
-     *      and filters the resulting 'data' object returned by the request.
-     *      Receives the 'data' object as first parameter. If this function
-     *      returns undefined, the entire request will be rejected. Otherwise,
-     *      the request will be resolved with the return value of this function
-     *      instead of the complete 'data' object.
      *
      * @returns {jQuery.Promise}
      *  The promise of the request. Will be resolved with the 'data' object
@@ -111,30 +71,34 @@ define('io.ox/office/tk/io', [
 
         // extract the request method
         var method = Utils.getStringOption(options, 'method', 'GET');
-        // extract the result filter callback
-        var resultFilter = Utils.getFunctionOption(options, 'resultFilter');
         // properties passed to the server request
         var requestProps = { module: module, params: params };
-        // the promise representing the core AJAX request
-        var ajaxRequest = null;
-        // the Promise returned by this method
-        var promise = null;
-
         // send the AJAX request
-        ajaxRequest = CoreHTTP[method](requestProps);
+        var ajaxRequest = CoreHTTP[method](requestProps);
+        // deferred for synchronous abort (54803)
+        var deferred = Scheduler.createDeferred('IO', 'IO.sendRequest');
+        // the corresponding promise object
+        var promise = deferred.promise();
 
-        // reject, if the response contains 'hasErrors:true'
-        promise = ajaxRequest.then(function (response) {
-            return Utils.getBooleanOption(response, 'hasErrors', false) ? $.Deferred().reject(response) : response;
+        ajaxRequest.done(function (response) {
+            if (Utils.getBooleanOption(response, 'hasErrors', false)) {
+                deferred.reject(response);
+            } else {
+                deferred.resolve(response);
+            }
         });
 
-        // filter the result of the original request according to the passed filter callback
-        if (_.isFunction(resultFilter)) {
-            promise = promise.then(IO.createDeferredFilter(resultFilter));
-        }
+        ajaxRequest.fail(function (response) {
+            deferred.reject(response);
+        });
 
-        // add an abort() method, forward invocation to AJAX request
-        return _.extend(promise, { abort: function () { ajaxRequest.abort(); } });
+        // add an abort() method
+        promise.abort = function () {
+            ajaxRequest.abort();
+            deferred.reject('abort');
+        };
+
+        return promise;
     };
 
     /**
@@ -155,17 +119,17 @@ define('io.ox/office/tk/io', [
         return require(['text!' + fileName + '.json']).then(function (response) {
 
             // check response
-            if (!_.isString(response) || (response.length === 0)) {
+            if ((typeof response !== 'string') || (response.length === 0)) {
                 Utils.error('IO.loadJSON(): invalid response');
-                return $.Deferred().reject(response);
+                return new $.Deferred().reject(response);
             }
 
             // parse JSON string to object
             try {
                 return JSON.parse(response);
-            } catch (ex) {
-                Utils.exception(ex);
-                return $.Deferred().reject(ex);
+            } catch (err) {
+                Utils.exception(err);
+                return new $.Deferred().reject(err);
             }
         });
     };
@@ -189,8 +153,11 @@ define('io.ox/office/tk/io', [
 
         // fetch source code for module
         _.delay(function () {
-            Utils.log('IO.prefetchModuleSource(): fetching ' + modulePath);
-            require([modulePath + '/main']);
+            Utils.log('IO.prefetchModuleSource(): fetching ' + modulePath + ' ...');
+            var t0 = Date.now();
+            require([modulePath + '/main'], function () {
+                Utils.log('... fetching ' + modulePath + ' done in ' + (Date.now() - t0) + 'ms');
+            });
         }, 2500);
     });
 
