@@ -180,9 +180,11 @@ define.async('io.ox/office/tk/locale/localedata', [
      *  - {String} b
      *      The translated format token for buddhist years.
      *  - {String} g
-     *      The translated format token for era names.
+     *      The translated format token for Japanese era names.
      *  - {String} e
-     *      The translated format token for era years.
+     *      The translated format token for Japanese era years.
+     *  - {String} a
+     *      The translated format token for the name of the day (OOXML).
      *
      * @property {Array<String>} shortWeekdays
      *  The translated short names of all days in a week, starting with Sunday.
@@ -219,7 +221,7 @@ define.async('io.ox/office/tk/locale/localedata', [
 
         // convert date/time format code tokens from string to map
         this.dateTokens = (function (t) {
-            return { Y: t[0], M: t[1], D: t[2], h: t[3], m: t[4], s: t[5], b: t[6], g: t[7], e: t[8] };
+            return { Y: t[0], M: t[1], D: t[2], h: t[3], m: t[4], s: t[5], b: t[6], g: t[7], e: t[8], a: t[9] };
         }(this.dateTokens));
 
         // add other properties
@@ -455,11 +457,11 @@ define.async('io.ox/office/tk/locale/localedata', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.merge=false]
+     *  - {Boolean} [options.merge=false]
      *      If set to true, the data mapped by the generic language name (e.g.
      *      "en"), and the data mapped by the exact locale identifier (e.g.
      *      "en_GB") will be merged.
-     *  @param {String} [options.locale]
+     *  - {String} [options.locale]
      *      If specified, the resource data for the specified locale will be
      *      loaded instead for the current UI locale. MUST be a complete locale
      *      identifier with language and region, separated by an underscore
