@@ -943,8 +943,7 @@ define('io.ox/office/tk/popup/listmenu', [
         if (mruSize > 0) {
             this.createSectionNode(MRU_SECTION_ID, { label: mruLabel, sortItems: true });
             multiSelect = false;
-            mruList = mruSettingsKey ? Config.get(mruSettingsKey, null) : null;
-            mruList = _.isArray(mruList) ? mruList.slice(0, mruSize) : [];
+            mruList = mruSettingsKey ? Config.getArray(mruSettingsKey).slice(0, mruSize) : [];
             this.one('popup:beforeshow', function () { mruList.forEach(createMRUItemNode); });
         }
 
