@@ -41,7 +41,7 @@ define('io.ox/office/tk/popup/tooltip', [
      *  Supports all options also supported by the base class BasePopup. The
      *  default value of the option 'anchorPadding' will be set to 3 though.
      *  Additionally, the following options are supported:
-     *  @param {Boolean} [initOptions.hoverStyle=false]
+     *  - {Boolean} [initOptions.hoverStyle=false]
      *      If set to true, the tool tip will be shown with dark background and
      *      light text color, and with a small arrow pointing towards the
      *      anchor node. Intended to be used for tool tips that will be shown
@@ -99,7 +99,7 @@ define('io.ox/office/tk/popup/tooltip', [
     var hoverToolTip = new ToolTip(ToolTip.SINGLETON, {
         anchor: function () { return hoverNode; },
         anchorAlign: 'center',
-        anchorBorder: 'bottom',
+        anchorBorder: ['bottom', 'top'],
         hoverStyle: true
     });
 
