@@ -404,7 +404,7 @@ define('io.ox/office/tk/render/canvas', [
      * @param {Object} options
      *  Stroke style parameters. Omitting a property will not change the
      *  respective style setting.
-     *  @param {String|CanvasGradient|CanvasPattern} [options.style]
+     *  - {String|CanvasGradient|CanvasPattern} [options.style]
      *      The fill style for rendering line segments of a path, as string for
      *      a solid fill color (any CSS color: as '#RRGGBB', '#RRGGBBAA',
      *      '#RGB', '#RGBA' style, or as 'rgb()', 'rgba()', 'hsl()', or
@@ -412,16 +412,16 @@ define('io.ox/office/tk/render/canvas', [
      *      or as instance of CanvasGradient for linear or radial gradient
      *      styles, or as instance of CanvasPattern for pattern or bitmap fill
      *      styles.
-     *  @param {Number} [options.width]
+     *  - {Number} [options.width]
      *      The width of the line segments.
-     *  @param {Number} [options.cap]
+     *  - {Number} [options.cap]
      *      The style of the line end points. Supports all values supported by
      *      the property 'lineCap' of the native rendering context.
-     *  @param {Number} [options.join]
+     *  - {Number} [options.join]
      *      The style of the line connection points. Supports all values
      *      supported by the property 'lineJoin' of the native rendering
      *      context.
-     *  @param {Array<Number>|Number|Null} [options.pattern]
+     *  - {Array<Number>|Number|Null} [options.pattern]
      *      The line dash pattern, as pairs of numbers in a flat array. Each
      *      number in the array MUST be non-negative, and the sum of all
      *      numbers (the length of the pattern) MUST be greater than zero. The
@@ -434,7 +434,7 @@ define('io.ox/office/tk/render/canvas', [
      *      copies of the array. If set to a number, uses a simple pattern with
      *      equally sized segments and gaps. If set to null, the current line
      *      dash pattern will be removed, and solid lines will be rendered.
-     *  @param {Number} [options.patternOffset]
+     *  - {Number} [options.patternOffset]
      *      The initial pattern offset for every subpath in a path stroked with
      *      a dash pattern.
      *
@@ -459,15 +459,15 @@ define('io.ox/office/tk/render/canvas', [
      * @param {Object} options
      *  Shadow style parameters. Omitting a property will not change the
      *  respective style setting.
-     *  @param {String} [options.color]
+     *  - {String} [options.color]
      *      The shadow color (any CSS color: as '#RRGGBB', '#RRGGBBAA', '#RGB',
      *      '#RGBA' style, or as 'rgb()', 'rgba()', 'hsl()', or 'hsla()'
      *      function style, or any predefined or system color name).
-     *  @param {Number} [options.blur]
+     *  - {Number} [options.blur]
      *      The size of the blur effect.
-     *  @param {Number} [options.offsetX]
+     *  - {Number} [options.offsetX]
      *      The offset of the shadow relative to the path in X direction.
-     *  @param {Number} [options.offsetY]
+     *  - {Number} [options.offsetY]
      *      The offset of the shadow relative to the path in Y direction.
      *
      * @returns {ContextWrapper}
@@ -490,13 +490,13 @@ define('io.ox/office/tk/render/canvas', [
      * @param {Object} options
      *  Font style parameters. Omitting a property will not change the
      *  respective style setting.
-     *  @param {String} [options.font]
+     *  - {String} [options.font]
      *      The font styles, as expected by the property 'font' of the canvas
      *      rendering context. Initial value is '10pt sans-serif'.
-     *  @param {String} [options.align]
+     *  - {String} [options.align]
      *      The horizontal alignment (accepts all values supported by the
      *      property 'textAlign' of a canvas rendering context).
-     *  @param {String} [options.baseline]
+     *  - {String} [options.baseline]
      *      The text baseline mode (accepts all values supported by the
      *      property 'textBaseline' of a canvas rendering context).
      *
@@ -688,7 +688,7 @@ define('io.ox/office/tk/render/canvas', [
 
         // generate the path in the rendering context, and render the path
         if (fill || stroke) { this._pathGenerator.generatePath(path); }
-        if (fill) { this._context.fill(); }
+        if (fill) { this._context.fill('evenodd'); }
         if (stroke) { this._context.stroke(); }
 
         return this;
@@ -1183,11 +1183,11 @@ define('io.ox/office/tk/render/canvas', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {HTMLCanvasElement|jQuery} [initOptions.node]
+     *  - {HTMLCanvasElement|jQuery} [initOptions.node]
      *      An existing <canvas> element to be wrapped by this instance. The
      *      current size of that canvas will be retained. By default, a new
      *      <canvas> element with zero size will be created automatically.
-     *  @param {String} [initOptions.classes]
+     *  - {String} [initOptions.classes]
      *      Additional CSS classes (space-separated list) that will be added to
      *      the passed or created <canvas> element.
      */
@@ -1277,16 +1277,16 @@ define('io.ox/office/tk/render/canvas', [
          * @param {Rectangle|Object} rectangle
          *  The new rectangle represented by the canvas DOM element (with
          *  optional start position), with the following properties:
-         *  @param {Number} [rectangle.left=0]
+         *  - {Number} [rectangle.left=0]
          *      Global horizontal translation, in pixels. A pixel drawn at this
          *      position will appear at the left border of the canvas area.
-         *  @param {Number} [rectangle.top=0]
+         *  - {Number} [rectangle.top=0]
          *      Global vertical translation, in pixels. A pixel drawn at this
          *      position will appear at the top border of the canvas area.
-         *  @param {Number} rectangle.width
+         *  - {Number} rectangle.width
          *      Width of the bitmap in the canvas area, in pixels. Will also be
          *      set as element size of the <canvas> DOM element.
-         *  @param {Number} rectangle.height
+         *  - {Number} rectangle.height
          *      Height of the bitmap in the canvas area, in pixels. Will also
          *      be set as element size of the <canvas> DOM element.
          *
