@@ -13,8 +13,9 @@
  */
 
 define('io.ox/office/tk/render/colorutils', [
-    'io.ox/office/tk/utils'
-], function (Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class'
+], function (Utils, Class) {
 
     'use strict';
 
@@ -114,7 +115,7 @@ define('io.ox/office/tk/render/colorutils', [
      *  value 0 represents full transparency, the value 1 represents full
      *  opacity.
      */
-    var AlphaModel = _.makeExtendable(function (a) {
+    var AlphaModel = Class.extendable(function (a) {
 
         // public properties
         this.a = Utils.minMax(a, 0, 1);
@@ -206,7 +207,7 @@ define('io.ox/office/tk/render/colorutils', [
      * @property {Number} b
      *  The value of the blue channel, in the interval [0;1].
      */
-    var RGBModel = AlphaModel.extend({ constructor: function (r, g, b, a) {
+    var RGBModel = AlphaModel.extend(function (r, g, b, a) {
 
         // base constructor
         AlphaModel.call(this, a);
@@ -216,7 +217,7 @@ define('io.ox/office/tk/render/colorutils', [
         this.g = Utils.minMax(g, 0, 1);
         this.b = Utils.minMax(b, 0, 1);
 
-    } }); // class RGBModel
+    }); // class RGBModel
 
     // static methods ---------------------------------------------------------
 
@@ -539,7 +540,7 @@ define('io.ox/office/tk/render/colorutils', [
      *  represents black (regardless of the other values), and the value 1
      *  represents white.
      */
-    var HSLModel = AlphaModel.extend({ constructor: function (h, s, l, a) {
+    var HSLModel = AlphaModel.extend(function (h, s, l, a) {
 
         // base constructor
         AlphaModel.call(this, a);
@@ -549,7 +550,7 @@ define('io.ox/office/tk/render/colorutils', [
         this.s = Utils.minMax(s, 0, 1);
         this.l = Utils.minMax(l, 0, 1);
 
-    } }); // class HSLModel
+    }); // class HSLModel
 
     // public methods ---------------------------------------------------------
 
