@@ -579,6 +579,7 @@ define('io.ox/office/tk/utils/driveutils', [
         var preselect = Utils.getStringOption(initOptions, 'folderId');
 
         var folderTree = new TreeView({
+            context: 'popup',
             persistent: false,
             tabindex: 0,
             root: DriveUtils.getRootId(),
@@ -607,6 +608,10 @@ define('io.ox/office/tk/utils/driveutils', [
             self.trigger('change');
         });
 
+        folderTree.on('select:item', function () {
+            self.trigger('select:item');
+        });
+
         if (preselect) {
             DriveUtils.preselectFolder(folderTree, preselect);
         }
@@ -1068,6 +1073,7 @@ define('io.ox/office/tk/utils/driveutils', [
                         if (!next) {
                             //done
                             folderEl.click();
+                            treeView.trigger('select:item');
                             return;
                         }
                         treeView.once('appear:' + next.id, function () {
