@@ -1103,12 +1103,17 @@ define('io.ox/office/tk/utils/iterator', [
      *  The source sequence to be iterated over. Will be passed to the static
      *  method Iterator.from() to create an iterator object.
      *
+     * @param {Array} [array]
+     *  The array to be filled. The values of the source sequence will be
+     *  appended to the array. If omitted, a bew empty array will be created
+     *  and returned.
+     *
      * @returns {Array}
      *  An array with all values returned by the sequence.
      */
-    Iterator.toArray = function (iterable) {
+    Iterator.toArray = function (iterable, array) {
         var iterator = Iterator.from(iterable);
-        var array = [];
+        array = array || [];
         for (var result = iterator.next(); !result.done; result = iterator.next()) {
             array.push(result.value);
         }
