@@ -15,8 +15,9 @@
 define('io.ox/office/tk/utils/scheduler', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/tk/container/valueset'
-], function (Config, Utils, ValueSet) {
+], function (Config, Utils, Class, ValueSet) {
 
     'use strict';
 
@@ -77,14 +78,13 @@ define('io.ox/office/tk/utils/scheduler', [
         function fillNode(targetNode, pendingObjects, titleLabel) {
 
             var lines = pendingObjects.map(function (pendingObj) {
-                var line = { markup: '', uid: pendingObj.uid };
-                line.markup += '<tr>';
-                line.markup += '<td>' + pendingObj.uid + '</td>';
-                line.markup += '<td>' + Utils.escapeHTML(pendingObj.windowId) + '</td>';
-                line.markup += '<td>' + Utils.escapeHTML(pendingObj.logMessage) + '</td>';
-                line.markup += '<td>' + (pendingObj.background ? 'background' : '') + '</td>';
-                line.markup += '</tr>';
-                return line;
+                var markup = '<tr>';
+                markup += '<td>' + pendingObj.uid + '</td>';
+                markup += '<td>' + Utils.escapeHTML(pendingObj.windowId) + '</td>';
+                markup += '<td>' + Utils.escapeHTML(pendingObj.logMessage) + '</td>';
+                markup += '<td>' + (pendingObj.background ? 'background' : '') + '</td>';
+                markup += '</tr>';
+                return { markup: markup, uid: pendingObj.uid };
             }).sort(function (line1, line2) {
                 return Utils.compareIndexedStrings(line1.uid, line2.uid);
             });
@@ -132,13 +132,13 @@ define('io.ox/office/tk/utils/scheduler', [
      *
      * @param {Object} [logOptions]
      *  Optional parameters for debug logging:
-     *  @param {Boolean} [logOptions.background=false]
+     *  - {Boolean} [logOptions.background=false]
      *      Whether the pending timer or pending promise represents a
      *      long-running background task with low priority. These background
      *      tasks will be ignored when waiting for pending tasks in automated
      *      test environments.
      */
-    var PendingObj = _.makeExtendable(function (idPrefix, windowId, logMessage, logOptions) {
+    var PendingObj = Class.extendable(function (idPrefix, windowId, logMessage, logOptions) {
 
         this.uid = _.uniqueId(idPrefix);
         this.windowId = windowId.getWindowId ? windowId.getWindowId() : windowId;
@@ -174,18 +174,18 @@ define('io.ox/office/tk/utils/scheduler', [
      *
      * @param {Object} [logOptions]
      *  Optional parameters for debug logging:
-     *  @param {Boolean} [logOptions.background=false]
+     *  - {Boolean} [logOptions.background=false]
      *      Whether the pending timer represents a long-running background task
      *      with low priority. These background tasks will be ignored when
      *      waiting for pending tasks in automated test environments.
      */
-    var TimerObj = PendingObj.extend({ constructor: function (callback, delay, windowId, logMessage, logOptions) {
+    var TimerObj = PendingObj.extend(function (callback, delay, windowId, logMessage, logOptions) {
 
         PendingObj.call(this, 'timer', windowId, logMessage, logOptions);
         this.timestamp = _.now() + delay;
         this.callback = callback;
 
-    } }); // class TimerObj
+    }); // class TimerObj
 
     // class TimerQueue =======================================================
 
@@ -446,16 +446,16 @@ define('io.ox/office/tk/utils/scheduler', [
      *
      * @param {Object} [logOptions]
      *  Optional parameters for debug logging:
-     *  @param {Boolean} [logOptions.background=false]
+     *  - {Boolean} [logOptions.background=false]
      *      Whether the pending promise represents a long-running background
      *      task with low priority. These background tasks will be ignored when
      *      waiting for pending tasks in automated test environments.
      */
-    var DeferredObj = PendingObj.extend({ constructor: function (windowId, logMessage, logOptions) {
+    var DeferredObj = PendingObj.extend(function (windowId, logMessage, logOptions) {
 
         PendingObj.call(this, 'deferred', windowId, logMessage, logOptions);
 
-    } }); // class DeferredObj
+    }); // class DeferredObj
 
     // singletons =============================================================
 
@@ -492,8 +492,7 @@ define('io.ox/office/tk/utils/scheduler', [
      * The forced interval time between timer callbacks, in milliseconds.
      *
      * @constant
-     *
-     * @type {Number}
+     * @type Number
      */
     Scheduler.INTERVAL = INTERVAL;
 
@@ -502,8 +501,7 @@ define('io.ox/office/tk/utils/scheduler', [
      * milliseconds.
      *
      * @constant
-     *
-     * @type {Number}
+     * @type Number
      */
     Scheduler.SLICE = SLICE;
 
@@ -530,7 +528,7 @@ define('io.ox/office/tk/utils/scheduler', [
      *
      * @param {Object} [logOptions]
      *  Optional parameters for debug logging:
-     *  @param {Boolean} [logOptions.background=false]
+     *  - {Boolean} [logOptions.background=false]
      *      Whether the pending timer represents a long-running background task
      *      with low priority. These background tasks will be ignored when
      *      waiting for pending tasks in automated test environments.
@@ -586,7 +584,7 @@ define('io.ox/office/tk/utils/scheduler', [
      *
      * @param {Object} [logOptions]
      *  Optional parameters for debug logging:
-     *  @param {Boolean} [logOptions.background=false]
+     *  - {Boolean} [logOptions.background=false]
      *      Whether the pending promise represents a long-running background
      *      task with low priority. These background tasks will be ignored when
      *      waiting for pending tasks in automated test environments.
