@@ -30,12 +30,15 @@ module.exports = function (grunt) {
 
         options: {
             base: 'apps',
-            externals: ['io.ox/{backbone,contacts,core,files,guard,mail,realtime,metrics}/**/*', 'static/3rd.party/**/*'],
+            externals: ['io.ox/{backbone,contacts,core,files,guard,mail,realtime,metrics}/**/*', 'static/3rd.party/**/*', '3rd.party/swiper/**/*'],
             libs: 'io.ox/office/drawinglayer/lib/**/*',
             plugins: {
                 less: {
                     ext: 'less'
                 },
+                css: {
+                    ext: 'css'
+                },
                 json: {
                     ext: 'json'
                 },
@@ -44,6 +47,8 @@ module.exports = function (grunt) {
                 },
                 gettext: {
                     match: function (module, dep) {
+                        // exemption for grabbing translated Application-Titles from central core-translations
+                        if (dep === 'io.ox/core') { return true; }
 
                         var moduleDirs = module.split('/');
                         var depDirs = dep.split('/');
@@ -95,7 +100,7 @@ module.exports = function (grunt) {
                     },
                     spreadsheet: {
                         src: 'io.ox/office/spreadsheet/**/*',
-                        dependsOn: 'editframework'
+                        dependsOn: 'textframework'
                     }
                 }
             }
