@@ -13,5 +13,5 @@ module.exports = function (grunt) {
     // create a distribution ready version of the ui
     grunt.registerTask('dist', ['clean', 'build', 'copy_dist', 'uglify']);
     // default task (grunt called without target)
-    grunt.registerTask('default', ['checkDependencies', 'bower', 'build']);
+    grunt.registerTask('default', ['build']);
 };
