@@ -13,10 +13,10 @@
  */
 
 define('intervalset/intervalset1', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (IteratorUtils, SortedArray, IntervalArray) {
+], function (Iterator, SortedArray, IntervalArray) {
 
     'use strict';
 
@@ -500,7 +500,7 @@ define('intervalset/intervalset1', [
      *      The index interval currently visited.
      */
     IntervalSet.prototype.iterator = function () {
-        return IteratorUtils.createPropertyIterator(this._map);
+        return new Iterator.ObjectIterator(this._map);
     };
 
     /**
