@@ -260,9 +260,11 @@ define('globals/apphelper', [
                         operation = _.clone(operation);
                         converters[operation.name](operation);
                     }
-                    if (!docModel.invokeOperationHandler(operation)) {
+                    try {
+                        docModel.invokeOperationHandler(operation);
+                    } catch (err) {
                         console.error(appBaseName + ' operation #' + index + ' (' + operation.name + ') failed', operation);
-                        throw new Error('operation failed');
+                        throw err;
                     }
                 });
             }
@@ -373,6 +375,17 @@ define('globals/apphelper', [
         { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' }
     ];
 
+    var SPREADSHEET_OPERATION_ERRORCODES = {
+        '#NULL': '#NULL!',
+        '#DIV0': '#DIV/0!',
+        '#VALUE': '#VALUE!',
+        '#REF': '#REF!',
+        '#NAME': '#NAME?',
+        '#NUM': '#NUM!',
+        '#NA': '#N/A',
+        '#DATA': '#GETTING_DATA'
+    };
+
     var SPREADSHEET_OPERATION_CONVERTERS = (function () {
 
         function convertAddress(operation, propName) {
@@ -394,7 +407,7 @@ define('globals/apphelper', [
                     if (_.isArray(rowData)) { rowData = { c: rowData }; }
                     rowData.c = rowData.c.map(function (cellData) {
                         cellData = (cellData === null) ? {} :
-                            (cellData instanceof SheetHelper.ErrorCode) ? { e: cellData.toJSON() } :
+                            (cellData instanceof SheetHelper.ErrorCode) ? { e: SPREADSHEET_OPERATION_ERRORCODES[cellData.toString()] || '#N/A' } :
                                 _.isObject(cellData) ? cellData :
                                     { v: cellData };
                         return cellData;
