@@ -236,41 +236,33 @@ define([
 
         describe('method "pasteInternalClipboard"', function () {
             var // a drawing node
-                drawing = null,
-                // the delete promise
-                clipboardPromise = null;
+                drawing = null;
 
             it('should exist', function () {
                 expect(model).to.respondTo('pasteInternalClipboard');
             });
-            it('should paste some text into the text frame that is selected', function (done) {
+            it('should paste some text into the text frame that is selected', function () {
                 model.getSelection().setTextSelection([0, 1], [0, 2]);
                 drawing = model.getSelection().getSelectedDrawing();
                 expect(drawing.find(DOM.PARAGRAPH_NODE_SELECTOR).first().text()).to.equal(secondDrawingText);
-                clipboardPromise = model.pasteInternalClipboard();
-                clipboardPromise.always(function () {
+                return model.pasteInternalClipboard().then(function () {
                     model.getSelection().setTextSelection([0, 1], [0, 2]);
                     expect(drawing.find(DOM.PARAGRAPH_NODE_SELECTOR).first().text()).to.equal(pasteDrawingText1);
-                    done();
                 });
             });
-            it('should paste some text into the text frame that contains the selection', function (done) {
+            it('should paste some text into the text frame that contains the selection', function () {
                 model.getSelection().setTextSelection([0, 1, 0, 6]);
-                clipboardPromise = model.pasteInternalClipboard();
-                clipboardPromise.always(function () {
+                return model.pasteInternalClipboard().then(function () {
                     expect(drawing.find(DOM.PARAGRAPH_NODE_SELECTOR).first().text()).to.equal(pasteDrawingText2);
-                    done();
                 });
             });
-            it('should paste some text into a new created text frame, if the browser selection is in the clipboard', function (done) {
+            it('should paste some text into a new created text frame, if the browser selection is in the clipboard', function () {
                 var followingDrawings = drawing.nextAll('div.drawing').length;
                 expect(drawing.nextAll('div.drawing').length).to.equal(followingDrawings);
                 model.getSelection().setTextSelection([0, 0]);
-                clipboardPromise = model.pasteInternalClipboard();
-                clipboardPromise.always(function () {
+                return model.pasteInternalClipboard().then(function () {
                     expect(drawing.nextAll('div.drawing').length).to.equal(followingDrawings + 1);
                     expect(drawing.nextAll('div.drawing').text()).to.equal(pasteText);
-                    done();
                 });
             });
         });
@@ -279,8 +271,6 @@ define([
 
             var // the affected drawing, paragraph and text span nodes
                 drawing = null, paragraph = null,
-                // the delete promise
-                delPromise = null,
                 // the length of the default text
                 defaultTextLength = 0;
 
@@ -296,7 +286,7 @@ define([
                 defaultTextLength = defaultText.length;
                 expect(defaultTextLength).to.be.above(0);
             });
-            it('should insert the default template text into an empty text frame', function (done) {
+            it('should insert the default template text into an empty text frame', function () {
                 model.getSelection().setTextSelection([0, 1, 0, 0]); // setting cursor into drawing
                 model.getSelection().selectAll(); //
 
@@ -308,14 +298,11 @@ define([
                 expect(_.last(model.getSelection().getStartPosition())).to.equal(0);
                 expect(_.last(model.getSelection().getEndPosition())).to.be.above(0);
 
-                delPromise = model.deleteSelected({ deleteKey: true });
-                delPromise.always(function () {
+                return model.deleteSelected({ deleteKey: true }).then(function () {
 
                     var // the text span inside the paragraph
                         textspan = null;
 
-                    expect(delPromise.state()).to.equal('resolved');
-
                     expect(_.last(model.getSelection().getStartPosition())).to.equal(0);
                     expect(_.last(model.getSelection().getEndPosition())).to.equal(0);
 
@@ -353,13 +340,9 @@ define([
                     expect(textspan.length).to.equal(1);
                     expect(textspan.text().length).to.equal(defaultTextLength);
                     expect(DOM.isTextFrameTemplateTextSpan(textspan)).to.equal(true);
-
-                    done();
                 });
-
             });
         });
-
     });
 
     // ========================================================================
