@@ -25,7 +25,11 @@ define([
     var a = SheetHelper.a;
     var r = SheetHelper.r;
     var ra = SheetHelper.ra;
-    var MoveMode = SheetUtils.MoveMode;
+
+    var LEFT = SheetUtils.Direction.LEFT;
+    var RIGHT = SheetUtils.Direction.RIGHT;
+    var UP = SheetUtils.Direction.UP;
+    var DOWN = SheetUtils.Direction.DOWN;
 
     // class CellCollection ===================================================
 
@@ -354,14 +358,14 @@ define([
             });
         });
 
-        describe('method "rangesOverlapAnyMatrix"', function () {
+        describe('method "coversAnyMatrixRange"', function () {
             it('should exist', function () {
-                expect(cellCollection1).to.respondTo('rangesOverlapAnyMatrix');
+                expect(cellCollection1).to.respondTo('coversAnyMatrixRange');
             });
             it('should return whether the range overlaps with a matrix', function () {
-                expect(cellCollection1.rangesOverlapAnyMatrix(r('A1:B4'))).to.equal(false);
-                expect(cellCollection1.rangesOverlapAnyMatrix(r('B8:B9'))).to.equal(true);
-                expect(cellCollection1.rangesOverlapAnyMatrix(r('C9:D10'))).to.equal(true);
+                expect(cellCollection1.coversAnyMatrixRange(r('A1:B4'))).to.equal(false);
+                expect(cellCollection1.coversAnyMatrixRange(r('B8:B9'))).to.equal(true);
+                expect(cellCollection1.coversAnyMatrixRange(r('C9:D10'))).to.equal(true);
             });
         });
 
@@ -406,7 +410,7 @@ define([
         describe('method "generateMoveCellsOperations"', function () {
             it('should fail to split matrix formulas', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.RIGHT).then(function () {
+                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), RIGHT).then(function () {
                     throw new Error('operation is expected to fail');
                 }, function (result) {
                     expect(result).to.deep.equal({ cause: 'formula:matrix:insert' });
@@ -414,7 +418,7 @@ define([
             });
             it('should fail to shorten matrix formulas', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT).then(function () {
+                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), LEFT).then(function () {
                     throw new Error('operation is expected to fail');
                 }, function (result) {
                     expect(result).to.deep.equal({ cause: 'formula:matrix:delete' });
@@ -422,7 +426,7 @@ define([
             });
             it('should move all formula cells and defined names when inserting columns', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A1:B1048576'), MoveMode.RIGHT);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A1:B1048576'), RIGHT);
                 return promise.then(function () {
                     expectFormulaCell(0, 'D2', 'G2+1', null, null, null);
                     expectFormulaCell(0, 'E3', 'H3+4', null, null, null);
@@ -455,7 +459,7 @@ define([
             });
             it('should move all formula cells and defined names when deleting rows', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A2:XFD2 A5:XFD5'), MoveMode.UP);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A2:XFD2 A5:XFD5'), UP);
                 return promise.then(function () {
                     expectFormulaCell(0, 'B2', 'E2+3', null, null, null);
                     expectFormulaCell(0, 'E2', 'Sheet2!E3+7', null, null, null);
@@ -484,7 +488,7 @@ define([
             });
             it('should split shared formulas when inserting cells inbetween', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A6:XFD6'), MoveMode.DOWN);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A6:XFD6'), DOWN);
                 return promise.then(function () {
                     var si1 = expectFormulaCell(0, 'B5', 'E2', 'any', 'B5:C5', null).si;
                     expectFormulaCell(0, 'C5', null, si1, null, null);
@@ -503,7 +507,7 @@ define([
             });
             it('should update data validation and formatting rules when inserting rows', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.DOWN);
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), DOWN);
                 return promise.then(function () {
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B12');
                     expectValidation(1, 0, 'B8:C10', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
@@ -530,7 +534,7 @@ define([
             });
             it('should update data validation and formatting rules when deleting rows', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.UP);
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), UP);
                 return promise.then(function () {
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B10');
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B10+Sheet1!B11');
@@ -557,7 +561,7 @@ define([
             });
             it('should update table references when deleting table', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A11:XFD12'), MoveMode.UP);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A11:XFD12'), UP);
                 return promise.then(function () {
                     expectFormulaCell(0, 'A11', 'SUM(#REF!,Table2[],#REF!,#REF!,Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])', null, null, null);
                     expectApplyUndo(generator);
@@ -566,7 +570,7 @@ define([
             });
             it('should update table references when deleting columns', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT);
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('C1:C1048576'), LEFT);
                 return promise.then(function () {
                     expectFormulaCell(0, 'A13', 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],#REF!,#REF!)', null, null, null);
                     expectApplyUndo(generator);
@@ -575,7 +579,7 @@ define([
             });
             it('should update chart source links when inserting rows', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A3:XFD3 A11:XFD11'), MoveMode.DOWN);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A3:XFD3 A11:XFD11'), DOWN);
                 return promise.then(function () {
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$4', 'Sheet1!$J$2:$J$4');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$4', 'Sheet1!$K$2:$K$4');
@@ -594,7 +598,7 @@ define([
             });
             it('should update chart source links when deleting columns', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('J1:J1048576'), MoveMode.LEFT);
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('J1:J1048576'), LEFT);
                 return promise.then(function () {
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!#REF!', 'Sheet1!$I$2:$I$3', 'Sheet1!#REF!');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
