@@ -49,7 +49,7 @@ define([
             // empty test sheet for operation generator methods
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
 
-            // test data for CellCollection.hasRangeHeadline()
+            // test data for CellCollection.hasHeaderRow()
             { name: 'insertSheet', sheet: 1, sheetName: 'Sheet2' },
             { name: 'changeCells', sheet: 1, start: 'A1', contents: [
                 ['headline', 'headline', 'headline', 9],
@@ -156,24 +156,16 @@ define([
             });
         });
 
-        describe('method "hasRangeHeadline"', function () {
+        describe('method "hasHeaderRow"', function () {
             it('should exist', function () {
-                expect(cellCollection0).to.respondTo('hasRangeHeadline');
+                expect(cellCollection0).to.respondTo('hasHeaderRow');
             });
             it('should detect headlines', function () {
                 var cellCollection = getCellCollection(1);
-                var range1 = r('A1:D5');
-                var range2 = r('A2:D5');
-                var range3 = r('A11:D15');
-                var range4 = r('B11:D15');
-                expect(cellCollection.hasRangeHeadline(range1, 'vertical')).to.equal(true);
-                expect(cellCollection.hasRangeHeadline(range1, 'horizontal')).to.equal(false);
-                expect(cellCollection.hasRangeHeadline(range2, 'vertical')).to.equal(false);
-                expect(cellCollection.hasRangeHeadline(range2, 'horizontal')).to.equal(false);
-                expect(cellCollection.hasRangeHeadline(range3, 'vertical')).to.equal(false);
-                expect(cellCollection.hasRangeHeadline(range3, 'horizontal')).to.equal(true);
-                expect(cellCollection.hasRangeHeadline(range4, 'vertical')).to.equal(false);
-                expect(cellCollection.hasRangeHeadline(range4, 'horizontal')).to.equal(false);
+                expect(cellCollection.hasHeaderRow(r('A1:D5'))).to.equal(true);
+                expect(cellCollection.hasHeaderRow(r('A2:D5'))).to.equal(false);
+                expect(cellCollection.hasHeaderRow(r('A11:D15'))).to.equal(false);
+                expect(cellCollection.hasHeaderRow(r('B11:D15'))).to.equal(false);
             });
         });
 
