@@ -38,35 +38,60 @@ define([
 
         // operator implementations -------------------------------------------
 
-        moduleTester.testFunction('add', function (ADD, descriptor) {
+        moduleTester.testFunction('uplus', function (UPLUS, descriptor) {
             it('should provide correct parameter count', function () {
                 expect(descriptor).to.have.a.property('minParams', 1);
-                expect(descriptor).to.have.a.property('maxParams', 2);
+                expect(descriptor).to.have.a.property('maxParams', 1);
             });
             it('should return the unconverted value', function () {
-                expect(ADD(10)).to.equal(10);
-                expect(ADD(true)).to.equal(true);
-                expect(ADD('10')).to.equal('10');
-                expect(ADD('abc')).to.equal('abc');
+                expect(UPLUS(10)).to.equal(10);
+                expect(UPLUS(true)).to.equal(true);
+                expect(UPLUS('10')).to.equal('10');
+                expect(UPLUS('abc')).to.equal('abc');
+            });
+        });
+
+        moduleTester.testFunction('uminus', function (UMINUS, descriptor) {
+            it('should provide correct parameter count', function () {
+                expect(descriptor).to.have.a.property('minParams', 1);
+                expect(descriptor).to.have.a.property('maxParams', 1);
+            });
+            it('should return the negated number', function () {
+                expect(UMINUS(10)).to.equal(-10);
+                expect(UMINUS(-10)).to.equal(10);
+                expect(UMINUS(0)).to.equal(0);
+            });
+        });
+
+        moduleTester.testFunction('upct', function (PERCENT, descriptor) {
+            it('should provide correct parameter count', function () {
+                expect(descriptor).to.have.a.property('minParams', 1);
+                expect(descriptor).to.have.a.property('maxParams', 1);
+            });
+            it('should return a hundreth of the argument', function () {
+                expect(PERCENT(1)).to.equal(0.01);
+                expect(PERCENT(123)).to.equal(1.23);
+                expect(PERCENT(-1)).to.equal(-0.01);
+                expect(PERCENT(-123)).to.equal(-1.23);
+                expect(PERCENT(0)).to.equal(0);
+            });
+        });
+
+        moduleTester.testFunction('add', function (ADD, descriptor) {
+            it('should provide correct parameter count', function () {
+                expect(descriptor).to.have.a.property('minParams', 2);
+                expect(descriptor).to.have.a.property('maxParams', 2);
             });
             it('should return the sum', function () {
                 expect(ADD(10, 2)).to.equal(12);
-                expect(ADD(true, 2)).to.equal(3);
-                expect(ADD('10', 2)).to.equal(12);
-            });
-            it('should throw #VALUE! for invalid first argument', function () {
-                expect(ADD('abc', 2)).to.equal(ErrorCode.VALUE);
             });
         });
 
         moduleTester.testFunction('sub', function (SUB, descriptor) {
             it('should provide correct parameter count', function () {
-                expect(descriptor).to.have.a.property('minParams', 1);
+                expect(descriptor).to.have.a.property('minParams', 2);
                 expect(descriptor).to.have.a.property('maxParams', 2);
             });
-            it('should return the negated number', function () {
-                expect(SUB(10)).to.equal(-10);
-            });
             it('should return the difference', function () {
                 expect(SUB(10, 2)).to.equal(8);
             });
@@ -105,20 +130,6 @@ define([
             });
         });
 
-        moduleTester.testFunction('pct', function (PERCENT, descriptor) {
-            it('should provide correct parameter count', function () {
-                expect(descriptor).to.have.a.property('minParams', 1);
-                expect(descriptor).to.have.a.property('maxParams', 1);
-            });
-            it('should return a hundreth of the argument', function () {
-                expect(PERCENT(1)).to.equal(0.01);
-                expect(PERCENT(123)).to.equal(1.23);
-                expect(PERCENT(-1)).to.equal(-0.01);
-                expect(PERCENT(-123)).to.equal(-1.23);
-                expect(PERCENT(0)).to.equal(0);
-            });
-        });
-
         moduleTester.testFunction('con', function (CONCAT, descriptor) {
             it('should provide correct parameter count', function () {
                 expect(descriptor).to.have.a.property('minParams', 2);
