@@ -77,17 +77,15 @@ define([
                 [5,        null, 62]
             ] },
 
-            //unsorted match
+            // MATCH function
             { name: 'insertSheet', sheet: 4, sheetName: 'Sheet5' },
-            { name: 'changeCells', sheet: 4, start: 'A1', contents: [
-                ['a'],
-                ['c'],
-                ['b'],
-                ['d'],
-                [null],
-                [null],
-                [null],
-                [null]
+            { name: 'changeCells', sheet: 4, start: 'K1', contents: [
+                [1, 2, 3, 4, null, null, null, 5, 6, 7],
+                [7, 6, 5, 4, null, null, null, 3, 2, 1],
+                [1, 2, 3, 99, null, null, null, 5, 6, 7],
+                [1, 2, 3, null, null, null, 99, 5, 6, 7],
+                [7, 6, 5, -99, null, null, null, 3, 2, 1],
+                [7, 6, 5, null, null, null, -99, 3, 2, 1]
             ] }
         ];
 
@@ -193,26 +191,104 @@ define([
         });
 
         moduleTester.testFunction('INDEX', { refSheet: 1, targetAddress: 'Z26', toOperand: [0] }, function (INDEX) {
-            it('should return the result of the INDEX on arrays/matrices', function () {
-                expect(INDEX(mat([[1, 2], [3, 4]]), 0, 2)).to.deep.equal(mat([[2], [4]]));
+            it('should return results for a scalar', function () {
+                expect(INDEX(42, 1)).to.equal(42);
+                expect(INDEX(42, 0)).to.equal(42);
+                expect(INDEX(42, 1, 1)).to.equal(42);
+                expect(INDEX(42, 1, 0)).to.equal(42);
+                expect(INDEX(42, 0, 0)).to.equal(42);
+                expect(INDEX(42, 1, 1, 1)).to.equal(42);
             });
-            it('should return the result of the INDEX on refs', function () {
-                expect(INDEX(r3d('1:1!A1:B2'), 2, 2)).to.deep.equal(r3d('1:1!B2:B2'));
-                expect(INDEX(r3d('1:1!A1:B2'), 2, 1)).to.deep.equal(r3d('1:1!A2:A2'));
+            it('should return REF error for a scalar', function () {
+                expect(INDEX(42, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(42, 2)).to.equal(ErrorCode.REF);
+                expect(INDEX(42, 1, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(42, 1, 2)).to.equal(ErrorCode.REF);
+                expect(INDEX(42, 1, 1, 0)).to.equal(ErrorCode.REF);
+                expect(INDEX(42, 1, 1, 2)).to.equal(ErrorCode.REF);
             });
-            it('should return the result of the INDEX on refs', function () {
-                expect(INDEX(r3d('1:1!A1:C5'), 2, 3)).to.deep.equal(r3d('1:1!C2:C2'));
-                expect(INDEX(r3d('1:1!A1:C5'), 5, 2)).to.deep.equal(r3d('1:1!B5:B5'));
-                expect(INDEX(r3da('1:1!A1:C5 1:1!A7:C10'), 2, 2, 2)).to.deep.equal(r3d('1:1!B8:B8'));
-                expect(INDEX(r3d('1:1!A1:C10'), 0, 3, 1)).to.deep.equal(r3d('1:1!C1:C10'));
-            });
-            it('should return the expected Error of the INDEX function', function () {
-                expect(INDEX(mat([[1, 2], [3, 4]]), 0, 2, 2)).to.equal(ErrorCode.REF);
-                expect(INDEX(1, 0, 2)).to.equal(ErrorCode.VALUE);
 
-                expect(INDEX(r3da('1:1!A1:B2 1:1!A7:B8'), 3, 2, 2)).to.equal(ErrorCode.REF);
-                expect(INDEX(r3da('1:1!A1:B2 1:1!A7:B8'), 2, 3, 2)).to.equal(ErrorCode.REF);
-                expect(INDEX(r3da('1:1!A1:B2 1:1!A7:B8'), 2, 2, 3)).to.equal(ErrorCode.REF);
+            var m1 = mat([[2, 3], [4, 5]]);
+            it('should return scalar results for a matrix', function () {
+                expect(INDEX(m1, 1)).to.equal(2);
+                expect(INDEX(m1, 1, 1)).to.equal(2);
+                expect(INDEX(m1, 1, 2)).to.equal(3);
+                expect(INDEX(m1, 2)).to.equal(4);
+                expect(INDEX(m1, 2, 1)).to.equal(4);
+                expect(INDEX(m1, 2, 2)).to.equal(5);
+                expect(INDEX(m1, 2, 2, 1)).to.equal(5);
+            });
+            it('should return vector results for a matrix', function () {
+                expect(INDEX(m1, 1, 0)).to.deep.equal(mat([[2, 3]]));
+                expect(INDEX(m1, 2, 0)).to.deep.equal(mat([[4, 5]]));
+                expect(INDEX(m1, 0)).to.deep.equal(mat([[2], [4]]));
+                expect(INDEX(m1, 0, 1)).to.deep.equal(mat([[2], [4]]));
+                expect(INDEX(m1, 0, 2)).to.deep.equal(mat([[3], [5]]));
+                expect(INDEX(m1, 0, 2, 1)).to.deep.equal(mat([[3], [5]]));
+            });
+            it('should return the entire matrix', function () {
+                expect(INDEX(m1, 0, 0)).to.deep.equal(m1);
+                expect(INDEX(m1, 0, 0, 1)).to.deep.equal(m1);
+            });
+            it('should return REF error for a matrix', function () {
+                expect(INDEX(m1, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(m1, 3)).to.equal(ErrorCode.REF);
+                expect(INDEX(m1, 1, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(m1, 1, 3)).to.equal(ErrorCode.REF);
+                expect(INDEX(m1, 1, 1, 0)).to.equal(ErrorCode.REF);
+                expect(INDEX(m1, 1, 1, 2)).to.equal(ErrorCode.REF);
+            });
+
+            var r1 = r3d('1:1!B3:C4');
+            var ra1 = r3da('1:1!B3:C4 2:2!C4:E6');
+            it('should return single cell address for a reference', function () {
+                expect(INDEX(r1, 1)).to.stringifyTo('1:1!B3:B3');
+                expect(INDEX(r1, 1, 1)).to.stringifyTo('1:1!B3:B3');
+                expect(INDEX(r1, 1, 2)).to.stringifyTo('1:1!C3:C3');
+                expect(INDEX(r1, 2)).to.stringifyTo('1:1!B4:B4');
+                expect(INDEX(r1, 2, 1)).to.stringifyTo('1:1!B4:B4');
+                expect(INDEX(r1, 2, 2)).to.stringifyTo('1:1!C4:C4');
+                expect(INDEX(r1, 2, 2, 1)).to.stringifyTo('1:1!C4:C4');
+                expect(INDEX(ra1, 2, 2)).to.stringifyTo('1:1!C4:C4');
+                expect(INDEX(ra1, 2, 2, 1)).to.stringifyTo('1:1!C4:C4');
+                expect(INDEX(ra1, 2, 2, 2)).to.stringifyTo('2:2!D5:D5');
+                expect(INDEX(ra1, 3, 3, 2)).to.stringifyTo('2:2!E6:E6');
+            });
+            it('should return vector results for a reference', function () {
+                expect(INDEX(r1, 1, 0)).to.stringifyTo('1:1!B3:C3');
+                expect(INDEX(r1, 2, 0)).to.stringifyTo('1:1!B4:C4');
+                expect(INDEX(r1, 0, 1)).to.stringifyTo('1:1!B3:B4');
+                expect(INDEX(r1, 0, 2)).to.stringifyTo('1:1!C3:C4');
+                expect(INDEX(r1, 0, 2, 1)).to.stringifyTo('1:1!C3:C4');
+                expect(INDEX(ra1, 0, 2)).to.stringifyTo('1:1!C3:C4');
+                expect(INDEX(ra1, 0, 2, 1)).to.stringifyTo('1:1!C3:C4');
+                expect(INDEX(ra1, 2, 0, 2)).to.stringifyTo('2:2!C5:E5');
+                expect(INDEX(ra1, 0, 2, 2)).to.stringifyTo('2:2!D4:D6');
+                expect(INDEX(ra1, 3, 0, 2)).to.stringifyTo('2:2!C6:E6');
+                expect(INDEX(ra1, 0, 3, 2)).to.stringifyTo('2:2!E4:E6');
+            });
+            it('should return the entire reference', function () {
+                expect(INDEX(r1, 0, 0)).to.stringifyTo('1:1!B3:C4');
+                expect(INDEX(r1, 0, 0, 1)).to.stringifyTo('1:1!B3:C4');
+                expect(INDEX(ra1, 0, 0)).to.stringifyTo('1:1!B3:C4');
+                expect(INDEX(ra1, 0, 0, 1)).to.stringifyTo('1:1!B3:C4');
+                expect(INDEX(ra1, 0, 0, 2)).to.stringifyTo('2:2!C4:E6');
+            });
+            it('should return REF error for a reference', function () {
+                expect(INDEX(r1, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(r1, 3)).to.equal(ErrorCode.REF);
+                expect(INDEX(r1, 1, -1)).to.equal(ErrorCode.REF);
+                expect(INDEX(r1, 1, 3)).to.equal(ErrorCode.REF);
+                expect(INDEX(r1, 1, 1, 0)).to.equal(ErrorCode.REF);
+                expect(INDEX(r1, 1, 1, 2)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 3, 1)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 1, 3)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 3, 1, 1)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 1, 3, 1)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 4, 1, 2)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 1, 4, 2)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 1, 1, 0)).to.equal(ErrorCode.REF);
+                expect(INDEX(ra1, 1, 1, 3)).to.equal(ErrorCode.REF);
             });
         });
 
@@ -316,85 +392,143 @@ define([
             });
         });
 
-        moduleTester.testFunction('MATCH', { toOperand: [1] }, function (MATCH) {
-            var count = mat([[25, 38, 40, 41]]);
-            var countRevers = mat([[41, 40, 38, 25]]);
+        moduleTester.testFunction('MATCH', { toOperand: 1 }, function (MATCH) {
 
-            it('should return the result of the match', function () {
-                expect(MATCH(39, count, 1)).to.equal(2);
-                expect(MATCH(41, count, 0)).to.equal(4);
-                expect(MATCH(41, count, 1)).to.equal(4);
+            it('should reject 2D ranges', function () {
+                expect(MATCH(1, r3d('4:4!K1:L2'), 1)).to.equal(ErrorCode.NA);
+                expect(MATCH(1, r3d('4:4!K1:L2'), 0)).to.equal(ErrorCode.NA);
+                expect(MATCH(1, r3d('4:4!K1:L2'), -1)).to.equal(ErrorCode.NA);
             });
-            it('should throw for invalid parameters (1)', function () {
-                expect(MATCH(39, count, 0)).to.equal(ErrorCode.NA);
+            it('should fail for blank ranges', function () {
+                expect(MATCH(1, r3d('4:4!A1:B1'), 1)).to.equal(ErrorCode.NA);
+                expect(MATCH(1, r3d('4:4!A1:B1'), 0)).to.equal(ErrorCode.NA);
+                expect(MATCH(1, r3d('4:4!A1:B1'), -1)).to.equal(ErrorCode.NA);
             });
 
-            /*
-            it('should throw for invalid parameters (2)', function () {
-                expect(MATCH(39, count, -1)).to.equal(ErrorCode.NA);
+            // search mode 0 (exact match)
+            it('should find exact values', function () {
+                expect(MATCH(0, mat([[false, true, '0', '1', '', 0, 1]]), 0)).to.equal(6);
+                expect(MATCH(1, mat([[false, true, '0', '1', '', 0, 1]]), 0)).to.equal(7);
+                expect(MATCH(2, mat([[false, true, '0', '1', '', 0, 1]]), 0)).to.equal(ErrorCode.NA);
+                expect(MATCH(null, mat([[false, true, '0', '1', '', 0, 1]]), 0)).to.equal(6);
+                expect(MATCH(false, mat([[0, 1, 'false', 'true', '', false, true]]), 0)).to.equal(6);
+                expect(MATCH(true, mat([[0, 1, 'false', 'true', '', false, true]]), 0)).to.equal(7);
+                expect(MATCH('0', mat([[0, 1, false, true, '', '0', '1']]), 0)).to.equal(6);
+                expect(MATCH('1', mat([[0, 1, false, true, '', '0', '1']]), 0)).to.equal(7);
+                expect(MATCH('2', mat([[0, 1, false, true, '', '0', '1']]), 0)).to.equal(ErrorCode.NA);
+                expect(MATCH('', mat([[0, 1, false, true, '', '0', '1']]), 0)).to.equal(5);
+            });
+            it('should ignore error codes', function () {
+                expect(MATCH(1, mat([[ErrorCode.NULL, 1]]), 0)).to.equal(2);
+            });
+            it('should find strings ignoring case', function () {
+                expect(MATCH('B', mat([['a', 'b', 'B', 'c']]), 0)).to.equal(2);
+            });
+            it('should use search patterns', function () {
+                var data = mat([['cba', 'bac', 'abc', 'acb', 10, '10']]);
+                expect(MATCH('a*', data, 0)).to.equal(3);
+                expect(MATCH('B*', data, 0)).to.equal(2);
+                expect(MATCH('c*', data, 0)).to.equal(1);
+                expect(MATCH('?c?', data, 0)).to.equal(4);
+                expect(MATCH('?c', data, 0)).to.equal(ErrorCode.NA);
+                expect(MATCH('1*', data, 0)).to.equal(6);
+            });
+            it('should match first entry', function () {
+                expect(MATCH(2, mat([[1, 2, 2, 2, 3]]), 0)).to.equal(2);
             });
 
-            it('should throw for invalid parameters (3)', function () {
-                expect(MATCH(41, count, -1)).to.equal(ErrorCode.NA);
+            // search mode 1 (binary search in ascending data)
+            it('should find entry in ascending data', function () {
+                var data = mat([[2, 4, 6, 'bb', 'DD', true]]);
+                expect(MATCH(1, data, 1)).to.equal(ErrorCode.NA);
+                expect(MATCH(2, data, 1)).to.equal(1);
+                expect(MATCH(3, data, 1)).to.equal(1);
+                expect(MATCH(4, data, 1)).to.equal(2);
+                expect(MATCH(5, data, 1)).to.equal(2);
+                expect(MATCH(6, data, 1)).to.equal(3);
+                expect(MATCH(7, data, 1)).to.equal(3);
+                expect(MATCH(1e100, data, 1)).to.equal(3);
+                expect(MATCH('a', data, 1)).to.equal(3);
+                expect(MATCH('b', data, 1)).to.equal(3);
+                expect(MATCH('B', data, 1)).to.equal(3);
+                expect(MATCH('ba', data, 1)).to.equal(3);
+                expect(MATCH('bb', data, 1)).to.equal(4);
+                expect(MATCH('BB', data, 1)).to.equal(4);
+                expect(MATCH('c', data, 1)).to.equal(4);
+                expect(MATCH('c', data, 1)).to.equal(4);
+                expect(MATCH('d', data, 1)).to.equal(4);
+                expect(MATCH('dc', data, 1)).to.equal(4);
+                expect(MATCH('dd', data, 1)).to.equal(5);
+                expect(MATCH('DD', data, 1)).to.equal(5);
+                expect(MATCH('zz', data, 1)).to.equal(5);
+                expect(MATCH(false, data, 1)).to.equal(5);
+                expect(MATCH(true, data, 1)).to.equal(6);
+                expect(MATCH(8, r3d('4:4!K1:T1'), 1)).to.equal(10);
+                expect(MATCH(8, r3d('4:4!A1:AD1'), 1)).to.equal(20);
             });
-            */
-
-            it('should return the result of the match with reverse order (1)', function () {
-                expect(MATCH(39, countRevers, -1)).to.equal(2);
+            it('should accept any positive number', function () {
+                expect(MATCH(5, mat([[2, 4, 6]]), 1e100)).to.equal(2);
+                expect(MATCH(5, mat([[2, 4, 6]]), 1e-99)).to.equal(2);
+            });
+            it('should default to ascending search', function () {
+                expect(MATCH(5, mat([[2, 4, 6]]))).to.equal(2);
+            });
+            it('should match last entry', function () {
+                expect(MATCH(2, mat([[1, 2, 2, 2, 3]]), 1)).to.equal(4);
+            });
+            it('should use binary search algorithm', function () {
+                expect(MATCH(8, mat([[1, 99, 3, 4, 5, 6, 7]]), 1)).to.equal(7);
+                expect(MATCH(8, mat([[1, 2, 3, 99, 5, 6, 7]]), 1)).to.equal(3);
+                expect(MATCH(8, mat([[1, 2, 3, 4, 5, 99, 7]]), 1)).to.equal(5);
+                expect(MATCH(8, mat([[1, 99, 3, 99, 5, 6, 7]]), 1)).to.equal(1);
+                expect(MATCH(8, r3d('4:4!K3:T3'), 1)).to.equal(10);
+                expect(MATCH(8, r3d('4:4!K4:T4'), 1)).to.equal(3);
             });
 
-            it('should return the result of the match with reverse order (2)', function () {
-                expect(MATCH(41, countRevers, 0)).to.equal(1);
+            // search mode -1 (binary search in descending data)
+            it('should find entry in descending data', function () {
+                var data = mat([[false, 'DD', 'bb', 6, 4, 2]]);
+                expect(MATCH(1, data, -1)).to.equal(6);
+                expect(MATCH(2, data, -1)).to.equal(6);
+                expect(MATCH(3, data, -1)).to.equal(5);
+                expect(MATCH(4, data, -1)).to.equal(5);
+                expect(MATCH(5, data, -1)).to.equal(4);
+                expect(MATCH(6, data, -1)).to.equal(4);
+                expect(MATCH(7, data, -1)).to.equal(3);
+                expect(MATCH(1e100, data, -1)).to.equal(3);
+                expect(MATCH('a', data, -1)).to.equal(3);
+                expect(MATCH('b', data, -1)).to.equal(3);
+                expect(MATCH('B', data, -1)).to.equal(3);
+                expect(MATCH('ba', data, -1)).to.equal(3);
+                expect(MATCH('bb', data, -1)).to.equal(3);
+                expect(MATCH('BB', data, -1)).to.equal(3);
+                expect(MATCH('c', data, -1)).to.equal(2);
+                expect(MATCH('c', data, -1)).to.equal(2);
+                expect(MATCH('d', data, -1)).to.equal(2);
+                expect(MATCH('dc', data, -1)).to.equal(2);
+                expect(MATCH('dd', data, -1)).to.equal(2);
+                expect(MATCH('DD', data, -1)).to.equal(2);
+                expect(MATCH('zz', data, -1)).to.equal(1);
+                expect(MATCH(false, data, -1)).to.equal(1);
+                expect(MATCH(true, data, -1)).to.equal(ErrorCode.NA);
+                expect(MATCH(0, r3d('4:4!K2:T2'), -1)).to.equal(10);
+                expect(MATCH(0, r3d('4:4!A2:AD2'), -1)).to.equal(20);
             });
-
-            it('should return the result of the match with reverse order (3)', function () {
-                expect(MATCH(41, countRevers, -1)).to.equal(1);
+            it('should accept any positive number', function () {
+                expect(MATCH(5, mat([[2, 4, 6]]), 1e100)).to.equal(2);
+                expect(MATCH(5, mat([[2, 4, 6]]), 1e-99)).to.equal(2);
             });
-
-            it('should return the result of the last entry without match (1)', function () {
-                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]))).to.equal(4);
-
-                expect(MATCH('z', r3d('4:4!A1:A4'))).to.equal(4);
-                expect(MATCH('z', r3d('4:4!A1:A50'))).to.equal(4);
-                expect(MATCH('z', r3d('4:4!A1:A50'), 1)).to.equal(4);
-
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', r3d('4:4!A1:A50'), 1)).to.equal(4);
+            it('should match last entry', function () {
+                expect(MATCH(2, mat([[3, 2, 2, 2, 1]]), -1)).to.equal(4);
             });
-
-            it('should return the result of the last entry without match (2)', function () {
-                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), 0)).to.equal(ErrorCode.NA);
+            it('should use binary search algorithm', function () {
+                expect(MATCH(0, mat([[7, -99, 5, 4, 3, 2, 1]]), -1)).to.equal(7);
+                expect(MATCH(0, mat([[7, 6, 5, -99, 3, 2, 1]]), -1)).to.equal(3);
+                expect(MATCH(0, mat([[7, 6, 5, 4, 3, -99, 1]]), -1)).to.equal(5);
+                expect(MATCH(0, mat([[7, -99, 5, -99, 3, 2, 1]]), -1)).to.equal(1);
+                expect(MATCH(0, r3d('4:4!K5:T5'), -1)).to.equal(10);
+                expect(MATCH(0, r3d('4:4!K6:T6'), -1)).to.equal(3);
             });
-
-            it('should return the result of the last entry without match (3)', function () {
-                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), 1)).to.equal(4);
-            });
-
-            it('should return the result of the last entry without match (4)', function () {
-                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), -1)).to.equal(ErrorCode.NA);
-            });
-
-            it('match without solid order (1)', function () {
-                expect(MATCH('Bagels', mat([['[  BREAKFAST ]', 'haha', 'Bagels', 'Breakfast Burrito', 'Cold cereal']]))).to.equal(3);
-            });
-
-            /*
-            it('match without solid order (2)', function () {
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
-            });
-
-            it('match without solid order (3)', function () {
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
-            });
-            */
-
-            it('match with alphabetic order (1)', function () {
-                expect(MATCH('Pants', mat([[0, 'Sweater', 'Jacket', 'Pants']]))).to.equal(4);
-            });
-
-            it('match with alphabetic order (2)', function () {
-                expect(MATCH('Med', mat([[0, 'Small', 'Med', 'Large']]))).to.equal(3);
-            });
-
         });
 
         moduleTester.testFunction('ROW', { targetAddress: 'E6' }, function (ROW) {
