@@ -236,26 +236,51 @@ define([
             });
         });
 
-        describe('method "getRow"', function () {
+        describe('method "getRowAsArray"', function () {
             it('should exist', function () {
-                expect(Matrix).to.respondTo('getRow');
+                expect(Matrix).to.respondTo('getRowAsArray');
             });
             var m2 = new Matrix(a2);
             it('should return row vector', function () {
-                expect(m2.getRow(0)).to.deep.equal([1, 2]);
-                expect(m2.getRow(1)).to.deep.equal(['a', 'b']);
-                expect(m2.getRow(2)).to.deep.equal([false, true]);
+                expect(m2.getRowAsArray(0)).to.deep.equal([1, 2]);
+                expect(m2.getRowAsArray(1)).to.deep.equal(['a', 'b']);
+                expect(m2.getRowAsArray(2)).to.deep.equal([false, true]);
             });
         });
 
-        describe('method "getCol"', function () {
+        describe('method "getRowVector"', function () {
             it('should exist', function () {
-                expect(Matrix).to.respondTo('getCol');
+                expect(Matrix).to.respondTo('getRowVector');
+            });
+            var m2 = new Matrix(a2);
+            it('should return row vector', function () {
+                expect(m2.getRowVector(0)).to.be.an.instanceof(Matrix);
+                expect(m2.getRowVector(0).values()).to.deep.equal([[1, 2]]);
+                expect(m2.getRowVector(1).values()).to.deep.equal([['a', 'b']]);
+                expect(m2.getRowVector(2).values()).to.deep.equal([[false, true]]);
+            });
+        });
+
+        describe('method "getColAsArray"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('getColAsArray');
             });
             var m2 = new Matrix(a2);
             it('should return column vector', function () {
-                expect(m2.getCol(0)).to.deep.equal([1, 'a', false]);
-                expect(m2.getCol(1)).to.deep.equal([2, 'b', true]);
+                expect(m2.getColAsArray(0)).to.deep.equal([1, 'a', false]);
+                expect(m2.getColAsArray(1)).to.deep.equal([2, 'b', true]);
+            });
+        });
+
+        describe('method "getColVector"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('getColVector');
+            });
+            var m2 = new Matrix(a2);
+            it('should return column vector', function () {
+                expect(m2.getColVector(0)).to.be.an.instanceof(Matrix);
+                expect(m2.getColVector(0).values()).to.deep.equal([[1], ['a'], [false]]);
+                expect(m2.getColVector(1).values()).to.deep.equal([[2], ['b'], [true]]);
             });
         });
 
