@@ -26,9 +26,8 @@ define([
     var a = SheetHelper.a;
     var r = SheetHelper.r;
     var ra = SheetHelper.ra;
-    var MoveMode = SheetUtils.MoveMode;
+    var Direction = SheetUtils.Direction;
     var MergeMode = SheetUtils.MergeMode;
-    var RangeArray = SheetUtils.RangeArray;
 
     // class HyperlinkCollection ==============================================
 
@@ -65,19 +64,13 @@ define([
         }
 
         function linkOp(range, url) {
-            var json = range.toJSON();
+            var json = r(range).toJSON();
             json.url = url;
             return op(json);
         }
 
         function getLinkRanges(collection) {
-            var linkModels = collection._getCloneData().linkModels;
-            var ranges = RangeArray.map(linkModels, function (linkModel) {
-                var range = linkModel.range.clone();
-                range.url = linkModel.url;
-                return range;
-            });
-            return ranges.sort();
+            return collection._getCloneData().linkRangeSet.values().sort();
         }
 
         // private methods ----------------------------------------------------
@@ -88,8 +81,7 @@ define([
             });
             it('should return the current link models', function () {
                 var cloneData = hyperlinkCollection._getCloneData();
-                expect(cloneData).to.have.a.property('linkModels');
-                expect(cloneData.linkModels.length).to.equal(0);
+                expect(cloneData).to.have.a.property('linkRangeSet');
             });
         });
 
@@ -101,7 +93,7 @@ define([
             });
             it('should execute an "insertHyperlink" operation', function () {
                 var collection = new HyperlinkCollection(sheetModel);
-                var context = linkOp(r('A1:C3'), 'http://www.example.org');
+                var context = linkOp('A1:C3', 'http://www.example.org');
                 collection.applyInsertHyperlinkOperation(context);
                 var ranges = getLinkRanges(collection);
                 expect(ranges).to.stringifyTo('A1:C3');
@@ -116,7 +108,7 @@ define([
             });
             it('should execute a "deleteHyperlink" operation', function () {
                 var collection = new HyperlinkCollection(sheetModel);
-                var context = linkOp(r('A1:C3'), 'http://www.example.org');
+                var context = linkOp('A1:C3', 'http://www.example.org');
                 expect(getLinkRanges(collection).length).to.equal(0);
                 collection.applyInsertHyperlinkOperation(context);
                 expect(getLinkRanges(collection).length).to.equal(1);
@@ -132,7 +124,7 @@ define([
             });
             it('should clone the existing hyperlinks from the given collection', function () {
                 var collection1 = new HyperlinkCollection(sheetModel);
-                var context = linkOp(r('A1:C3'), 'http://www.example.org');
+                var context = linkOp('A1:C3', 'http://www.example.org');
                 collection1.applyInsertHyperlinkOperation(context);
                 var sheetModel2 = docModel.getSheetModel(1);
                 var collection2 = new HyperlinkCollection(sheetModel2);
@@ -147,18 +139,18 @@ define([
 
         // public methods -----------------------------------------------------
 
-        describe('method "rangeOverlapsHyperlinks"', function () {
+        describe('method "coversAnyLinkRange"', function () {
             it('should exist', function () {
-                expect(hyperlinkCollection).to.respondTo('rangeOverlapsHyperlinks');
+                expect(hyperlinkCollection).to.respondTo('coversAnyLinkRange');
             });
             it('should return true, if the given range overlaps a hyperlink range', function () {
                 var collection = new HyperlinkCollection(sheetModel);
-                var context = linkOp(r('A1:C3'), 'http://www.example.org');
-                expect(collection.rangeOverlapsHyperlinks(r('B2:F9'))).to.equal(false);
+                var context = linkOp('A1:C3', 'http://www.example.org');
+                expect(collection.coversAnyLinkRange(r('B2:F9'))).to.equal(false);
                 collection.applyInsertHyperlinkOperation(context);
-                expect(collection.rangeOverlapsHyperlinks(r('B2:F9'))).to.equal(true);
+                expect(collection.coversAnyLinkRange(r('B2:F9'))).to.equal(true);
                 collection.applyDeleteHyperlinkOperation(context);
-                expect(collection.rangeOverlapsHyperlinks(r('B2:F9'))).to.equal(false);
+                expect(collection.coversAnyLinkRange(r('B2:F9'))).to.equal(false);
                 collection.destroy();
             });
         });
@@ -170,7 +162,7 @@ define([
             it('should return the correct url on the basis of an address', function () {
                 var collection = new HyperlinkCollection(sheetModel);
                 expect(collection.getCellURL(a('B3'))).to.equal(null);
-                var context = linkOp(r('A1:C3'), 'http://www.example.org');
+                var context = linkOp('A1:C3', 'http://www.example.org');
                 collection.applyInsertHyperlinkOperation(context);
                 expect(collection.getCellURL(a('B3'))).to.equal('http://www.example.org');
                 expect(collection.getCellURL(a('Z99'))).to.equal(null);
@@ -207,7 +199,10 @@ define([
                         expect(ranges2[4].url).to.equal('http://www.example.org');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
-                        expect(getLinkRanges(hyperlinkCollection).length).to.equal(2);
+                        var ranges3 = getLinkRanges(hyperlinkCollection);
+                        expect(ranges3).to.stringifyTo('A1:C3,E1:G4');
+                        expect(ranges3[0].url).to.equal('http://www.example.org');
+                        expect(ranges3[1].url).to.equal('http://www.example.org');
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
                     });
@@ -226,7 +221,7 @@ define([
                 return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
-                    var promise2 = hyperlinkCollection.generateAutoFillOperations(generator2, r('A1:B4'), r('A5:B10'), true, false);
+                    var promise2 = hyperlinkCollection.generateAutoFillOperations(generator2, r('A1:B4'), Direction.DOWN, 6);
                     return promise2.then(function () {
 
                         var ranges = getLinkRanges(hyperlinkCollection);
@@ -254,7 +249,7 @@ define([
                 return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
-                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.RIGHT);
+                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), Direction.RIGHT);
                     return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:C2,A5:A6,D5:E6');
 
@@ -273,7 +268,7 @@ define([
                 return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
-                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.LEFT);
+                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), Direction.LEFT);
                     return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:A2,C5:D6');
 
