@@ -46,12 +46,12 @@ define([
 
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a1', attrs: { character: { fontName: 'Arial', fontSize: 13, bold: true, italic: false, underline: false, strike: 'none', color: { type: 'scheme', value: 'dark1' } }, apply: applyAttrs1, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' }, borderLeft: noBorder, borderRight: noBorder, borderTop: noBorder, borderBottom: noBorder, borderDown: noBorder, borderUp: noBorder, unlocked: false, hidden: false }, styleId: 'Standard' } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a2', attrs: { character: { fontName: 'Arial', fontSize: 13, bold: true, italic: false, underline: false, strike: 'none', color: { type: 'scheme', value: 'dark1' } }, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' }, borderLeft: noBorder, borderRight: noBorder, borderTop: noBorder, borderBottom: noBorder, borderDown: noBorder, borderUp: noBorder, unlocked: false, hidden: false }, styleId: 'Standard' } },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a1', attrs: { character: { fontName: 'Arial', fontSize: 13, bold: true, italic: false, underline: false, strike: 'none', color: { type: 'scheme', value: 'dark1' } }, apply: applyAttrs1, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' }, borderLeft: noBorder, borderRight: noBorder, borderTop: noBorder, borderBottom: noBorder, borderDown: noBorder, borderUp: noBorder, unlocked: false, hidden: false }, styleId: 'Standard' } },
+            { name: 'insertAutoStyle', styleId: 'a2', attrs: { character: { fontName: 'Arial', fontSize: 13, bold: true, italic: false, underline: false, strike: 'none', color: { type: 'scheme', value: 'dark1' } }, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' }, borderLeft: noBorder, borderRight: noBorder, borderTop: noBorder, borderBottom: noBorder, borderDown: noBorder, borderUp: noBorder, unlocked: false, hidden: false }, styleId: 'Standard' } },
             // border auto-styles
             // A3 - autostyle: border top/left corner
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a3', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a3', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     singleBorder,
                 borderRight:    noBorder,
                 borderTop:      singleBorder,
@@ -60,7 +60,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A4 - autostyle: border top/right corner
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a4', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a4', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    singleBorder,
                 borderTop:      singleBorder,
@@ -69,7 +69,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A5 - autostyle: border bottom/left corner
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a5', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, formatCode: 'General', fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a5', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, formatCode: 'General', fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     singleBorder,
                 borderRight:    noBorder,
                 borderTop:      noBorder,
@@ -78,7 +78,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A6 - autostyle: border bottom/right corner
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a6', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a6', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    singleBorder,
                 borderTop:      noBorder,
@@ -87,7 +87,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A7 - autostyle: border top
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a7', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a7', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    noBorder,
                 borderTop:      singleBorder,
@@ -96,7 +96,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A8 - autostyle: border right
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a8', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a8', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    singleBorder,
                 borderTop:      noBorder,
@@ -105,7 +105,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A9 - autostyle: border bottom
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a9', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a9', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    noBorder,
                 borderTop:      noBorder,
@@ -114,7 +114,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A10 - autostyle: border left
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a10', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a10', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     singleBorder,
                 borderRight:    noBorder,
                 borderTop:      noBorder,
@@ -123,7 +123,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A11 - no border
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a11', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a11', attrs: { character: charAttrs, apply: applyAttrs2, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    noBorder,
                 borderTop:      noBorder,
@@ -132,7 +132,7 @@ define([
                 borderUp:       noBorder,
                 unlocked: false, hidden: false }, styleId: 'Standard' } },
             // A12 - autostyle: special border top
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a12', attrs: { character: charAttrs, apply: { font: true, fill: true, border: true, align: false, number: false, protect: false }, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
+            { name: 'insertAutoStyle', styleId: 'a12', attrs: { character: charAttrs, apply: { font: true, fill: true, border: true, align: false, number: false, protect: false }, cell: { alignHor: 'auto', alignVert: 'bottom', wrapText: false, formatId: 0, fillColor: { type: 'rgb', value: '00B050' },
                 borderLeft:     noBorder,
                 borderRight:    noBorder,
                 borderTop:      doubleBorder,
@@ -244,13 +244,12 @@ define([
                 expect(getMergeCollection(0)).to.respondTo('generateMergeCellsOperations');
             });
 
-            it('should merge cell ranges and move first value cells', function (done) {
+            it('should merge cell ranges and move first value cells', function () {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.MERGE);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectMergedRanges(0, 'A5:C7,E5:G7');
                     expectValueMatrix(0, 'A5', [[1, null, null], [null, null, null], [null, null, null]]);
                     expectStyleMatrix(0, 'A5', [['a1', 'a1', 'a1'], ['a1', 'a1', 'a1'], ['a1', 'a1', 'a1']]);
@@ -262,17 +261,15 @@ define([
                     expectStyleMatrix(0, 'A5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
                     expectValueMatrix(0, 'E5', [[null, null, 'a'], [null, 5, 'b'], [3, 6, 'c']]);
                     expectStyleMatrix(0, 'E5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
-                    done();
                 });
             });
 
-            it('should merge cell ranges horizontally and move first value cells', function (done) {
+            it('should merge cell ranges horizontally and move first value cells', function () {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.HORIZONTAL);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectMergedRanges(0, 'A5:C5,E5:G5,A6:C6,E6:G6,A7:C7,E7:G7');
                     expectValueMatrix(0, 'A5', [[1, null, null], [2, null, null], [3, null, null]]);
                     expectStyleMatrix(0, 'A5', [['a1', 'a1', 'a1'], ['', '', ''], ['', '', '']]);
@@ -284,17 +281,15 @@ define([
                     expectStyleMatrix(0, 'A5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
                     expectValueMatrix(0, 'E5', [[null, null, 'a'], [null, 5, 'b'], [3, 6, 'c']]);
                     expectStyleMatrix(0, 'E5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
-                    done();
                 });
             });
 
-            it('should merge cell ranges vertically and move first value cells', function (done) {
+            it('should merge cell ranges vertically and move first value cells', function () {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.VERTICAL);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectMergedRanges(0, 'A5:A7,B5:B7,C5:C7,E5:E7,F5:F7,G5:G7');
                     expectValueMatrix(0, 'A5', [[1, 4, 'a'], [null, null, null], [null, null, null]]);
                     expectStyleMatrix(0, 'A5', [['a1', '', ''], ['a1', '', ''], ['a1', '', '']]);
@@ -306,43 +301,38 @@ define([
                     expectStyleMatrix(0, 'A5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
                     expectValueMatrix(0, 'E5', [[null, null, 'a'], [null, 5, 'b'], [3, 6, 'c']]);
                     expectStyleMatrix(0, 'E5', [['a1', '', ''], ['', 'a2', ''], ['', '', 'a1']]);
-                    done();
                 });
             });
 
-            it('should unmerge cell ranges', function (done) {
+            it('should unmerge cell ranges', function () {
                 var sheetModel = docModel.getSheetModel(1);
                 var mergeCollection = sheetModel.getMergeCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), MergeMode.UNMERGE);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectMergedRanges(1, 'A5:C7');
                     expectStyleMatrix(1, 'E5', [['a1', 'a1', 'a1'], ['a1', 'a1', 'a1'], ['a1', 'a1', 'a1']]);
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectMergedRanges(1, 'A5:C7,E5:G7');
                     expectStyleMatrix(1, 'E5', [['a1', 'a1', 'a1'], ['a1', 'a1', 'a1'], ['a1', 'a1', 'a1']]);
-                    done();
                 });
             });
 
-            it('should unmerge cell ranges implicitly when merging', function (done) {
+            it('should unmerge cell ranges implicitly when merging', function () {
                 var sheetModel = docModel.getSheetModel(1);
                 var mergeCollection = sheetModel.getMergeCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), MergeMode.MERGE);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectMergedRanges(1, 'A5:C7,D6:F6');
                     expectStyleMatrix(1, 'E5', [['a1', 'a1', 'a1'], ['', '', 'a1'], ['a1', 'a1', 'a1']]);
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectMergedRanges(1, 'A5:C7,E5:G7');
                     expectStyleMatrix(1, 'E5', [['a1', 'a1', 'a1'], ['a1', 'a1', 'a1'], ['a1', 'a1', 'a1']]);
-                    done();
                 });
             });
 
-            it('should merge with framed border', function (done) {
+            it('should merge with framed border', function () {
                 var sheet           = 2,
                     sheetModel      = docModel.getSheetModel(sheet),
                     cellCollection  = sheetModel.getCellCollection(),
@@ -376,9 +366,7 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         // console.log('after: ', obj.adr.toString());
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.after.v);
@@ -397,12 +385,10 @@ define([
 
                     mergedRanges = mergeCollection.getMergedRanges(checkRange);
                     expect(mergedRanges.length).to.equal(0);
-
-                    done();
                 });
             });
 
-            it('should merge with framed border except the top one', function (done) {
+            it('should merge with framed border except the top one', function () {
                 var sheet           = 3,
                     sheetModel      = docModel.getSheetModel(sheet),
                     cellCollection  = sheetModel.getCellCollection(),
@@ -436,9 +422,7 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         // console.log('after: ', obj.adr.toString());
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.after.v);
@@ -457,12 +441,10 @@ define([
 
                     mergedRanges = mergeCollection.getMergedRanges(checkRange);
                     expect(mergedRanges.length).to.equal(0);
-
-                    done();
                 });
             });
 
-            it('should merge with framed border and reset the middle cells', function (done) {
+            it('should merge with framed border and reset the middle cells', function () {
                 var sheet           = 4,
                     sheetModel      = docModel.getSheetModel(sheet),
                     cellCollection  = sheetModel.getCellCollection(),
@@ -504,9 +486,7 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         // console.log('after: ', obj.adr.toString());
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.after.v);
@@ -525,8 +505,6 @@ define([
 
                     mergedRanges = mergeCollection.getMergedRanges(checkRange);
                     expect(mergedRanges.length).to.equal(0);
-
-                    done();
                 });
             });
         });
