@@ -84,18 +84,18 @@ define([
             { name: 'insertName', sheet: 1, label: 'TestRangeSheet2', formula: 'Sheet2!$C$5:$C$6' },
             // Chart Drawing
             { name: 'insertDrawing', start: [1, 0], type: 'chart', attrs: { drawing: { startCol: 8, startColOffset: 132, startRow: 0, startRowOffset: 0, endCol: 8, endColOffset: 4101, endRow: 4, endRowOffset: 370, anchorType: 'twoCell' }, chart: { chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 0], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 0], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
-            { name: 'setChartAxisAttributes', start: [1, 0], axis: 'x', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
-            { name: 'setChartAxisAttributes', start: [1, 0], axis: 'y', attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
-            { name: 'setChartGridlineAttributes', start: [1, 0], axis: 'y', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
+            { name: 'insertChartDataSeries', start: [1, 0], series: 0, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 0], series: 1, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
+            { name: 'setChartAxisAttributes', start: [1, 0], axis: 0, axPos: 'b', crossAx: 1, attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartAxisAttributes', start: [1, 0], axis: 1, axPos: 'l', crossAx: 0, attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartGridlineAttributes', start: [1, 0], axis: 1, attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
             { name: 'setChartLegendAttributes', start: [1, 0], attrs: { legend: { pos: 'off' } } },
             { name: 'insertDrawing', start: [1, 1], type: 'chart', attrs: { drawing: { startCol: 9, startColOffset: 1667, startRow: 0, startRowOffset: 0, endCol: 11, endColOffset: 79, endRow: 4, endRowOffset: 344, anchorType: 'twoCell' }, chart: { chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 1], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 1], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
-            { name: 'setChartAxisAttributes', start: [1, 1], axis: 'x', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
-            { name: 'setChartAxisAttributes', start: [1, 1], axis: 'y', attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
-            { name: 'setChartGridlineAttributes', start: [1, 1], axis: 'y', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
+            { name: 'insertChartDataSeries', start: [1, 1], series: 0, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 1], series: 1, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
+            { name: 'setChartAxisAttributes', start: [1, 1], axis: 0, axPos: 'b', crossAx: 1, attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartAxisAttributes', start: [1, 1], axis: 1, axPos: 'l', crossAx: 0, attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartGridlineAttributes', start: [1, 1], axis: 1, attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
             { name: 'setChartLegendAttributes', start: [1, 1], attrs: { legend: { pos: 'off' } } },
             // Data validation
             { name: 'insertValidation', sheet: 1, index: 0, ranges: [{ start: [4, 5] }], type: 'source', value1: '$E$3:$E$4' },
@@ -256,14 +256,17 @@ define([
             it('should exist', function () {
                 expect(docModel).to.respondTo('generateDeleteSheetOperations');
             });
-            it('should generate correct cell operations', function (done) {
+
+            it('should generate correct cell operations', function () {
+
                 var sheetModel = docModel.getSheetModel(1);
                 var cellCollection = sheetModel.getCellCollection();
-                // Cell formula
+
+                // cell formula
                 expect(cellCollection.getFormula(a('A1'), 'op')).to.equal('Sheet1!$A$1');
                 expect(cellCollection.getFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
 
-                // Named range
+                // named range
                 var nameCollection = docModel.getNameCollection();
                 expect(cellCollection.getFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
                 expect(nameCollection.getName('ObstGlobal').getFormula('op', a('C1'))).to.equal('Sheet1!$A$5:$A$7');
@@ -273,12 +276,12 @@ define([
                 expect(cellCollection.getFormula(a('C3'), 'op')).to.equal('COUNT(Sheet1!ObstPreis)');
                 expect(nameCollection.getName('ObstPreis').getFormula('op', a('C1'))).to.equal('Sheet1!$B$5:$B$7');
 
-                // Named range on sheet2
+                // named range on sheet2
                 nameCollection = docModel.getSheetModel(1).getNameCollection();
                 expect(cellCollection.getFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
                 expect(nameCollection.getName('TestRangeSheet2').getFormula('op', a('C1'))).to.equal('Sheet2!$C$5:$C$6');
 
-                // Chart Drawing
+                // chart Drawing
                 var drawingCollection = sheetModel.getDrawingCollection();
                 var chartModel = drawingCollection.getModel([0], { type: 'chart' });
                 testChartModel(chartModel, { title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, { title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' });
@@ -286,24 +289,22 @@ define([
                 chartModel = drawingCollection.getModel([1], { type: 'chart' });
                 testChartModel(chartModel, { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' });
 
-                // Data validation
+                // data validation
                 var validationCollection = sheetModel.getValidationCollection();
                 expect(validationCollection.getValidationSettings(a('E1')).attributes.value1).to.equal('Sheet1!$A$5:$A$7');
                 expect(validationCollection.getValidationSettings(a('E6')).attributes.value1).to.equal('$E$3:$E$4');
 
-                //Delete Sheet1
+                // delete Sheet1
                 var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
                 var promise = docModel.generateDeleteSheetOperations(generator, 0);
-                expect(promise).to.respondTo('promise');
 
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
 
-                    // Cell formula
+                    // cell formula
                     expect(cellCollection.getFormula(a('A1'), 'op')).to.equal('#REF!');
                     expect(cellCollection.getFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
 
-                    // Named range
+                    // named range
                     nameCollection = docModel.getNameCollection();
                     expect(cellCollection.getFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
                     expect(nameCollection.getName('ObstGlobal').getFormula('op', a('C1'))).to.equal('#REF!');
@@ -311,12 +312,12 @@ define([
 
                     expect(cellCollection.getFormula(a('C3'), 'op')).to.equal('COUNT([0]!ObstPreis)');
 
-                    // Named range on sheet2
+                    // named range on sheet2
                     nameCollection = docModel.getSheetModel(0).getNameCollection();
                     expect(cellCollection.getFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
                     expect(nameCollection.getName('TestRangeSheet2').getFormula('op', a('C1'))).to.equal('Sheet2!$C$5:$C$6');
 
-                    // Chart Drawing
+                    // chart Drawing
                     drawingCollection = sheetModel.getDrawingCollection();
                     chartModel = drawingCollection.getModel([0], { type: 'chart' });
                     testChartModel(chartModel, { title: '#REF!', names: '#REF!', values: '#REF!' }, { title: '#REF!', names: '#REF!', values: '#REF!' });
@@ -324,11 +325,10 @@ define([
                     chartModel = drawingCollection.getModel([1], { type: 'chart' });
                     testChartModel(chartModel, { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' });
 
-                    // Data validation
+                    // data validation
                     validationCollection = sheetModel.getValidationCollection();
                     expect(validationCollection.getValidationSettings(a('E1')).attributes.value1).to.equal('#REF!');
                     expect(validationCollection.getValidationSettings(a('E6')).attributes.value1).to.equal('$E$3:$E$4');
-                    done();
                 });
             });
         });
