@@ -155,34 +155,45 @@ define([
             });
         });
 
-        describe('method "findByIndex"', function () {
+        describe('method "findOneByIndex"', function () {
             it('should exist', function () {
-                expect(IntervalSet).to.respondTo('findByIndex');
+                expect(IntervalSet).to.respondTo('findOneByIndex');
             });
-            it('should return an empty array for an empty set', function () {
+            it('should return null for an empty set', function () {
                 var set = new IntervalSet();
-                expect(set.findByIndex(0)).to.deep.equal(ia());
-                expect(set.findByIndex(9)).to.deep.equal(ia());
+                expect(set.findOneByIndex(0)).to.equal(null);
+                expect(set.findOneByIndex(9)).to.equal(null);
             });
         });
 
-        describe('method "overlaps"', function () {
+        describe('method "findAllByIndex"', function () {
             it('should exist', function () {
-                expect(IntervalSet).to.respondTo('overlaps');
-            });
-            it('should return false for an empty set', function () {
-                var set = new IntervalSet();
-                expect(set.overlaps(i('1:10'))).to.equal(false);
-            });
-        });
-
-        describe('method "findIntervals"', function () {
-            it('should exist', function () {
-                expect(IntervalSet).to.respondTo('findIntervals');
+                expect(IntervalSet).to.respondTo('findAllByIndex');
             });
             it('should return an empty array for an empty set', function () {
                 var set = new IntervalSet();
-                expect(set.findIntervals(i('1:10'))).to.deep.equal(ia());
+                expect(set.findAllByIndex(0)).to.deep.equal(ia());
+                expect(set.findAllByIndex(9)).to.deep.equal(ia());
+            });
+        });
+
+        describe('method "findOne"', function () {
+            it('should exist', function () {
+                expect(IntervalSet).to.respondTo('findOne');
+            });
+            it('should return null for an empty set', function () {
+                var set = new IntervalSet();
+                expect(set.findOne(i('1:10'))).to.equal(null);
+            });
+        });
+
+        describe('method "findAll"', function () {
+            it('should exist', function () {
+                expect(IntervalSet).to.respondTo('findAll');
+            });
+            it('should return an empty array for an empty set', function () {
+                var set = new IntervalSet();
+                expect(set.findAll(i('1:10'))).to.deep.equal(ia());
             });
         });
 
@@ -253,11 +264,11 @@ define([
                 expect(set.containsIndex(3)).to.equal(false);
                 expect(set.containsIndex(9)).to.equal(false);
             });
-            it('should detect the intervals by overlap test', function () {
-                expect(set.overlaps(i('1:2'))).to.equal(true);
-                expect(set.overlaps(i('2:3'))).to.equal(true);
-                expect(set.overlaps(i('3:4'))).to.equal(true);
-                expect(set.overlaps(i('4:5'))).to.equal(false);
+            it('should find the interval', function () {
+                expect(set.findOne(i('1:2'))).to.not.equal(null);
+                expect(set.findOne(i('2:3'))).to.not.equal(null);
+                expect(set.findOne(i('3:4'))).to.not.equal(null);
+                expect(set.findOne(i('4:5'))).to.equal(null);
             });
             it('should insert and find another interval', function () {
                 set.insert(i('5:9'));
@@ -268,14 +279,14 @@ define([
                 expect(set.containsIndex(6)).to.equal(true);
                 expect(set.containsIndex(8)).to.equal(true);
                 expect(set.containsIndex(9)).to.equal(false);
-                expect(set.overlaps(i('1:2'))).to.equal(true);
-                expect(set.overlaps(i('2:3'))).to.equal(true);
-                expect(set.overlaps(i('3:4'))).to.equal(true);
-                expect(set.overlaps(i('4:5'))).to.equal(true);
-                expect(set.overlaps(i('5:6'))).to.equal(true);
-                expect(set.overlaps(i('9:10'))).to.equal(true);
-                expect(set.overlaps(i('10:10'))).to.equal(false);
-                expect(set.overlaps(i('1:10'))).to.equal(true);
+                expect(set.findOne(i('1:2'))).to.not.equal(null);
+                expect(set.findOne(i('2:3'))).to.not.equal(null);
+                expect(set.findOne(i('3:4'))).to.not.equal(null);
+                expect(set.findOne(i('4:5'))).to.not.equal(null);
+                expect(set.findOne(i('5:6'))).to.not.equal(null);
+                expect(set.findOne(i('9:10'))).to.not.equal(null);
+                expect(set.findOne(i('10:10'))).to.equal(null);
+                expect(set.findOne(i('1:10'))).to.not.equal(null);
                 expect(set.values().length).to.equal(2);
             });
             it('should insert and find multiple intervals', function () {
@@ -285,21 +296,24 @@ define([
                 set.insert(i('6:8'));
                 set.insert(i('6:10'));
                 set.insert(i('2:3'));
-                expect(set.findByIndex(0)).to.satisfy(unorderedMatcher('1:3 1:1'));
-                expect(set.findByIndex(1)).to.satisfy(unorderedMatcher('1:3 2:3'));
-                expect(set.findByIndex(2)).to.satisfy(unorderedMatcher('1:3 2:3'));
-                expect(set.findByIndex(3)).to.satisfy(unorderedMatcher(''));
-                expect(set.findByIndex(4)).to.satisfy(unorderedMatcher('5:9'));
-                expect(set.findByIndex(5)).to.satisfy(unorderedMatcher('5:9 6:8 6:10'));
-                expect(set.findByIndex(6)).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
-                expect(set.findByIndex(7)).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
-                expect(set.findByIndex(8)).to.satisfy(unorderedMatcher('5:9 7:9 6:10'));
-                expect(set.findByIndex(9)).to.satisfy(unorderedMatcher('6:10'));
-                expect(set.findIntervals(i('1:2'))).to.satisfy(unorderedMatcher('1:3 1:1 2:3'));
-                expect(set.findIntervals(i('2:3'))).to.satisfy(unorderedMatcher('1:3 2:3'));
-                expect(set.findIntervals(i('3:5'))).to.satisfy(unorderedMatcher('1:3 5:9 2:3'));
-                expect(set.findIntervals(i('4:6'))).to.satisfy(unorderedMatcher('5:9 6:8 6:10'));
-                expect(set.findIntervals(i('8:8'))).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
+                expect(set.findAllByIndex(0)).to.satisfy(unorderedMatcher('1:3 1:1'));
+                expect(set.findAllByIndex(1)).to.satisfy(unorderedMatcher('1:3 2:3'));
+                expect(set.findAllByIndex(2)).to.satisfy(unorderedMatcher('1:3 2:3'));
+                expect(set.findAllByIndex(3)).to.satisfy(unorderedMatcher(''));
+                expect(set.findAllByIndex(4)).to.satisfy(unorderedMatcher('5:9'));
+                expect(set.findAllByIndex(5)).to.satisfy(unorderedMatcher('5:9 6:8 6:10'));
+                expect(set.findAllByIndex(6)).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
+                expect(set.findAllByIndex(7)).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
+                expect(set.findAllByIndex(8)).to.satisfy(unorderedMatcher('5:9 7:9 6:10'));
+                expect(set.findAllByIndex(9)).to.satisfy(unorderedMatcher('6:10'));
+                expect(set.findAll(i('1:2'))).to.satisfy(unorderedMatcher('1:3 1:1 2:3'));
+                expect(set.findAll(i('2:3'))).to.satisfy(unorderedMatcher('1:3 2:3'));
+                expect(set.findAll(i('3:5'))).to.satisfy(unorderedMatcher('1:3 5:9 2:3'));
+                expect(set.findAll(i('4:6'))).to.satisfy(unorderedMatcher('5:9 6:8 6:10'));
+                expect(set.findAll(i('7:8'))).to.satisfy(unorderedMatcher('5:9 7:8 7:9 6:8 6:10'));
+                expect(set.findAll(i('7:8'), 'contain')).to.satisfy(unorderedMatcher('7:8'));
+                expect(set.findAll(i('7:8'), 'partial')).to.satisfy(unorderedMatcher('5:9 7:9 6:8 6:10'));
+                expect(set.findAll(i('7:8'), 'reference')).to.satisfy(unorderedMatcher('7:8 7:9'));
                 expect(set.values().length).to.equal(8);
             });
         });
@@ -371,16 +385,16 @@ define([
             set.insert(i('8:8'));
             set.insert(i('11:11'));
             it('should return whether intervals overlap', function () {
-                expect(set.overlaps(i('11:11'))).to.equal(true);
-                expect(set.overlaps(i('11:13'))).to.equal(true);
-                expect(set.overlaps(i('9:11'))).to.equal(true);
-                expect(set.overlaps(i('9:13'))).to.equal(true);
+                expect(set.findOne(i('11:11'))).to.not.equal(null);
+                expect(set.findOne(i('11:13'))).to.not.equal(null);
+                expect(set.findOne(i('9:11'))).to.not.equal(null);
+                expect(set.findOne(i('9:13'))).to.not.equal(null);
             });
             it('should return overlapping intervals', function () {
-                expect(set.findIntervals(i('11:11'))).to.satisfy(unorderedMatcher('11:11'));
-                expect(set.findIntervals(i('11:13'))).to.satisfy(unorderedMatcher('11:11'));
-                expect(set.findIntervals(i('9:11'))).to.satisfy(unorderedMatcher('11:11'));
-                expect(set.findIntervals(i('9:13'))).to.satisfy(unorderedMatcher('11:11'));
+                expect(set.findAll(i('11:11'))).to.satisfy(unorderedMatcher('11:11'));
+                expect(set.findAll(i('11:13'))).to.satisfy(unorderedMatcher('11:11'));
+                expect(set.findAll(i('9:11'))).to.satisfy(unorderedMatcher('11:11'));
+                expect(set.findAll(i('9:13'))).to.satisfy(unorderedMatcher('11:11'));
             });
         });
     });
