@@ -68,6 +68,10 @@ define([
             checkOperationName('CHANGE_CELLS', 'changeCells');
             checkOperationName('MOVE_CELLS', 'moveCells');
             checkOperationName('MERGE_CELLS', 'mergeCells');
+            checkOperationName('INSERT_COMMENT', 'insertComment');
+            checkOperationName('CHANGE_COMMENT', 'changeComment');
+            checkOperationName('DELETE_COMMENT', 'deleteComment');
+            checkOperationName('MOVE_COMMENTS', 'moveComments');
         });
     });
 
