@@ -35,7 +35,6 @@ define([
         var i = SheetHelper.i;
         var a = SheetHelper.a;
         var r = SheetHelper.r;
-        var ra = SheetHelper.ra;
 
         // constructor --------------------------------------------------------
 
@@ -262,27 +261,6 @@ define([
             });
         });
 
-        describe('method "fitsIn"', function () {
-            it('should exist', function () {
-                expect(Range).to.respondTo('fitsIn');
-            });
-            var sourceRange     = r('A2:B3');                   // range:  2x2
-            var suitableRanges  = ra('B4:C5 D5:G6 G16:H19');    // ranges: 2x2 + 4x2 + 2x4
-            var inaptRanges     = ra('B4:C6 E5:G6 G16:H19');    // ranges: 2x3 + 3x2 + 2x4
-            it('should return false for equal ranges', function () {
-                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
-                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
-                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
-                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
-            });
-            it('should return true for suitable ranges', function () {
-                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
-                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
-                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
-                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
-            });
-        });
-
         describe('method "compareTo"', function () {
             var r1 = r('C3:E5');
             it('should exist', function () {
@@ -427,6 +405,25 @@ define([
             });
         });
 
+        describe('method "sizeFitsInto"', function () {
+            it('should exist', function () {
+                expect(Range).to.respondTo('sizeFitsInto');
+            });
+            var r1 = r('B1:E6');
+            it('should return false for mismatching sizes', function () {
+                expect(r('A1:C1').sizeFitsInto(r1)).to.equal(false);
+                expect(r('A1:A4').sizeFitsInto(r1)).to.equal(false);
+            });
+            it('should return true for matching sizes', function () {
+                expect(r('A1:A1').sizeFitsInto(r1)).to.equal(true);
+                expect(r('A1:B1').sizeFitsInto(r1)).to.equal(true);
+                expect(r('A1:D1').sizeFitsInto(r1)).to.equal(true);
+                expect(r('A1:A2').sizeFitsInto(r1)).to.equal(true);
+                expect(r('A1:A3').sizeFitsInto(r1)).to.equal(true);
+                expect(r('A1:A6').sizeFitsInto(r1)).to.equal(true);
+            });
+        });
+
         describe('method "startsAt"', function () {
             it('should exist', function () {
                 expect(Range).to.respondTo('startsAt');
