@@ -237,15 +237,15 @@ define([
             });
         });
 
-        describe('enumeration "MoveMode"', function () {
+        describe('enumeration "Direction"', function () {
             it('should exist', function () {
-                expect(SheetUtils.MoveMode).to.be.a('function');
+                expect(SheetUtils.Direction).to.be.a('function');
             });
-            it('should contain all move modes', function () {
-                expect(SheetUtils.MoveMode).to.have.a.property('LEFT');
-                expect(SheetUtils.MoveMode).to.have.a.property('RIGHT');
-                expect(SheetUtils.MoveMode).to.have.a.property('UP');
-                expect(SheetUtils.MoveMode).to.have.a.property('DOWN');
+            it('should contain all directions', function () {
+                expect(SheetUtils.Direction).to.have.a.property('LEFT');
+                expect(SheetUtils.Direction).to.have.a.property('RIGHT');
+                expect(SheetUtils.Direction).to.have.a.property('UP');
+                expect(SheetUtils.Direction).to.have.a.property('DOWN');
             });
         });
 
@@ -261,6 +261,40 @@ define([
             });
         });
 
+        describe('enumeration "UpdateMode"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.UpdateMode).to.be.a('function');
+            });
+            it('should contain all update modes', function () {
+                expect(SheetUtils.UpdateMode).to.have.a.property('DELETE_SHEET');
+                expect(SheetUtils.UpdateMode).to.have.a.property('RENAME_SHEET');
+                expect(SheetUtils.UpdateMode).to.have.a.property('RELABEL_NAME');
+                expect(SheetUtils.UpdateMode).to.have.a.property('MOVE_CELLS');
+                expect(SheetUtils.UpdateMode).to.have.a.property('CUT_PASTE');
+            });
+        });
+
+        describe('enumeration "SortDirection"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.SortDirection).to.be.a('function');
+            });
+            it('should contain all sorting directions', function () {
+                expect(SheetUtils.SortDirection).to.have.a.property('VERTICAL');
+                expect(SheetUtils.SortDirection).to.have.a.property('HORIZONTAL');
+            });
+        });
+
+        describe('enumeration "AnchorMode"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.AnchorMode).to.be.a('function');
+            });
+            it('should contain all anchor modes', function () {
+                expect(SheetUtils.AnchorMode).to.have.a.property('ABSOLUTE');
+                expect(SheetUtils.AnchorMode).to.have.a.property('ONE_CELL');
+                expect(SheetUtils.AnchorMode).to.have.a.property('TWO_CELL');
+            });
+        });
+
         // static methods -----------------------------------------------------
 
         describe('method "getNameKey"', function () {
@@ -470,6 +504,58 @@ define([
             });
         });
 
+        describe('method "isVerticalDir"', function () {
+            var Direction = SheetUtils.Direction;
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('isVerticalDir');
+            });
+            it('should return correct flag', function () {
+                expect(SheetUtils.isVerticalDir(Direction.LEFT)).to.equal(false);
+                expect(SheetUtils.isVerticalDir(Direction.RIGHT)).to.equal(false);
+                expect(SheetUtils.isVerticalDir(Direction.UP)).to.equal(true);
+                expect(SheetUtils.isVerticalDir(Direction.DOWN)).to.equal(true);
+            });
+        });
+
+        describe('method "isLeadingDir"', function () {
+            var Direction = SheetUtils.Direction;
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('isLeadingDir');
+            });
+            it('should return correct flag', function () {
+                expect(SheetUtils.isLeadingDir(Direction.LEFT)).to.equal(true);
+                expect(SheetUtils.isLeadingDir(Direction.RIGHT)).to.equal(false);
+                expect(SheetUtils.isLeadingDir(Direction.UP)).to.equal(true);
+                expect(SheetUtils.isLeadingDir(Direction.DOWN)).to.equal(false);
+            });
+        });
+
+        describe('method "getDirection"', function () {
+            var Direction = SheetUtils.Direction;
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('getDirection');
+            });
+            it('should return correct directions', function () {
+                expect(SheetUtils.getDirection(false, false)).to.equal(Direction.RIGHT);
+                expect(SheetUtils.getDirection(false, true)).to.equal(Direction.LEFT);
+                expect(SheetUtils.getDirection(true, false)).to.equal(Direction.DOWN);
+                expect(SheetUtils.getDirection(true, true)).to.equal(Direction.UP);
+            });
+        });
+
+        describe('method "getAdjacentRange"', function () {
+            var Direction = SheetUtils.Direction;
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('getAdjacentRange');
+            });
+            it('should return correct range', function () {
+                expect(SheetUtils.getAdjacentRange(r('D4:F6'), Direction.LEFT, 2)).to.stringifyTo('B4:C6');
+                expect(SheetUtils.getAdjacentRange(r('D4:F6'), Direction.RIGHT, 2)).to.stringifyTo('G4:H6');
+                expect(SheetUtils.getAdjacentRange(r('D4:F6'), Direction.UP, 2)).to.stringifyTo('D2:F3');
+                expect(SheetUtils.getAdjacentRange(r('D4:F6'), Direction.DOWN, 2)).to.stringifyTo('D7:F8');
+            });
+        });
+
         describe('method "isOriginCell"', function () {
             var MergeMode = SheetUtils.MergeMode;
             it('should exist', function () {
