@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -51,6 +52,24 @@ define([
             });
         });
 
+        describe('method "getColRowLabel"', function () {
+            it('should exist', function () {
+                expect(Labels).itself.to.respondTo('getColRowLabel');
+            });
+            it('should return the English column label', function () {
+                expect(Labels.getColRowLabel(0, true)).to.equal('Column A');
+                expect(Labels.getColRowLabel(1, true)).to.equal('Column B');
+                expect(Labels.getColRowLabel(25, true)).to.equal('Column Z');
+                expect(Labels.getColRowLabel(26, true)).to.equal('Column AA');
+            });
+            it('should return the English row label', function () {
+                expect(Labels.getColRowLabel(0, false)).to.equal('Row 1');
+                expect(Labels.getColRowLabel(1, false)).to.equal('Row 2');
+                expect(Labels.getColRowLabel(8, false)).to.equal('Row 9');
+                expect(Labels.getColRowLabel(9, false)).to.equal('Row 10');
+            });
+        });
+
         describe('method "getCategoryLabel"', function () {
             it('should exist', function () {
                 expect(Labels).itself.to.respondTo('getCategoryLabel');
