@@ -25,6 +25,18 @@ define([
         it('should exist', function () {
             expect(RenderUtils).to.be.an('object');
         });
+
+        describe('constant "CANVAS_RESOLUTION"', function () {
+            it('should exist', function () {
+                expect(RenderUtils).to.have.a.property('CANVAS_RESOLUTION').that.is.a('number').and.is.at.least(1);
+            });
+        });
+
+        describe('constant "GRID_LINE_WIDTH"', function () {
+            it('should exist', function () {
+                expect(RenderUtils).to.have.a.property('GRID_LINE_WIDTH').that.is.a('number').and.is.at.most(1);
+            });
+        });
     });
 
     // ========================================================================
