@@ -14,8 +14,9 @@
 
 define([
     'globals/apphelper',
+    'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position'
-], function (AppHelper, Position) {
+], function (AppHelper, DOM, Position) {
 
     'use strict';
 
@@ -38,7 +39,8 @@ define([
             span5 = $('<span>').text(' World'),
             span6 = $('<span>').text('Test'),
             listLabel1 = $('<div>').addClass('helper list-label').append($('<span>').text('123.)')),
-            hardBreak = $('<div>').addClass('inline hardbreak');
+            hardBreak = $('<div>').addClass('inline hardbreak'),
+            para2Text = 'Hello Earth';
 
         paraNode1.append(span1);
         paraNode1.append(span2);
@@ -59,7 +61,9 @@ define([
             { name: 'insertRange', start: [0, 5], id: 'cmt0', type: 'comment', position: 'end' },
             { name: 'insertComment', start: [0, 6], author: 'a b', date: '2015-11-28T22:10:00Z', /*uid: 111, */ id: 'cmt0' },
             { name: 'insertParagraph', start: [0], target: 'cmt0' },
-            { name: 'insertText', start: [0, 0], target: 'cmt0', text: 'I am inside the comment' }
+            { name: 'insertText', start: [0, 0], target: 'cmt0', text: 'I am inside the comment' },
+            { name: 'insertParagraph', start: [1] },
+            { name: 'insertText', start: [1, 0], text: para2Text }
         ];
 
         var model, rootNode;
@@ -250,6 +254,65 @@ define([
             });
         });
 
+        // testing word boundaries on second paragraph
+        describe('method "getWordBoundaries"', function () {
+            it('should exist', function () {
+                expect(Position).itself.to.respondTo('getWordBoundaries');
+            });
+            it('should return true for a range of positions', function () { // AAA
+                var paraLength = para2Text.length; // para2Text is 'Hello Earth'
+                var secondPara = Position.getParagraphElement(rootNode, [1]);
+                expect(DOM.isParagraphNode(secondPara)).to.equal(true);
+                expect(Position.getParagraphLength(rootNode, [1])).to.equal(paraLength); // counting length (value is 11)
+
+                var lastLogicalPos = [1, paraLength]; // the logical position behind the word 'Earth'
+                // searching the last word
+                var wordBoundaries = Position.getWordBoundaries(rootNode, lastLogicalPos);
+                expect(wordBoundaries).to.be.an('array');
+                expect(wordBoundaries.length).to.equal(2);
+
+                // comparing the logical border positions of the word earth: [1,6] and [1,11].
+                // -> the end position is the position behind the word.
+                expect(wordBoundaries[0][0]).to.equal(1);
+                expect(wordBoundaries[0][1]).to.equal(6);
+                expect(wordBoundaries[1][0]).to.equal(1);
+                expect(wordBoundaries[1][1]).to.equal(11);
+
+                // comparing value with function 'Position.getWordSelection'
+                expect(Position.getWordSelection(secondPara, paraLength)).to.deep.equal({ start: 6, end: 11, text: 'Earth', node: null, nodes: null });
+            });
+        });
+
+        // testing valid selections on second paragraph (checking the word 'Earth' at the end of the paragraph)
+        // -> valid element ranges can be used for setAttributes operation, where the final position inside a
+        //    a paragraph behind the last character is invalid.
+        describe('method "isValidElementRange"', function () {
+            it('should exist', function () {
+                expect(Position).itself.to.respondTo('isValidElementRange');
+            });
+            it('should exist', function () {
+                expect(Position).itself.to.respondTo('isValidElementPosition'); // used by function 'isValidElementRange'
+            });
+            it('should return true for a range of positions', function () {
+                var paraPos = 1;
+                var secondPara = Position.getParagraphElement(rootNode, [paraPos]);
+                var paraLength = para2Text.length; // para2Text is 'Hello Earth'
+                var lastWordStartPos = 6; // the start position of the last word inside the paragraph
+
+                expect(Position.getParagraphLength(rootNode, [paraPos])).to.equal(paraLength); // counting length
+                // checking that paragraph ends with 'Earth'
+                expect(Position.getWordSelection(secondPara, paraLength)).to.deep.equal({ start: lastWordStartPos, end: paraLength, text: 'Earth', node: null, nodes: null });
+
+                // checking isValidElementRange -> this is not valid behind the last character in the paragraph!
+                // checking missing end position (start and end position are equal)
+                expect(Position.isValidElementRange(rootNode, [paraPos, (paraLength - 1)])).to.equal(true); // position of last character
+                expect(Position.isValidElementRange(rootNode, [paraPos, paraLength])).to.equal(false); // position behind last character
+                // checking with range from logical start to end position
+                expect(Position.isValidElementRange(rootNode, [paraPos, lastWordStartPos], [paraPos, (paraLength - 1)])).to.equal(true); // position of last character
+                expect(Position.isValidElementRange(rootNode, [paraPos, lastWordStartPos], [paraPos, paraLength])).to.equal(false); // position behind last character
+            });
+        });
+
     });
 
     // ========================================================================
