@@ -20,7 +20,7 @@ define([
 
     // class SortedArray ======================================================
 
-    describe('Spreadsheet class SortedArray', function () {
+    describe('Toolkit class SortedArray', function () {
 
         it('should exist', function () {
             expect(SortedArray).to.be.a('function');
@@ -28,12 +28,12 @@ define([
 
         // private helpers ----------------------------------------------------
 
-        var StringArray = SortedArray.extend({
-            constructor: function () { SortedArray.call(this, function (value) { return parseInt(value, 10); }); }
+        var StringArray = SortedArray.extend(function () {
+            SortedArray.call(this, function (value) { return parseInt(value, 10); });
         });
 
-        var ObjectArray = SortedArray.extend({
-            constructor: function () { SortedArray.call(this, function (object) { return object.prop; }); }
+        var ObjectArray = SortedArray.extend(function () {
+            SortedArray.call(this, function (object) { return object.prop; });
         });
 
         // public methods -----------------------------------------------------
