@@ -13,8 +13,9 @@
  */
 
 define([
+    'io.ox/office/tk/container/extarray',
     'io.ox/office/tk/container/typedarray'
-], function (TypedArray) {
+], function (ExtArray, TypedArray) {
 
     'use strict';
 
@@ -32,14 +33,13 @@ define([
             it('should exist', function () {
                 expect(TypedArray).itself.to.respondTo('create');
             });
-            it('should create a subclass of array', function () {
-                var ArrayClass = TypedArray.create(Object);
-                expect(ArrayClass).to.be.a('function');
-                expect(ArrayClass).to.have.property('prototype');
-                expect(ArrayClass.prototype).to.have.property('constructor', ArrayClass);
-                expect(ArrayClass).to.have.property('ElementType', Object);
-                expect(ArrayClass).to.have.property('ArrayType', ArrayClass);
-                expect(ArrayClass).to.have.property('__super__', Array.prototype);
+            it('should create a subclass of ExtArray', function () {
+                var ObjectArray = TypedArray.create(Object);
+                expect(ObjectArray).to.be.a('function');
+                expect(ObjectArray).to.have.property('prototype');
+                expect(ObjectArray.prototype).to.be.an.instanceof(ExtArray);
+                expect(ObjectArray.prototype).to.have.property('constructor', ObjectArray);
+                expect(ObjectArray).to.have.property('ElementType', Object);
             });
         });
     });
@@ -57,14 +57,14 @@ define([
         Element.prototype.add = function (m) { return new Element(this.n + m); };
         Element.prototype.cloneOdd = function () { return (this.n % 2 > 0) ? this.clone() : null; };
         Element.prototype.toString = function () { return 'e' + this.n; };
-        Element.prototype.toJSON = function () { return { n: this.n }; };
+        Element.prototype.toJSON = function () { return { e: this.n }; };
 
         var ArrayClass = TypedArray.create(Element);
 
-        var e1 = new Element(1),
-            e2 = new Element(2),
-            e3 = new Element(3),
-            a0 = new ArrayClass();
+        var e1 = new Element(1);
+        var e2 = new Element(2);
+        var e3 = new Element(3);
+        var a0 = new ArrayClass();
 
         // constructor --------------------------------------------------------
 
@@ -1251,6 +1251,31 @@ define([
             });
         });
 
+        describe('method "invoke"', function () {
+            it('should exist', function () {
+                expect(ArrayClass).to.respondTo('invoke');
+            });
+            it('should build an array from a typed array', function () {
+                var a1 = new ArrayClass(e1, e2, e3),
+                    a2 = a1.invoke('clone');
+                expect(a2).to.be.an.instanceof(Array);
+                expect(a2).to.have.length(3);
+                expect(a2).to.not.equal(a1);
+                expect(a2[0]).to.not.equal(a1[0]);
+                expect(a2[0]).to.deep.equal(a1[0]);
+                var a3 = a1.invoke('add', 1);
+                expect(a3).to.have.length(3);
+                expect(a3[0]).to.have.property('n', 2);
+                expect(a3[1]).to.have.property('n', 3);
+                expect(a3[2]).to.have.property('n', 4);
+            });
+            it('should accept empty arrays', function () {
+                var a1 = a0.invoke('clone');
+                expect(a1).to.be.an.instanceof(Array);
+                expect(a1).to.be.empty;
+            });
+        });
+
         describe('method "group"', function () {
             it('should exist', function () {
                 expect(ArrayClass).to.respondTo('group');
@@ -1299,16 +1324,16 @@ define([
                 sinon.assert.calledWithExactly(stub.getCall(0), e1, 0, a1);
                 sinon.assert.calledWithExactly(stub.getCall(1), e2, 1, a1);
             });
-            it('should return null if no element matches', function () {
+            it('should return undefined if no element matches', function () {
                 var a1 = new ArrayClass(e1, e2, e3, e2, e1),
                     stub = sinon.stub().returns(false);
-                expect(a1.find(stub, a0)).to.equal(null);
+                expect(a1.find(stub, a0)).to.equal(undefined);
                 sinon.assert.callCount(stub, 5);
                 sinon.assert.alwaysCalledOn(stub, a0);
             });
             it('should accept empty arrays', function () {
                 var spy = sinon.spy();
-                expect(a0.find(spy, a0)).to.equal(null);
+                expect(a0.find(spy, a0)).to.equal(undefined);
                 sinon.assert.callCount(spy, 0);
             });
         });
@@ -1419,10 +1444,10 @@ define([
             });
             var a1 = new ArrayClass(e1, e2, e3);
             it('should convert to JSON data', function () {
-                expect(a1.toJSON()).to.deep.equal([{ n: 1 }, { n: 2 }, { n: 3 }]);
+                expect(a1.toJSON()).to.deep.equal([{ e: 1 }, { e: 2 }, { e: 3 }]);
             });
             it('should stringify to JSON', function () {
-                expect(JSON.stringify(a1)).to.equal('[{"n":1},{"n":2},{"n":3}]');
+                expect(JSON.stringify(a1)).to.equal('[{"e":1},{"e":2},{"e":3}]');
             });
         });
     });
