@@ -412,16 +412,26 @@ define([
             // TODO: more
         });
 
+        describe('method "getStandardCode"', function () {
+            it('should exist', function () {
+                expect(Parser).itself.to.respondTo('getStandardCode');
+            });
+            it('should return the standard format codes', function () {
+                expect(Parser.getStandardCode('op')).to.equal('General');
+                expect(Parser.getStandardCode('ui')).to.equal('Standard');
+            });
+        });
+
         describe('method "parseFormatCode"', function () {
             it('should exist', function () {
                 expect(Parser).itself.to.respondTo('parseFormatCode');
             });
             it('should cache the parsed format codes', function () {
-                var parsedFormat = Parser.parseFormatCode('ooxml', 'op', 'General');
-                expect(Parser.parseFormatCode('ooxml', 'op', 'General')).to.equal(parsedFormat);
-                expect(Parser.parseFormatCode('ooxml', 'ui', 'General')).to.not.equal(parsedFormat);
-                expect(Parser.parseFormatCode('odf', 'op', 'General')).to.not.equal(parsedFormat);
-                expect(Parser.parseFormatCode('odf', 'ui', 'General')).to.not.equal(parsedFormat);
+                var parsedFormat = Parser.parseFormatCode('ooxml', 'op', '0');
+                expect(Parser.parseFormatCode('ooxml', 'op', '0')).to.equal(parsedFormat);
+                expect(Parser.parseFormatCode('ooxml', 'ui', '0')).to.not.equal(parsedFormat);
+                expect(Parser.parseFormatCode('odf', 'op', '0')).to.not.equal(parsedFormat);
+                expect(Parser.parseFormatCode('odf', 'ui', '0')).to.not.equal(parsedFormat);
             });
             it('should recognize "standard" category', function () {
                 expect(Parser.parseFormatCode('ooxml', 'op', 'General')).to.have.a.property('category', 'standard');
@@ -523,7 +533,7 @@ define([
 
     // class ParsedFormat =====================================================
 
-    describe('Toolkit class ParsedParser', function () {
+    describe('Toolkit class ParsedFormat', function () {
 
         var stdFormat, percentFormat1, percentFormat2, dateFormat, timeFormat, dateTimeFormat;
 
