@@ -4,5 +4,7 @@ define('io.ox/core/folder/api', {
     },
     pool: { models: {} },
     path: _.constant($.when([])),
-    can: _.constant($.when(false))
+    can: _.constant($.when(false)),
+    get: _.constant($.when({})),
+    isExternalFileStorage: _.constant(false)
 });
