@@ -5,13 +5,10 @@ define('io.ox/core/gettext', function () {
     function gt() {
         var gt = function (text) {
             var args = arguments;
-            return text.replace(/%(\d+)\$[ds]/g, function (match, index) {
-                return args[index];
-            });
+            return text.replace(/%(\d+)\$[ds]/g, function (match, index) { return args[index]; });
         };
-        gt.pgettext = function (ctxt, text) { return gt(text); };
-        gt.npgettext = function (ctxt, ctxt2, text) { return gt(text); };
-        gt.format = function (text, opt) { return gt(text); };
+        gt.pgettext = function () { return gt.apply(null, _.toArray(arguments).slice(1)); };
+        gt.npgettext = function () { return gt.apply(null, _.toArray(arguments).slice(2)); };
         return gt;
     }
 
